<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    pixelform
 * @subpackage pixelform/admin
 * @author     Kamleshyadav <#>
 */
class pixelform_admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		add_action( 'wp_ajax_pixelform_form_create_new_form', array($this,'pixelform_form_create_new_form') );
		add_action( 'wp_ajax_pixelform_form_update_form_data', array($this,'pixelform_form_update_form_data') );
		add_action( 'wp_ajax_pixelform_form_create_form', array($this,'pixelform_form_create_form') );
		add_action( 'wp_ajax_pixelform_form_get_form_data', array($this,'pixelform_form_get_form_data') );
		add_action( 'wp_ajax_pixelform_form_remove_form', array($this,'pixelform_form_remove_form') );
		add_action( 'wp_ajax_pixelform_form_tabs_data_save', array($this,'pixelform_form_tabs_data_save') );
		add_action( 'wp_ajax_pixelform_form_additional_tab_data_save', array($this,'pixelform_form_additional_tab_data_save') );
		add_action( 'wp_ajax_pixelform_form_export_form_data', array($this,'pixelform_form_export_form_data') );
		add_action( 'wp_ajax_pixelform_form_export_single_form_data', array($this,'pixelform_form_export_single_form_data') );
		add_action( 'wp_ajax_pixelform_form_import_form_data', array($this,'pixelform_form_import_form_data') );
		add_action( 'wp_ajax_pixelform_form_remove_form_data', array($this,'pixelform_form_remove_form_data') );
		add_action( 'wp_ajax_pixelform_form_all_form_database', array($this,'pixelform_form_all_form_database') );
		add_action( 'wp_ajax_pixelform_form_duplicate_form', array($this,'pixelform_form_duplicate_form') );
		
		add_action( 'wp_ajax_pixelform_form_autoresponder_connect', array($this,'pixelform_form_autoresponder_connect') );
		
		add_action( 'wp_ajax_pixelform_form_autoresponder_subscribe', array($this,'pixelform_form_autoresponder_subscribe') );
		add_action( 'wp_ajax_nopriv_pixelform_form_autoresponder_subscribe', array($this,'pixelform_form_autoresponder_subscribe') );
		
		add_action( 'wp_ajax_pixelform_form_autoresponder_get_list', array($this,'pixelform_form_autoresponder_get_list') );
		add_action( 'wp_ajax_pixelform_form_autoresponder_get_autoresponderes', array($this,'pixelform_form_autoresponder_get_autoresponderes') );
				
		add_shortcode( 'pixelform_form', array($this,'pixelform_form_render_form') );
		add_action( 'after_setup_theme', array($this, 'pixelform_form_fb_internal_css') );
		add_action( 'wp_footer', array($this, 'pixelform_form_load_footer_scripts') );
		// Pixel Template Setting 
		add_action( 'wp_ajax_pixelform_template_load_more', array($this,'pixelform_template_load_more'));
	    add_action( 'wp_ajax_pixelform_import_template', array($this,'pixelform_import_template'));
        add_action( 'wp_ajax_pixelform_creat_new_template', array($this,'pixelform_creat_new_template'));
		
        require_once plugin_dir_path(__FILE__) . 'pixelform-shortcode.php';
	}
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in pixelform_formbuilder_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The pixelform_formbuilder_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		 if( isset($_GET['page']) && ($_GET['page'] == 'pixelform_form-forms' || $_GET['page'] == 'pixelform_form-autoresponder' || $_GET['page'] == 'pixelform_form-form-data' || $_GET['page']=='form-builder' || $_GET['page']=='pixelform_template')){
			
		  wp_enqueue_style( 'bootstrap.min', PIXELFORM_URL . 'admin/css/bootstrap.min.css', array(), $this->version, 'all' );
		  wp_enqueue_style( 'font-awesome', PIXELFORM_URL . 'admin/css/font-awesome.css', array(), $this->version, 'all' );
		  wp_enqueue_style( $this->plugin_name, PIXELFORM_URL . 'admin/css/pixelform-admin.css', array(), $this->version, 'all' );
		  wp_enqueue_style( 'wp-color-picker' );
		  wp_enqueue_style( $this->plugin_name, PIXELFORM_URL . 'admin/css/pixelform-admin.css', array(), $this->version, 'all' );
		  wp_enqueue_style('pixelform-public', PIXELFORM_URL . 'public/css/pixelform-public.css', array(), $this->version, 'all' );
		} 
			if( isset($_GET['page']) && $_GET['page'] == 'pixelform_form-form-data'){
				wp_enqueue_style( 'datatables.min', PIXELFORM_URL . 'admin/css/datatables.min.css', array(), $this->version, 'all' );
			}
			
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in pixelform_formbuilder_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The pixelform_formbuilder_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script('pixelform_form_bootstrap_js', PIXELFORM_URL . 'admin/js/bootstrap.min.js', array( 'jquery' ), $this->version, true);
		if(isset($_GET['page'])){
			if( isset($_GET['page']) && $_GET['page'] == 'pixelform_form-form-data'){
				wp_enqueue_script( 'pixelform_form_datatable_js', PIXELFORM_URL . 'admin/js/datatables.min.js', array( 'jquery' ), $this->version, true );
			}
			
			if( isset($_GET['page']) && ($_GET['page'] == 'pixelform_form-forms' || $_GET['page'] == 'pixelform_form-form-data') || $_GET['page']=='form-builder'  || $_GET['page']=='pixelform_template'){
				wp_enqueue_script('jquery-ui-draggable');
				wp_enqueue_script('jquery-ui-droppable');
				wp_enqueue_script('jquery-ui-sortable');
				wp_enqueue_script('pixelform-admin', PIXELFORM_URL . 'admin/js/pixelform-admin.js', array( 'jquery','wp-color-picker' ), $this->version, true );
			    wp_localize_script('pixelform-admin', 'pixelform_form',array(
					'ajaxurl' => admin_url( 'admin-ajax.php' )
				  ) );
				
			}
			
			/** Autoresponder Js **/
			if(isset($_GET['page']) && $_GET['page'] == 'pixelform_form-autoresponder'){
				wp_enqueue_script( 'pixelform-autoresponder-admin', plugin_dir_url( __FILE__ ) . 'js/pixelform-autoresponder-admin.js', array( 'jquery' ), $this->version, false );
		        $translation_array = array(
					'ajaxurl' => admin_url( 'admin-ajax.php' )
				);
				wp_localize_script( 'pixelform-autoresponder-admin', 'pixelform_form', $translation_array );
			}

	   }
		
	}
	
	public function pixelform_form_render_form( $atts ) {
		$a = shortcode_atts( array(
			'id' => 'something',
		), $atts );
		
		global $wpdb;
		$table_name = $wpdb->prefix . 'pixelform_form_forms';
		$id = $a['id'];
		$results = $wpdb->get_results ( "SELECT * FROM $table_name WHERE ID = $id" );
		$data = json_decode(base64_decode($results[0]->Data));
		
		return $this->pixelform_form_fields_setup($data,$id);
	}
	
	public function pixelform_form_fields_setup($data,$id){
		 global $wpdb;
		 $table_name = $wpdb->prefix . 'pixelform_form_forms';
		 $row = $wpdb->get_results ( "SELECT * FROM  $table_name WHERE ID = $id" );
		 
		 $messages = json_decode($row[0]->Messages);
		 $validation = !empty($messages[2]) ? $messages[2] : esc_html__('One or more fields have an error. Please check and try again.','Pixelform');
		 $required = !empty($messages[3]) ? $messages[3] : esc_html__('The field is required.','Pixelform');
		 $email_validation = !empty($messages[4]) ? $messages[4] : esc_html__('Invalid email adress.','Pixelform');

		 $button_class = ($row[0]->Render_As == 'autoresponder') ? 'pixelform_form_newsletter_submit' : ($row[0]->Render_As == 'both' ? 'pixelform_form_submit_both' : 'pixelform_form_submit' );
		 $render  = '';
		 $render .= '<div class="pixelform_form_render ld_square">';
		 $render .= '<div class="pixelform_form_messages" style="display:none;">
						<input type="hidden" value="'.esc_html($validation).'">
						<input type="hidden" value="'.esc_html($required).'">
						<input type="hidden" value="'.esc_html($email_validation).'">
					</div>';
		 if( !empty($row) && ($row[0]->Render_As == 'autoresponder' || $row[0]->Render_As == 'both') ){
			$resp_name = json_decode($row[0]->Responder);
			$render .= '<input type="hidden" class="responder_data" data-responder="'.esc_attr($resp_name->responder).'" data-responder_listid="'.esc_attr($resp_name->list_id).'" data-responder_listname="'.esc_attr($resp_name->list_name).'" data-name_field="'.esc_attr($resp_name->name_field).'" data-email_field="'.esc_attr($resp_name->email_field).'">';
		 }
		 
		 foreach( $data as $fields ){
		 $col = $fields->column_data->columns;
			$render .= '<div class="col-xs-12 col-md-'.esc_attr($col).' col-lg-'.esc_attr($col).'">';
				foreach( $fields as $k => $v ){
					$fieldType = explode('_',$k)[0];
					if( $fieldType != 'column' ){
						switch( $fieldType ){
							case 'text':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$render .= '<div class="form-group" data-fieldType="text"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label><input type="text" class="form-control'.esc_attr($required).'" placeholder="'.esc_attr($v->placeholder).'" name="'.esc_attr($v->name).'"></div>';
							break;
							
							case 'email':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$render .= '<div class="form-group" data-fieldType="email"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label><input type="text" class="form-control'.esc_attr($required).'" placeholder="'.esc_attr($v->placeholder).'" name="'.esc_attr($v->name).'"></div>';
							break;
							
							case 'textarea':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$render .= '<div class="form-group" data-fieldType="textarea"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label><textarea class="form-control'.esc_attr($required).'" placeholder="'.esc_attr($v->placeholder).'" name="'.esc_attr($v->name).'"></textarea></div>';
							break;
							
							case 'checkboxgroup':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$inline = ($v->inline == 1) ? ' checkbox-inline' : '';
								$render .= '<div class="checkbox form-group" data-fieldType="checkboxgroup"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label>';
								foreach( $v->checkboxoptions as $options ){
									$render .= '<label class="'.esc_attr($inline).'"><input type="checkbox" name="'.esc_attr($v->name).'[]" value="'.esc_attr($options->value).'">'.esc_html($options->label).'</label>';
								}
								$render .= '</div>';
							break;
							
							case 'select':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$multiple = ($v->multiple == 1) ? 'multiple' : '';
								$render .= '<div class="form-group" data-fieldType="select">
											<label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label>
											<select class="form-control" '.esc_attr($multiple).'>';
											foreach( $v->selectoptions as $options ){
												$render .= '<option value="'.esc_attr($options->value).'">'.esc_html($options->label).'</option>';
											}
								$render .= '</select></div>';
							break;
							
							case 'radiogroup':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$inline = ($v->inline == 1) ? ' radio-inline' : '';
								$render .= '<div class="radio form-group" data-fieldType="radiogroup"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label>';
								foreach( $v->radiooptions as $options ){
									$render .= '<label class="'.esc_attr($inline).'"><input type="radio" name="'.esc_attr($v->name).'" value="'.esc_attr($options->value).'">'.esc_html($options->label).'</label>';
								}
								$render .= '</div>';
							break;
							
							case 'number':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$render .= '<div class="form-group" data-fieldType="number"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label><input type="number" class="form-control'.esc_attr($required).'" placeholder="'.esc_attr($v->placeholder).'" name="'.esc_attr($v->name).'"></div>';
							break;
														
							case 'date':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$render .= '<div class="form-group" data-fieldType="date"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label><input type="date" class="form-control'.esc_attr($required).'" placeholder="'.esc_attr($v->placeholder).'" name="'.esc_attr($v->name).'"></div>';
							break;
							
							case 'fileupload':
								$required = ($v->required == 1) ? ' pixelform_form_req_field' : '';
								$multiple = ($v->multifiles == 1) ? 'multiple' : '';
								$render .= '<div class="form-group" data-fieldType="fileupload"><label for="'.esc_attr($v->label).'" class="pixelform_form_label">'.esc_html($v->label).'</label><input type="file" class="form-control'.esc_attr($required).'" name="'.esc_attr($v->name).'" '.esc_attr($multiple).'></div>';
							break;
							
							case 'button':
								$required = (isset($v->required) && $v->required == 1) ? ' pixelform_form_req_field' : '';
								$render .= '<div class="form-group" data-fieldType="button"><button type="button" class="pixelform_form_btn '.esc_attr($button_class).'" name="'.esc_attr($v->name).'" data-form_id="'.$id.'">'.esc_html($v->label).'</button><div class="pixelform_form_loader_img"><div></div><div></div></div></div>';
							break;
						}
					}
				}
				$render .= '</div>';
			}
			$render .= '<div class="pixelform_form_msg" style="display:none"><p></p></div>';
			$render .= '</div>';
			return $render;
	}

		
	/****** Create Form Using Ajax ******/
	
	public function pixelform_form_create_new_form(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_create_new_form'){
			$form_name = sanitize_text_field($_POST['form_name']);
			global $wpdb;
			$charset_collate = $wpdb->get_charset_collate();
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			 $getRow = $wpdb->get_row("SELECT * FROM  $table_name WHERE Name = '$form_name'"); //Get Existed Form name

			 if( empty($getRow) ){
				 $sql = "INSERT INTO $table_name (Name, Date_Created) VALUES ('$form_name', CURRENT_TIMESTAMP)";
				 $result = $wpdb->query($sql);
				 if( $result == 1 ){
					echo $lastid = $wpdb->insert_id; 
				 }else{
					 echo 0;
				 }
			 }else{
				 echo -1;
			 }
			wp_die();
		}
	}
	
	/****** Update Form Data Using Ajax ******/
	public function pixelform_form_update_form_data(){
 		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_update_form_data'){
 			$form_name = sanitize_text_field($_POST['form_name']);
 			$data = base64_encode(stripslashes($_POST['formData']));
			$render_as = $_POST['render_as'];
 			if( $render_as != 'contact_form' ){
				$autoresponder['responder'] = $_POST['autoresponder'];
 				$autoresponder['listType'] = $_POST['listType']; //Only for sendiio
 				$autoresponder['list_name'] = $_POST['list_name'];
				$autoresponder['list_id'] = $_POST['list_id'];
 				$autoresponder['name_field'] = $_POST['name_field'];
 				$autoresponder['email_field'] = $_POST['email_field'];
 				$auto = json_encode($autoresponder);
 			}else{ $auto = ''; }
			
 			global $wpdb;
 			$charset_collate = $wpdb->get_charset_collate();
 			$table_name = $wpdb->prefix . 'pixelform_form_forms';
 			//Update Form
			
 			echo $wpdb->update( $table_name, array( 'Name' => $form_name, 'Data' => $data, 'Render_As' => $render_as, 'Responder' => $auto ), array('ID' => $_POST['form_id']) );

 			 wp_die();
		}
	}
	
	/****** Get FormData Ajax ******/
	public function pixelform_form_get_form_data(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'pixelform_form_forms';
		$id = $_POST['form_id'];
		$results = $wpdb->get_results ( "SELECT * FROM $table_name WHERE ID = $id" );
		foreach( $results as $row ){
			echo base64_decode($row->Data);
		}
		wp_die();
	}
	
	/****** Copy Form Ajax ******/
	public function pixelform_form_duplicate_form(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_duplicate_form'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			$id = $_POST['form_id'];
			
			$results = $wpdb->get_results ( "SELECT * FROM $table_name WHERE ID = $id" );
			
			foreach($results as $data){
				$form['Name'] = $data->Name.'-copy';
				$form['Data'] = $data->Data;
				$form['Mail'] = $data->Mail;
				$form['Messages'] = $data->Messages;
				$form['Render_As'] = $data->Render_As;
				$form['Responder'] = $data->Responder;
				$form['Additional_Settings'] = $data->Additional_Settings;
				$form['Date_Created'] = date("Y-m-d");
				echo $wpdb->insert( $table_name, $form );
			}
			
			wp_die();
		}
	}
	
	/****** Remove Form Ajax ******/
	public function pixelform_form_remove_form(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_remove_form'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			$id = $_POST['form_id'];
			echo $wpdb->delete( $table_name, array( 'ID' => $id ), $where_format = null );			
			wp_die();
		}
	}
	
	/****** Remove Form Data From pixelform_form_database Table. ******/
	public function pixelform_form_remove_form_data(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_remove_form_data'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_database';
			$id = $_POST['rowID'];
			echo $wpdb->delete( $table_name, array( 'ID' => $id ) );			
			wp_die();
		}
	}
	
	/****** Remove All(Selected) Form Data From pixelform_form_database Table. ******/
	public function pixelform_form_all_form_database(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_all_form_database'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_database';
			$ids = explode(',',$_POST['rowIDs']);
			foreach( $ids as $id ){
				$res = $wpdb->delete( $table_name, array( 'ID' => $id ) );
			}
			if($res == 1){
				echo "success";
			}
			wp_die();
		}
	}
	
	/****** Mail And Messages Tab Save Data Ajax ******/
	public function pixelform_form_tabs_data_save(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_tabs_data_save'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			if( $_POST['button_id'] == 'mail_tab_update' ){
				echo $wpdb->update( $table_name, array( 'Mail' => json_encode($_POST['tab_data']) ), array('ID' => $_POST['form_id']) );
			}else{
				echo $wpdb->update( $table_name, array( 'Messages' => json_encode($_POST['tab_data']) ), array('ID' => $_POST['form_id']) );
			}
			wp_die();
		}
	}
	
	/****** Additional Tab Save Data Ajax ******/
	public function pixelform_form_additional_tab_data_save(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_additional_tab_data_save'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			echo $wpdb->update( $table_name, array( 'Additional_Settings' => json_encode($_POST['tab_data']) ), array('ID' => $_POST['form_id']) );
			wp_die();
		}
	}
	
	public function pixelform_form_autoresponder_connect(){
		if(empty($_POST['responder'])){
			echo json_encode(array( 'error' => 'Error occur may be something wrong.'));
			return;
		}
		if($_POST['responder'] != 'CustomHtml'){
			$data = get_option('pixelform_form_autoresponder_settings');
			$data[$_POST['responder']] = $_POST['apikey'];
			
			if(isset($_POST['eraser']) && $_POST['eraser'] == 1){
				update_option('pixelform_form_autoresponder_settings', $data);	
				echo json_encode( array( 'status'=> 1, 'msg'=> esc_html__('Autoresponder disconnect successfully.','Pixelform') ) );
				die();
			}
			
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/autoresponder/subscriber.php';
			$subscriber = new pixelform_form_subscriber();
			$list = $subscriber->pixelform_form_switch_responder($_POST['apikey'], 'getList', $_POST['responder'], '');
			
			if(!isset($list['error'])){
				if($_POST['responder'] == 'Aweber'){
					$data[$_POST['responder']] = $list['data'];
				}
				update_option('pixelform_form_autoresponder_settings', $data);	
				echo json_encode( array( 'status'=> 1, 'msg'=> esc_html__('Settings are saved.','Pixelform') ) );
			}else{
				echo json_encode( array( 'status'=> 0, 'msg'=> esc_html__('An error occurred while getting your list.','Pixelform') ) );
			} 
		}else{
			$data = get_option('pixelform_form_custom_html_settings');
			if(isset($_POST['form_id']) && isset($_POST['add']) && $_POST['add']){
				$data[$_POST['form_id']] = array(
					'form_name' => $_POST['form_name'],
					'customhtml' => $_POST['customhtml']
				);
				update_option('pixelform_form_custom_html_settings', $data);		
				echo json_encode(array( 'status' => 1, 'msg'=>esc_html__('Custom HTML saved successfully!','Pixelform') ));
			}
			if(isset($_POST['form_id']) && isset($_POST['remove']) && $_POST['remove']){
				unset( $data[$_POST['form_id']] );
				update_option('pixelform_form_custom_html_settings', $data);
				echo json_encode(array( 'status' => 1, 'msg'=> esc_html__('Custom HTML removed successfully!','Pixelform') ));
			}
		}	
		die();
	}
	
	public function pixelform_form_autoresponder_subscribe(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_autoresponder_subscribe'){
			if(empty($_POST['responder'])){
				echo json_encode(array( 'error' => esc_html__('Error occur may be something wrong.','Pixelform')));
				die();
			}
			$data = get_option('pixelform_form_autoresponder_settings');
			if(empty($data[$_POST['responder']])){
				echo json_encode(array('error'=>esc_html__('Error occur may be something wrong.','Pixelform')));
				die();
			}
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/autoresponder/subscriber.php';
			$api = $data[$_POST['responder']];
			$subscriber = new pixelform_form_subscriber();
			$list = $subscriber->pixelform_form_switch_responder($api, 'subsCribe', $_POST['responder']);
			echo json_encode($list);
			die();
		}
		die();
	}
	
	public function pixelform_form_autoresponder_get_list(){
		
		if(empty($_POST['responder'])){
			echo json_encode(array( 'error' => esc_html__('Error occur may be something wrong.','Pixelform')));
			return;
		}
		if($_POST['responder'] != 'CustomHtml'){
			$data = get_option('pixelform_form_autoresponder_settings');

			 require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/autoresponder/subscriber.php';
			
			 $api = $data[$_POST['responder']];
			
			if($_POST['responder'] == 'Sendiio'){
				$api['list_type'] = $_POST['listType'];
			}
			
			$subscriber = new pixelform_form_subscriber();
			
			$list = $subscriber->pixelform_form_switch_responder($api, 'getList', $_POST['responder'], '');
			echo json_encode($list);
			
		}else{
			$CustomHtml = get_option('pixelform_form_custom_html_settings');
			$r = array();
			if(!empty($CustomHtml)){
				foreach($CustomHtml as $k=>$v){
					$r[$k] = $v['form_name'];
				}
			}
			$list['list'] = $r;
			echo json_encode($list);
		}
		
		wp_die();
	}
	
	public function pixelform_form_autoresponder_get_autoresponderes(){
		$data = get_option('pixelform_form_autoresponder_settings');
		echo implode(',',array_keys(array_filter($data)));
		wp_die();
	}
	
	/****** Export Form Data Ajax ******/
	public function pixelform_form_export_form_data(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_export_form_data'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			$results = $wpdb->get_results ( "SELECT * FROM $table_name" );
					
			 $fp = fopen(plugin_dir_path( __FILE__ ) . 'pixelform-form-backup.json', 'w');
			 fwrite($fp, json_encode($results));
			 fclose($fp);
			 
			 if(!empty($fp)){
				 echo plugin_dir_url(__FILE__) . 'pixelform-download-form-data.php';
			 }else{
				 echo '';
			 }
			
			wp_die();
		}
	}
	
	/****** Export A Perticular Form Data Ajax ******/
	public function pixelform_form_export_single_form_data(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_export_single_form_data'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			$id = $_POST['rowID'];
			$results = $wpdb->get_results ( "SELECT * FROM $table_name WHERE ID = $id" );
					
			 $fp = fopen(plugin_dir_path( __FILE__ ) . 'pixelform_form_backup.json', 'w');
			 fwrite($fp, json_encode($results));
			 fclose($fp);
			 
			 if(!empty($fp)){
				 echo plugin_dir_url(__FILE__) .'pixelform-download-form-data.php';
			 }else{
				 echo '';
			 }
			
			wp_die();
		}
	}
	
	/****** Import Form Data Ajax ******/
	public function pixelform_form_import_form_data(){
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_import_form_data'){
				global $wpdb;
				$ids = array();
				$table_name = $wpdb->prefix . 'pixelform_form_forms';
				$getdata = wp_unslash($_POST['importData']);
				
				$results = $wpdb->get_results ( "SELECT ID FROM $table_name" );
				foreach( $results as $getID ){
					$ids[] = $getID->ID;
				}
				
				if(!empty($getdata)) {
					foreach( json_decode($getdata) as $data ){
						if( in_array($data->ID, $ids) ){
							$last_id = (int) end($ids);
							$data->ID = $last_id+1;
						}
						echo $wpdb->insert( $table_name, (array) $data );
					}
				}
			wp_die();
		}
	}
	
	/*** Form Builder Custom Css(internal) ***/
	public function pixelform_form_fb_internal_css(){
		global $fb_internal_css;
		$fb_internal_css = array();
		return $fb_internal_css;
	}
	
	public function pixelform_form_load_footer_scripts() {
		global $fb_internal_css;
		echo !empty($fb_internal_css) ? '<style>'.implode(' ', $fb_internal_css).'</style>' : '';
		
		echo '<p class="pixelform_form-alert"></p><!-- Alert Notice -->';
	}

	/**
	 * Pixel Template Load More
	 */
	public function pixelform_template_load_more(){
		global $wpdb;
        $min = $max = 0;
        if(!empty($_POST['min'])){
            $min = sanitize_text_field($_POST['min']);
        }
		
		if(!empty($_POST['max'])){
		    $max = sanitize_text_field($_POST['max']);
	    }
		
		$num = $min+$max;
		
		
		$query = "SELECT * FROM {$wpdb->prefix}pixelform_pages_templates LIMIT $max OFFSET $min";
		$templates = $wpdb->get_results($query);
		$html = '';
		$i = 0;
		if(!empty($templates)){
		    foreach($templates as $template){
		        $html .='<div class="template-box">
    				<div class="template-img">
    					<img src="'. esc_url(plugins_url()."/pixel-formbuilder/templates/thumbs/".$template->template_thumb).'" alt="'.esc_attr($template->template_name).'">
    					<div class="template-options">
    						<ul>
    							<li>
    							<a href="javascript:void(0);" class="Pixelform-get-data" data-toggle="'. esc_attr__('modal','Pixelform').'" data-temid="'. esc_attr($template->id).'"  data-target="'. esc_attr__('#template_import_onpage','Pixelform').'" data-whatever="'. esc_attr__('@mdo','Pixelform').'">
    								<img src="'. esc_url(plugins_url('/pixel-formbuilder/admin/images/edit.svg')).' " alt="'. esc_attr__('Template Use','Pixelform').'">
    							</a>
    							</li>
    							<li>
    							<a href="'. esc_url($template->template_preview_link).'" target="'. esc_attr__('_blank','Pixelform').'" target="'. esc_attr__('_blank','Pixelform').'"><img src="'. esc_url(plugins_url('/pixel-formbuilder/admin/images/view.svg')).'" alt="'. esc_attr__('privew template','Pixelform').'">
    							</a>
    							</li>
    						</ul>
    					</div>
    				</div>
    				<div class="template-info">
    					<a href="javascript:void(0);" class="template-title">'. esc_html($template->template_name).'</a>
    				</div>
    			</div>';
    			$i++;
		    }
		    $res_arr = array('status'=>'true','html'=>$html,'num'=>$num);
		    echo json_encode($res_arr);
		}
		wp_die();
	}
	/**
	 * Pixel in Import Template
	*/
	public function pixelform_import_template(){
    	global $wpdb;
    	$new_page = 0;
    	if(!empty($_POST['new_page'])):
    		$new_page = sanitize_text_field($_POST['new_page']);
    	endif;
    	$page_option_value = '';
    	if(!empty($_POST['page_option_value'])):
    		$page_option_value = sanitize_text_field($_POST['page_option_value']);
    	endif;
    	
    	$select_page = 0;
    	if(!empty($_POST['select_page'])):
    		$select_page = sanitize_text_field($_POST['select_page']);
    	endif;
    	$temid = 0;
    	if(!empty($_POST['temid'])):
    		$temid = sanitize_text_field($_POST['temid']);
    	endif;
    	$rowperpage = 4;
    	$query = "SELECT * FROM {$wpdb->prefix}pixelform_pages_templates where id={$temid}";
    	$templates = $wpdb->get_results($query);
    	$template_data = $template_extra = '';
    	if(!empty($templates)): 
    		foreach($templates as $template):
    		$template_data = $template->template_data;
			$template_extra = $template->template_extra;
    		endforeach; 
    	endif;
    	
        if($page_option_value=='creat_new_page'):
    		$post_arr = array(
    			'post_title'   => $new_page,
    			'post_content' => '',
    			'post_status'  => 'publish',
    			'post_type'  => 'page',
    			'post_author'  => get_current_user_id(),
    		);
    		$post_id = wp_insert_post($post_arr);
    		if(!empty($post_id )):
				$data = addslashes(base64_decode($template_data));
				$extra = addslashes(base64_decode($template_extra));
				update_post_meta($post_id, "_elementor_data", $data);
				update_post_meta($post_id, "_elementor_controls_usage", $extra);
				update_post_meta($post_id, "_elementor_edit_mode", 'builder'); 
    		    update_post_meta($post_id, "_wp_page_template", 'elementor_canvas');
    		    $elementor_page = admin_url('post.php?post='.$post_id.'&action=elementor');
                $res_arr = array(
    			           'status'=>'true',
    					   'message'=>esc_html__('Data has been saved successfully','Pixelform'),
    					   'page_url' => $elementor_page
    					   );
    		else: 
                $res_arr = array(
    				'status'=>'false',
    				'message'=>esc_html__('Something went wrong!','Pixelform'),
    				);
    		endif;
        else:
            $post_arr = array(
    			   'ID' => $select_page,
    			);
    	    $post_id = wp_update_post($post_arr);			
    		if(!empty($post_id )):
				$data = addslashes(base64_decode($template_data));
				$extra = addslashes(base64_decode($template_extra));
				update_post_meta($post_id, "_elementor_data", $data);
				update_post_meta($post_id, "_elementor_controls_usage", $extra);
				update_post_meta($post_id, "_elementor_edit_mode", 'builder'); 
    		    update_post_meta($post_id, "_wp_page_template", 'elementor_canvas');
    		    $elementor_page = admin_url('post.php?post='.$post_id.'&action=elementor');
    			$res_arr = array(
    				'status'=>'true',
    				'message'=>esc_html__('Data has been saved successfully','Pixelform'),
    				'page_url' => $elementor_page
    				);
    		else: 
    			$res_arr = array(
    				'status'=>'false',
    				'message'=>esc_html__('Something went wrong!','Pixelform'),
    				);
    		endif;
    	endif; 
    	echo json_encode($res_arr);
        wp_die();	
	}
	/**
	 * Pixel Creat New Page
	 */
	public function pixelform_creat_new_template(){
		$new_page = 0;
		if(!empty($_POST['new_page'])):
			$new_page = sanitize_text_field($_POST['new_page']);
		endif;
		if(!empty($new_page)):
			$post_arr = array(
				'post_title'   => $new_page,
				'post_status'  => 'publish',
				'post_type'  => 'page',
				'post_author'  => get_current_user_id(),
			);
			$post_id = wp_insert_post($post_arr);
			if(!empty($post_id )):
				$elementor_page = admin_url('post.php?post='.$post_id.'&action=elementor');
				$res_arr = array(
					'status'=>'true',
					'message'=>esc_html__('Creat New Template has been successfully','Pixelform'),
					'page_url' => $elementor_page
					);
			else: 
				$res_arr = array(
					'status'=>'false',
					'message'=>esc_html__('Something went wrong!','Pixelform'),
					);
			endif;
	   else:
			$res_arr = array(
				'status'=>'false',
				'message'=>esc_html__('Something went wrong!','Pixelform'),
				);
	   endif;
	  echo json_encode($res_arr);
	  wp_die();
	}
}
