<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_App_Aboutus extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_aap_aboutus';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture App Aboutus', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__( 'App About us Settings', 'leadcapture' ),
            ] 
        );
		
        $this->add_control(
            'leadcapture_about_image',
            [
			'label' => esc_html__('About us Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );

        $this->add_control(
            'leadcapture_ab_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_ab_main_head',
            [
            'label'  => esc_html__('Heading', 'leadcapture'),
            'type'   => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );

        $this->add_control(
            'leadcapture_ab_description_one',
            [
            'label' => esc_html__( 'Description First', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_ab_description_two',
            [
            'label' => esc_html__( 'Description Second', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );

        $this->add_control(
            'leadcapture_ab_button_text',
            [
            'label' => esc_html__('Button Text', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture'),
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_button_url',
            [
            'label' => esc_html__('Button Url', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->end_controls_section();
       /** 
        * Lead Captur Style Tab
        */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
			'lps_heading_text_color',
    		[
    		'label' => esc_html__('Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
    		'selectors' => [
    			'{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
    		   ],
			]
		);
		$this->add_control(
			'lps_sub_heading_text_color',
    		[
    		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
    		'selectors' => [
    		   '{{WRAPPER}} .lc-about-para00 h5' => 'color: {{VALUE}}',
    		 ],
			]
		);
		$this->add_control(
			'lps_sub_heading_line_bg_color',
    		[
    		'label' => esc_html__('Sub Heading Line Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
    		'selectors' => [
    			'{{WRAPPER}} .lc-about-para00 h5:before' => 'background-color: {{VALUE}}',
    		  ],
			]
		);
		$this->add_control(
		  'lps_paragraph_text_color',
    		[
    		'label' => esc_html__('Paragraph Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
    		'selectors' => [
    			'{{WRAPPER}} .add-paragraph-text-colors' => 'color: {{VALUE}}',
    			],
			]
		);
        $this->add_control(
        	'lps_button_text_color',
        	[
        	'label' => esc_html__('Button Text Color', 'leadcapture' ),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	  '{{WRAPPER}} .add-button-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_button_background_color',
        	 [
        	'label' => esc_html__('Button Background Color', 'leadcapture' ),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-button-bg-colors' => 'background-color: {{VALUE}}',
        		],
        	]
         );
         $this->add_control(
        	'lps_button_hover_color',
        		[
        		'label' => esc_html__('Button Hover Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		'{{WRAPPER}} .lc-al-portfolio_btn:hover' => 'background-color: {{VALUE}}',
        		],
        	]
         );   
         $this->add_control(
        	'lps_button_shadow_color',
        		[
        		'label' => esc_html__('Button Shadow Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		'{{WRAPPER}} .lc-al-portfolio_btn' => 'box-shadow: {{VALUE}}',
        		],
        	]
         );  
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-about-section" style="overflow-x:hidden">
                <div class="container">
                    <div class="row " style="align-items: center;">';
                    if(!empty($settings['leadcapture_about_image']['url'])):
                        echo '<div class="col-lg-6 col-md-12 col-sm-12">
                                <div class="lc-al-about-img">
                                    <img src="'.esc_url($settings['leadcapture_about_image']['url']).'" alt="'.esc_attr__('About Image','leadcapture').'">
                                </div>
                             </div>';
                    endif;
            echo '<div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-about-para00">';
                            if(!empty($settings['leadcapture_ab_sub_head'])):
                                echo '<h5 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_ab_sub_head']).'</h5>';
                            endif;
                            if(!empty($settings['leadcapture_ab_main_head'])):
                                echo '<h3 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_ab_main_head']).'</h3>';
                            endif;
                            if(!empty($settings['leadcapture_ab_description_one'])):
                                echo '<p class="lps-description-fontstyle">'.esc_html($settings['leadcapture_ab_description_one']).'</p>';
                            endif;
                            if(!empty($settings['leadcapture_ab_description_two'])):
                                echo '<p class="lc-al-sec-para lps-description-fontstyle add-paragraph-text-colors">'.esc_html($settings['leadcapture_ab_description_two']).'</p>';
                            endif;
                            if(!empty($settings['leadcapture_ab_button_url'])):
                            echo '<div class="lc-al-know-btn  ">
                                    <a href="'.esc_url($settings['leadcapture_ab_button_url']).'" class="lc-al-portfolio_btn add-button-text-colors add-button-bg-colors">';
                                    if(!empty($settings['leadcapture_ab_button_text'])):
                                        echo '<span class="lc-al-first_text">'.esc_html($settings['leadcapture_ab_button_text']).'</span>
                                             <span class="lc-al-second_text">'.esc_html($settings['leadcapture_ab_button_text']).'</span>';
                                    endif;
                                  echo '</a>
                                </div>';
                            endif;
                    echo '</div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}