<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;
// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_App_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_aap_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture App Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__( 'Aap Banner Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'leadcapture_aap_banner_heading',
            [
            'label'       => esc_html__('Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
        
        $this->add_control(
            'leadcapture_aap_banner_sub_head',
            [
            'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_aap_banner_formshortcode',
            [
            'label'       => esc_html__('Form Shortcode', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_aap_banner_dow_heading',
            [
            'label'       => esc_html__('Dowenload Aap Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_aap_image_icon_one',
            [
			'label'       => esc_html__('Aap Image One', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_aap_url_one',
            [
            'label'       => esc_html__('Icon One  Url', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_aap_heading_one',
            [
            'label'       => esc_html__('Icon One Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_aap_image_icon_two',
            [
			'label'       => esc_html__('Aap Image Two', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_aap_url_two',
            [
            'label'       => esc_html__('Icon Two  Url', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_aap_heading_two',
            [
            'label' => esc_html__('Icon Two Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_aap_left_image',
            [
			'label' => esc_html__('Banner Left Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_aap_background_image',
            [
			'label' => esc_html__('Banner Background Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
			'lps_heading_text_color',
    			[
    			'label' => esc_html__('Heading Text Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
    			],
			]
		);
		$this->add_control(
        	'lps_heading_aap_banner_custom_text_color',
        	 [
        	 'label' => esc_html__('Heading Custom Text Color', 'leadcapture' ),
        	 'type' => \Elementor\Controls_Manager::COLOR,
        	 'selectors' => [
        		  '{{WRAPPER}} .add-heading-custom-text-colors' => 'color: {{VALUE}}',
        	   ],
        	]
        );
		$this->add_control(
			'lps_paragraph_text_color',
    			[
    			'label' => esc_html__('Paragraph Text Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .add-paragraph-text-colors' => 'color: {{VALUE}}',
    			],
			]
		);
		$this->add_control(
			'lps_app_download_heading_text_color',
    			[
    			'label' => esc_html__('App Download Heading Text Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .add-app-download-heading-text-colors' => 'color: {{VALUE}}',
    			],
			]
		);
	    $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
        echo '<div class="lc-banner-section lc-banner-section-style3">';
        if(!empty($settings['leadcapture_aap_background_image']['url'])):
            echo '<style>.lc-banner-section.lc-banner-section-style3::before {
                background-image: url('.esc_url($settings['leadcapture_aap_background_image']['url']).');
                }
               </style>';
        endif;
        echo '<div class="container-fluid">
              <div class="row">
                <div class="col-lg-6 col-md-12 col-sm-12">
                    <div class="lc-main-banner-para">
                        <div class=" lc-banner-para lc-banner-para-style3">';
                        if(!empty($settings['leadcapture_aap_banner_heading'])):
                            echo '<h1 class="lps-heading-fontstyle add-heading-text-colors">'.wp_kses($settings['leadcapture_aap_banner_heading'],true).'</h1>';
                        endif;
                        if(!empty($settings['leadcapture_aap_banner_sub_head'])):
                            echo '<p class="lps_description_typography add-paragraph-text-colors">'.esc_html($settings['leadcapture_aap_banner_sub_head']).'</p>';
                        endif;
            echo '</div>';
            if(!empty($settings['leadcapture_aap_banner_formshortcode'])):
                echo do_shortcode($settings['leadcapture_aap_banner_formshortcode']);
            endif;
            echo '<div class="lc-app-store">';
            if(!empty($settings['leadcapture_aap_banner_dow_heading'])):
               echo '<p class="lps_description_typography add-app-download-heading-text-colors">'.esc_html($settings['leadcapture_aap_banner_dow_heading']).'</p>';
            endif;
            if(!empty($settings['leadcapture_aap_url_one'])):
            echo '<span class="lc-al-play">
                <a href="'.esc_url($settings['leadcapture_aap_url_one']).'"><img src="'.esc_url($settings['leadcapture_aap_image_icon_one']['url']).'" alt="'.esc_attr__('Play Store','leadcapture').'"></a>
                '.esc_html($settings['leadcapture_aap_heading_one']).'</span>'; 
            endif;
            if(!empty($settings['leadcapture_aap_url_two'])):
            echo '<span>
                <a href="'.esc_url($settings['leadcapture_aap_url_two']).'"><img src="'.esc_url($settings['leadcapture_aap_image_icon_two']['url']).'" alt="'.esc_attr__('Aap Store','leadcapture').'"></a>
                '.esc_html($settings['leadcapture_aap_heading_one']).'</span>';
            endif;
             echo '</div>
                </div>
            </div>
            <div class="col-lg-6 col-md-12 col-sm-12">
                <div class="lc-banner-img lc-banner-img-style3">';
                    if(!empty($settings['leadcapture_aap_left_image']['url'])):
                        echo '<img src="'.esc_url($settings['leadcapture_aap_left_image']['url']).'" alt="'.esc_attr__('Banner Image','leadcapture').'">';
                    endif;
                echo '</div>
                    </div>
               </div>
           </div>
        </div>';
	}
}