<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_App_Feature extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_aap_feature';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture App Feature', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
    	$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'Aap Features Settings', 'leadcapture' ),
            ] 
        );
    	$this->add_control(
            'leadcapture_ab_sub_head',
            [
                'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__('Aap Feature Sub Heading', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_ab_main_head',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__('Aap Feature Main Heading', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
    	$repeater->add_control(
            'leadcapture_image',
            [
    			'label'       => esc_html__( 'Icon Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
    		]
        );
    	$repeater->add_control(
            'leadcapture_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
    	$repeater->add_control(
            'leadcapture_descreption',
            [
                'label'       => esc_html__('Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
    	$repeater->add_control(
            'leadcapture_read_more_text',
            [
                'label'       => esc_html__( 'Read More Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_read_more_url',
            [
                'label'       => esc_html__( 'Read More Url', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
    	$this->add_control(
            'leadcapture_features_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [	
    					'leadcapture_title'  => esc_html__( '', 'leadcapture' ),
                        'leadcapture_descreption'  => esc_html__( '', 'leadcapture' ),
    					'leadcapture_read_more_text'  => esc_html__( '', 'leadcapture' ),
                        'leadcapture_read_more_url'  => esc_html__( '#', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_title}}',
            ]
        );
    
        $this->add_control(
            'leadcapture_view_more_text',
            [
            'label'       => esc_html__( 'View More Text', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__('View More', 'leadcapture' ),
            ]
        );
        
        $this->add_control(
            'leadcapture_view_more_url',
            [
            'label'       => esc_html__( 'View More Page Url', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
    
      
    
    	$this->end_controls_section();
    	
    	/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
       	$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
			'lps_sub_heading_text_color',
    		[
    		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
    		'selectors' => [
    		   '{{WRAPPER}} .lc-Features h5' => 'color: {{VALUE}}',
    		 ],
			]
		);
		$this->add_control(
			'lps_sub_heading_line_bg_color',
    		[
    		'label' => esc_html__('Sub Heading Line Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
    		'selectors' => [
    			'{{WRAPPER}} .lc-Features h5:before' => 'background-color: {{VALUE}}',
    		  ],
			]
		);
        $this->add_control(
			'lps_heading_text_color',
    			[
    			'label' => esc_html__('Heading Text Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
    			],
			]
		);
		 
        $this->add_control(
        	'lps_paragraph_text_color',
        		[
        		'label' => esc_html__('Paragraph Text Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-paragraph-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        
        $this->add_control(
        	'lps_button_read_more_text_color',
        		[
        		'label' => esc_html__('Read More Button Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		'{{WRAPPER}} .add-button-read-more-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_read_more_line_color',
        		[
        		'label' => esc_html__('Read More Button Line Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		'{{WRAPPER}} .lc-fast-box a:before' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_box_hover_effect_color',
        		[
        		'label' => esc_html__('Box Hover Effect Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		'{{WRAPPER}} .lc-fast-box:before' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_text_color',
        		[
        		'label' => esc_html__('Button Text Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		  '{{WRAPPER}} .add-button-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_background_color',
        		[
        		'label' => esc_html__('Button Background Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		'{{WRAPPER}} .add-button-bg-colors' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_hover_color',
        		[
        		'label' => esc_html__('Button Hover Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        		'{{WRAPPER}} .lc-al-portfolio_btn:hover' => 'background-color: {{VALUE}}',
        		],
        	]
         );   
         $this->add_control(
        	'lps_button_shadow_color',
        		[
        		'label' => esc_html__('Button Shadow Color', 'leadcapture' ),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        	    	'{{WRAPPER}} .lc-al-portfolio_btn:hover' => 'box-shadow: {{VALUE}}',
        		],
        	]
         );  
       	$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
            echo '<div class="lc-features-section" style="overflow-x:hidden">
                    <div class="container">
                       <div class="lc-Features">';
                        if(!empty($settings['leadcapture_ab_sub_head'])):
                          echo '<h5>'.esc_html($settings['leadcapture_ab_sub_head']).'</h5>';
                        endif;
                        if(!empty($settings['leadcapture_ab_main_head'])):
                            echo '<h3>'.esc_html($settings['leadcapture_ab_main_head']).'</h3>';
                        endif;
            echo '</div>
                    <div class="row">';
                    if(!empty($settings['leadcapture_features_list'])):
                        foreach ($settings['leadcapture_features_list'] as $key => $values ):

                            echo '<div class="col-lg-4 col-md-6 col-sm-12">
                                    <div class="lc-fast-box">';
                                        if(!empty($values['leadcapture_image']['url'])):
                                          echo '<img src="'.esc_url($values['leadcapture_image']['url']).'" alt="'.esc_attr__('Leadcapture Image','leadcapture').'">';
                                        endif;
                                        if(!empty($values['leadcapture_title'])):
                                           echo '<h3 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($values['leadcapture_title']).'</h3>';
                                        endif;
                                        if(!empty($values['leadcapture_descreption'])):
                                            echo '<p class="lps-description-fontstyle add-paragraph-text-colors">'.esc_html($values['leadcapture_descreption']).'</p>';
                                        endif;
                                       if(!empty($values['leadcapture_read_more_url'])):
                                           echo '<a href="'.esc_url($values['leadcapture_read_more_url']).'" class="add-button-read-more-text-colors lps-heading-fontstyle">'.esc_html($values['leadcapture_read_more_text']).'</a>';
                                       endif;
                             echo '</div>
                                </div>';
                        endforeach;
                    endif;
            echo '</div>';
            if(!empty($settings['leadcapture_view_more_url'])):
                 echo '<div class="lc-al-know-btn lc-al-more">
                    <a href="'.esc_url($settings['leadcapture_view_more_url']).'" class="lc-al-portfolio_btn add-button-bg-colors add-button-text-colors">';
                       if(!empty($settings['leadcapture_view_more_text'])):
                        echo '<span class="lc-al-first_text">'.esc_html($settings['leadcapture_view_more_text']).'</span>
                            <span class="lc-al-second_text">'.esc_html($settings['leadcapture_view_more_text']).'</span>';
                       endif;
                echo '</a>
                    </div>';
                endif;
              echo '</div>
            </div>';
        
	}
}