<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Auto_Banner extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_auto_banner';
	}
    
    /**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Auto Banner', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__('Auto Insurance Banner Settings', 'leadcapture' ),
            ] 
        ); 
        $this->add_control(
            'leadcapture_auto_banner_heading',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_auto_banner_sub_head',
            [
            'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_auto_form_box_head',
            [
            'label' => esc_html__( 'Form Box Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_auto_image_icon_one',
            [
			'label' => esc_html__('Eamil Icon Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_auto_banner_formshortcode',
            [
            'label' => esc_html__('Form Shortcode', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_sub_heading_text_color',
        		[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        		[
        		'label' => esc_html__('Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_paragraph_text_color',
        		[
        		'label' => esc_html__('Paragraph Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-paragraph-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_text_bg_color',
        		[
        		'label' => esc_html__('Text background Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-bg-text-colors' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_custom_text_color',
        		[
        		'label' => esc_html__('Custom Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-custom-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
       $this->end_controls_section();
    }
   
  	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
        echo '<div class="lc-banner-section lc-banner-section-style4">';
            echo '<div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="lc-inner-top">
                                <div class="lc-said-bar">';
                            if(!empty($settings['leadcapture_auto_banner_sub_head'])):
                                echo '<h6 class="lps-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_auto_banner_sub_head']).'</h6>';
                            endif;
                            if(!empty($settings['leadcapture_auto_banner_heading'])):
                                echo wp_kses($settings['leadcapture_auto_banner_heading'],true);
                            endif;
                            echo '</div>
                                  <div class="lc-Newsletter">
                                    <div class="lc-top00">';
                                    if(!empty($settings['leadcapture_auto_image_icon_one']['url'])):
                                        echo '<div class="lc-mail-icon">
                                               <img src="'.esc_url($settings['leadcapture_auto_image_icon_one']['url']).'" alt="'.esc_attr__('email icon','leadcapture').'">
                                             </div>';
                                    endif;
                                    if(!empty($settings['leadcapture_auto_form_box_head'])):
                                        echo '<div class="lc-form-heading">
                                                <h4 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_auto_form_box_head']).'</h4>
                                             </div>';
                                    endif;
                            echo '</div>';
                            if(!empty($settings['leadcapture_auto_banner_formshortcode'])):
                                echo '<div class="lc-search-wrapper lc-form-control0">';
                                echo do_shortcode($settings['leadcapture_auto_banner_formshortcode']);
                                echo '</div>';
                            endif;
                            echo '</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}