<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Insurance_Section extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_aap_features';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Auto Insurance Section', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__( 'About Section Settings', 'leadcapture' ),
            ] 
        );
		$this->add_control(
            'leadcapture_auto_ab_sub_head',
            [
             'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
             'type'        => Controls_Manager::TEXT,
             'label_block' => true,
             'default'     => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_auto_ab_main_head',
            [
             'label' => esc_html__( 'Heading', 'leadcapture' ),
             'type'  => Controls_Manager::TEXTAREA,
             'label_block' => true,
             'default' => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_auto_ab_desc',
            [
             'label' => esc_html__( 'Description', 'leadcapture' ),
             'type'  => Controls_Manager::TEXTAREA,
             'label_block' => true,
             'default' => esc_html__( 'Our Salon Service Are sit amet, consectetur adipisicing elit, sed do eiusmod tempor iencididunt uerseit labore et dolore magna aliqua.', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_auto_ab_list',
            [
             'label' => esc_html__( 'List', 'leadcapture' ),
             'type'  => Controls_Manager::TEXTAREA,
             'label_block' => true,
             'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_auto_left_images',
            [
			'label' => esc_html__('About Left Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'leadcapture_auto_in_ab_image',
            [
            'label'       => esc_html__('Icon Image', 'leadcapture' ),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $repeater->add_control(
            'leadcapture_auto_in_ab_counter',
            [
            'label'       => esc_html__('Counter Number', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_auto_in_ab_title',
            [
            'label'       => esc_html__('Title', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_auto_ab_counters',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [	
					'leadcapture_auto_in_ab_title'  => esc_html__( '', 'leadcapture' ),
                    'leadcapture_auto_in_ab_counter'  => esc_html__( '', 'leadcapture' ),
					] 
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_auto_in_ab_title}}',
            ]
        ); 
        
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .lc-insurance-section .lc-inner-icone .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        	[
        		'label' => esc_html__('Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_paragraph_text_color',
        	[
        	'label' => esc_html__('Paragraph Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-paragraph-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_counter_background_color',
        		[
        		'label' => esc_html__('Counter Background Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add_counter_background_colors' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        
        $this->add_control(
        	'lps_counter_background_color_icon',
        		[
        		'label' => esc_html__('Counter Icon Background Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add_counter_icon_background_colors' => 'background-color: {{VALUE}}',
        		],
        	]
        );
         $this->add_control(
        	'list_color',
        	[
        		'label' => esc_html__('List Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .list-color p' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'subTITLE',
        	[
        		'label' => esc_html__('sub title color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-insurance-section">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6 col-md-6 col-sm-12">
                            <div class="lc-heading">';
                                if(!empty($settings['leadcapture_auto_ab_sub_head'])):
                                   echo '<h2 class="lps-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_auto_ab_sub_head']).'</h2>';
                                endif;
                                if(!empty($settings['leadcapture_auto_ab_main_head'])):
                                  echo '<h1 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_auto_ab_main_head']).'</h1>';
                                endif;
                                if(!empty($settings['leadcapture_auto_ab_desc'])):
                                    
                                    echo "<div class='lps-description-fontstyle'>".wp_kses($settings['leadcapture_auto_ab_desc'],true)."</div> <div class='lps-description-fontstyle list-color'>".wp_kses($settings['leadcapture_auto_ab_list'],true)."</div>";
                                endif;
                         echo '</div>
                             </div>
                            <div class="col-lg-6 col-md-6 col-sm-12">
                            <div class="lc-main-img">';
                                if(!empty($settings['leadcapture_auto_left_images']['url'])):
                                   echo '<img src="'.esc_url($settings['leadcapture_auto_left_images']['url']).'" alt="'.esc_attr__('Auto Insurance','leadcapture').'">';
                                endif;
                                echo '<div class="lc-inner-icone add_counter_background_colors">';
                                if(!empty($settings['leadcapture_auto_ab_counters'])):
                                    foreach ($settings['leadcapture_auto_ab_counters'] as $key => $values ):
                                    echo '<div class="lc-box1">';
                                    if(!empty($values['leadcapture_auto_in_ab_image']['url'])):
                                        echo '<div class="lc-car add_counter_icon_background_colors">
                                                <img src="'.esc_url($values['leadcapture_auto_in_ab_image']['url']).'" alt="'.esc_attr__('Counters','leadcapture').'">
                                            </div>'; 
                                    endif;
                                    if(!empty($values['leadcapture_auto_in_ab_image']['url'])):   
                                        echo '<div class="lc-inner-box">';
                                            if(!empty($values['leadcapture_auto_in_ab_counter'])):
                                              echo '<h4 class="lps-heading-fontstyle add-sub-heading-text-colors">'.esc_html($values['leadcapture_auto_in_ab_counter']).'</h4>';
                                            endif;
                                            if(!empty($values['leadcapture_auto_in_ab_title'])):
                                              echo '<p class="lps-description-fontstyle add-service-paragraph-text-colors">'.esc_html($values['leadcapture_auto_in_ab_title']).'</p>';
                                            endif;
                                        echo '</div>'; 
                                    endif;
                                    echo '</div>';
                                    endforeach;
                                endif;
                                echo '</div>
                               </div>
                           </div>
                       </div>
                    </div>
               </div>';
	}
}