<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Auto_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_auto_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Auto Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */ 
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'Service Settings', 'leadcapture' ),
            ] 
        );
		$this->add_control(
            'leadcapture_as_sub_head',
            [
            'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_as_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture' ),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('About Our Salon', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'services_icon_type',
            [
            'label' => esc_html__('Icon Type', 'leadcapture'),
            'type'  => Controls_Manager::SELECT,
            'default' => 'image',
                'options' => [
                'icon'   => esc_html__('Icon', 'leadcapture'),
                'image'   => esc_html__('Image', 'leadcapture'),
                ],
            ]
        );
        $repeater->add_control(
            'services_image',
            [
            'label' => esc_html__('Services Icon', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
                'condition' => [
                  'services_icon_type' => 'image',
                ],
            ]
        );
        $repeater->add_control(
            'leadcapture_service_title',
            [
            'label' => esc_html__('Service Title', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_service_descreption',
            [
            'label' => esc_html__('Service Descreption', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_service_button_text',
            [
            'label' => esc_html__('Service Button Text', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_service_button_url',
            [
            'label' => esc_html__('Service Button Url', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
		
		$this->add_control(
            'leadcapture_service_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_service_title'  => esc_html__('Lorem Ipsum', 'leadcapture'),
					'leadcapture_service_descreption'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
					]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_service_title}}',
            ]
        );
        $this->end_controls_section();
        
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_paragraph_text_color',
        	[
        	'label' => esc_html__('Paragraph Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-paragraph-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_service_heading_text_color',
        	[
        	'label' => esc_html__('Service Heading Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-service-heading-text-colors' => 'color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_paragraph_text_color',
        	[
        	'label' => esc_html__('Service Paragraph Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-service-paragraph-text-colors' => 'color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_button_text_color',
        	[
        	'label' => esc_html__('Service Button Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-service-button-text-colors' => 'color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_button_bg_color',
        	[
        	'label' => esc_html__('Service Button Bg Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-service-button-bg-colors' => 'color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_man_heading_border_color',
        	[
        	'label' => esc_html__('Heading Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-services-slider-btn:before' => 'background-color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_heading_border_color',
        	[
        	'label' => esc_html__('Heading Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-Car-Insurance h3:before ' => 'background-color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_button_border_color',
        	[
        	'label' => esc_html__('Service Button Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-Car-Insurance a::before' => 'background-color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_hover_color',
        	[
        	'label' => esc_html__('Service Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-Car-Insurance:hover h3' => 'color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_slide_arrow_color',
        	[
        	'label' => esc_html__('Service Arrow Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-services-slider-btn > div' => 'background-color: {{VALUE}}',
        	   ],
        	]
        );
        $this->add_control(
        	'lps_service_slide_arrow_hover_color',
        	[
        	'label' => esc_html__('Service Arrow Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-services-slider-btn >div:hover' => 'background-color: {{VALUE}}',
        	   ],
        	]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-our-services-section" style="overflow-x:hidden">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-3 col-md-3 col-sm-12">';
                        echo '<div class="lc-best-insurance">';
                            if(!empty($settings['leadcapture_as_sub_head'])):
                                echo '<p class="lps-description-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_as_sub_head']).'</p>';
                            endif;
                            if(!empty($settings['leadcapture_as_main_head'])):
                                echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_as_main_head']).'</h2>';
                            endif;
                        echo '</div>';
                        if(!empty($settings['leadcapture_service_list'])):
                            echo '<div class="lc-services-slider-btn">
                                   <div class="swiper-button-prev1 "></div>
                                   <div class="swiper-button-next1 "></div>
                                 </div>';
                        endif;
                    echo '</div> 
                          <div class="col-lg-9 col-md-9 col-sm-12">
                            <div class="lc-ai-services-slider">
                                <div class="swiper lc-ai-services-container">
                                    <div class="swiper-wrapper">';
                                    if(!empty($settings['leadcapture_service_list'])):
                                        foreach ($settings['leadcapture_service_list'] as $key => $values ):
                                            echo '<div class="swiper-slide">
                                                   <div class="lc-Car-Insurance">';
                                                    if(!empty($values['services_image']['url'])):
                                                        echo '<img src="'.esc_url($values['services_image']['url']).'" alt="'.esc_attr__('Service','leadcapture').'">';
                                                    endif;
                                                    if(!empty($values['leadcapture_service_title'])):
                                                        echo '<h3 class="lps-heading-fontstyle add-service-heading-text-colors">'.esc_html($values['leadcapture_service_title']).'</h3>';
                                                    endif;
                                                    if(!empty($values['leadcapture_service_descreption'])):
                                                        echo '<p class="lps-description-fontstyle add-service-paragraph-text-colors">'.esc_html($values['leadcapture_service_descreption']).'</p>';
                                                    endif;
                                                    if(!empty($values['leadcapture_service_button_url'])):
                                                        echo '<a href="'.esc_url($values['leadcapture_service_button_url']).'" class="add-service-button-bg-colors add-service-button-text-colors">'.esc_html($values['leadcapture_service_button_text']).'</a>';
                                                    endif;
                                            echo '</div>
                                            </div>';
                                        endforeach;
                                    endif;
                                echo '</div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>'; 
	}
}