<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Auto_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_auto_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __('Leadcapture Auto Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );

		$this->add_control(
            'leadcapture_tm_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_tm_main_head',
            [
            'label' => esc_html__( 'Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_testi',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );

		$this->end_controls_section();
		
		/** 
        * Lead Captur Style Tab
        */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__( 'Heading Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .lc-client-heading p' => 'color: {{VALUE}}',
        		],
        	]
        );
       	$this->end_controls_section();
       	
       	$this->start_controls_section(
			'section_style_content',
			[
			'label' => esc_html__( 'Content', 'elementor' ),
			'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_border_color',
        	[
        	'label' => esc_html__('Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-paragraph20 p:before' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_author_name_color',
        	[
        	'label' => esc_html__('Author Name Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lp-author-color' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_author_name_desc_color',
        	[
        	'label' => esc_html__('Designationr Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lp-designation-color' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-Testimonials2-section auto-insurance-testimonial">
                <div class="lc-client-heading">';
                if(!empty($settings['leadcapture_tm_sub_head'])):
                    echo '<p class="lps-heading-fontstyle">'.esc_html($settings['leadcapture_tm_sub_head']).'</p>';
                endif;
                if(!empty($settings['leadcapture_tm_main_head'])):
                    echo '<h3 class="add-heading-text-colors lps-heading-fontstyle">'.esc_html($settings['leadcapture_tm_main_head']).'</h3>';
                endif;
        echo '</div>
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-testimonials-slider">
                                <div class="swiper lc-ai-test-contant">
                                    <div class="swiper-wrapper ">';
                                    if(!empty($settings['leadcapture_testimonial_list'])):
                                           foreach($settings['leadcapture_testimonial_list'] as $testi):
                                                echo '<div class="swiper-slide twoo">
                                                  <div class="lc-main-testimonials">';
                                                    if(!empty($testi['leadcapture_testimonial_image']['url'])):
                                                        echo '<div class="lc-clint-img">
                                                                <img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr($testi['leadcapture_testimonial_image']['alt']).'">
                                                            </div>';
                                                    endif;
                                                echo '<div class="lc-paragraph20 ">';
                                                    if(!empty($testi['leadcapture_testimonial_testi'])):
                                                       echo '<p class="lps-description-fontstyle lp-author-color">'.esc_html($testi['leadcapture_testimonial_testi']).'</p>';
                                                    endif;
                                                if(!empty($testi['leadcapture_testimonial_author'])):
                                                echo '<h1 class="lps-heading-fontstyle">'.esc_html($testi['leadcapture_testimonial_author']);
                                                        if(!empty($testi['leadcapture_testimonial_dest'])):
                                                        echo '<span class="lp-designation-color"> '.esc_html($testi['leadcapture_testimonial_dest']).'</span>';
                                                        endif; 
                                                echo '</h1>';
                                                endif;
                                                echo '</div>
                                                     </div>
                                                   </div>'; 
                                            endforeach;
                                echo '</div>
                                     <div class="swiper-button-next ">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 7 14" width="7" height="14">
                                            <path id="Shape 12" class="s0" d="m7 7q0 0.3-0.2 0.5l-5.3 6.3q-0.2 0.2-0.5 0.2-0.2 0-0.4-0.2l-0.4-0.5q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.6l4.4-5.2-4.4-5.2c-0.3-0.3-0.3-0.8 0-1.1l0.4-0.5q0.2-0.2 0.4-0.2 0.3 0 0.5 0.2l5.3 6.3q0.2 0.2 0.2 0.5z"/>
                                        </svg>
                                     </div>
                                     <div class="swiper-button-prev ">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 7 14" width="7" height="14">
                                            <path id="Shape 12" class="s0" d="m0.2 6.5l5.3-6.3q0.2-0.2 0.5-0.2 0.2 0 0.4 0.2l0.4 0.5c0.3 0.3 0.3 0.8 0 1.1l-4.4 5.2 4.4 5.2q0.2 0.3 0.2 0.6 0 0.3-0.2 0.5l-0.4 0.5q-0.2 0.2-0.4 0.2-0.3 0-0.5-0.2l-5.3-6.3q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.5z"/>
                                        </svg>
                                    </div>
                                    <div class="swiper-pagination "></div>';
                                endif;      
                            echo '</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}