<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Auto_Repair_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_auto_repair_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Auto Repair', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_auto_repair_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
       $this->add_control(
            'lcp__banner_left_image',
            [
			'label' => esc_html__( 'Left Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $this->add_control(
            'lcp__banner_logo_image',
            [
			'label' => esc_html__( 'Logo Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $this->add_control(
            'lcp_auto_repair_banner_subtitle',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_auto_repair_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_auto_repair_banner_btn_text',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_auto_repair_banner_btn_url',
            [
                'label'       => esc_html__( 'Button URL', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_auto_repair_banner_newsletter_head',
            [
                'label'       => esc_html__( 'News Letter Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_auto_repair_newsletter_form',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
       
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_auto_repair_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Sub Heading Style
        $this->add_control(
			'lcp_auto_repair_banner_style_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_auto_repair_banner_style_subheading_typography',
                'label'       => esc_html__( 'Sub Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style44 span'
            ]
        );
        $this->add_control(
            'lcp_auto_repair_banner_style_subheading_color',
            [
                'label'     => esc_html__( 'Sub Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style44 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_auto_repair_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_auto_repair_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style44 h1'
            ]
        );
        $this->add_control(
            'lcp_auto_repair_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style44 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button Style
        $this->add_control(
			'lcp_auto_repair_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_auto_repair_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style44 a'
            ]
        );
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_auto_repair_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_auto_repair_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style44 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_auto_repair_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style44 a' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_auto_repair_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style44 a',
            ]
        );
		$this->add_control(
            'lcp_auto_repair_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style45' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
        
        
        // NewsLetter Heading Style
        $this->add_control(
			'lcp_auto_repair_banner_style_news_heading',
			[
				'label' => esc_html__( 'News Letter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_auto_repair_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subupdate-form-style44 h2'
            ]
        );
        $this->add_control(
            'lcp_auto_repair_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subupdate-form-style44 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<div class="lc-banner-section-style44">
			<div class="container-fluid">
				<div class="row">';
				if(!empty($settings['lcp__banner_left_image']['url'])):
				    echo '<div class="col-lg-6 col-md-12 col-sm-12">
						<div class="lc-banner-rightimg-style44">
						<img src="'.esc_url($settings['lcp__banner_left_image']['url']).'" alt="'.esc_attr__('left-boy-image','leadcapture').'">
						</div>
					</div>';
				endif;
				echo '<div class="col-lg-6 col-md-12 col-sm-12">
						<div class="lc-banner-text-style44">';
						    if(!empty($settings['lcp__banner_logo_image']['url'])):
						        echo '<div class="lc-logo-style44">
								<img src="'.esc_url($settings['lcp__banner_logo_image']['url']).'" alt="'.esc_attr__('logo','leadcapture').'">
							    </div>';
						    endif;
						    if(!empty($settings['lcp_auto_repair_banner_subtitle'])):
						        echo '<span>'.esc_html($settings['lcp_auto_repair_banner_subtitle']).'<span></span></span>';
						    endif;
						    if(!empty($settings['lcp_auto_repair_banner_title'])):
						        echo '<h1>'.esc_html($settings['lcp_auto_repair_banner_title']).'</h1>';
						    endif;
							if(!empty($settings['lcp_auto_repair_banner_btn_text'])):
							    echo '<div class="lc-btn-style44 lc-banner-style44">
								    <a href="'.esc_url($settings['lcp_auto_repair_banner_btn_url']).'">'.esc_html($settings['lcp_auto_repair_banner_btn_text']).'</a>
							    </div>';
							endif;    
						echo '<div class="lc-subscribe-wrapper-style44">
							<div class="lc-subupdate-form-style44">';
							    if(!empty($settings['lcp_auto_repair_banner_newsletter_head'])):
								    echo '<h2>'.esc_html($settings['lcp_auto_repair_banner_newsletter_head']).'</h2>';
								endif; 
								if(!empty($settings['lcp_auto_repair_newsletter_form'])):
								  echo do_shortcode($settings['lcp_auto_repair_newsletter_form']);
								endif; 
							echo '</div>
						</div>
					</div>
					</div>
				</div>
			</div>
		</div>';
	}
	}
}