<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Bakery_about extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_bakery_about';
	}
    /**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __('Leadcapture Bakery About', 'leadcapture');
	}
   /**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}
    /**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__('About Bakery Settings', 'leadcapture' ),
            ] 
        );
		$this->add_control(
            'leadcapture_bakery_sub_head',
            [
            'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_bakery_main_head',
            [
            'label' => esc_html__( 'Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_bakery_right_image',
            [
			'label' => esc_html__('Right Image', 'leadcapture' ),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_bakery_button_text',
            [
			'label' => esc_html__('Button Text', 'leadcapture' ),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_bakery_button_url',
            [
			'label' => esc_html__('Button Url', 'leadcapture' ),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,	
			]
        );
		$this->add_control(
            'leadcapture_bakery_desc',
            [
            'label' => esc_html__('Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_bakery_left_image',
            [
			'label' => esc_html__('Left Image', 'leadcapture' ),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_bakery_days',
            [
            'label' => esc_html__( 'Enter Days', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_bakery_hours',
            [
            'label' => esc_html__('Enter Hours', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_bakery_minutes',
            [
            'label' => esc_html__('Enter Minutes', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'leadcapture_bakery_seconds',
            [
            'label' => esc_html__('Enter Seconds', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->end_controls_section();
		/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_description_text_color',
        	[
        		'label' => esc_html__('Description Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-description-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_text_color',
        	[
        	'label' => esc_html__('Button Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .lc-btn-style7' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_bg_color',
        	[
        	'label' => esc_html__('Button Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	    '{{WRAPPER}} .lc-btn-style7' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        
        $this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
			'name' => 'border',
			'label' => esc_html__( 'Button Border Color', 'leadcapture'),
			'selector' => '{{WRAPPER}} .lc-btn-style7 a',
			]
		);
		
		$this->add_control(
        	'lps_counter_bg_color',
        	[
        	'label' => esc_html__('Counter Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	    '{{WRAPPER}} .lc-countdown' => 'background-color: {{VALUE}}',
        		],
        	]
        );
	    
	    $this->end_controls_section();
	}
  
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
        echo '<div class="lc-about-wrapper lc-about-wrapper-style7">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6 col-mg-6 col-sm-12">
                            <div class="lc-about-img lc-about-img-style7">';
                                if(!empty($settings['leadcapture_bakery_left_image']['url'])):
                                    echo '<img src="'.esc_url($settings['leadcapture_bakery_left_image']['url']).'" alt="'.esc_attr__('about image','leadcapture').'">';
                                 endif; 
                                echo '<div class="lc-countdown">
                                        <div id="countdown">
                                            <ul>
                                                <li><span id="days" data-days="'.esc_attr($settings['leadcapture_bakery_days']).'"></span>
                                                    <h6>'.esc_html__('days','leadcapture').'</h6>
                                                </li>
                                                <li><span id="hours" data-hours="'.esc_attr($settings['leadcapture_bakery_hours']).'"></span>
                                                    <h6>'.esc_html__('Hours','leadcapture').'</h6>
                                                </li>
                                                <li><span id="minutes" data-minutes="'.esc_attr($settings['leadcapture_bakery_minutes']).'"></span>
                                                    <h6>'.esc_html__('Minutes','leadcapture').'</h6>
                                                </li>
                                                <li><span id="seconds" data-seconds="'.esc_attr($settings['leadcapture_bakery_seconds']).'"></span>
                                                    <h6>'.esc_html__('Seconds','leadcapture').'</h6>
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
			            </div>
                        <div class="col-lg-6 col-mg-6 col-sm-12">
				        <div class="lc-about-text lc-about-test-style7">';
                        if(!empty($settings['leadcapture_bakery_sub_head'])):
                            echo '<h3 class="lps-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_bakery_sub_head']).'</h3>';
                         endif; 
                        if(!empty($settings['leadcapture_bakery_main_head'])):
                           echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_bakery_main_head']).'</h2>';
                        endif;
                        if(!empty($settings['leadcapture_bakery_desc'])):
                           echo '<p class="lps_description_typography add-description-text-colors">' .esc_html($settings['leadcapture_bakery_desc']).'</p>';
                        endif; 
                        if(!empty($settings['leadcapture_bakery_button_text'])):
                            echo '<div class="lc-btn lc-btn-style7 lc-more-style7"><a href="'.esc_url($settings['leadcapture_bakery_button_url']).'">'.esc_html($settings['leadcapture_bakery_button_text']).'</a></div>';
                        endif;
                    echo '</div>
                    </div>
                </div>
            </div>
        </div>';
    }
}