<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();
 
/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Bakery_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_bakery_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Bakery Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__('Bakery Banner Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_bakery_sub_head',
            [
            'label' => esc_html__('Bakery Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_bakery_logo_image',
            [
			'label'       => esc_html__( 'Bakery Logo Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,
			]
         );
        $this->add_control(
            'leadcapture_bakery_main_head',
            [
            'label' => esc_html__('Bakery Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_bakery_desc',
            [
            'label' => esc_html__('Bakery Description', 'leadcapture' ),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_bakery_form_imageicon',
            [ 
			'label' => esc_html__('Form Icon', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
			]
         );
        $this->add_control(
            'leadcapture_bakery_banner_formshortcode',
            [
            'label' => esc_html__('Form Shortcode', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
        	'lps_logo_heading_text_color',
        	[
        	'label' => esc_html__('Logo Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-logo-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        ); 
        $this->add_control(
        	'lps_logo_bg_heading_text_color',
        	[
        	'label' => esc_html__('Logo Heading Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-background-text-colors' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
       	
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-banner-section-wrapper" style="overflow-x:hidden">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-banner-text lc-banner-text-style7">
                                <div class="lc-logo-img lc-logo-img-style7">';
                                    if(!empty($settings['leadcapture_bakery_logo_image']['url'])):
                                       echo '<img src="'.esc_url($settings['leadcapture_bakery_logo_image']['url']).'" alt="'.esc_attr__('Bakery Logo','leadcapture').'">';
                                    endif;
                                    if(!empty($settings['leadcapture_bakery_sub_head'])):
                                       echo '<p class="lps-description-fontstyle lps-sub-heading-fontstyle add-background-text-colors add-logo-heading-text-colors">'.esc_html($settings['leadcapture_bakery_sub_head']).'</p>';
                                    endif;
                        echo '</div>
                        <div class="lc-header-text lc-header-text-style7">';
                        if(!empty($settings['leadcapture_bakery_main_head'])):
                               echo '<h1 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_bakery_main_head']).'</h1>';
                        endif;
                        if(!empty($settings['leadcapture_bakery_desc'])):
                             echo '<p class="lps-sub-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_bakery_desc']).'</p>';
                        endif;
                        if(!empty($settings['leadcapture_bakery_banner_formshortcode'])):
                            echo '<div class="lc-search-wrapper lc-search-wrapper-style7">
                                <div class="lc-message-icon">';
                                if(!empty($settings['leadcapture_bakery_form_imageicon']['url'])):
                                    echo '<img src="'.esc_url($settings['leadcapture_bakery_form_imageicon']['url']).'" alt="'.esc_attr__('Message Icon','leadcapture').'">';
                                endif;
                              echo do_shortcode($settings['leadcapture_bakery_banner_formshortcode']);
                            echo '</div> 
                            </div>'; 
                        endif;
                        echo '</div>
                        </div>
                    </div>
                </div>
            </div>
        </div>';
	}
}