<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();
 
/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Bakery_Products extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_bakery_product';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __('Leadcapture Bakery Products', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__('Product Settings', 'leadcapture' ),
            ] 
        );
		$this->add_control(
            'leadcapture_pro_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_pro_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture' ),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
	    $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_product_title',
            [
            'label' => esc_html__( 'Product Title', 'leadcapture' ),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_real_price',
            [
            'label'  => esc_html__('Real Price', 'leadcapture' ),
            'type'   => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_sale_price',
            [
            'label' => esc_html__('Sale Price', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_product_image',
            [
			'label' => esc_html__( 'Product Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_product_review',
            [
			'label' => esc_html__( 'Product Review Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $this->add_control(
            'leadcapture_product_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_product_title'  => esc_html__('', 'leadcapture'),
					'leadcapture_real_price'  => esc_html__('', 'leadcapture'),
					'leadcapture_real_price'  => esc_html__('', 'leadcapture'),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_product_title}}',
            ]
        );
		$this->end_controls_section();
		/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->end_controls_section();
       	/**
       	 * Product Setting
       	 */ 
       	$this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Product Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
        	'lps_pro_heading_text_color',
        	[
        	'label' => esc_html__('Product Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-pro-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_real_price_color',
        	[
        	'label' => esc_html__('Real Price Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-real-price-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sales_price_color',
        	[
        	'label' => esc_html__('Sale Price Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-sales-price-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_carticon_bg_colors',
        	[
        	'label' => esc_html__('Cart Icon Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-cake-product span' => 'background-color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_carticon_border_colors',
        	[
        	'label' => esc_html__('Cart Icon Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-cake-product span' => 'border: {{VALUE}}',
        	  ],
        	]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		        echo '<div class="lc-sweet-cupcake-wrapper" style="overflow-x:hidden">
                        <div class="container">
                            <div class="row">
                                <div class="col-lg-12 col-md-12 col-sm-12">
                                    <div class="lc-heading-wrapper lc-heading-style7">';
                                        if(!empty($settings['leadcapture_pro_sub_head'])):
                                           echo '<h3 class="lps-heading-fontstyle add-sub-heading-text-colors ">'.esc_html($settings['leadcapture_pro_sub_head']).'</h3>';
                                        endif;
                                        if(!empty($settings['leadcapture_pro_main_head'])):
                                           echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_pro_main_head']).'</h2>';
                                        endif;
                            echo '</div>
                                </div>
                            </div>
                        <div class="row ">';
                        if(!empty($settings['leadcapture_product_list'])):
                            foreach($settings['leadcapture_product_list'] as $product_de):
                            echo '<div class="col-lg-3 col-md-6 col-sm-12">
                                    <div class="lc-product">';
                                        if(!empty($product_de['leadcapture_product_image']['url'])):
                                            echo '<div class="lc-product-img-style7">
                                                <img src="'.esc_url($product_de['leadcapture_product_image']['url']).'" alt="'.esc_attr__('product','leadcapture').'">
                                                </div>';
                                        endif;
                                        if(!empty($product_de['leadcapture_product_review']['url'])):
                                        echo '<div class="lc-stare-icon">
                                                <img src="'.esc_url($product_de['leadcapture_product_review']['url']).'" alt="'.esc_attr__('review Image','leadcapture').'">
                                            </div>';
                                       endif;
                            echo '<div class="lc-cake-product">';
                                        if(!empty($product_de['leadcapture_product_title'])):
                                        echo '<h2 class="lps-heading-fontstyle add-pro-heading-text-colors add-pro-heading-text-colors">'.esc_html($product_de['leadcapture_product_title']).'</h2>
                                        <span><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" width="24" height="24">
                                        <g id="Layer">
                                        <path id="Layer" class="s0"
                                        d="m4 1c0.4 0 0.8 0.3 0.9 0.7l1 2.8q0 0.1 0.1 0.2 0.1 0.1 0.1 0.2 0.1 0 0.2 0.1 0.1 0 0.3 0h16.1c0.6 0 1.1 0.7 0.9 1.3l-2.7 8c-0.1 0.4-0.5 0.7-0.9 0.7h-10.7q-0.1 0-0.2 0-0.1 0.1-0.2 0.1-0.1 0.1-0.2 0.2 0 0.1 0 0.2l-0.2 0.8c-0.1 0.4 0.1 0.7 0.5 0.7h12c0.6 0 1 0.4 1 1 0 0.6-0.4 1-1 1h-12c-1.6 0-2.9-1.6-2.5-3.2l0.3-1.1q0.2-0.7-0.1-1.3l-3.3-9.9q0-0.1-0.1-0.2 0-0.1-0.1-0.2-0.1 0-0.2-0.1-0.1 0-0.2 0h-1.8c-0.6 0-1-0.4-1-1 0-0.6 0.4-1 1-1zm6 21c0 1.1-0.9 2-2 2-1.1 0-2-0.9-2-2 0-1.1 0.9-2 2-2 1.1 0 2 0.9 2 2zm12 0c0 1.1-0.9 2-2 2-1.1 0-2-0.9-2-2 0-1.1 0.9-2 2-2 1.1 0 2 0.9 2 2z" />
                                        </g>
                                        </svg>
                                        </span>';
                                        endif;
                                        echo '</div>';
                                        if(!empty($product_de['leadcapture_real_price'])):
                                        echo '<span class="lc-cake-del add-real-price-colors"><del>'.esc_html($product_de['leadcapture_real_price']).'</del></span>';
                                        endif;
                                        if(!empty($product_de['leadcapture_sale_price'])):
                                        echo '<span class="lc-cake-number add-sales-price-colors">'.esc_html($product_de['leadcapture_sale_price']).'</span>';
                                        endif;
                               echo '</div>
                                </div>';
                            endforeach;                                 
                        endif;
                echo '</div>
                </div>
            </div>'; 
	}
}