<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();
  
/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Bakery_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_bakery_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Bakery Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
     
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_tm_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_tm_main_head',
            [
            'label' => esc_html__( 'Heading', 'leadcapture' ),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
       
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
            'label' => esc_html__( 'Author Name', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
         $repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label' => esc_html__('Author Image', 'leadcapture' ),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$repeater->add_control(
            'leadcapture_testimonial_testi',
            [
            'label' => esc_html__( 'Testimonial', 'leadcapture' ),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'  => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonial_rating_image',
            [
			'label' => esc_html__('Rating Image', 'leadcapture' ),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default'  => [
                [
              'leadcapture_testimonial_rating_image' => esc_html__('', 'leadcapture'),
			  'leadcapture_testimonial_dest' => esc_html__('', 'leadcapture'),
			  'leadcapture_testimonial_testi' => esc_html__('', 'leadcapture'),
              ]
            ],
            'fields' => $repeater->get_controls(),
            'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'  => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_desc_border_color',
        	[
        	'label' => esc_html__('Description Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .lc-test-name-style7::before' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
       	$this->end_controls_section();
       	$this->start_controls_section(
            'lps_testimonial_style_tab',
            [
            'label' => esc_html__('Testimonial Content Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
        	'lps_autor_name_text_color',
        	[
        		'label' => esc_html__('Author Name Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-author-name-color' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
			'name' => 'background',
			'label' => esc_html__( 'Pagination Background', 'leadcapture' ),
			'types' => [ 'classic'],
			'selector' => '{{WRAPPER}} .lc-testimonial-style7 .swiper-pagination span.swiper-pagination-bullet-active',
			]
		);
        $this->end_controls_section();
    }
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */ 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-testimonial-wrapper lc-testimonial-style7">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-sm-12 col-md-12">
                            <div class="lc-heading-wrapper lc-heading-style7 lc-top-heading-style7">';
                                if(!empty($settings['leadcapture_tm_sub_head'])):
                                echo '<h3 class="add-sub-heading-text-colors">'.$settings['leadcapture_tm_sub_head'].'</h3>';
                                endif;
                                if(!empty($settings['leadcapture_tm_main_head'])):
                                echo '<h2 class="add-heading-text-colors">'.$settings['leadcapture_tm_main_head'].'</h2>';
                                endif;
                    echo '</div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-testimonial-slider-wrapper lc-test-slide-style7">
                             <div class="swiper lc-testimonial-slider-style7">
                                    <div class="swiper-wrapper">';
                                    if(!empty($settings['leadcapture_testimonial_list'])):
                                        foreach($settings['leadcapture_testimonial_list'] as $testi):
                                            echo '<div class="swiper-slide">
                                                    <div class="lc-test-wrapper-style7">
                                                        <div class="lc-test-para-style7">';
                                        if(!empty($testi['leadcapture_testimonial_testi'])):
                                        echo '<p class="lps-description-fontstyle">'.esc_html($testi['leadcapture_testimonial_testi']).'</p>';
                                        endif; 
                                        if(!empty($settings['leadcapture_testimonial_quote_image']['url'])):
                                        echo '<div class="lc-quote-img-style7">
                                        <img src="'.esc_url($settings['leadcapture_testimonial_quote_image']['url']).'" alt="'.esc_attr__('Quote Image','leadcapture').'">
                                        </div>';
                                        endif;         
                                        echo '</div>
                                        <div class="lc-test-img-style7">
                                        <div class="lc-test-name-style7">';
                                        if(!empty($testi['leadcapture_testimonial_author'])):
                                        echo '<h5 class="lps-heading-fontstyle add-heading-text-colors add-author-name-color">'.esc_html($testi['leadcapture_testimonial_author']).'</h5>'; 
                                        endif;
                                        if(!empty($testi['leadcapture_testimonial_rating_image']['url'])):
                                        echo '<div class="lc-stare-icon lc-stare-icon-style7">
                                        <img src="'.esc_url($testi['leadcapture_testimonial_rating_image']['url']).'" alt="'.esc_attr__('rating image','leadcapture').'">
                                        </div>';
                                        endif;
                                        echo '</div>
                                        </div>
                                    </div>
                                </div>';
                                endforeach; 
                            endif;    
                        echo '</div>
                        </div>';
                        if(!empty($settings['leadcapture_testimonial_list'])):
                        echo '<div class="swiper-button-next">
                                <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 18" width="20"
                                    height="18">
                                    <path id="Shape 11" class="s0"
                                        d="m3 7.9q0.1-0.1 0.2-0.1h11.2l-0.2-0.1q-0.4-0.2-0.6-0.4l-3.2-3.3c-0.4-0.4-0.5-1-0.2-1.5 0.4-0.5 1.1-0.7 1.6-0.3q0.1 0.1 0.1 0.1l5.8 5.9c0.4 0.4 0.4 1.2 0 1.6q0 0 0 0l-5.8 5.9c-0.4 0.4-1.1 0.4-1.6 0q0-0.1-0.1-0.2c-0.3-0.4-0.2-1.1 0.2-1.5l3.1-3.2q0.3-0.3 0.6-0.5l0.4-0.1h-11.3c-0.6 0-1.1-0.4-1.2-1-0.1-0.6 0.3-1.2 1-1.3z" />
                                </svg>
                            </div>
                            <div class="swiper-button-prev">
                                <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 18" width="20"
                                height="18">
                                <path id="Shape 11" class="s0"
                                    d="m18 9.2c-0.1 0.6-0.6 1-1.2 1h-11.3l0.4 0.1q0.3 0.2 0.6 0.5l3.1 3.2c0.4 0.4 0.5 1.1 0.2 1.5q-0.1 0.1-0.1 0.2c-0.5 0.4-1.2 0.4-1.6 0l-5.8-5.9q0 0 0 0c-0.4-0.4-0.4-1.2 0-1.6l5.8-5.9q0 0 0.1-0.1c0.5-0.4 1.2-0.2 1.6 0.3 0.3 0.5 0.2 1.1-0.2 1.5l-3.2 3.3q-0.2 0.2-0.6 0.4l-0.2 0.1h11.2q0.1 0 0.2 0.1c0.7 0.1 1.1 0.7 1 1.3z" />
                                </svg>
                            </div>
                        <div class="swiper-pagination "></div>';
                        endif;
                    echo '</div>
                    </div>
                </div>
            </div>
        </div>';
	}
}