<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Barber_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_barber_banner';
	}
 
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __('Leadcapture Barber Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	 
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_barber_banner',
            [
            'label' => esc_html__( 'Barber Banner Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_bb_logo_image',
            [
			'label' => esc_html__('Barber Logo Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
		$this->add_control(
            'leadcapture_bb_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_bb_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_bb_form_heading',
            [
            'label' => esc_html__('Form Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_bb_form_shortcode',
            [
            'label' => esc_html__('Form Shortcode', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
		$this->end_controls_section();
		/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
        	'lps_heading_style_tab',
        	[
        	'label' => esc_html__('Style Tab', 'leadcapture'),
        	'tab'   => Controls_Manager::TAB_STYLE,
        	]
        );
        
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Heading Typography', 'leadcapture'),
        	'name'     => 'lps_heading_typography',
        	'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
        	]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
        	'name'     => 'lps_sub_heading_typography',
        	'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
    		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_form_heading_text_color',
        	[
    		'label' => esc_html__('Form Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .add-form-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-header-wrapper">
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-lg-6 col-md-12 col-sm-12">
                                <div class="lc-header-text-wrapper">';
                            if(!empty($settings['leadcapture_bb_logo_image']['url'])):
                                echo '<div class="lc-logo-img">
                                        <img src="'.esc_url($settings['leadcapture_bb_logo_image']['url']).'" alt="'.esc_attr__('logo-img','leadcapture').'">
                                        </div>';
                            endif;
                            echo '<div class="lc-header-text">';
                                if(!empty($settings['leadcapture_bb_sub_head'])):
                                    echo '<h3 class="add-sub-heading-text-colors lps-sub-heading-fontstyle">'.esc_html__($settings['leadcapture_bb_sub_head']).'</h3>';
                                endif;
                                if(!empty($settings['leadcapture_bb_main_head'])):
                                    echo '<h1 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html__($settings['leadcapture_bb_main_head']).'</h1>';
                                endif;
                                if(!empty($settings['leadcapture_bb_form_heading'])):
                                    echo '<p class="lps-sub-heading-fontstyle add-form-heading-text-colors">'.esc_html__($settings['leadcapture_bb_form_heading']).'</p>';
                                endif;
                                if(!empty($settings['leadcapture_bb_form_shortcode'])):
                                    echo '<div class="lc-search-wrapper">';
                                    echo do_shortcode($settings['leadcapture_bb_form_shortcode']);
                                    echo '</div>';
                                endif;
                        echo '</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}