<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */  
class Leadcapture_Barber_Specialist extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_barber_specialist';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Barber Specialist', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        
        $this->start_controls_section(
            'leadcapture_barber_specialist',
            [
            'label' => esc_html__('Barber Services Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_specialist_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_specialist_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'specialist_profile_image',
            [
            'label' => esc_html__('Specialist Profile Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $repeater->add_control(
            'leadcapture_specialist_name',
            [
            'label' => esc_html__('Specialist Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_specialist_email',
            [
            'label' => esc_html__('Specialist Email', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_specialist_contact',
            [
            'label' => esc_html__('Specialist Contact', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_specialist_designation',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_specialist_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator'   => 'before',
            'default' => [
                [
                'leadcapture_specialist_name'  => esc_html__('', 'leadcapture'),
                ]
            ], 
            'fields'  => $repeater->get_controls(),
            'title_field' => '{{leadcapture_specialist_name}}',
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tabs',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
       	/**
       	 * Team Section List 
       	 */ 
       	$this->start_controls_section(
            'lps_team_style_tab',
            [
            'label' => esc_html__('Team Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Team Member Name Typography', 'leadcapture'),
            'name'     => 'lps_team_member_name_typography',
            'selector' => '{{WRAPPER}} .lps-team-member-name-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Small Text Typography', 'leadcapture'),
            'name'     => 'lps_team_member_designation_typography',
            'selector' => '{{WRAPPER}} .lps-team-member-designation-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_team_member_name_text_color',
        	[
        	'label' => esc_html__('Team Member Name Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-team-member-name-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_team_member_designation_text_color',
        	[
        	'label' => esc_html__('Small Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-team-member-designation-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
         $this->add_control(
        	'lps_team_member_contact_text_color',
        	[
        	'label' => esc_html__('Small Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-team-member-contact-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_icon_text_color',
        	[
        	'label' => esc_html__('Icon Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-team-mail-icon > svg > .s0, .lc-team-call-icon > svg > .s0' => 'fill: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
       	
       	
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		        echo '<div class="lc-team-wrapper">
                        <div class="container">
                            <div class="row">
                                <div class="col-lg-12 col-md-12 col-sm-12">
                                 <div class="lc-heading-wrapper">';
                                if(!empty($settings['leadcapture_specialist_sub_head'])):
                                    echo '<h3 class="lps-sub-heading-fontstyle add-sub-heading-text-colors">'.$settings['leadcapture_specialist_sub_head'].'</h3>';
                                endif;
                                if(!empty($settings['leadcapture_specialist_main_head'])):
                                    echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.$settings['leadcapture_specialist_main_head'].'</h2>';
                                endif;
                        echo '</div>
                        </div>
                    </div>
                    <div class="lc-teambox-wrapper">
                        <div class="row">'; 
                        if(!empty($settings['leadcapture_specialist_list'])):
                            foreach ($settings['leadcapture_specialist_list'] as $key => $values):
                                    echo '<div class="col-lg-3 col-md-6 col-sm-6">
                                            <div class="lc-team-box-wrapper">
                                                <div class="lc-team-box">';
                                                if(!empty($values['specialist_profile_image']['url'])):
                                                echo '<div class="lc-team-box-img">
                                                        <img src="'.esc_url($values['specialist_profile_image']['url']).'" alt="'.esc_attr__('profile','leadcapture').'"> 
                                                        <div class="lc-team-box-img-overlay">
                                                            <div class="lc-team-box-hover">
                                                                <div class="lc-team-mail-icon">
                                                                    <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 21 15" width="21" height="15">
                                                                        <path id="Shape 9" class="s0" d="m19.1 13.9q-0.3 0.1-0.7 0.1h-14.8q-0.4 0-0.7-0.1l5.4-5.2 1.5 1.4c0.7 0.6 1.7 0.6 2.4 0l1.5-1.4zm0-11.7l-5.8 5.5q0 0 0 0 0 0 0 0l-1.9 1.8c-0.2 0.2-0.6 0.2-0.8 0l-1.9-1.8q0 0 0 0 0 0 0 0l-5.8-5.5q0.3-0.1 0.7-0.2h14.8q0.4 0.1 0.7 0.2zm-11.5 5.8l-5.4 5.2q-0.2-0.3-0.2-0.7v-9q0-0.3 0.2-0.6zm12.4-4.5v9q0 0.3-0.2 0.6l-5.4-5.1 5.4-5.2q0.2 0.3 0.2 0.7z"/>
                                                                    </svg>';
                                                                if(!empty($values['leadcapture_specialist_email'])):
                                                                echo '<p class="add-team-member-designation-text-colors lps-team-member-designation-fontstyle">'.esc_html($values['leadcapture_specialist_email']).'</p>';
                                                                endif;
                                                            echo '</div>
                                                                <div class="lc-team-call-icon">
                                                                    <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 19 20" width="19" height="20">
                                                                        <path id="Shape 8" class="s0" d="m18 14.7c0 0.6-3.3 3.3-3.7 3.3-0.1 0-3.5-0.1-7.9-4.4-4.3-4.4-4.4-7.8-4.4-7.9 0-0.4 2.7-3.7 3.3-3.7 0.2 0 0.3 0.1 0.5 0.3 0.4 0.5 2.3 3.5 2.2 4-0.1 0.2-0.3 0.4-0.8 0.8q-0.4 0.4-0.8 0.7 0.2 0.8 0.5 1.4c0.8 1.7 2.2 3.1 3.9 3.9q0.6 0.3 1.4 0.5 0.3-0.4 0.7-0.8c0.4-0.5 0.6-0.7 0.8-0.8 0.5-0.1 3.5 1.8 4 2.2 0.2 0.2 0.3 0.3 0.3 0.5zm-7.4-8.7v-1.1c2.5 0 4.5 2 4.5 4.5h-1.1c0-1.9-1.5-3.4-3.4-3.4zm0-2.9v-1.1c4.1 0 7.4 3.3 7.4 7.4h-1.1c0-3.4-2.9-6.3-6.3-6.3z"/>
                                                                    </svg>';
                                                                    if(!empty($values['leadcapture_specialist_contact'])):
                                                                       echo '<p class="add-team-member-designation-text-colors lps-team-member-designation-fontstyle">'.esc_html($values['leadcapture_specialist_contact']).'</p>';
                                                                    endif;
                                                           echo '</div>
                                                            </div>
                                                        </div>
                                                    </div>';
                                            endif;
                                            echo '</div>
                                                  <div class="lc-team-box-text">';
                                                  if(!empty($values['leadcapture_specialist_name'])):
                                                    echo ' <h4 class="add-team-member-name-text-colors lps-team-member-name-fontstyle">'.esc_html($values['leadcapture_specialist_name']).'</h4>';
                                                 endif;
                                                 if(!empty($values['leadcapture_specialist_contact'])):
                                                    echo '<p class="add-team-member-contact-text-colors lps-team-member-designation-fontstyle">'.esc_html($values['leadcapture_specialist_contact']).'</p>';
                                                 endif;
                                            echo '</div>
                                            </div>
                                        </div>';
                                    endforeach;
                                endif;        
                       echo '</div>
                       </div>
                    </div>
               </div>';
	}
}