<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Barber_Testimonials extends Widget_Base {
	 
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_Barber_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Barber Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */ 
	protected function register_controls() {

		$this->start_controls_section(
            'leadcapture_barber_testimonials',
            [
            'label' => esc_html__('Barber Testimonials Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_testimonials_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_testimonials_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'testimonials_profile_image',
            [
            'label' => esc_html__('Testimonials Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_name',
            [
            'label' => esc_html__('Testimonials Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_designation',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_review_image',
            [
            'label' => esc_html__('Testimonials Review Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_description',
            [
            'label' => esc_html__('Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_testimonials_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator'   => 'before',
            'default' => [
                [
                'leadcapture_testimonials_name'  => esc_html__('', 'leadcapture'),
                ]
            ], 
            'fields'  => $repeater->get_controls(),
            'title_field' => '{{leadcapture_testimonials_name}}',
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab_testimonial',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
       	  /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Testimonials Content Style ', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonials Author Name Typography', 'leadcapture'),
            'name'     => 'lps_authore_name_typography',
            'selector' => '{{WRAPPER}} .lps-testimonials-heading-fontstyle',
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonials Description Typography', 'leadcapture'),
            'name'     => 'lps_testimonials_description_typography',
            'selector' => '{{WRAPPER}} .lps-testimonials-description-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_testimonials_autorname_text_color',
        	[
        	'label' => esc_html__('Testimonials Author Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonials-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_testimonials_designation_text_color',
        	[
        	'label' => esc_html__('Testimonials Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonials-designation-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_testimonials_description_text_color',
        	[
        	'label' => esc_html__('Testimonials Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-testimonials-description-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
	}
    
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$id = uniqid();	
	    $settings = $this->get_settings_for_display();
		echo '<div class="lc-testimonial-wrapper">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-testimonial-heading-style2">';
                            if(!empty($settings['leadcapture_testimonials_sub_head'])):
                                echo '<h3 class="lps-sub-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_testimonials_sub_head']).'</h3>';
                            endif;
                            if(!empty($settings['leadcapture_testimonials_main_head'])):
                                echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_testimonials_main_head']).'</h2>';
                            endif;
                    echo '</div>
                        </div>
                    </div>';
                    if(!empty($settings['leadcapture_testimonials_list'])):
                        echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-testimonial-slider-wrapper">
                                    <div class="swiper lc-testimonial-slider">
                                        <div class="swiper-wrapper">';
                                            if(!empty($settings['leadcapture_testimonials_list'])):
                                                foreach ($settings['leadcapture_testimonials_list'] as $key => $values):
                                                    echo '<div class="swiper-slide">
                                                        <div class="lc-testimonial-box">
                                                            <div class="lc-testimonial-box-img-wrapper">
                                                                <div class="lc-testimonial-box-img">';
                                                                    if(!empty($values['testimonials_profile_image']['url'])):
                                                                        echo '<img src="'.esc_html($values['testimonials_profile_image']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">';
                                                                    endif;
                                                                    echo '<div class="btest-box-text">';
                                                                        if(!empty($values['leadcapture_testimonials_name'])):
                                                                        echo '<h4 class="add-testimonials-heading-text-colors lps-testimonials-heading-fontstyle">'.esc_html($values['leadcapture_testimonials_name']).'</h4>';
                                                                        endif;
                                                                        if(!empty($values['leadcapture_testimonials_designation'])):
                                                                        echo '<p class="add-testimonials-designation-text-colors lps-testimonials-heading-fontstyle">'.esc_html($values['leadcapture_testimonials_designation']).'</p>';
                                                                        endif;
                                                                    echo '</div>';
                                                                echo '</div>
                                                                <div class="lc-testimonial-box-star">';
                                                                if(!empty($values['leadcapture_testimonials_review_image']['url'])):
                                                                    echo '<img src="'.esc_html($values['leadcapture_testimonials_review_image']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">';
                                                                endif;
                                                            echo '</div>
                                                        </div>'; 
                                                            if(!empty($values['leadcapture_testimonials_description'])):
                                                                echo '<p class="add-testimonials-heading-text-colors add-testimonials-heading-text-colors">'.esc_html($values['leadcapture_testimonials_description']).'</p>';
                                                            endif;
                                                        echo '</div>
                                                    </div>';
                                                endforeach;
                                            endif;
                                        echo '</div>
                                    </div>';
                                    if(!empty($settings['leadcapture_testimonials_list'])):
                                        echo '<div class="swiper-button-next">
                                            <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 18" width="20" height="18"><path id="Shape 11" class="s0" d="m3 7.9q0.1-0.1 0.2-0.1h11.2l-0.2-0.1q-0.4-0.2-0.6-0.4l-3.2-3.3c-0.4-0.4-0.5-1-0.2-1.5 0.4-0.5 1.1-0.7 1.6-0.3q0.1 0.1 0.1 0.1l5.8 5.9c0.4 0.4 0.4 1.2 0 1.6q0 0 0 0l-5.8 5.9c-0.4 0.4-1.1 0.4-1.6 0q0-0.1-0.1-0.2c-0.3-0.4-0.2-1.1 0.2-1.5l3.1-3.2q0.3-0.3 0.6-0.5l0.4-0.1h-11.3c-0.6 0-1.1-0.4-1.2-1-0.1-0.6 0.3-1.2 1-1.3z"/>
                                            </svg>
                                        </div>
                                        <div class="swiper-button-prev">
                                            <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 18" width="20" height="18">
                                               <path id="Shape 11" class="s0" d="m18 9.2c-0.1 0.6-0.6 1-1.2 1h-11.3l0.4 0.1q0.3 0.2 0.6 0.5l3.1 3.2c0.4 0.4 0.5 1.1 0.2 1.5q-0.1 0.1-0.1 0.2c-0.5 0.4-1.2 0.4-1.6 0l-5.8-5.9q0 0 0 0c-0.4-0.4-0.4-1.2 0-1.6l5.8-5.9q0 0 0.1-0.1c0.5-0.4 1.2-0.2 1.6 0.3 0.3 0.5 0.2 1.1-0.2 1.5l-3.2 3.3q-0.2 0.2-0.6 0.4l-0.2 0.1h11.2q0.1 0 0.2 0.1c0.7 0.1 1.1 0.7 1 1.3z"/>
                                            </svg>
                                        </div>';
                                    endif;
                                echo '</div>
                                </div>
                            </div>
                        </div>
                     </div>';
                    endif;
	}
}