<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Barclub_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_barclub_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Barclub Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_tm_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_tm_main_head',
            [
            'label' => esc_html__( 'Heading', 'leadcapture' ),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_testimonial_quote_image',
            [
			'label' => esc_html__('Quote Image', 'leadcapture' ),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_testi',
            [
                'label'       => esc_html__( 'Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonial_rating_image',
            [
				'label'       => esc_html__('Rating Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_testimonial_rating_image'  => esc_html__('', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('', 'leadcapture'),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
       $this->end_controls_section();
       /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
       $this->end_controls_section();
    }
    /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-header-banner" style="overflow-x:hidden">
                    <div class="container">
                        <div class="row">
                            <div class="col-lg-12 col-md-12">
                                <div class="lc-banner-text lc-banner-text-style5" >';
                                if(!empty($settings['leadcapture_br_logo_image']['url'])):
									echo '<div class="lc-bc-logo">
											<a href="'.esc_url(home_url('/')).'">
											<img src="'.esc_url($settings['leadcapture_br_logo_image']['url']).'" alt="'.esc_attr__('Logo Image','leadcapture').'" /></a>
										</div>';
								endif;
                                if(!empty($settings['leadcapture_br_sub_head'])):
                                   echo '<h1 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_br_sub_head']).'</h1>';
								endif;
								if(!empty($settings['leadcapture_br_main_head'])):
                                   echo '<p class="lps-description-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_br_main_head']).'</p>';
								endif;
                        echo '</div>
                            </div>
                        </div>
                    </div>
              </div>';
	}
}