<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Barclub_Booking extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_barclub_booking';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __('Leadcapture Barclub Booking', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_barclub_booking',
            [
            'label' => esc_html__('BarClub Booking Form Settings', 'leadcapture'),
            ] 
        );
		$this->add_control(
            'leadcapture_barclub_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_barclub_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_br_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_br_description',
            [
            'label' => esc_html__('Description', 'leadcapture' ),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_list_image',
            [
			'label' => esc_html__('List Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_br_booking_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator'  => 'before',
            'default' => [
                [
                'leadcapture_list_image'  => esc_html__('', 'leadcapture'),
                'leadcapture_br_description'  => esc_html__('', 'leadcapture'),
                'leadcapture_br_title'  => esc_html__('', 'leadcapture'),
                ]
            ],
            'fields'      => $repeater->get_controls(),
            'title_field' => '{{leadcapture_br_title}}',
            ]
        );
        $this->add_control(
            'leadcapture_leftside_image',
            [
			'label' => esc_html__('Left Side Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
	    $this->end_controls_section();
	    /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_description_text_color',
        	[
    		 'label' => esc_html__('Description Text Color', 'leadcapture'),
    	  	 'type' => \Elementor\Controls_Manager::COLOR,
    		 'selectors' => [
    			'{{WRAPPER}} .add-description-text-colors' => 'color: {{VALUE}}',
    	 	   ],
        	]
        );
       $this->end_controls_section();
	}
    /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		    echo '<div class="lc-table-booking-section" style="overflow-x:hidden">
                    <div class="container">';
            if(!empty($settings['leadcapture_barclub_sub_head']) || !empty($settings['leadcapture_barclub_main_head'])):
            echo '<div class="lc-table-booking-heading">';
            if(!empty($settings['leadcapture_barclub_sub_head'])):
               echo '<h6 class="add-sub-heading-text-colors lps-heading-fontstyle">'.esc_html($settings['leadcapture_barclub_sub_head']).'</h6>';
            endif;
            if(!empty($settings['leadcapture_barclub_main_head'])):
               echo '<h1 class="add-heading-text-colors lps-heading-fontstyle">'.esc_html($settings['leadcapture_barclub_main_head']).'</h1>';
            endif;
             echo '</div>';
            endif;
            echo '<div class="row">
                    <div class="col-lg-6 col-md-6 col-sm-12">
                    <div class="lc-para-list">';
                    if(!empty($settings['leadcapture_br_booking_list'])):
                        foreach($settings['leadcapture_br_booking_list'] as $testi):
                                echo '<div class="lc-list">';
                                    if(!empty($testi['leadcapture_list_image']['url'])):
                                        echo '<div class="lc-booking01">
                                               <img src="'.esc_url($testi['leadcapture_list_image']['url']).'" alt="'.esc_attr__('List Images','leadcapture').'">
                                             </div>';
                                    endif;
                                if(!empty($testi['leadcapture_br_title']) || !empty($testi['leadcapture_br_description'])):
                                    echo '<div class="lc-booking0-para">';
                                        if(!empty($testi['leadcapture_br_title'])):
                                            echo '<h6 class="add-heading-text-colors lps-heading-fontstyle">'.esc_html($testi['leadcapture_br_title']).'</h6>';
                                        endif;
                                        if(!empty($testi['leadcapture_br_description'])):
                                            echo '<p class="add-description-text-colors lps-description-fontstyle">'.esc_html($testi['leadcapture_br_description']).'</p>';
                                        endif;

                                    echo '</div>';
                                endif;
                            echo '</div>';
                        endforeach;             
                    endif;
                    echo '</div>
                     </div>';
                    if(!empty($settings['leadcapture_leftside_image']['url'])):
                        echo '<div class="col-lg-6 col-md-6 col-sm-12">
                                <div class="lc-bc-table-booking-img" >
                                <img src="'.esc_url($settings['leadcapture_leftside_image']['url']).'" alt="'.esc_attr__('left about ','leadcapture').'"> 
                                </div>
                            </div>';
                    endif;
                 echo '</div>
                  </div>
            </div>';
	}
}