<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Barclub_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_barclub_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Barclub Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
           
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_tm_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_tm_main_head',
            [
            'label' => esc_html__( 'Heading', 'leadcapture' ),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_testimonial_quote_image',
            [
			'label' => esc_html__('Quote Image', 'leadcapture' ),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
            'label' => esc_html__( 'Author Name', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonial_author_designation',
            [
            'label' => esc_html__('Designation', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonial_author_image',
            [
			'label' => esc_html__('Author Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$repeater->add_control(
            'leadcapture_testimonial_testi',
            [
            'label' => esc_html__( 'Testimonial', 'leadcapture' ),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author_image'  => esc_html__('', 'leadcapture'),
					'leadcapture_testimonial_author_designation'  => esc_html__('', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('', 'leadcapture'),
                    ]
                ],
            'fields'      => $repeater->get_controls(),
            'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
       $this->end_controls_section();
       /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_sub_heading_background_color',
        	[
        		'label' => esc_html__('Sub Heading Background  Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .lc-table-booking-heading h6' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_description_text_color',
        	[
        		'label' => esc_html__('Description Text Color', 'leadcapture'),
        		'type' => \Elementor\Controls_Manager::COLOR,
        		'selectors' => [
        			'{{WRAPPER}} .add-description-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
       $this->end_controls_section();
       $this->start_controls_section(
            'lps_testimonial_style',
            [
                'label' => esc_html__( 'Testimonial Style', 'invory' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lps_testimonial_author',
                'label' => esc_html__( 'Author', 'invory' ),
                'selector' => '{{WRAPPER}} .lc-main-Testimonial .lc-test1 h2',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lps_testimonial_title',
                'label' => esc_html__( 'Designation', 'invory' ),
                'selector' => '{{WRAPPER}} .lc-main-Testimonial .lc-test1 p',
            ]
        );
         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lps_testimonial_testimonial',
                'label' => esc_html__( 'Testimonial', 'invory' ),
                'selector' => '{{WRAPPER}} .lc-parat0 p',
            ]
        );
        $this->add_control(
            'lps_testimonial_author_color',
            [
                'label'     => esc_html__( 'Author Color', 'invory' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#',
                'selectors' => [
                    '{{WRAPPER}} .lc-main-Testimonial .lc-test1 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lps_testimonial_author_colorh',
            [
                'label'     => esc_html__( 'Author Hover Color', 'invory' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#',
                'selectors' => [
                    '{{WRAPPER}} .lc-Testimonials00:hover .lc-test1 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lps_testimonial_designation_color',
            [
                'label'     => esc_html__( 'Designation Color', 'invory' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#',
                'selectors' => [
                    '{{WRAPPER}} .lc-main-Testimonial .lc-test1 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lps_testimonial_testimonial_color',
            [
                'label'     => esc_html__( 'Testimonial', 'invory' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#',
                'selectors' => [
                    '{{WRAPPER}} .lc-parat0 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        $this->end_controls_section();
	}
    /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-Testimonials-section" style="overflow-x:hidden">
                <div class="container">
                <div class="lc-table-booking-heading lc-Testimonials">';
                if(!empty($settings['leadcapture_tm_sub_head'])):
                    echo '<h6 class="lps-description-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_tm_sub_head']).'</h6>';
                endif;
                if(!empty($settings['leadcapture_tm_main_head'])):
                    echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_tm_main_head']).'</h2>';
                endif;
        echo '</div>
             <div class="row">
                <div class="col-lg-12">
                    <div class="lc-bc-Testimonials-slider">
                        <div class="swiper lc-bc-swiper-container">
                            <div class="swiper-wrapper">';
                            if(!empty($settings['leadcapture_testimonial_list'])):
                                foreach($settings['leadcapture_testimonial_list'] as $testi):
                                    echo '<div class="swiper-slide">
                                            <div class="lc-Testimonials00">
                                                <div class="lc-main-Testimonial">';
                                            if(!empty($testi['leadcapture_testimonial_author_image']['url'])):
                                                echo '<div class="lc-Testimonial-image">
                                                        <img src="'.esc_url($testi['leadcapture_testimonial_author_image']['url']).'"
                                                            alt="'.esc_attr__('image','leadcapture').'" />
                                                      </div>';
                                            endif;
                                            if(!empty($testi['leadcapture_testimonial_author']) && !empty($testi['leadcapture_testimonial_author_designation']) ):
                                                echo '<div class="lc-test1">';
                                                 if(!empty($testi['leadcapture_testimonial_author'])):
                                                    echo '<h2 class="lps-heading-fontstyle lps-author add-heading-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h2>';
                                                 endif;
                                                 if(!empty($testi['leadcapture_testimonial_author_designation'])):
                                                    echo '<p class="add-description-text-colors lps-description-fontstyle">'.$testi['leadcapture_testimonial_author_designation'].'</p>';
                                                 endif;
                                                echo '</div>';
                                                endif;       
                                            echo '</div>';
                                            if(!empty($testi['leadcapture_testimonial_testi'])):
                                                echo '<div class="lc-parat0">
                                                        <p class="add-description-text-colors lps-description-fontstyle">'.esc_html($testi['leadcapture_testimonial_testi']).'</p>
                                                    </div>';
                                            endif;
                                            echo '<span>';
                                                if(!empty($settings['leadcapture_testimonial_quote_image']['url'])):
                                                    echo '<img src="'.esc_url($settings['leadcapture_testimonial_quote_image']['url']).'"
                                                            alt="'.esc_attr__('image','leadcapture').'" />';
                                                else :
                                                    echo '<svg xmlns="http://www.w3.org/2000/svg" fill="#ffff" width="25" height="18"
                                                        viewBox="0 0 25 18">
                                                        <path class="cls-1"
                                                            d="M667.667,3062.94a14.312,14.312,0,0,1-2.575,4.15,1.284,1.284,0,0,0-.117,1.52,1.2,1.2,0,0,0,1.033.57,0.849,0.849,0,0,0,.35-0.05c2.45-.73,8.175-3.32,8.334-11.63a6.1,6.1,0,0,0-5.234-6.28,5.847,5.847,0,0,0-4.533,1.51,6.027,6.027,0,0,0-1.925,4.43A5.852,5.852,0,0,0,667.667,3062.94Zm15.091-11.72a5.839,5.839,0,0,0-4.525,1.51,6.027,6.027,0,0,0-1.925,4.43,5.852,5.852,0,0,0,4.667,5.78,14.312,14.312,0,0,1-2.575,4.15,1.284,1.284,0,0,0-.117,1.52,1.2,1.2,0,0,0,1.034.57,0.853,0.853,0,0,0,.35-0.05c2.45-.73,8.175-3.32,8.333-11.63v-0.12A6.086,6.086,0,0,0,682.758,3051.22Z"
                                                            transform="translate(-663 -3051.19)" />
                                                    </svg>';
                                                endif; 
                                               echo '</span>
                                            </div>
                                        </div>';
                                    endforeach; 
                        echo '</div>
                            </div>
                           <div class="swiper-pagination lc-bc-pagination"></div>';
                       endif;  
                echo '</div>
                </div>
            </div>
        </div>
    </div>';
	}
}