<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Business_Marketing_Blogs extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_business_marketing_blogs';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Business Marketings Blogs', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $categories = get_categories();
		$cats = array();
		foreach( $categories as $terms ){
			$cats[$terms->term_id] = $terms->name;
		}
	    $this->start_controls_section(
            'lcp_business_blogs_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_business_marketing_blogs_style',
            [
                'label'   => __( 'Services Style', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'style_one',
                'options' => [
                    'style_one'   => __( 'Style One', 'leadcapture' ),
                    'style_two'   => __( 'Style Two', 'leadcapture' ),
					
                ],
            ]
        );
        $this->add_control(
            'lcp_business_blogs_post_show',
            [
                'label'       => esc_html__( 'Number of Post', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '3', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_business_blogs_category',
            [
                'label'   => __( 'Select Categories', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT2,
				'multiple' => true,
                'options' => $cats
            ]
        );
        $this->add_control(
            'lcp_business_blogs_order_by',
            [
                'label'   => __( 'Order By', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'   => __( 'None', 'leadcapture' ),
                    'id'   => __( 'Id', 'leadcapture' ),					
					'title'   => __( 'Title', 'leadcapture' ),
					'date'   => __( 'Date', 'leadcapture' ),
                ],
            ]
        );
		$this->add_control(
            'lcp_business_blogs_sort',
            [
                'label'   => __( 'Sort Order', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC'   => __( 'Ascending', 'leadcapture' ),
                    'DESC'   => __( 'Descending', 'leadcapture' ),
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_business_blogs_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_business_blogs_style_sheading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_business_blogs_style_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style41 h4'
            ]
        );
        $this->add_control(
            'lcp_business_blogs_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style41 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_business_blogs_text_hover_color',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style41 h4:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_business_blogs_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_business_blogs_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style41 p'
            ]
        );
        $this->add_control(
            'lcp_business_blogs_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style41 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button Style
        $this->add_control(
			'lcp_business_blogs_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_business_blogs_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style41 a'
            ]
        );
        $this->add_control(
            'lcp_business_blogs_style_button_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .llc-blog-text-style41 a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    if(!empty($settings['lcp_business_blogs_category'])){
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_business_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_business_blogs_sort'],
    				'orderby'         => $settings['lcp_business_blogs_order_by'],
    				'tax_query' => array(
    				array(
    					'taxonomy'  => 'category',
    					'field'     => 'ID',
    					'terms'     => $settings['lcp_business_blogs_category'],
    					),
    				),	
    			));
    		} else {
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_business_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_business_blogs_sort'],
    				'orderby'         => $settings['lcp_business_blogs_order_by'],
    			));
    		}
        	if($settings['lcp_business_marketing_blogs_style'] == 'style_one'){
        	    if($query->have_posts() ):
            	    while($query->have_posts()): $query->the_post();
                    echo '<div class="lc-blog-box-style46">
                            <div class="lc-blogimg-style46">
                                '.get_the_post_thumbnail().'
                                <div class="lc-blog-cal-style46">
                                    <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 18 19" width="18" height="19">
                                    	<style>
                                    		.s0 { fill: #ffffff } 
                                    	</style>
                                    	<path id="Shape 13" fill-rule="evenodd" class="s0" d="m7.1 10.8v1.3c0 0.2-0.2 0.4-0.4 0.4h-1.1c-0.2 0-0.3-0.2-0.3-0.4v-1.3c0-0.2 0.1-0.3 0.3-0.3h1.1c0.2 0 0.4 0.1 0.4 0.3zm2.8 1.3c0 0.2-0.2 0.4-0.3 0.4h-1.2c-0.1 0-0.3-0.2-0.3-0.4v-1.3c0-0.2 0.2-0.3 0.3-0.3h1.2c0.1 0 0.3 0.1 0.3 0.3zm2.8 0c0 0.2-0.1 0.4-0.3 0.4h-1.1c-0.2 0-0.4-0.2-0.4-0.4v-1.2c0-0.2 0.2-0.4 0.4-0.4h1.1c0.2 0 0.3 0.2 0.3 0.4zm-5.6 1.9v1.2c0 0.2-0.2 0.4-0.4 0.4h-1.1c-0.2 0-0.3-0.2-0.3-0.4v-1.2c0-0.2 0.1-0.4 0.3-0.4h1.1c0.2 0 0.4 0.2 0.4 0.4zm2.8 1.2c0 0.2-0.2 0.4-0.3 0.4h-1.2c-0.1 0-0.3-0.2-0.3-0.4v-1.2c0-0.2 0.2-0.4 0.3-0.4h1.2c0.1 0 0.3 0.2 0.3 0.4zm2.8-1.3v1.3c0 0.2-0.1 0.3-0.3 0.3h-1.1c-0.2 0-0.4-0.1-0.4-0.3v-1.3c0-0.2 0.2-0.4 0.4-0.4h1.1c0.2 0 0.3 0.2 0.3 0.4zm3.3-8.8v11.4c0 0.7-0.6 1.4-1.3 1.4h-11.4c-0.7 0-1.3-0.7-1.3-1.4v-11.4c0-0.8 0.6-1.4 1.2-1.4v1.9c0 0.9 0.7 1.6 1.5 1.6h0.9c0.7 0 1.4-0.7 1.4-1.6v-1.9h4v1.9c0 0.9 0.7 1.6 1.4 1.6h0.9c0.8 0 1.5-0.7 1.5-1.6v-1.9c0.6 0 1.2 0.6 1.2 1.4zm-1.7 10.6v-5.8c0-0.4-0.2-0.6-0.5-0.6h-9.6c-0.3 0-0.6 0.2-0.6 0.6v5.8c0 0.4 0.3 0.7 0.6 0.7h9.6c0.3 0 0.5-0.3 0.5-0.7zm-10.1-10.1v-3.2c0-0.3 0.2-0.5 0.5-0.5h0.8c0.3 0 0.5 0.2 0.5 0.5v3.2c0 0.3-0.2 0.6-0.5 0.6h-0.8c-0.3 0-0.5-0.3-0.5-0.6zm7.7 0v-3.2c0-0.3 0.3-0.5 0.5-0.5h0.9c0.3 0 0.5 0.2 0.5 0.5v3.2c0 0.3-0.2 0.6-0.5 0.6h-0.9c-0.2 0-0.5-0.3-0.5-0.6z"/>
                                    </svg>
                                    <h4>'.get_the_date().'</h4>
                                </div>
                            </div>
                            <div class="lc-blogimg-text-style46">
                                <h4>'. substr(get_the_title(),0,100).'</h4>
                                <p>'. substr(get_the_excerpt(),0,147).'</p>
                                <div class="lc-blog-comment-style46">
                                    <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 26 26" width="26" height="26">
                                    	<style>
                                    		.date1 { fill: #ff811c } 
                                    	</style>
                                    	<path fill-rule="evenodd" class="date1" d="m22.6 22.8l1.8 2.2h-7.1c-4.1 0-7.5-3.2-7.7-7.2 4.3-0.4 7.8-3.9 8.2-8.2 4 0.2 7.2 3.6 7.2 7.7 0 2.1-0.9 4.1-2.4 5.5zm-7.4-6.2h-1.5v1.4h1.5zm2.8 0h-1.4v1.4h1.4zm2.8 0h-1.4v1.4h1.4zm-10.4-10c0.7 0 1.1 0.6 1.1 1.2 0 0.9-0.9 1.7-2.4 2.9q-0.2 0.2-0.4 0.4-0.2-0.2-0.5-0.4c-1.5-1.4-2.3-2-2.3-2.9 0-0.6 0.4-1.2 1.1-1.2 0.6 0 0.9 0.7 1 1l0.2 0.5h1l0.2-0.5c0.1-0.3 0.4-1 1-1zm0 0c0.7 0 1.1 0.6 1.1 1.2 0 0.9-0.9 1.7-2.4 2.9q-0.2 0.2-0.4 0.4-0.2-0.2-0.5-0.4c-1.5-1.4-2.3-2-2.3-2.9 0-0.6 0.4-1.2 1.1-1.2 0.6 0 0.9 0.7 1 1l0.2 0.5h1l0.2-0.5c0.1-0.3 0.4-1 1-1zm6.1 2.2c0 4.2-3.5 7.7-7.8 7.7h-7.1l1.8-2.2c-1.5-1.5-2.4-3.4-2.4-5.5 0-4.3 3.5-7.8 7.7-7.8 4.3 0 7.8 3.5 7.8 7.8zm-6.4 2.9c1.5-1.2 2.8-2.3 2.8-3.9 0-1.4-1.1-2.6-2.5-2.6-0.8 0-1.3 0.4-1.7 0.8-0.4-0.4-0.9-0.8-1.7-0.8-1.4 0-2.5 1.2-2.5 2.6 0 1.6 1.2 2.6 2.8 3.9 0.9 0.8 0.9 0.8 1.4 1.2 0.4-0.4 0.5-0.4 1.4-1.2zm-0.7-4.1l-0.2 0.5h-1l-0.2-0.5c-0.1-0.3-0.4-1-1-1-0.7 0-1.1 0.6-1.1 1.2 0 0.9 0.8 1.5 2.3 2.9q0.3 0.2 0.5 0.4 0.2-0.2 0.4-0.4c1.5-1.2 2.4-2 2.4-2.9 0-0.6-0.4-1.2-1.1-1.2-0.6 0-0.9 0.7-1 1z"/>
                                    </svg>
                                    <p>'.esc_html__('5k Like', 'leadcapture').' | '.get_comments_number().' '.esc_html__('Comments', 'leadcapture').' </p>
                                </div>
                            </div>
                       </div>';
                    endwhile;
                    wp_reset_query();
                endif;  
    		}else{
    		    if($query->have_posts() ):
            	    while($query->have_posts()): $query->the_post();
                    echo '<div class="lc-blog-box-style46 lc-boog2-box-style46">
                        <div class="lc-blogimg-style46">
                            '.get_the_post_thumbnail().'
                        </div>
                        <div class="lc-blogimg-text-style46">
                            <div class="lc-blog-cal-style46">
                                <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 18 19" width="18" height="19">
                                	<style>.s0 { fill: #ffffff } </style>
                                	<path id="Shape 13" fill-rule="evenodd" class="s0" d="m7.1 10.8v1.3c0 0.2-0.2 0.4-0.4 0.4h-1.1c-0.2 0-0.3-0.2-0.3-0.4v-1.3c0-0.2 0.1-0.3 0.3-0.3h1.1c0.2 0 0.4 0.1 0.4 0.3zm2.8 1.3c0 0.2-0.2 0.4-0.3 0.4h-1.2c-0.1 0-0.3-0.2-0.3-0.4v-1.3c0-0.2 0.2-0.3 0.3-0.3h1.2c0.1 0 0.3 0.1 0.3 0.3zm2.8 0c0 0.2-0.1 0.4-0.3 0.4h-1.1c-0.2 0-0.4-0.2-0.4-0.4v-1.2c0-0.2 0.2-0.4 0.4-0.4h1.1c0.2 0 0.3 0.2 0.3 0.4zm-5.6 1.9v1.2c0 0.2-0.2 0.4-0.4 0.4h-1.1c-0.2 0-0.3-0.2-0.3-0.4v-1.2c0-0.2 0.1-0.4 0.3-0.4h1.1c0.2 0 0.4 0.2 0.4 0.4zm2.8 1.2c0 0.2-0.2 0.4-0.3 0.4h-1.2c-0.1 0-0.3-0.2-0.3-0.4v-1.2c0-0.2 0.2-0.4 0.3-0.4h1.2c0.1 0 0.3 0.2 0.3 0.4zm2.8-1.3v1.3c0 0.2-0.1 0.3-0.3 0.3h-1.1c-0.2 0-0.4-0.1-0.4-0.3v-1.3c0-0.2 0.2-0.4 0.4-0.4h1.1c0.2 0 0.3 0.2 0.3 0.4zm3.3-8.8v11.4c0 0.7-0.6 1.4-1.3 1.4h-11.4c-0.7 0-1.3-0.7-1.3-1.4v-11.4c0-0.8 0.6-1.4 1.2-1.4v1.9c0 0.9 0.7 1.6 1.5 1.6h0.9c0.7 0 1.4-0.7 1.4-1.6v-1.9h4v1.9c0 0.9 0.7 1.6 1.4 1.6h0.9c0.8 0 1.5-0.7 1.5-1.6v-1.9c0.6 0 1.2 0.6 1.2 1.4zm-1.7 10.6v-5.8c0-0.4-0.2-0.6-0.5-0.6h-9.6c-0.3 0-0.6 0.2-0.6 0.6v5.8c0 0.4 0.3 0.7 0.6 0.7h9.6c0.3 0 0.5-0.3 0.5-0.7zm-10.1-10.1v-3.2c0-0.3 0.2-0.5 0.5-0.5h0.8c0.3 0 0.5 0.2 0.5 0.5v3.2c0 0.3-0.2 0.6-0.5 0.6h-0.8c-0.3 0-0.5-0.3-0.5-0.6zm7.7 0v-3.2c0-0.3 0.3-0.5 0.5-0.5h0.9c0.3 0 0.5 0.2 0.5 0.5v3.2c0 0.3-0.2 0.6-0.5 0.6h-0.9c-0.2 0-0.5-0.3-0.5-0.6z"/>
                                </svg>
                                <h4>'.get_the_date().'</h4>
                            </div>
                            <h4>'. substr(get_the_title(),0,100).'</h4>
                            <p>'. substr(get_the_excerpt(),0,147).'</p>
                            <div class="lc-blog-comment-style46">
                                <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 26 26" width="26" height="26">
                                	<style>
                                		.date1 { fill: #ff811c } 
                                	</style>
                                	<path fill-rule="evenodd" class="date1" d="m22.6 22.8l1.8 2.2h-7.1c-4.1 0-7.5-3.2-7.7-7.2 4.3-0.4 7.8-3.9 8.2-8.2 4 0.2 7.2 3.6 7.2 7.7 0 2.1-0.9 4.1-2.4 5.5zm-7.4-6.2h-1.5v1.4h1.5zm2.8 0h-1.4v1.4h1.4zm2.8 0h-1.4v1.4h1.4zm-10.4-10c0.7 0 1.1 0.6 1.1 1.2 0 0.9-0.9 1.7-2.4 2.9q-0.2 0.2-0.4 0.4-0.2-0.2-0.5-0.4c-1.5-1.4-2.3-2-2.3-2.9 0-0.6 0.4-1.2 1.1-1.2 0.6 0 0.9 0.7 1 1l0.2 0.5h1l0.2-0.5c0.1-0.3 0.4-1 1-1zm0 0c0.7 0 1.1 0.6 1.1 1.2 0 0.9-0.9 1.7-2.4 2.9q-0.2 0.2-0.4 0.4-0.2-0.2-0.5-0.4c-1.5-1.4-2.3-2-2.3-2.9 0-0.6 0.4-1.2 1.1-1.2 0.6 0 0.9 0.7 1 1l0.2 0.5h1l0.2-0.5c0.1-0.3 0.4-1 1-1zm6.1 2.2c0 4.2-3.5 7.7-7.8 7.7h-7.1l1.8-2.2c-1.5-1.5-2.4-3.4-2.4-5.5 0-4.3 3.5-7.8 7.7-7.8 4.3 0 7.8 3.5 7.8 7.8zm-6.4 2.9c1.5-1.2 2.8-2.3 2.8-3.9 0-1.4-1.1-2.6-2.5-2.6-0.8 0-1.3 0.4-1.7 0.8-0.4-0.4-0.9-0.8-1.7-0.8-1.4 0-2.5 1.2-2.5 2.6 0 1.6 1.2 2.6 2.8 3.9 0.9 0.8 0.9 0.8 1.4 1.2 0.4-0.4 0.5-0.4 1.4-1.2zm-0.7-4.1l-0.2 0.5h-1l-0.2-0.5c-0.1-0.3-0.4-1-1-1-0.7 0-1.1 0.6-1.1 1.2 0 0.9 0.8 1.5 2.3 2.9q0.3 0.2 0.5 0.4 0.2-0.2 0.4-0.4c1.5-1.2 2.4-2 2.4-2.9 0-0.6-0.4-1.2-1.1-1.2-0.6 0-0.9 0.7-1 1z"/>
                                </svg>
                                <p>'.esc_html__('5k Like', 'leadcapture').' | '.get_comments_number().' '.esc_html__('Comments', 'leadcapture').' </p>
                            </div>
                        </div>
                </div>';
                endwhile;
                wp_reset_query();
            endif;  
    		}
                
    		}
	}
}