<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Cardealer_Blogs extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_cardealer_blogs';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Car Dealer Blogs', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_cardealer_blog',
            [
            'label' => esc_html__('Car Dealer Blog Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'leadcapture_car_dealer_heading',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_car_dealer_description',
            [
            'label' => esc_html__('Sub Heading Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'leadcapture_blog_image',
            [
			'label' => esc_html__('Blog Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_blog_title',
            [
            'label' => esc_html__('Blog Title', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_blog_button_text',
            [
            'label' => esc_html__('Blog Button Text', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_blog_date',
            [
            'label' => esc_html__('Blog Date', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_blog_button_url',
            [
            'label' => esc_html__('Blog Button Url', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_blog_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                [
                'leadcapture_blog_title' => esc_html__('', 'leadcapture'),
                ]
            ],
            'fields'  => $repeater->get_controls(),
            'title_field' => '{{leadcapture_blog_title}}',
            ]
        ); 
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography_calender',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography_calender',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_heading_line_color',
        	[
        	'label' => esc_html__('Heading Line Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-heading-style8 > h2::after' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
       	
       	/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_blog_section_style_tab',
            [
            'label' => esc_html__('Blog Section Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Blog Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-blog-heading-fontstyle',
            ]
        );
        $this->add_control(
        	'lps_blog_heading_text_color',
        	[
        	'label' => esc_html__('Blog Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-blog-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_blog_heading_hover_color',
        	[
        	'label' => esc_html__('Blog Heading Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-blog-box-wrapper:hover .lc-blog-text >h4' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_blog_date_text_color',
        	[
        	'label' => esc_html__('Blog Date Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-news-date' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_blog_date_bg_color',
        	[
        	'label' => esc_html__('Blog Date Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-news-date' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_blog_button_text_color',
        	[
        	'label' => esc_html__('Blog Button Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-blog-text > .lc-blog-btn > a' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_blog_button_arrow_color',
        	[
        	'label' => esc_html__('Blog Button Arrow Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-blog-btn > a >svg > .s0' => 'fill: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_blog_button_hover_color',
        	[
        	'label' => esc_html__('Blog Button Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-blog-btn.lc-blog-btn-style8:hover a' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();

	}
    /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();

		echo '<div class="lc-blog-wrapper lc-blog-wrapper-style8">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-style8">';
                                if(!empty($settings['leadcapture_car_dealer_heading'])):
                                   echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_car_dealer_heading']).'</h2>';
                                endif;
                                if(!empty($settings['leadcapture_car_dealer_description'])):
                                   echo '<p class="lps-sub-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_car_dealer_description']).'</p>';
                                endif;
                        echo '</div>
                        </div>
                    </div>
                    <div class="row">';
                    if(!empty($settings['leadcapture_blog_list'])):
                        foreach($settings['leadcapture_blog_list'] as $car_list):
                            echo '<div class="col-lg-4 col-md-6 col-sm-12">
                                   <div class="lc-blog-box-wrapper lc-blog-box-style8">';
                                    if(!empty($car_list['leadcapture_blog_image']['url'])):
                                        echo '<div class="lc-blog-img lc-blog-img-style8">
                                                <img src="'.esc_url($car_list['leadcapture_blog_image']['url']).'" alt="'.esc_attr__('news-img','').'">
                                            </div>';
                                    endif;
                            echo '<div class="lc-blog-text lc-blog-text-style8">';
                                        if(!empty($car_list['leadcapture_blog_title'])):
                                            echo '<h4 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($car_list['leadcapture_blog_title']).'</h4>';
                                        endif;
                                        if(!empty($car_list['leadcapture_blog_button_text'])):
                                        echo '<div class="lc-blog-btn lc-blog-btn-style8">
                                                <a href="'.esc_url($car_list['leadcapture_blog_button_url']).'">'.esc_html($car_list['leadcapture_blog_button_text']).'
                                                <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 14" width="16" height="14">
                                                <path id="Shape 11" class="s0" d="m2.7 6.2q0.1 0 0.2 0h8.4l-0.1-0.1q-0.3-0.1-0.5-0.4l-2.4-2.3c-0.3-0.2-0.4-0.7-0.1-1.1 0.2-0.3 0.8-0.4 1.2-0.1q0 0 0.1 0l4.2 4.2c0.4 0.3 0.4 0.8 0 1.2q0 0 0 0l-4.2 4.1c-0.4 0.4-0.9 0.4-1.3 0q0 0 0 0c-0.3-0.4-0.2-0.9 0.1-1.2l2.4-2.3q0.2-0.1 0.4-0.3l0.2-0.1h-8.4c-0.4 0-0.8-0.3-0.9-0.7-0.1-0.4 0.3-0.9 0.7-0.9z"/>
                                                </svg>
                                                </a>
                                             </div>';
                                        endif;
                                        if(!empty($car_list['leadcapture_blog_date'])):
                                            echo '<div class="lc-news-date lc-news-date-style8">
                                                   <p>'.esc_html($car_list['leadcapture_blog_date']).'</p>
                                                 </div>';
                                        endif;
                            echo '</div>
                                </div>
                            </div>';
                           endforeach;  
                        endif;   
              echo '</div>
                </div>
            </div>';
	    }
}