<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;
// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();
/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Cardealer_Products extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_cardealer_products';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Car Dealer Products', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        
	    $this->start_controls_section(
            'leadcapture_cardealer_blog',
            [
            'label' => esc_html__('Car Dealer Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_car_dealer_heading',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_car_dealer_description',
            [
            'label' => esc_html__('Sub Heading Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_car_dealer_btn_title',
            [
            'label' => esc_html__('Button Title', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_car_dealer_btn_link',
            [
            'label' => esc_html__('Button Link', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_product_title',
            [
            'label' => esc_html__('Product Title', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_real_price',
            [
            'label'  => esc_html__('Real Price', 'leadcapture' ),
            'type'   => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_sale_price',
            [
            'label' => esc_html__('Sale Price', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_product_image',
            [
			'label' => esc_html__('Product Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_product_review',
            [
			'label' => esc_html__('Product Review Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $this->add_control(
            'leadcapture_product_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                [
                'leadcapture_product_title'  => esc_html__('', 'leadcapture'),
                'leadcapture_real_price'  => esc_html__('', 'leadcapture'),
                'leadcapture_real_price'  => esc_html__('', 'leadcapture'),
                ]
            ],
            'fields'      => $repeater->get_controls(),
            'title_field' => '{{leadcapture_product_title}}',
            ]
        );
        // Use car
        $repeater = new Repeater();
        $repeater->add_control(
            'leadcapture_product_usecar_title',
            [
            'label' => esc_html__('Use Car Product Title', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_real_usecar_price',
            [
            'label'  => esc_html__('Use Car Real Price', 'leadcapture' ),
            'type'   => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_sale_usecar_price',
            [
            'label' => esc_html__('Use Car Sale Price', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_product_usecar_image',
            [
			'label' => esc_html__('Use Car Product Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_product_usecar_review',
            [
			'label' => esc_html__('Use Car Product Review Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $this->add_control(
            'leadcapture_product_usecar_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                [
                'leadcapture_product_usecar_title'  => esc_html__('', 'leadcapture'),
                'leadcapture_real_usecar_price'  => esc_html__('', 'leadcapture'),
                'leadcapture_sale_usecar_price'  => esc_html__('', 'leadcapture'),
                ]
            ],
            'fields'      => $repeater->get_controls(),
            'title_field' => '{{leadcapture_product_usecar_title}}',
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_heading_underline_color',
        	[
        	'label' => esc_html__('Heading Under Line Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-heading-style8 > h2::after' => 'background-color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_tab_active_buttonbg_color',
        	[
        	'label' => esc_html__('Product Active Tab Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-nav-tabs-wrapper > .nav-tabs > .nav-item > .nav-link.active' => 'background-color: {{VALUE}}',
        	  ],
        	]
        ); 
       	$this->end_controls_section();
       	
       	// Button
       	$this->start_controls_section(
            'lps_car_deler_style_tab',
            [
            'label' => esc_html__('Button Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lps_car_deler_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-view-style8 a',
            ]
        );
        $this->add_control(
            'lps_car_deler_button_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-btn-view-style8' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->start_controls_tabs( 'button_settings' );
        $this->start_controls_tab(
			'lps_car_deler_button_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lps_car_deler_button_tcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-view-style8 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lps_car_deler_button_border',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-view-style8',
            ]
        );
		$this->add_control(
            'lps_car_deler_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [ 
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-view-style8' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lps_car_deler_button_bt_bg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-view-style8' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lps_car_deler_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lps_car_deler_button_htcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-view-style8:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lps_car_deler_button_hborder',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-view-style8:hover',
            ]
        );
		$this->add_control(
            'lps_car_deler_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-view-style8:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lps_car_deler_button_bt_hbg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-view-style8:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
       	
       	
       	
    }
 	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-most-search-wrapper lc-most-search-wrapper-style8">
                    <div class="container">
                        <div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-heading-wrapper lc-heading-style8">';
                                    if(!empty($settings['leadcapture_car_dealer_heading'])):
                                        echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_car_dealer_heading']).'</h2>';
                                    endif;
                                    if(!empty($settings['leadcapture_car_dealer_description'])):
                                        echo '<p class="lps-sub-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_car_dealer_description']).'</p>';
                                    endif; 
                        echo '</div>
                            </div>
                        </div>
                        <div class="lc-msearch-icon-wrapper">
                            <div class="row">
                                <div class="col-lg-12 col-xl-12">
                                    <div class="lc-nav-tabs-wrapper">
                                        <ul class="nav nav-tabs">';
                                        if(!empty($settings['leadcapture_product_usecar_list'])):
                                            echo '<li class="nav-item">
                                                   <a class="nav-link active" data-bs-toggle="tab" aria-current="page" href="#new-car">'.esc_html__('New Car','leadcapture').'</a>
                                                 </li>';
                                        endif;
                                        if(!empty($settings['leadcapture_product_usecar_list'])):
                                            echo '<li class="nav-item">
                                                    <a class="nav-link" data-bs-toggle="tab" href="#used-car">'.esc_html__('Used Car','leadcapture').'</a>
                                                  </li>';
                                        endif;
                                        echo '</ul>
                                        <div class="tab-content">
                                            <div id="new-car" class="container tab-pane active">
                                                <div class="row">';
                                                if(!empty($settings['leadcapture_product_list'])):
                                                    foreach($settings['leadcapture_product_list'] as $product_de):
                                                        echo '<div class="col-lg-3 col-md-6 col-sm-12">
                                                               <div class="lc-car-box-wrapper">';
                                                                if(!empty($product_de['leadcapture_product_image']['url'])):
                                                                    echo '<img src="'.esc_url($product_de['leadcapture_product_image']['url']).'" alt="'.esc_attr__('Product List','leadcapture').'">';
                                                                endif;
                                                        echo '<div class="lc-car-box-text">';
                                                                if(!empty($product_de['leadcapture_product_review']['url'])):
                                                                    echo '<div class="lc-car-box-star-rating">'; 
                                                                    echo '<img src="'.esc_url($product_de['leadcapture_product_review']['url']).'" alt="'.esc_attr__('Product List','leadcapture').'">';
                                                                    echo '</div>';
                                                                endif;
                                                                if(!empty($product_de['leadcapture_product_title'])):
                                                                    echo '<h2 class="lps-heading-fontstyle">'.esc_html($product_de['leadcapture_product_title']).'</h2>';
                                                                endif;
                                                                echo '<p class="lps-heading-fontstyle">';
                                                                if(!empty($product_de['leadcapture_real_price'])):
                                                                   echo esc_html($product_de['leadcapture_real_price']);
                                                                endif;
                                                                if(!empty($product_de['leadcapture_sale_price'])):
                                                                    echo esc_html__('-','leadcapture');
                                                                    echo esc_html($product_de['leadcapture_sale_price']);
                                                                 endif;
                                                                echo '</p>';
                                                        echo '</div>
                                                        </div>
                                                    </div>';
                                            endforeach;
                                        endif;
                                    echo '</div>
                                        </div>
                                        <div id="used-car" class="container tab-pane fade">
                                            <div class="row">';
                                                if(!empty($settings['leadcapture_product_usecar_list'])):
                                                    foreach($settings['leadcapture_product_usecar_list'] as $product_used_de):
                                                        echo '<div class="col-lg-3 col-md-6 col-sm-12">
                                                        <div class="lc-car-box-wrapper">';
                                                        if(!empty($product_used_de['leadcapture_product_usecar_image']['url'])):
                                                            echo '<img src="'.esc_url($product_used_de['leadcapture_product_usecar_image']['url']).'" alt="'.esc_attr__('Product List','leadcapture').'">';
                                                        endif;
                                                        echo '<div class="lc-car-box-text">';
                                                            if(!empty($product_used_de['leadcapture_product_review']['url'])):
                                                                echo '<div class="lc-car-box-star-rating">';
                                                                echo '<img src="'.esc_url($product_used_de['leadcapture_product_review']['url']).'" alt="'.esc_attr__('Product List','leadcapture').'">';
                                                                echo '</div>';
                                                            endif;
                                                        if(!empty($product_used_de['leadcapture_product_usecar_title'])):
                                                            echo '<h2>'.esc_html($product_used_de['leadcapture_product_usecar_title']).'</h2>';
                                                        endif;
                                                        echo '<p>';
                                                            if(!empty($product_used_de['leadcapture_real_usecar_price'])):
                                                                echo esc_html($product_used_de['leadcapture_real_usecar_price']);
                                                            endif;
                                                            if(!empty($product_used_de['leadcapture_sale_usecar_price'])):
                                                                echo esc_html__('-','leadcapture');
                                                                echo esc_html($product_used_de['leadcapture_sale_usecar_price']);
                                                            endif;
                                                        echo '</p>';
                                                echo '</div>
                                                    </div>
                                               </div>';
                                            endforeach;                                 
                                        endif;
                                    echo '</div>
                                       </div>
                                    </div>
                                </div>
                            </div>';
                            if(!empty($settings['leadcapture_car_dealer_btn_title'])){
                                echo '<div class="row">
                                    <div class="col-lg-12 col-sm-12 col-md-12">
                                        <div class="lc-btn lc-btn-view-style8">
                                            <a href="'.esc_url($settings['leadcapture_car_dealer_btn_link']).'">'.esc_html($settings['leadcapture_car_dealer_btn_title']).'</a>
                                        </div>
                                    </div>
                                </div>';
                            }
                        echo '</div>
                    </div>
                </div>
            </div>';
	}
}