<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;
// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Charity_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_charity_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Charity Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_charity',
            [
             'label' => esc_html__('Charity Banner Settings', 'leadcapture' ),
            ] 
        ); 
        $this->add_control(
            'leadcapture_logo_image',
            [
			'label' => esc_html__('Logo Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_charity_sub_head',
            [
            'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_charity_heading',
            [
            'label'       => esc_html__('Heading', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_charity_form_box_head',
            [
            'label'       => esc_html__('Form Box Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_charity_description',
            [
            'label'       => esc_html__('Form Box Description', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_email_icon_add',
            [
			 'label'       => esc_html__('Email Icon Form', 'leadcapture'),
             'type'        => Controls_Manager::MEDIA,
             'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_charity_banner_formshortcode',
            [
            'label'       => esc_html__('Form Shortcode', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_charity_button_text',
            [
            'label'       => esc_html__('Button Text', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_charity_button_url',
            [
            'label' => esc_html__('Button Url', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_left_image_add',
            [
			 'label'       => esc_html__('Left Image Add', 'leadcapture'),
             'type'        => Controls_Manager::MEDIA,
             'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_right_image_add',
            [
			 'label'  => esc_html__('Right Image Add', 'leadcapture'),
             'type'   => Controls_Manager::MEDIA,
             'label_block' => true,
			]
        );
       $this->end_controls_section();
       
       /** 
        * Lead Captur Style Tab
        */
        $this->start_controls_section(
        	'lps_heading_style_tab',
        	[
        	'label' => esc_html__('Style Tab', 'leadcapture'),
        	'tab'   => Controls_Manager::TAB_STYLE,
        	]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Heading Typography', 'leadcapture'),
        	'name'     => 'lps_heading_typography',
        	'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
        	]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
        	'name'     => 'lps_sub_heading_typography',
        	'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
    		'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_form_heading_text_color',
        	[
    		'label' => esc_html__('Form Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .add-form-heading-text-colors' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_text_color',
        	[
    		'label' => esc_html__('Button Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .lc-btn' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->add_control(
        	'lps_button_background_color',
        	[
    		'label' => esc_html__('Button Background Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .lc-btn' => 'background-color: {{VALUE}}',
        		],
        	]
        );
        $this->end_controls_section();
    }
    /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-header-wrapper lc-header-wrapper-style9">
        	    <div class="container-fluid">
        		   <div class="lc-banner-section lc-banner-section-style9">
        			<div class="row">';
        			echo '<div class="col-lg-5">';
        			if(!empty($settings['leadcapture_left_image_add']['url'])):
        				echo '<div class="lc-banner-img-wrapper lc-banner-img-style9 " >
        					  <img src="'.esc_url($settings['leadcapture_left_image_add']['url']).'" alt="'.esc_attr__('bg-img1','leadcapture').'">
        					</div>';
        			endif;
    			echo '</div>
    				 <div class="col-lg-7 col-sm-12 col-md-12">
    					<div class="lc-banner-text lc-banner-text-style9">';
    					if(!empty($settings['leadcapture_logo_image']['url'])):
    						echo '<div class="lc-logo-img lc-logo-img-style9">
    							 <img src="'.esc_url($settings['leadcapture_logo_image']['url']).'" alt="'.esc_attr__('bg-img1','leadcapture').'">
    							</div>';
    					endif;
    					if(!empty($settings['leadcapture_charity_sub_head'])):
    					   echo '<h2 class="lps-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_charity_sub_head']).'</h2>';
    					endif;
    					if(!empty($settings['leadcapture_charity_heading'])):
    					  echo '<h1 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_charity_heading']).'</h1>';
    					endif; 
    					if(!empty($settings['leadcapture_charity_button_text'])):
    						echo '<div class="lc-btn lc-btn-donate-style9">
    								<a href="'.esc_url($settings['leadcapture_charity_button_url']).'">'.esc_html($settings['leadcapture_charity_button_text']).'</a>
    							</div>'; 
    					endif;
    					echo '<div class="lc-search-section lc-search-section-style9">
    							<div class="lc-domain-text lc-domain-text-style9">';
    							if(!empty($settings['leadcapture_charity_form_box_head'])):
    								echo '<h1 class="lps-heading-fontstyle add-form-heading-text-colors">'.esc_html($settings['leadcapture_charity_form_box_head']).'</h1>';
    							endif;
    							if(!empty($settings['leadcapture_charity_description'])):
    								echo '<p class="lps-sub-heading-fontstyle">'.esc_html($settings['leadcapture_charity_description']).'</p>';
    							endif;  
    					echo '</div>';
    					if(!empty($settings['leadcapture_charity_banner_formshortcode'])):
    							echo '<div class="lc-search-wrapper lc-search-wrapper-style9">';
    									if(!empty($settings['leadcapture_email_icon_add']['url'])):
    									echo '<img src="'.esc_url($settings['leadcapture_email_icon_add']['url']).'" alt="'.esc_attr__('bg-img1','leadcapture').'">';
    									endif;
    								   echo do_shortcode($settings['leadcapture_charity_banner_formshortcode']);
    							echo '</div>';
    					endif; 
    					echo '</div>
    					</div>';
    					if(!empty($settings['leadcapture_right_image_add']['url'])):
    						echo '<div class="lc-banner-bg-img">
    								<img src="'.esc_url($settings['leadcapture_right_image_add']['url']).'" alt="'.esc_attr__('bg-img1','leadcapture').'">
    							</div>';
    					endif;
    			echo '</div>
    				</div>
    			 </div>
               </div>
            </div>';
	}
}