<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Charity_Service extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_charity_service';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Charity Service', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__( 'Service Settings', 'leadcapture'),
            ] 
        );
		$this->add_control(
            'leadcapture_as_sub_head',
            [
            'label' => esc_html__( 'Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( 'About Our Salon', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_as_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('About Our Salon', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
        
        $repeater->add_control(
            'services_image',
            [
            'label' => esc_html__('Services Icon', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $repeater->add_control(
            'leadcapture_service_title',
            [
            'label' => esc_html__('Service Title', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_service_descreption',
            [
            'label' => esc_html__('Service Descreption', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_service_button_text',
            [
            'label' => esc_html__('Service Button Text', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_service_button_url',
            [
            'label' => esc_html__('Service Button Url', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_service_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_service_title'  => esc_html__('', 'leadcapture'),
					'leadcapture_service_descreption'  => esc_html__('', 'leadcapture'),
					]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_service_title}}',
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
       	/** 
         * Lead Captur Service Section
         */
        $this->start_controls_section(
            'lps_service_style_tab',
            [
            'label' => esc_html__('Service Section Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Service Heading Typography', 'leadcapture'),
            'name'     => 'lps_service_heading_typography',
            'selector' => '{{WRAPPER}} .lps-service-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Service Description Typography', 'leadcapture'),
            'name'     => 'lps_service_description_typography',
            'selector' => '{{WRAPPER}} .lps-service-description-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_service_heading_text_color',
        	[
        	'label' => esc_html__('Service Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-service-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_service_background_hover_color',
        	[
        	'label' => esc_html__('Service Box Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-charity-box::after' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_service_heading_hover_color',
        	[
        	'label' => esc_html__('Service Heading Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-charity-box:hover h3' => 'color: {{VALUE}}',
        	 ],
           ]
        );   
        $this->add_control(
        	'lps_service_box_line_hover_color',
        	[
        	'label' => esc_html__('Service Box Line Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-service-box-wrapper:after' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );  
        $this->add_control(
        	'lps_service_description_text_color',
        	[
        	'label' => esc_html__('Service Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-service-description-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Service Button Typography', 'leadcapture'),
            'name'     => 'lps_button_heading_typography',
            'selector' => '{{WRAPPER}} .lps-service-button-fontstyle',
            ]
        );
        $this->add_control(
        	'lps_service_button_text_color',
        	[
        	'label' => esc_html__('Service Button Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-service-button-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        ); 
        $this->add_control(
        	'lps_service_button_line_color',
        	[
        	'label' => esc_html__('Service Button Line Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-charity-box::after' => 'background-color: {{VALUE}}',
        	  ],
        	]
        ); 
       	$this->end_controls_section();
    }
    /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-our-services-section lc-our-services-section-style9">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-3 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-style9 lc-heading-charity-style9">';
                            if(!empty($settings['leadcapture_as_sub_head'])):
                                echo '<p class="add-sub-heading-text-colors add-heading-text-colors">'.esc_html($settings['leadcapture_as_sub_head']).'</p>';
                            endif;
                            if(!empty($settings['leadcapture_as_main_head'])):
                                echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_as_main_head']).'</h2>';
                            endif;
                 echo '</div>
                    </div>
                    <div class="col-lg-9 col-md-12 col-sm-12">
                        <div class="lc-charity-wrapper">';
                            if(!empty($settings['leadcapture_service_list'])):
                                foreach ($settings['leadcapture_service_list'] as $key => $values):    
                                    echo '<div class="lc-charity-box">';
                                        if(!empty($values['services_image']['url'])):
                                        echo '<img src="'.esc_url($values['services_image']['url']).'" alt="'.esc_attr__('service','leadcapture').'">';
                                        endif;
                                        if(!empty($values['leadcapture_service_title'])):
                                         echo '<h3 class="lps-service-heading-fontstyle add-service-heading-text-colors">'.esc_html($values['leadcapture_service_title']).'</h3>';
                                        endif;
                                        if(!empty($values['leadcapture_service_descreption'])):
                                        echo '<p class="lps-service-description-fontstyle add-service-description-text-colors">'.esc_html($values['leadcapture_service_descreption']).'</p>';
                                        endif;
                                        if(!empty($values['leadcapture_service_button_text'])):
                                        echo '<a href="'.esc_url($values['leadcapture_service_button_url']).'" class="lps-service-button-fontstyle add-service-button-text-colors">'.esc_html($values['leadcapture_service_button_text']).'</a>';
                                        endif;
                                    echo '</div>';
                                endforeach;
                            endif;
                    echo '</div>
                    </div>
                </div>
            </div>
        </div>';
	}
}