<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Charity_Team extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_charity_team';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Charity Team', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
            'leadcapture_charity_team',
            [
            'label' => esc_html__('Charity Team Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_charity_team_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_charity_team_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'charity_team_profile_image',
            [
            'label' => esc_html__('Charity Team Profile Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );  
        $repeater->add_control(
            'leadcapture_charity_team_name',
            [
            'label' => esc_html__('Charity Team Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_charity_team_designation',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_charity_team_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator'   => 'before',
            'default' => [
                [
                'leadcapture_charity_team_name'  => esc_html__('', 'leadcapture'),
                ]
            ], 
            'fields'  => $repeater->get_controls(),
            'title_field' => '{{leadcapture_charity_team_name}}',
            ]
        );
        $this->end_controls_section();
        
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );  
       	$this->end_controls_section();
       	/**
       	 * Team Section List 
       	 */ 
       	$this->start_controls_section(
            'lps_team_style_tab',
            [
            'label' => esc_html__('Team Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Team Member Name Typography', 'leadcapture'),
            'name'     => 'lps_team_member_name_typography',
            'selector' => '{{WRAPPER}} .lps-team-member-name-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Text Typography', 'leadcapture'),
            'name'     => 'lps_team_member_designation_typography',
            'selector' => '{{WRAPPER}} .lps-team-member-designation-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_team_member_name_text_color',
        	[
        	'label' => esc_html__('Team Member Name Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-team-member-name-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_team_member_designation_text_color',
        	[
        	'label' => esc_html__('Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-team-member-designation-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_team_member_quote_text_color',
        	[
        	'label' => esc_html__('Slide Arrow Icon Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .swiper-button-arrow-color' => 'background: {{VALUE}} !important',
        	  ],
        	]
        ); 
        $this->end_controls_section();

	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
	    echo '<div class="lc-team-wrapper lc-team-wrapper-style9">
        		<div class="container">
        			<div class="row">
        				<div class="col-lg-12 col-md-12 col-sm-12">
        					<div class="lc-heading-wrapper lc-heading-style9">';
        					if(!empty($settings['leadcapture_charity_team_sub_head'])):
        						echo '<h3 class="lps-sub-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_charity_team_sub_head']).'</h3>';
        					endif;
        					if(!empty($settings['leadcapture_charity_team_main_head'])):
        						echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_charity_team_main_head']).'</h2>';
        					endif;
        			echo '</div>
        				</div>
        			</div>
        			<div class="lc-team-slider-wrapper">
        				<div class="row">
        					<div class="col-lg-12 col-sm-12 col-md-12">
        						<div class="lc-team-slide-wrapper">
        						<div class="swiper lc-team-slider-style9">
        							<div class="swiper-wrapper">';
        							if(!empty($settings['leadcapture_charity_team_list'])):
        								foreach ($settings['leadcapture_charity_team_list'] as $key => $values):
        								echo '<div class="swiper-slide">
        										<div class="lc-team-box lc-team-box-style9">';
        										if(!empty($values['charity_team_profile_image']['url'])):
        											echo '<div class="lc-team-box-img lc-teambox-img-style9">
        											<img src="'.esc_url($values['charity_team_profile_image']['url']).'" alt="'.esc_attr__('charity team','leadcapture').'">
        										</div>';
        										endif;
        										echo '<div class="lc-team-box-text lc-teambox-text-style9">';
        												if(!empty($values['leadcapture_charity_team_name'])):
        													echo '<h4 class="lps-team-member-name-fontstyle add-team-member-name-text-colors">'.esc_html($values['leadcapture_charity_team_name']).'</h4>';
        												endif;
        												if(!empty($values['leadcapture_charity_team_designation'])):
        													echo '<p class="lps-team-member-designation-fontstyle add-team-member-designation-text-colors">'.esc_html($values['leadcapture_charity_team_designation']).'</p>';
        												endif;
        										echo '</div>';
        								echo '</div>
        									</div>';
        								endforeach;
        							endif;   
        							echo '</div>
        							  </div>
        							<div class="swiper-pagination"></div>
        						</div>';
        						if(!empty($values['leadcapture_charity_team_name'])):
        							echo '<div class="lc-team-slider-btn">
        									<div class="swiper-button-next swiper-button-arrow-color">
        									<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 11 17" width="11" height="17">
        									<path id="Shape 12" class="s0" d="m9 9q0 0.3-0.2 0.5l-5.3 6.3q-0.2 0.2-0.5 0.2-0.2 0-0.4-0.2l-0.4-0.5q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.6l4.4-5.2-4.4-5.2c-0.3-0.3-0.3-0.8 0-1.1l0.4-0.5q0.2-0.2 0.4-0.2 0.3 0 0.5 0.2l5.3 6.3q0.2 0.2 0.2 0.5z"/>
        									</svg>
        									</div>
        									<div class="swiper-button-prev swiper-button-arrow-color">
        									<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 11 17" width="11" height="17">
        									<path id="Shape 12" class="s0" d="m2.2 8.5l5.3-6.3q0.2-0.2 0.5-0.2 0.2 0 0.4 0.2l0.4 0.5c0.3 0.3 0.3 0.8 0 1.1l-4.4 5.2 4.4 5.2q0.2 0.3 0.2 0.6 0 0.3-0.2 0.5l-0.4 0.5q-0.2 0.2-0.4 0.2-0.3 0-0.5-0.2l-5.3-6.3q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.5z"/>
        									</svg>
        									</div>
        							    </div>';
        						  endif; 
        				 echo '</div>
        			</div>
        		</div>
        	</div>
        </div>';
	}
}