<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Charity_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_Charity_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Charity Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_barber_testimonials',
            [
            'label' => esc_html__('Barber Testimonials Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_testimonials_sub_head',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$this->add_control(
            'leadcapture_testimonials_main_head',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'testimonials_profile_image',
            [
            'label' => esc_html__('Testimonials Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_name',
            [
            'label' => esc_html__('Testimonials Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_designation',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_review_image',
            [
            'label' => esc_html__('Testimonials Review Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonials_description',
            [
            'label' => esc_html__('Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_testimonials_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator'   => 'before',
            'default' => [
                [
                'leadcapture_testimonials_name'  => esc_html__('', 'leadcapture'),
                ]
            ], 
            'fields'  => $repeater->get_controls(),
            'title_field' => '{{leadcapture_testimonials_name}}',
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tabs',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
       	  /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Testimonials Content Style ', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonials Author Name Typography', 'leadcapture'),
            'name'     => 'lps_authore_name_typography',
            'selector' => '{{WRAPPER}} .lps-testimonials-heading-fontstyle',
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonials Description Typography', 'leadcapture'),
            'name'     => 'lps_testimonials_description_typography',
            'selector' => '{{WRAPPER}} .lps-testimonials-description-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_testimonials_autorname_text_color',
        	[
        	'label' => esc_html__('Testimonials Author Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonials-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_testimonials_designation_text_color',
        	[
        	'label' => esc_html__('Testimonials Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonials-designation-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_testimonials_description_text_color',
        	[
        	'label' => esc_html__('Testimonials Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-testimonials-description-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_testimonials_quote_text_color',
        	[
        	'label' => esc_html__('Testimonials Quote Icon Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-test-quote-icon-style9 > svg > .s0' => 'fill: {{VALUE}}',
        	  ],
        	]
        );
       	$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-testimonial-wrapper lc-testimonial-style9">
                <div class="container">
                    <div class="row">
                       <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="lc-heading-wrapper lc-heading-style9">';
                        if(!empty($settings['leadcapture_testimonials_sub_head'])):
                         echo '<h3 class="lps-testimonials-heading-fontstyle add-sub-heading-text-colors ">'.esc_html($settings['leadcapture_testimonials_sub_head']).'</h3>';
                        endif;
                        if(!empty($settings['leadcapture_testimonials_main_head'])):
                        echo '<h2 class="lps-sub-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_testimonials_main_head']).'</h2>';
                        endif;
                    echo '</div>
                        </div> 
                    </div>
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-testimonial-slider-wrapper">
                            <div class="swiper lc-testimonial-slider-style9">
                                <div class="swiper-wrapper">';
                                if(!empty($settings['leadcapture_testimonials_list'])):
                                foreach   ($settings['leadcapture_testimonials_list'] as $key => $values):
                                        echo '<div class="swiper-slide">
                                        <div class="lc-testimonial-box lc-testimonial-box-style9">
                                        <div class="lc-testimonial-box-img-wrapper lc-testimonial-box-img-wrapper-style9">
                                        <div class="lc-testimonial-box-img lc-testimonial-box-img-style9">';
                                        if(!empty($values['testimonials_profile_image']['url'])):
                                        echo '<img src="'.esc_url($values['testimonials_profile_image']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">';
                                        endif; 
                                        echo '<div class="btest-box-text btest-box-text-style9">';
                                        if(!empty($values['leadcapture_testimonials_name'])):
                                        echo '<h4 class="lps-testimonials-heading-fontstyle add-testimonials-heading-text-colors">'.esc_html($values['leadcapture_testimonials_name']).'</h4>';
                                        endif; 
                                        if(!empty($values['leadcapture_testimonials_designation'])):
                                        echo '<p class="lps-testimonials-description-fontstyle add-testimonials-designation-text-colors">'.esc_html($values['leadcapture_testimonials_designation']).'</p>';
                                        endif; 
                                        echo '</div>
                                            </div>
                                        </div>';
                                        if(!empty($values['leadcapture_testimonials_description'])):
                                        echo '<p class="add-testimonials-description-text-colors lps-testimonials-description-fontstyle">'.esc_html($values['leadcapture_testimonials_description']).'</p>
                                        <div class="lc-test-quote-icon lc-test-quote-icon-style9">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 48 35" width="48" height="35"><path id="Shape 7" class="s0" d="m1 12.3c0-2.9 1.3-5.7 3.5-7.7 2.3-1.9 5.3-2.8 8.4-2.6 5.5 0.6 9.7 5.3 9.6 10.9-0.3 14.3-10.8 18.8-15.3 20q-0.3 0.1-0.7 0.1c-0.7 0-1.4-0.3-1.9-1-0.5-0.8-0.4-1.9 0.2-2.6 2.2-2.3 3.8-4.7 4.8-7.2-5-0.9-8.6-5.1-8.6-9.9zm46 0.4v0.2c-0.3 14.3-10.8 18.8-15.3 20q-0.4 0.1-0.7 0.1c-0.7 0-1.4-0.3-1.9-1-0.5-0.8-0.4-1.9 0.2-2.6 2.2-2.3 3.8-4.7 4.8-7.2-5-0.9-8.6-5.1-8.6-9.9 0-2.9 1.3-5.7 3.5-7.7 2.3-1.9 5.3-2.8 8.4-2.6 5.4 0.6 9.6 5.2 9.6 10.7z"/>
                                        </svg>
                                        </div>';
                                        endif;
                                echo '</div>
                                </div>';
                             endforeach;
                            endif;  
                    echo '</div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>';
    
	}
}