<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Clothing_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_clothing_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Clothing Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_clothing',
            [
             'label' => esc_html__('Clothing Banner Settings', 'leadcapture' ),
            ] 
        ); 
        $this->add_control(
            'leadcapture_clothing_logo_image',
            [
			'label' => esc_html__('Clothing Logo Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_clothing_sub_head',
            [
            'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_clothing_heading',
            [
            'label'       => esc_html__('Heading', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_clothing_form_box_head',
            [
            'label'       => esc_html__('Form Box Heading', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_clothing_description',
            [
            'label'       => esc_html__('Form Box Description', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_clothing_email_icon_add',
            [
			 'label'       => esc_html__('Email Icon Form', 'leadcapture'),
             'type'        => Controls_Manager::MEDIA,
             'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_clothing_banner_formshortcode',
            [
            'label'       => esc_html__('Form Shortcode', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_clothing_button_text',
            [
            'label'       => esc_html__('Button Text', 'leadcapture' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_clothing_button_url',
            [
            'label' => esc_html__('Button Url', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_left_image_add',
            [
			 'label'       => esc_html__('Left Image Add', 'leadcapture'),
             'type'        => Controls_Manager::MEDIA,
             'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_right_image_add',
            [
			 'label'  => esc_html__('Right Image Add', 'leadcapture'),
             'type'   => Controls_Manager::MEDIA,
             'label_block' => true,
			]
        );
       $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-header-wrapper lc-header-wrapper-style10">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-header-text-wrapper lc-header-text-wrapper-style10">
                                <div class="lc-logo-img">
                                    <img src="assets/images/clothing/Logo.png" alt="">
                                </div>
                                <div class="lc-header-text lc-header-text-style10 ">
                                    <h3>25% off on all products</h3>
                                    <h1>Explore Fashion
                                        world</h1>
                                    <p>Subscribe Here To Get Email Updates</p>
                                    <div class="lc-search-wrapper lc-search-wrapper-style10">
                                        <div class="lc-message-icon">
                                            <img src="assets/images/clothing/message-icon.png" alt="message-icon">

                                            <input type="Email" placeholder="Enter Email Here..." class="lc-search-form"
                                                name="" id="">
                                        </div>
                                        <div class="lc-btn lc-btn-style10">
                                            <a href="#">Subscribe Now</a>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="animation-area">
                <ul class="lc-box-area">
                    <li></li>
                    <li></li>
                    <li></li>
                    <li></li>
                    <li></li>
                    <li></li>
                </ul>
            </div>';
	}
}