<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Clothing_Highlight extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_clothing_highlight';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Clothing Products', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'Product Settings', 'leadcapture' ),
            ] 
        );
        
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_product_img',
            [
				'label'       => esc_html__( 'Product Images', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
        $repeater->add_control(
            'leadcapture_product_hover_img',
            [
				'label'       => esc_html__( 'Product Hover Images', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
        $repeater->add_control(
            'leadcapture_product_rate_img',
            [
				'label'       => esc_html__( 'Small Icon Image ', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
        $repeater->add_control(
            'leadcapture_product_title',
            [
                'label'       => esc_html__( 'Product Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Product Title', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_product_title_link',
            [
                'label'       => esc_html__( 'Product Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '#', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_prod_price',
            [
                'label'       => esc_html__( 'Product Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '$50', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_prod_offer_price',
            [
                'label'       => esc_html__( 'Product Offer Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '$50', 'leadcapture' ),
            ]
        );

		$this->add_control(
            'leadcapture_product_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_product_img'  => esc_html__('Product Image', 'leadcapture'),
                    'leadcapture_product_hover_img'  => esc_html__('Product Hover Image', 'leadcapture'),
                    'leadcapture_product_rate_img'  => esc_html__('Product Samll Image', 'leadcapture'),
                    'leadcapture_product_title'  => esc_html__('Product Title', 'leadcapture'),
                    'leadcapture_product_title_link'  => esc_html__('Product Link', 'leadcapture'),
                    'leadcapture_prod_price'  => esc_html__('Product Price', 'leadcapture'),
                    'leadcapture_prod_offer_price'  => esc_html__('Product Offer Price', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_product_title}}',
            ]
        );
		$this->end_controls_section();
		
		
		
		
		/** 
        * Lead Captur Style Tab
        */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Title Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lc-top-box-text h2',
            ]
        );
        $this->add_control(
			'lps_heading_text_color',
    			[
    			'label' => esc_html__('Title Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .lc-top-box-text h2' => 'color: {{VALUE}}',
    			],
			]
		);
		 $this->add_control(
			'lps_heading_text_hover_color',
    			[
    			'label' => esc_html__('Title Hover Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .lc-top-box-text h2:hover' => 'color: {{VALUE}}',
    			],
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Price Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lc-top-box-text p, .lc-top-box-text p span',
            ]
        ); 
        $this->add_control(
			'lps_text_color',
    			[
    			'label' => esc_html__('Del Price Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .lc-top-box-text p del' => 'color: {{VALUE}}',
    			],
			]
		);
		 $this->add_control(
			'lps_price_color',
    			[
    			'label' => esc_html__('Price Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .lc-top-box-text p span' => 'color: {{VALUE}}',
    			],
			]
		);
        
       	$this->end_controls_section();
		
		
		
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-highlight-wrapper">
                <div class="container">
                    <div class="row">';
                            if(!empty($settings['leadcapture_product_list'])):
                                foreach($settings['leadcapture_product_list'] as $product):
                                    echo ' <div class="col-lg-3 col-md-6 col-sm-12">
                                                <div class="lc-top-box-wrapper">';
                                                    if(!empty($product['leadcapture_product_img']['url'])):
                                                        echo '<a href="javascript:;" class="product-img">
                                                                <img src="'.esc_url($product['leadcapture_product_img']['url']).'" alt="'.esc_attr($product['leadcapture_product_img']['alt']).'" class="lc-top-parent">
                                                                <img src="'.esc_url($product['leadcapture_product_hover_img']['url']).'" alt="'.esc_attr($product['leadcapture_product_hover_img']['alt']).'" class="lc-top-child">
                                                            </a>';
                                                    endif;
                                                    echo '<div class="lc-top-box-text">';
                                                            if(!empty($product['leadcapture_product_rate_img']['url'])):
                                                                echo '<div class="product-rating-img">
                                                                        <img src="'.esc_url($product['leadcapture_product_rate_img']['url']).'" alt="'.esc_attr($product['leadcapture_product_rate_img']['alt']).'">
                                                                    </div>';
                                                            endif;                                                           
                                                                
                                                            if(!empty($product['leadcapture_product_title'])):
                                                                echo '<h2>'.esc_html($product['leadcapture_product_title']);
                                                                echo '</h2>';
                                                            endif;

                                                            if(!empty($product['leadcapture_prod_offer_price'])):
                                                            echo '<p>';
                                                                    if(!empty($product['leadcapture_prod_price'])):
                                                                    echo '<del> '.esc_html($product['leadcapture_prod_price']).'</del>';
                                                                    endif; 
                                                            echo '<span class="m-2">-</span><span>'.esc_html($product['leadcapture_prod_offer_price']);
                                                            echo '</span></p>';
                                                            endif;
                                        echo '</div></div>
                                        </div>';
                                endforeach;
                            endif;        
                echo '</div></div></div>';
	}
}