<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Clothing_Shipping extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_clothing_shipping';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Clothing Shipping', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
		$this->add_control(
            'leadcapture_ab_sub_head',
            [
                'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_main_head',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_divider',
            [
				'label'       => esc_html__( 'Divider Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
		$this->add_control(
            'leadcapture_ab_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Our Salon Service Are sit amet, consectetur adipisicing elit, sed do eiusmod tempor iencididunt uerseit labore et dolore magna aliqua.', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_button',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Read More', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '#', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_extra_text',
            [
                'label'       => esc_html__( 'Extra Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Call To Make An Appointment From Mobile', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_big_text',
            [
                'label'       => esc_html__( 'Big Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__('Since 1995', 'leadcapture' ),
            ]
        );	
		$this->add_control(
            'leadcapture_ab_phone',
            [
                'label'       => esc_html__( 'Phone Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '+(81) 1800-15487', 'leadcapture' ),
            ]
        );	
		$this->add_control(
            'leadcapture_ab_slider_image',
			[
				'label' => esc_html__( 'Add Images', 'leadcapture' ),
				'type' => Controls_Manager::GALLERY,
				'default' => [],
				'show_label' => false,
			]
        );
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-shipping-wrapper">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-3 col-md-6 col-sm-12">
                            <div class="lc-shipping-box-wrapper">
                                <div class="lc-shipping-icon">
                                    <img src="assets/images/clothing/icon1.png" alt="">
                                </div>
                                <div class="lc-shipping-text">
                                    <h2>Free Shipping & Return</h2>
                                    <p>consectetur adipiscing elit, sed do eiusmod temporbgj incididunt ut labore dolore
                                        magna aliqua.</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12">
                            <div class="lc-shipping-box-wrapper">
                                <div class="lc-shipping-icon">
                                    <img src="assets/images/clothing/Icon2.png" alt="">
                                </div>
                                <div class="lc-shipping-text">
                                    <h2>Online Support</h2>
                                    <p>consectetur adipiscing elit, sed do eiusmod temporbgj incididunt ut labore dolore
                                        magna aliqua.</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12">
                            <div class="lc-shipping-box-wrapper">
                                <div class="lc-shipping-icon">
                                    <img src="assets/images/clothing/icon3.png" alt="">
                                </div>
                                <div class="lc-shipping-text">
                                    <h2>Secure Payments</h2>
                                    <p>consectetur adipiscing elit, sed do eiusmod temporbgj incididunt ut labore dolore
                                        magna aliqua.</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-3 col-md-6 col-sm-12">
                            <div class="lc-shipping-box-wrapper">
                                <div class="lc-shipping-icon">
                                    <img src="assets/images/clothing/Icon4.png" alt="">
                                </div>
                                <div class="lc-shipping-text">
                                    <h2>Money back Guarantee</h2>
                                    <p>consectetur adipiscing elit, sed do eiusmod temporbgj incididunt ut labore dolore
                                        magna aliqua.</p>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}