<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Construction_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_construction_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Construction Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_construction_general',
            [
            'label' => esc_html__('Construction Banner Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
        	'leadcapture_construction_banner_logo_image',
        	[
        	'label' => esc_html__('Construction Logo Image', 'leadcapture'),
        	'type'  => Controls_Manager::MEDIA,
        	'label_block' => true,
        	]
        );
        $this->add_control(
            'leadcapture_construction_banner_heading',
            [
            'label' => esc_html__('Construction Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_construction_banner_sub_head',
            [
            'label' => esc_html__('Construction Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'  => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_construction_banner_button_text',
            [
            'label' => esc_html__('Button Text', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
         $this->add_control(
            'leadcapture_construction_banner_button_url',
            [
            'label' => esc_html__('Button Url', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_construction_banner_formshortcode',
            [
            'label' => esc_html__('Form Shortcode', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_construction_formshortcode_heading',
            [
            'label' => esc_html__('Form Shortcode Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
        	'leadcapture_construction_banner_icon_image',
        	[
        	'label' => esc_html__('Construction Count Dowen Icon Image', 'leadcapture'),
        	'type' => Controls_Manager::MEDIA,
        	'label_block' => true,
        	]
        );
        $this->add_control(
            'leadcapture_construction_banner_countdowen',
            [
            'label' => esc_html__('Construction Happy Customer Number', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default'  => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_construction_banner_countdowen_heading',
            [
            'label' => esc_html__('Construction Happy Customer Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default'  => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
        	'leadcapture_construction_banner_left_image',
        	[
        	'label' => esc_html__('Construction Left Image', 'leadcapture'),
        	'type'  => Controls_Manager::MEDIA,
        	'label_block' => true,
        	]
        );
        $this->add_control(
        	'leadcapture_construction_banner_right_image',
        	[
        	'label' => esc_html__('Construction Right Image', 'leadcapture'),
        	'type'  => Controls_Manager::MEDIA,
        	'label_block' => true,
        	]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_const_banner_heading_style_tab',
            [
            'label' => esc_html__('Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_const_banner_one_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_const_banner_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_const_banner_sub_heading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-sub-heading-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Button Typography', 'leadcapture'),
            'name'     => 'lps_const_banner_two_heading_typography',
            'selector' => '{{WRAPPER}} .lps-button-fontstyle',
            ]
        );
        $this->add_control(
        	'lps_const_banner_button_text_color',
        	[
        	'label' => esc_html__('Button Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-button-text-colors' => 'color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_const_banner_button_background_color',
        	[
        	'label' => esc_html__('Button Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .add-button-background-colors' => 'background-color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_control(
        	'lps_const_banner_button_hover_color',
        	[
        	'label' => esc_html__('Button Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-btn-donate-style11:hover a' => 'color: {{VALUE}}',
        	  ],
        	]
        ); 
        $this->add_control(
        	'lps_const_banner_button_border_color',
        	[
        	'label' => esc_html__('Button Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-btn-donate-style11:hover' => 'border-color: {{VALUE}}',
        	  ],
        	]
        ); 
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Form Heading Typography', 'leadcapture'),
            'name'     => 'lps_const_banner_form_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
        $this->add_control(
        	'lps_const_banner_form_heading_text_color',
        	[
        	'label' => esc_html__('Form Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-form-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
	}
	
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-header-wrapper lc-header-wrapper-style11">
                <div class="container-fluid">';
                if(!empty($settings['leadcapture_construction_banner_logo_image']['url'])):
                    echo '<div class="lc-header-section lc-header-section-style11">
                            <div class="lc-logo-img lc-logo-img-style6">
                                <img src="'.esc_url($settings['leadcapture_construction_banner_logo_image']['url']).'" alt="'.esc_attr__('logo-img','leadcapture').'">
                            </div>
                        </div>';
                endif;
               echo '<div class="lc-banner-section lc-banner-section-style11">
                        <div class="row">';
                        if(!empty($settings['leadcapture_construction_banner_left_image']['url'])):
                            echo '<div class="col-lg-5 col-md-12 col-sm-12">
                            <div class="lc-banner-img-wrapper lc-banner-img-style11">';
                            if(!empty($settings['leadcapture_construction_banner_left_image']['url'])):   
                               echo '<img src="'.esc_url($settings['leadcapture_construction_banner_left_image']['url']).'" alt="'.esc_attr__('logo-img','leadcapture').'">';
                            endif;      
                            echo '<div class="lc-banner-icon-style11">';
                            if(!empty($settings['leadcapture_construction_banner_icon_image']['url'])):
                               echo '<img src="'.esc_url($settings['leadcapture_construction_banner_icon_image']['url']).'" alt="'.esc_attr__('logo-img','leadcapture').'">';
                            endif;
                            if(!empty($settings['leadcapture_construction_banner_countdowen'])):
                              echo '<h2 class="lps-heading-fontstyle">'.esc_html($settings['leadcapture_construction_banner_countdowen']).'</h2>';
                            endif;
                            if(!empty($settings['leadcapture_construction_banner_countdowen_heading'])):
                               echo '<p class="lps-sub-heading-fontstyle">'.esc_html($settings['leadcapture_construction_banner_countdowen_heading']).'</p>';
                            endif;
                        echo '</div>
                            </div>
                        </div>';
                        endif;   
                        echo '<div class="col-lg-7 col-sm-12 col-md-12">
                                <div class="row">
                                    <div class="col-lg-7 col-md-6 col-sm-12">
                                        <div class="lc-banner-text lc-banner-text-style11">';
                                        if(!empty($settings['leadcapture_construction_banner_heading'])):
                                        echo '<h2 id="kv_bannertext" class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_construction_banner_heading']).'</h2>';
                                        endif;
                                        if(!empty($settings['leadcapture_construction_banner_sub_head'])):
                                        echo '<p class="lps-heading-fontstyle add-sub-heading-text-colors">'.esc_html($settings['leadcapture_construction_banner_sub_head']).'</p>';
                                        endif;
                                        if(!empty($settings['leadcapture_construction_banner_button_text'])):
                                        echo '<div class="lc-btn lc-btn-donate-style11 add-button-background-colors">
                                          <a href="'.esc_url($settings['leadcapture_construction_banner_button_url']).'" class="lps-button-fontstyle add-button-text-colors">'.esc_html($settings['leadcapture_construction_banner_button_text']).'</a>
                                        </div>';
                                    endif;    
                                    echo '</div>
                                    </div>';
                                    if(!empty($settings['leadcapture_construction_banner_right_image']['url'])):
                                    echo '<div class="col-lg-5 col-md-6 col-sm-12">
                                            <div class="lc-banner-img-wrapper lc-banner-img-wrapper-style11">
                                               <img src="'.esc_url($settings['leadcapture_construction_banner_right_image']['url']).'" alt="'.esc_attr__('right image','leadcapture').'">
                                            </div>
                                         </div>
                                    </div>';
                                    endif; 
                                    if(!empty($settings['leadcapture_construction_banner_formshortcode'])):  
                                        echo '<div class="lc-subscribe lc-subscribe-style11">
                                            <div class="lc-subscribe-form lc-subscribe-form-style11">';
                                            if(!empty($settings['leadcapture_construction_formshortcode_heading'])):
                                            echo '<h2 class="lps_form_heading_typography add-form-heading-text-colors">'.esc_html($settings['leadcapture_construction_formshortcode_heading']).'</h2>';
                                                endif;
                                            echo '<div class="lc-sub-form lc-sub-form-style11">
                                                '.do_shortcode($settings['leadcapture_construction_banner_formshortcode']).'
                                                </div>
                                            </div>
                                        </div>';
                                    endif;
                            echo '</div>
                             </div>
                         </div>
                     </div>
                 </div>';
	}
}