<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Construction_Project extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_construction_project';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Construction Project', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
	    $this->start_controls_section(
            'leadcapture_construction_general',
            [
            'label' => esc_html__('Construction Settings', 'leadcapture' ),
            ] 
        );
    
        $this->add_control(
            'leadcapture_construction_main_head',
            [
            'label'  => esc_html__('Construction Heading', 'leadcapture' ),
            'type'   => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'  => esc_html__('', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
    	$repeater->add_control(
            'leadcapture_image',
            [
    		'label'       => esc_html__( 'Icon Image', 'leadcapture' ),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,
    		]
        );
    	$repeater->add_control(
            'leadcapture_title',
            [
            'label' => esc_html__( 'Title', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
    	$repeater->add_control(
            'leadcapture_descreption',
            [
            'label'       => esc_html__('Description', 'leadcapture' ),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__('', 'leadcapture' ),
            ]
        );
    	$repeater->add_control(
            'leadcapture_read_more_text',
            [
            'label' => esc_html__( 'Read More Text', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_read_more_url',
            [
            'label' => esc_html__( 'Read More Url', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
    	$this->add_control(
            'leadcapture_product_list',
            [
            'type'        => Controls_Manager::REPEATER,
            'seperator'   => 'before',
            'default'     => [
                [	
				'leadcapture_title'  => esc_html__( '', 'leadcapture' ),
                'leadcapture_descreption'  => esc_html__( '', 'leadcapture' ),
				'leadcapture_read_more_text'  => esc_html__( '', 'leadcapture' ),
                'leadcapture_read_more_url'  => esc_html__( '#', 'leadcapture' ),
                ]
            ],
            'fields' => $repeater->get_controls(),
            'title_field' => '{{leadcapture_title}}',
            ]
        );
    
        $this->add_control(
            'leadcapture_view_more_text',
            [
            'label'  => esc_html__( 'View More Text', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default'  => esc_html__('View More', 'leadcapture' ),
            ]
        );
    
        $this->add_control(
            'leadcapture_view_more_url',
            [
            'label' => esc_html__( 'View More Page Url', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->end_controls_section();
    	/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
    	$this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
       	/** 
         * Project List Style
         */
        $this->start_controls_section(
            'lps_cons_project_style_tab',
            [
            'label' => esc_html__('Project List Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        ); 
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Project Heading Typography', 'leadcapture'),
            'name'     => 'lps_cons_project_heading_typography',
            'selector' => '{{WRAPPER}} .lps-project-heading-fontstyle',
            ]
        );
    	$this->add_control(
        	'lps_cons_project_one_heading_text_color',
        	[
        	'label' => esc_html__('Project Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-project-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cons_project_heading_hover_color',
        	[
        	'label' => esc_html__('Project Heading Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-shipping-box-wrapper-style11:hover .lc-shipping-text-style11 h2' => 'color: {{VALUE}}',
        	 ],
           ]
        ); 
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Project Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_project_description_typography',
            'selector' => '{{WRAPPER}} .lps-project-description-fontstyle',
            ]
        );
    	$this->add_control(
        	'lps_cons_project_two_heading_text_color',
        	[
        	'label' => esc_html__('Project Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-project-description-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Project Button Typography', 'leadcapture'),
            'name'     => 'lps_cons_project_button_typography',
            'selector' => '{{WRAPPER}} .lps-project-button-fontstyle',
            ]
        );
       $this->add_control(
        	'lps_cons_project_button_text_color',
        	[
        	'label' => esc_html__('Project Button Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-project-button-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cons_project_one_button_line_color',
        	[
        	'label' => esc_html__('Project Button Line Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-shipping-text-style11 a:before' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
         $this->add_control(
        	'lps_cons_project_two_button_line_color',
        	[
        	'label' => esc_html__('Project Button Line Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-shipping-text-style11 a:before' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
        
       	$this->end_controls_section();
	} 
    /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-project-section">
                <div class="container">
                    <div class="row">';
                    if(!empty($settings['leadcapture_construction_main_head'])):
                        echo '<div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-heading-wrapper lc-heading-style11">
                                    <h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_construction_main_head']).'</h2>
                                </div>
                            </div>';
                    endif;
                    echo '</div>
                    <div class="row">';
                    if(!empty($settings['leadcapture_product_list'])):
                        foreach ($settings['leadcapture_product_list'] as $key => $values ):
                            echo '<div class="col-lg-3 col-md-6 col-sm-12">
                                  <div class="lc-shipping-box-wrapper lc-shipping-box-wrapper-style11">';
                                    if(!empty($values['leadcapture_image']['url'])):
                                       echo '<div class="lc-shipping-icon lc-shipping-icon-style11">
                                        <img src="'.esc_url($values['leadcapture_image']['url']).'" alt="'.esc_attr__('product','leadcapture').'">
                                        </div>';
                                    endif;    
                                    echo '<div class="lc-shipping-text lc-shipping-text-style11">';
                                    if(!empty($values['leadcapture_title'])):  
                                    echo '<h2 class="add-project-heading-text-colors lps-project-heading-fontstyle">'.esc_html($values['leadcapture_title']).'</h2>';
                                    endif;   
                                    if(!empty($values['leadcapture_descreption'])):
                                    echo '<p class="add-project-description-text-colors lps-project-description-fontstyle">'.esc_html($values['leadcapture_descreption']).'</p>';
                                    endif;  
                                if(!empty($values['leadcapture_read_more_text'])):
                                    echo '<a href="'.esc_url($values['leadcapture_read_more_url']).'" class="lps-project-button-fontstyle add-project-button-text-colors">'.esc_html($values['leadcapture_read_more_text']).'</a>';
                                endif;
                            echo '</div>
                                </div>
                            </div>';
                         endforeach;
                    endif;
             echo '</div>
                </div>
           </div>'; 
	}
}