<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Construction_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_construction_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Construction Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );
        
      	$this->add_control(
            'leadcapture_tm_main_head',
            [
            'label' => esc_html__( 'Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_testi',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
		/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_one_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_one_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_three_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Name Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_two_heading_typography',
            'selector' => '{{WRAPPER}} .lps-testimonial-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonial-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_heading_typography',
            'selector' => '{{WRAPPER}} .lps-testimonial-description-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonial-description-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_designation_typography',
            'selector' => '{{WRAPPER}} .lps-testimonial-designation-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_two_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonial-designation-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cons_testi_designation_bg_color',
        	[
        	'label' => esc_html__('Testimonial Designation Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-testimonial-designation-bg-colors' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cons_testi_designation_hover_color',
        	[
        	'label' => esc_html__('Testimonial Designation Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-test-box-style11:hover .lc-designer' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
        $this->add_control(
        	'lps_cons_testi_quote_color',
        	[
        	'label' => esc_html__('Testimonial Quote Icon Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-test-box-style11 .lc-test-quote-icon-style11>svg>.s0' => 'fill: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cons_testi_quote_hover_color',
        	[
        	'label' => esc_html__('Testimonial Quote Hover Icon Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-test-box-style11:hover .lc-test-quote-icon-style11>svg>.s0' => 'fill: {{VALUE}}',
        	 ],
           ]
        );
          
        $this->add_control(
        	'lps_cons_testi_pagination_color',
        	[
        	'label' => esc_html__('Testimonial Pagination Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testimonial-slider-style11 .swiper-pagination  .swiper-pagination-bullet-active' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
        echo '<div class="lc-testimonial-wrapper lc-testimonial-style11">
                <div class="container">';
                if(!empty($settings['leadcapture_tm_main_head'])):
                        echo '<div class="row">
                               <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-heading-wrapper lc-heading-text-style11">';
                                if(!empty($settings['leadcapture_tm_main_head'])):
                                  echo '<h2 class="lps-heading-fontstyle add-heading-text-colors">'.esc_html($settings['leadcapture_tm_main_head']).'</h2>';
                                endif;
                        echo '</div>
                        </div>
                    </div>';
                endif;
            echo '<div class="row">
                    <div class="col-lg-12 col-md-12">
                        <div class="lc-testimonial-slider-wrapper">
                            <div class="swiper lc-testimonial-slider-style11">';
                            if(!empty($settings['leadcapture_testimonial_list'])):
                            echo '<div class="swiper-wrapper">';
                                foreach($settings['leadcapture_testimonial_list'] as $testi):
                                   
                                echo '<div class="swiper-slide">
                                      <div class="lc-test-box lc-test-box-style11 ">';
                                        if(!empty($testi['leadcapture_testimonial_image']['url'])):  
                                        echo '<div class="lc-test-img lc-test-img-style11">
                                              <img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr('construction','leadcapture').'">
                                             </div>';
                                        endif;
                                echo '<div class="lc-test-text">';
                                            if(!empty($testi['leadcapture_testimonial_testi'])):
                                          echo '<div class="lc-test-para lc-test-para-style11">
                                                  <p class="lps-testimonial-description-fontstyle add-testimonial-description-text-colors">'.esc_html($testi['leadcapture_testimonial_testi']).'</p>
                                                </div>';
                                            endif;
                                echo '<div class="lc-test-name lc-test-name-style11">';
                                        if(!empty($testi['leadcapture_testimonial_author'])):
                                            echo '<h6 class="lps-testimonial-heading-fontstyle add-testimonial-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h6>';
                                        endif;        
                                        if(!empty($testi['leadcapture_testimonial_dest'])):
                                            echo '<div class="lc-designer add-testimonial-designation-bg-colors ">
                                                   <p class="lps-testimonial-description-fontstyle add-testimonial-designation-text-colors lps-testimonial-designation-fontstyle">'.esc_html($testi['leadcapture_testimonial_dest']).'</p>
                                                 </div>';
                                        endif;
                                        echo '</div>
                                        </div>
                                        <div class="lc-test-quote-icon lc-test-quote-icon-style11">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 51 36" width="51" height="36">
                                        <path id="Shape 2" class="s0"
                                         d="m0 11.9c0-3.3 1.4-6.6 3.9-8.8 2.5-2.3 5.9-3.4 9.3-3.1 6.1 0.7 10.8 6.2 10.7 12.6-0.4 16.7-12.1 21.9-17 23.3q-0.4 0.1-0.8 0.1c-0.8 0-1.6-0.4-2.1-1.1-0.6-1-0.5-2.2 0.3-3.1 2.3-2.7 4.1-5.5 5.2-8.3-5.5-1-9.5-6-9.5-11.6zm51 0.5v0.2c-0.3 16.7-12 21.9-17 23.3q-0.4 0.1-0.7 0.1c-0.9 0-1.6-0.4-2.1-1.1-0.6-1-0.5-2.2 0.2-3.1 2.4-2.7 4.1-5.5 5.3-8.3-5.6-1-9.6-6-9.6-11.6 0-3.3 1.5-6.6 4-8.8 2.5-2.3 5.8-3.4 9.2-3.1 6.1 0.7 10.7 6.1 10.7 12.4z" />
                                        </svg>
                                    </div>
                                </div>
                             </div>';
                        endforeach;
                        echo '</div>
                            <div class="swiper-pagination"></div>';
                       endif; 
                       echo '</div>
                        </div>
                     </div>
                   </div>
               </div>
           </div>';
  }
}