<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Corporate_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_corporate_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Corporate Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
	     $this->start_controls_section(
            'leadcapture_corporate_banner',
            [
            'label' => esc_html__('Corporate Banner Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_corporate_logo_image',
            [
			'label' => esc_html__('Corporate Logo Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_corporate_banner_sub_heading',
            [
            'label' => esc_html__('Corporate Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_heading',
            [
            'label' => esc_html__('Corporate Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_description',
            [
            'label' => esc_html__('Corporate Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_form_heading',
            [
            'label' => esc_html__('Corporate Form Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_form_image',
            [
			'label' => esc_html__('Corporate Form Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_corporate_banner_formshortcode',
            [
            'label' => esc_html__('Corporate Form Shortcode', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_image_left',
            [
			'label' => esc_html__('Corporate Banner Left Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
       
        $this->add_control(
            'leadcapture_corporate_banner_testimonial_name',
            [
            'label' => esc_html__('Corporate Testimonial Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_testimonial_pimage',
            [
            'label' => esc_html__('Corporate Testimonial Profile Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_testimonial_designation',
            [
            'label' => esc_html__('Corporate Testimonial Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
         $this->add_control(
            'leadcapture_corporate_banner_testimonial_rating_num',
            [
            'label' => esc_html__('Corporate Testimonial Rating Number', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_testimonial_rating_review',
            [
            'label' => esc_html__('Corporate Testimonial Rating Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_testimonial_description',
            [
            'label' => esc_html__('Corporate Testimonial Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_consulting_name',
            [
            'label' => esc_html__('Corporate Consulting Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_consulting_pimage',
            [
            'label' => esc_html__('Corporate Consulting Profile Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_consulting_description',
            [
            'label' => esc_html__('Corporate Consulting', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        
        $this->add_control(
            'leadcapture_corporate_banner_valuable_ideas_name',
            [
            'label' => esc_html__('Corporate Valuable Ideas Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_valuable_ideas_pimage',
            [
            'label' => esc_html__('Corporate Valuable IDeas Profile Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_banner_valuable_ideas_description',
            [
            'label' => esc_html__('Corporate Valuable IDeas Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
	    
	    // Sub Heading Style
        $this->add_control(
			'lcp_corporate_banner_style_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_corporate_banner_style_subheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style12 > h2'
            ]
        );
        $this->add_control(
            'lcp_corporate_banner_style_subheading_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style12 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_corporate_banner_style_subheading_heading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style12 > h2' => 'background: {{VALUE}};',
                ],
            ]
        );
	    
	    // Sub Heading Style
        $this->add_control(
			'lcp_corporate_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_corporate_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style12 h1'
            ]
        );
        $this->add_control(
            'lcp_corporate_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style12 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
	    
	    // Description Style
        $this->add_control(
			'lcp_corporate_banner_style_desc',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_corporate_banner_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style12 > p'
            ]
        );
        $this->add_control(
            'lcp_corporate_banner_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style12 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_control(
			'lcp_corporate_banner_newsletter_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_corporate_banner_newsletter_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lead_capture_form_newsletter_wrapper input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_corporate_banner_newsletter_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lead_capture_form_newsletter_wrapper button'
            ]
        );
        
        
       	$this->end_controls_section();
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
    	$id = uniqid();	
	    $settings = $this->get_settings_for_display();
	    echo '<div class="lc-header-wrapper lc-header-wrapper-style12" style="overflow-x: hidden;">';
                if(!empty($settings['leadcapture_corporate_logo_image']['url'])):
                    echo '<div class="container-fluid">
                           <div class="lc-header-section lc-header-section-style12">
                                <div class="row">
                                    <div class="col-lg-3 col-md-5 col-sm-6 col-10">
                                        <div class="lc-logo-img lc-logo-img-style12">
                                            <img src="'.esc_url($settings['leadcapture_corporate_logo_image']['url']).'" alt="'.esc_attr__('logo img','leadcapture').'">
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>';
                endif;
            echo '<!-- banner section start -->
                  <div class="lc-banner-section lc-banner-section-style12" style="overflow-x: hidden;">
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-lg-6 col-md-12 col-sm-12">
                                <div class="lc-banner-text lc-banner-text-style12">';
                                    if(!empty($settings['leadcapture_corporate_banner_sub_heading'])):
                                        echo '<h2>'.$settings['leadcapture_corporate_banner_sub_heading'].'</h2>';
                                    endif;
                                    if(!empty($settings['leadcapture_corporate_banner_heading'])):
                                        printf('<h1>'.$settings['leadcapture_corporate_banner_heading'].'</h1>');
                                    endif;   
                                    if(!empty($settings['leadcapture_corporate_banner_description'])):
                                        echo '<p>'.esc_html($settings['leadcapture_corporate_banner_description']).'</p>';
                                    endif; 
                                    if(!empty($settings['leadcapture_corporate_banner_form_heading'])):
                                        echo '<h3>'.esc_html($settings['leadcapture_corporate_banner_form_heading']).'</h3>';
                                    endif;
                                if(!empty($settings['leadcapture_corporate_banner_form_heading'])):  
                                echo '<div class="lc-search-wrapper lc-search-wrapper-style12 ">
                                        <div class="lc-message-icon">';
                                        if(!empty($settings['leadcapture_corporate_form_image']['url'])):
                                           echo '<img src="'.esc_url($settings['leadcapture_corporate_form_image']['url']).'" alt="'.esc_attr__('message icon','leadcapture').'">';
                                        endif;   
                                        if(!empty($settings['leadcapture_corporate_banner_formshortcode'])):
                                            echo do_shortcode($settings['leadcapture_corporate_banner_formshortcode']);
                                        endif;
                                echo '</div>
                                    </div>';
                                endif;   
                            echo '</div>
                            </div>
                            <div class="col-lg-6 col-md-12 col-sm-12">
                                <div class="lc-banner-image lc-banner-image-style12">';
                                
                                if(!empty($settings['leadcapture_corporate_banner_image_left']['url'])):
                                    echo '<img src="'.esc_url($settings['leadcapture_corporate_banner_image_left']['url']).'" alt="'.esc_attr__('Banner Image','leadcapture').'">';
                                endif;  
                                
                                if(!empty($settings['leadcapture_corporate_banner_consulting_pimage']['url'])):
                                    echo '<div class="lc-consulting-text">';
                                        if(!empty($settings['leadcapture_corporate_banner_consulting_pimage']['url'])):
                                           echo '<img src="'.esc_url($settings['leadcapture_corporate_banner_consulting_pimage']['url']).'" alt="'.esc_attr__('Corporate','leadcapture').'">';
                                        endif;
                                        if(!empty($settings['leadcapture_corporate_banner_consulting_name'])):
                                          echo '<h4>'.esc_html($settings['leadcapture_corporate_banner_consulting_name']).'</h4>';
                                        endif; 
                                        if(!empty($settings['leadcapture_corporate_banner_consulting_description'])):
                                           echo '<p>'.esc_html($settings['leadcapture_corporate_banner_consulting_description']).'</p>';
                                        endif;
                                    echo '</div>';
                                endif;   
                                
                                if(!empty($settings['leadcapture_corporate_banner_valuable_ideas_pimage']['url'])):
                                    echo '<div class=" lc-consulting-text-style12">';
                                    if(!empty($settings['leadcapture_corporate_banner_valuable_ideas_pimage'])):
                                        echo '<img src="'.esc_url($settings['leadcapture_corporate_banner_valuable_ideas_pimage']['url']).'" alt="'.esc_attr__('Corporate','leadcapture').'">';
                                    endif;
                                    if(!empty($settings['leadcapture_corporate_banner_valuable_ideas_name'])):        
                                        echo '<h4>'.esc_html($settings['leadcapture_corporate_banner_valuable_ideas_name']).'</h4>';
                                    endif;    
                                    if(!empty($settings['leadcapture_corporate_banner_valuable_ideas_description'])):
                                        echo '<p>'.esc_html($settings['leadcapture_corporate_banner_valuable_ideas_description']).'</p>';
                                    endif;
                                echo '</div>';
                                endif;    
                                if(!empty($settings['leadcapture_corporate_banner_testimonial_pimage']['url'])):
                                        echo '<div class="lc-designer-text">
                                               <div class="lc-flex-text">';
                                               if(!empty($settings['leadcapture_corporate_banner_testimonial_pimage']['url'])):
                                                echo '<div class="lc-flex-img">
                                                        <img src="'.esc_url($settings['leadcapture_corporate_banner_testimonial_pimage']['url']).'" alt="'.esc_attr__('Corporate','leadcapture').'">
                                                     </div>';
                                                endif;
                                                
                                                if(!empty($settings['leadcapture_corporate_banner_image_left'])):
                                                    echo '<div class="lc-flex-inner-text">';
                                                        if(!empty($settings['leadcapture_corporate_banner_testimonial_name'])):
                                                            echo '<h4>'.esc_html($settings['leadcapture_corporate_banner_testimonial_name']).'</h4>';
                                                        endif;  
                                                        if(!empty($settings['leadcapture_corporate_banner_testimonial_designation'])):
                                                            echo '<p>'.esc_html($settings['leadcapture_corporate_banner_testimonial_designation']).'</p>';
                                                        endif;
                                                    echo '</div>
                                                    </div>';
                                                endif;
                                                echo '<div class="lc-stare-wrapper">';
                                                    if(!empty($settings['leadcapture_corporate_banner_testimonial_rating_review'])):
                                                            echo '<div class="lc-stare-img">
                                                                   <img src="'.esc_url($settings['leadcapture_corporate_banner_testimonial_rating_review']['url']).'" alt="'.esc_attr__('Corporate','leadcapture').'">
                                                                  </div>';
                                                    endif;
                                                    if(!empty($settings['leadcapture_corporate_banner_testimonial_rating_num'])):
                                                            echo '<div class="lc-rating-text">
                                                                    <p>'.esc_html($settings['leadcapture_corporate_banner_testimonial_rating_num']).'</p>
                                                                 </div>';
                                                    endif;
                                                echo  '</div>';
                                                if(!empty($settings['leadcapture_corporate_banner_testimonial_description'])):
                                                    echo '<div class="lc-paragraph-box">
                                                            <p>'.esc_html($settings['leadcapture_corporate_banner_testimonial_description']).'</p>
                                                         </div>';
                                                endif;        
                                        echo  '</div>';
                                endif;  
                                
                         echo '</div>  
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}