<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Corporate_Contactform extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_corporate_contactform';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Corporate Contact Form', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_corporate_cf_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_cf_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_cf_subheading',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_cf_image',
            [
			'label' => esc_html__('Corporate Form Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
			'leadcapture_corporate_cf_shortcode',
			[
				'label' => esc_html__( 'Add Shortcode', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::CODE,
				'language' => 'html',
				'rows' => 20,
			]
		);
		$this->end_controls_section();
		
		// Style
		$this->start_controls_section(
            'lps_cp_cf_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'lps_cp_cf_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_cp_cf_heading_typography',
            'selector' => '{{WRAPPER}} .lc-cf-heading',
            ]
        );
        $this->add_control(
        	'lps_cp_cf_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-cf-heading' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_heading_margin',
            [
                'label'      => __( 'Margin', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-cf-heading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_heading_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-cf-heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
			'lps_cp_cf_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_cp_cf_subheading_typography',
            'selector' => '{{WRAPPER}} .lc-cf-subheading',
            ]
        );
        $this->add_control(
        	'lps_cp_cf_subheading_text_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-cf-subheading' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_subheading_margin',
            [
                'label'      => __( 'Margin', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-cf-subheading' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_subheading_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-cf-subheading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
        // Form Style
		$this->start_controls_section(
            'lps_cp_cf_form_style_tab',
            [
            'label' => esc_html__( 'Form Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Input Type Text
        $this->add_control(
			'lps_cp_cf_input',
			[
				'label' => esc_html__( 'Input Field', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Typography', 'leadcapture'),
            'name'     => 'lps_cp_cf_input_typography',
            'selector' => '{{WRAPPER}} .corporate_input_type input, .corporate_input_type textarea',
            ]
        );
        $this->add_control(
        	'lps_cp_cf_input_text_color',
        	[
        	'label' => esc_html__('Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .corporate_input_type input, .corporate_input_type textarea' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cp_cf_input_bg_color',
        	[
        	'label' => esc_html__('Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .corporate_input_type input' => 'background-color: {{VALUE}}',
        	   '{{WRAPPER}} .corporate_input_type textarea' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lps_cp_cf_input_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
				'selector' => '{{WRAPPER}} .corporate_input_type input, .corporate_input_type textarea',
            ]
        );
		$this->add_control(
            'lps_cp_cf_input_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .corporate_input_type input, .corporate_input_type textarea' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_input_margin',
            [
                'label'      => __( 'Margin', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .corporate_input_type input, .corporate_input_type textarea' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_input_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .corporate_input_type input, .corporate_input_type textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        // Input Type Button
        $this->add_control(
			'lps_cp_cf_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Typography', 'leadcapture'),
            'name'     => 'lps_cp_cf_button_typography',
            'selector' => '{{WRAPPER}} .corporate_form_btn',
            ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_button_margin',
            [
                'label'      => __( 'Margin', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .corporate_form_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'lps_cp_cf_button_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .corporate_form_btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        // Hover or Normal Tab
        $this->start_controls_tabs( 'button_colors' );
        $this->end_controls_tab();
        $this->start_controls_tab(
			'lps_cp_cf_button_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		
		
		$this->add_control(
            'lps_cp_cf_button_tcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .corporate_form_btn' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lps_cp_cf_button_border',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .corporate_form_btn',
            ]
        );
		$this->add_control(
            'lps_cp_cf_button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .corporate_form_btn' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lps_cp_cf_button_bt_bg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .corporate_form_btn' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->start_controls_tab(
			'lps_cp_cf_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lps_cp_cf_button_htcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .corporate_form_btn:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lps_cp_cf_button_hborder',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .corporate_form_btn:hover',
            ]
        );
		$this->add_control(
            'lps_cp_cf_button_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .corporate_form_btn:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lps_cp_cf_button_bt_hbg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .corporate_form_btn:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)):
		    echo '<div class="lc-book-form-wrapper lc-book-form-wrapper-style12" style="overflow-x: hidden;">
		        <div class="container">
		            <div class="row">
		                <div class="col-lg-6 col-md-12 col-sm-12">
		                    <div class="lc-book-inner-wrapper">';
    		                    if(!empty($settings['leadcapture_corporate_cf_heading'])):
    		                        echo '<p class="lc-cf-heading">'.esc_html($settings['leadcapture_corporate_cf_heading']).'</p>';
    		                    endif;
    		                    if(!empty($settings['leadcapture_corporate_cf_subheading'])):
    		                        echo '<p class="lc-cf-subheading">'.esc_html($settings['leadcapture_corporate_cf_subheading']).'</p>';
    		                    endif;
    		                    if($settings['leadcapture_corporate_cf_shortcode']):
    		                        echo do_shortcode($settings['leadcapture_corporate_cf_shortcode']); 
    		                    endif;
		                    echo '</div>
		                </div>
		                <div class="col-lg-6 col-md-12 col-sm-12">';
		                    if($settings['leadcapture_corporate_cf_image']['url']):
		                        echo '<div class="lc-book-form-img">
                                    <img src="'.esc_url($settings['leadcapture_corporate_cf_image']['url']).'" alt="">
                                </div>';
		                    endif;
                        echo '</div>
		            </div>
		        </div>
		    </div>';
		endif;
		
	}
}