<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Corporate_Project extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_corporate_project';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Corporate Project', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_corporate_project_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_project_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_project_sub_heading',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
			'leadcapture_corporate_project',
			[
				'label' => esc_html__( 'Add Images', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::GALLERY,
				'show_label' => false,
				'default' => [],
			]
		);
		$this->add_control(
            'leadcapture_corporate_project_bttitle',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'View All Projects', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_project_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '#', 'leadcapture' ),
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'leadcapture_corporate_project_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'leadcapture_corporate_project_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_corporate_project_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-project-heading-big'
            ]
        );
        $this->add_control(
            'leadcapture_corporate_project_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-project-heading-big' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'leadcapture_corporate_project_sheading_control',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_corporate_project_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-project-heading-small',
            ]
        );
        
        $this->add_control(
            'leadcapture_corporate_project_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-project-heading-small' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        
        // Button Settings Tab
        $this->add_control(
			'leadcapture_corporate_project_button_control',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_corporate_project_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-project-btn a',
            ]
        );
        $this->add_control(
            'leadcapture_corporate_project_button_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-project-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        // Hover or Normal Tab
        $this->start_controls_tabs( 'button_colors' );
        $this->start_controls_tab(
			'leadcapture_corporate_project_button_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'leadcapture_corporate_project_button_tcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-project-btn a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'leadcapture_corporate_project_button_border',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-project-btn',
            ]
        );
		$this->add_control(
            'leadcapture_corporate_project_button_border_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-project-btn' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'leadcapture_corporate_project_button_bt_bg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-project-btn' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'leadcapture_corporate_project_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'leadcapture_corporate_project_button_htcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-project-btn:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'leadcapture_corporate_project_button_hborder',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-project-btn:hover',
            ]
        );
		$this->add_control(
            'leadcapture_corporate_project_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-project-btn:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'leadcapture_corporate_project_button_bt_hbg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-project-btn:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
	}
	
	
	
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)):
		    echo '<div class="lc-project-wrapper" style="overflow-x: hidden;">
		        <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-project-heading">';
                                if(!empty($settings['leadcapture_corporate_project_heading'])):
                                    echo '<h2 class="lc-project-heading-big">'.esc_html($settings['leadcapture_corporate_project_heading']).'</h2>';
                                endif;
                                if(!empty($settings['leadcapture_corporate_project_sub_heading'])): 
                                    echo '<h2 class="lc-project-heading-small">'.esc_html($settings['leadcapture_corporate_project_sub_heading']).'</h2>';
                                endif;
                            echo '</div>
                        </div>
                    </div>
                    <section class="lc-gallery-popup" id="lc-galler-popup-style12">
                        <div class="row">
                            <div class="col-lg-3 col-md-6 col-sm-12">';
                                $i = 1;
                                foreach($settings['leadcapture_corporate_project'] as $images):
                                    if($i <= 1 || $i <= 2){
                                        echo '<div class="lc-projects-img">  
                                            <a href="'.$images['url'].'">
                                                <img src="'.$images['url'].'" alt="">
                                                <div class="lc-gallery-red-overlay"></div>
                                            </a>
                                        </div>';
                                    }
                                    $i++;
                                endforeach; 
                            echo '</div>
                            <div class="col-lg-3 col-md-6 col-sm-12">';
                                $i = 1;
                                foreach($settings['leadcapture_corporate_project'] as $images):
                                    if($i <= 5 && $i >= 3){
                                        echo '<div class="lc-projects-img">  
                                            <a href="'.$images['url'].'">
                                                <img src="'.$images['url'].'" alt="">
                                                <div class="lc-gallery-red-overlay"></div>
                                            </a>
                                        </div>';
                                    }
                                    $i++;
                                endforeach; 
                            echo '</div>
                            <div class="col-lg-3 col-md-6 col-sm-12">';
                                $i = 1;
                                foreach($settings['leadcapture_corporate_project'] as $images):
                                    if($i <= 7 && $i >= 6){
                                        echo '<div class="lc-projects-img">  
                                            <a href="'.$images['url'].'">
                                                <img src="'.$images['url'].'" alt="">
                                                <div class="lc-gallery-red-overlay"></div>
                                            </a>
                                        </div>';
                                    }
                                    $i++;
                                endforeach; 
                            echo '</div>
                            <div class="col-lg-3 col-md-6 col-sm-12">';
                                $i = 1;
                                foreach($settings['leadcapture_corporate_project'] as $images):
                                    if($i <= 10 && $i >= 8){
                                        echo '<div class="lc-projects-img">  
                                            <a href="'.$images['url'].'">
                                                <img src="'.$images['url'].'" alt="">
                                                <div class="lc-gallery-red-overlay"></div>
                                            </a>
                                        </div>';
                                    }
                                    $i++;
                                endforeach; 
                            echo '</div>
                        </div>
                    </section>';
                    if(!empty($settings['leadcapture_corporate_project_bttitle']) && !empty($settings['leadcapture_corporate_project_link'])):
                        echo '<div class="row">
                            <div class="col-lg-12 col-sm-12 col-md-12">
                                <div class="lc-btn lc-btn-view-style12 lc-project-btn">
                                    <a href="'.esc_url($settings['leadcapture_corporate_project_link']).'">'.esc_html($settings['leadcapture_corporate_project_bttitle']).'</a>
                                </div>
                            </div>
                        </div>';
                    endif;
                echo '</div>
		    </div>';
		endif;
	}
}