<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Corporate_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_corporate_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Corporate Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_corporate_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_corporate_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_corporate_sub_heading',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'leadcapture_corporate_services_image',
            [
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'leadcapture_corporate_services_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_corporate_services_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Praesent tincidunt lorem vel augue mollis, sed ultrices dui pretium.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_corporate_services_bttitle',
            [
                'label'       => esc_html__( 'Link Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_corporate_services_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        $this->add_control(
            'leadcapture_corporate_services_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'label'       => esc_html__( 'Add Services', 'leadcapture' ),
                        'leadcapture_corporate_services_title'  => esc_html__( 'Services', 'leadcapture' ),
						'leadcapture_corporate_services_desc'  => esc_html__( 'Praesent tincidunt lorem vel augue mollis, sed ultrices dui pretium.', 'leadcapture' ),
						'leadcapture_corporate_services_bttitle'  => esc_html__( 'Read More', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_corporate_services_title}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
		$this->start_controls_section(
            'leadcapture_ab_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'leadcapture_ab_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_heading_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-financial-services-wrapper .lc-heading-big'
            ]
        );
        $this->add_control(
            'leadcapture_ab_heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-financial-services-wrapper .lc-heading-big' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'heading_control',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-financial-services-wrapper .lc-heading-small',
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-financial-services-wrapper .lc-heading-small' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
		$this->end_controls_section();
		
		// Services Style Tab
		$this->start_controls_section(
            'leadcapture_ab_services_style_tab', 
            [
                'label' => esc_html__( 'Services Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Services Title style
		$this->add_control(
			'heading_servies_title_control',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_services_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-financial-text h2',
            ]
        );
        $this->add_control(
            'leadcapture_ab_servies_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-financial-text h2' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
    
        // Services Description style
        $this->add_control(
			'heading_servies_desc_control',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_servies_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-financial-text p',
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_servies_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-financial-text p' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        
        // Services Link style
        $this->add_control(
			'heading_servies_link_control',
			[
				'label' => esc_html__( 'Link', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_servies_link_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-financial-text a',
            ]
        );
        $this->add_control(
            'leadcapture_ab_servies_link_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-financial-text a' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)):
		    echo '<div class="lc-financial-services-wrapper" style="overflow-x: hidden;">
		        <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-wrapper-style12">';
                                if(!empty($settings['leadcapture_corporate_heading'])):
                                    echo '<h2 class="lc-heading-big">'.esc_html($settings['leadcapture_corporate_heading']).'</h2>';
                                endif;
                                if(!empty($settings['leadcapture_corporate_sub_heading'])):
                                    echo '<h2 class="lc-heading-small">'.esc_html($settings['leadcapture_corporate_sub_heading']).'</h2>';
                                endif;
                            echo '</div>
                        </div>
                    </div>
                    <div class="row">';
                        foreach($settings['leadcapture_corporate_services_list'] as $serv):
                            echo '<div class="col-lg-4 col-md-6 col-sm-12">
                                <div class="lc-financial-flex-box">
                                    <div class="lc-financial-img">';
                                        if(!empty($serv['leadcapture_corporate_services_image']['url'])):
                                            echo '<img src="'.esc_html($serv['leadcapture_corporate_services_image']['url']).'" alt="'.esc_attr($serv['leadcapture_corporate_services_title']).'">';
                                        endif;
                                    echo '</div>
                                    <div class="lc-financial-text">';
                                        if(!empty($serv['leadcapture_corporate_services_title'])):
                                            echo '<h2>'.esc_html($serv['leadcapture_corporate_services_title']).'</h2>';
                                        endif;
                                        if(!empty($serv['leadcapture_corporate_services_desc'])):
                                            echo '<p>'.esc_html($serv['leadcapture_corporate_services_desc']).'</p>';
                                        endif;
                                        if(!empty($serv['leadcapture_corporate_services_bttitle']) || !empty($serv['leadcapture_corporate_services_link'])):
                                            echo '<a href="'.esc_url($serv['leadcapture_corporate_services_link']).'">'.esc_html($serv['leadcapture_corporate_services_bttitle']).'</a>';
                                        endif;
                                    echo '</div>
                                </div>
                            </div>';
                        endforeach; 
                    echo '</div>
                </div>
		    </div>';
		endif;
    }
}