<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Creativeagency_Finestwork extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_creativeagency_finestwork';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Creativeagency Finestwork', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_agency_work_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
			'lcp_agency_work_image',
			[
				'label' => esc_html__( 'Add Images', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'show_label' => false,
				'default' => [],
			]
		);
		$this->add_control(
            'lcp_agency_work_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_agency_work_cat_name',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Branding', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_agency_work_cat_list',
            [
                'label'       => esc_html__( 'Add Category', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_agency_work_cat_name'  => esc_html__( 'Branding', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_agency_work_cat_name}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style Tab
		$this->start_controls_section(
            'lcp_agency_work_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Widget Heading Style Tab
        $this->add_control(
			'lcp_agency_work_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_work_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-finest-text h4'
            ]
        );
        $this->add_control(
            'lcp_agency_work_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-finest-text h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Category Style
        $this->add_control(
			'lcp_agency_work_style_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_work_style_subheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-finest-text p'
            ]
        );
        $this->add_control(
            'lcp_agency_work_style_subheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-finest-text p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Extra Style
        $this->add_control(
			'lcp_agency_work_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_agency_work_extra_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-finest-text' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_agency_work_extra_hbgcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-finest-box:before' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-finest-box aos-init aos-animate" data-aos="zoom-in" data-aos-duration="2000">';
    		    if(!empty($settings['lcp_agency_work_image']['url'])){
    		        echo '<img src="'.esc_url($settings['lcp_agency_work_image']['url']).'" alt="'.esc_attr($settings['lcp_agency_work_heading']).'">';
    		    }
    		    echo '<div class="lc-finest-text">';
        		    if(!empty($settings['lcp_agency_work_heading'])){
        		        echo '<h4>'.esc_html($settings['lcp_agency_work_heading']).'</h4>';
        		    }
        		    $i = 1;
        		    if(!empty($settings['lcp_agency_work_cat_list'])){
        		        echo '<p>';
            		        foreach($settings['lcp_agency_work_cat_list'] as $category){
            		            if($i == 1){
            		                echo $category['lcp_agency_work_cat_name'];
            		            } else {
            		                echo ', '. $category['lcp_agency_work_cat_name'];
            		            }
            		            $i++;
            		        }
        		        echo '</p>';
        		    }
                echo '</div>
            </div>';
		}
	}
}