<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Creativeagency_Pricingplan extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_creativeagency_pricingplan';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Creativeagency Pricing Plan', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_agency_pricing_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_period',
            [
                'label'       => esc_html__( 'Time Period', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_agency_pricing_list_title',
            [
                'label'       => esc_html__( 'List Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_agency_pricing_list_title'  => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_agency_pricing_list_title}}',
            ]
        );
		$this->end_controls_section();
		
	    
	    //Widget Style Tab
	    $this->start_controls_section(
            'lcp_agency_pricing_style_tab',
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        //Heading Style 
        $this->add_control(
			'lcp_agency_pricing_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box h4'
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Symbol & Price Style 
        $this->add_control(
			'lcp_agency_pricing_style_symbol',
			[
				'label' => esc_html__( 'Symbol & Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_symbol_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box h2'
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_style_symbol_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        //Time Period
        $this->add_control(
			'lcp_agency_pricing_style_time',
			[
				'label' => esc_html__( 'Time Period', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_symbol_time',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box h2 sub'
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_style_symbol_time',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box h2 sub' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        //Description
        $this->add_control(
			'lcp_agency_pricing_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_symbol_desc',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box p'
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_style_symbol_desc',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        //List
        $this->add_control(
			'lcp_agency_pricing_style_list',
			[
				'label' => esc_html__( 'List', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_symbol_list',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box ul li'
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_style_symbol_list',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box ul li' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Extra
        $this->add_control(
			'lcp_agency_pricing_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_agency_pricing_style_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box:before' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .lc-plan-box:after' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_style_line_color',
            [
                'label'     => esc_html__( 'Line Color ', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box p' => 'border-bottom-color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Button Settings Tab
        $this->add_control(
			'lcp_agency_pricing_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn a',
            ]
        );
        $this->add_control(
            'lcp_agency_pricing_style_button_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-plan-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        // Hover or Normal Tab
        $this->start_controls_tabs( 'button_colors' );
        $this->start_controls_tab(
			'lcp_agency_pricing_style_button_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_agency_pricing_style_button_tcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_button_border',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn',
            ]
        );
		$this->add_control(
            'lcp_agency_pricing_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lcp_agency_pricing_style_button_bt_bg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_agency_pricing_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_agency_pricing_style_button_htcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_agency_pricing_style_button_hborder',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn:hover',
            ]
        );
		$this->add_control(
            'lcp_agency_pricing_style_button_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lcp_agency_pricing_style_button_bt_hbg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-plan-box aos-init aos-animate" data-aos="fade-right" data-aos-duration="900">';
		        if(!empty($settings['lcp_agency_pricing_heading'])){
		            echo '<h4>'.esc_html($settings['lcp_agency_pricing_heading']).'</h4>';  
		        }
		        if(!empty($settings['lcp_agency_pricing_symbol']) || !empty($settings['lcp_agency_pricing_price']) || !empty($settings['lcp_agency_pricing_period'])){
		            echo '<h2>'.esc_html($settings['lcp_agency_pricing_symbol'].$settings['lcp_agency_pricing_price']).'<sub>/'.esc_html($settings['lcp_agency_pricing_period']).'</sub></h2>';
		        }
		        if(!empty($settings['lcp_agency_pricing_desc'])){
		            echo '<p>'.esc_html($settings['lcp_agency_pricing_desc']).'</p>';
		        }
		        if(!empty($settings['lcp_agency_pricing_list'])){
		            echo '<ul>';
		            foreach($settings['lcp_agency_pricing_list'] as $list){
		                echo '<li><img src="https://themes91.in/testing-html/lead-capture/Leadcapture-html/assets/images/Creative-Agency/right.png">'.esc_html($list['lcp_agency_pricing_list_title']).'</li>';
		            }
		            echo '</ul>';
		        }
		        if(!empty($settings['lcp_agency_pricing_btn_title'])){
		            echo '<div class="lc-plan-btn">
		                <a href="'.esc_url($settings['lcp_agency_pricing_btn_link']).'">'.esc_html($settings['lcp_agency_pricing_btn_title']).'</a>
		            </div>';
		        }
		    echo '</div>';
		}
	}
}