<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Creativeagency_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_creativeagency_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Creativeagency Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_agency_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_agency_services_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services #', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'lcp_agency_services_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_agency_services_icon',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_agency_services_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Read More', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_agency_services_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_agency_services_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_agency_services_title'  => esc_html__( 'Services', 'leadcapture' ),
						'lcp_agency_services_desc'  => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture' ),
						'lcp_agency_services_btn_title'  => esc_html__( 'Read More', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_agency_services_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_agency_services_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_agency_services_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_services_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-customer-text-box h3'
            ]
        );
        $this->add_control(
            'lcp_agency_services_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-customer-text-box h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_agency_services_style_heading_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-customer-text-box:hover h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_agency_services_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_services_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-customer-text-box p'
            ]
        );
        $this->add_control(
            'lcp_agency_services_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-customer-text-box p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Button Style
        $this->add_control(
			'lcp_agency_services_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_agency_services_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-customer-btn a'
            ]
        );
        $this->add_control(
            'lcp_agency_services_style_btn_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-customer-btn a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_agency_services_style_btn_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-customer-btn' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        //Extra Style
        $this->add_control(
			'lcp_agency_services_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_agency_services_style_extra_color',
            [
                'label'     => esc_html__( 'Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-customer-text-box:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="row justify-content-center">';
		        foreach($settings['lcp_agency_services_list'] as $services){
		            echo '<div class="col-xxl-3 col-xl-6 col-lg-4 col-md-6 col-sm-6">
		                <div class="lc-customer-box  aos-init aos-animate" data-aos="flip-left" data-aos-duration="2000">
                            <div class="lc-customer-text-box">';
                                if($services['lcp_agency_services_icon']['url']){
                                    echo '<img src="'.esc_url($services['lcp_agency_services_icon']['url']).'" alt="'.esc_attr($services['lcp_agency_services_title']).'">';
                                }
                                if($services['lcp_agency_services_title']){
                                    echo '<h3>'.$services['lcp_agency_services_title'].'</h3>';
                                }
                                if($services['lcp_agency_services_desc']){
                                    echo '<p>'.$services['lcp_agency_services_desc'].'</p>';
                                }
                                if($services['lcp_agency_services_btn_title']){
                                    echo '<div class="lc-customer-btn">
                                        <a href="'.esc_url($services['lcp_agency_services_btn_link']).'">'.esc_html($services['lcp_agency_services_btn_title']).'</a>
                                    </div>';
                                }
                            echo '</div>
                        </div>
		            </div>';
		        }
		    echo '</div>';
		}
	}
}