<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dancestudio_Classes extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dancestudio_classes';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dancestudio Classes', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'Classes Settings', 'leadcapture' ),
            ] 
        );
		
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_classes_img',
            [
				'label'       => esc_html__( 'Add Images', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
        $repeater->add_control(
            'leadcapture_title',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Product Title', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '$50', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_link_title',
            [
                'label'       => esc_html__( 'Link Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '$50', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_link_url',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '#', 'leadcapture' ),
            ]
        );
       
		$this->add_control(
            'leadcapture_product_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_classes_img'  => esc_html__('Box Image', 'leadcapture'),
                    'leadcapture_title'  => esc_html__('Enter Title', 'leadcapture'),
                    'leadcapture_desc'  => esc_html__('Enter Description', 'leadcapture'),
                    'leadcapture_link_title'  => esc_html__('Linkk Text', 'leadcapture'),
                    'leadcapture_link_url'  => esc_html__('Link URL', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_title}}',
            ]
        );
		$this->end_controls_section();

        /** 
        * Lead Captur Style Tab
        */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Content Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
		'title_color',
			[
				'label' => esc_html__( 'Title Color', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lc-style-box-text h4' => 'color: {{VALUE}}',
				],
			]
		);
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Title Typography', 'leadcapture'),
            'name'     => 'lps_title_typography',
            'selector' => '{{WRAPPER}} .lc-style-box-text h4',
            ]
        );
        $this->add_control(
        'text_color',
            [
                'label' => esc_html__( 'Description Color', 'leadcapture' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lc-style-box-text p' => 'color: {{VALUE}}',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lc-style-box-text p',
            ]
        ); 
        $this->add_control(
            'link_color',
                [
                    'label' => esc_html__( 'Link Color', 'leadcapture' ),
                    'type' => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .lc-style-box-text a' => 'color: {{VALUE}}',
                    ],
                ]
            );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Link Typography', 'leadcapture'),
            'name'     => 'lps_link_typography',
            'selector' => '{{WRAPPER}} .lc-style-box-text a',
            ]
        ); 
       	$this->end_controls_section();

	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="row">';

                if(!empty($settings['leadcapture_product_list'])):
                    foreach($settings['leadcapture_product_list'] as $classes):
                    
                 echo '<div class="col-lg-4 col-md-12 col-sm-12">
                                <div class="lc-style-box-wrapper">';
                                    if(!empty($classes['leadcapture_classes_img']['url'])):
                                        echo '<div class="lc-style-box-img">
                                                <img src="'.esc_url($classes['leadcapture_classes_img']['url']).'" alt="'.esc_attr($classes['leadcapture_classes_img']['alt']).'" class="lc-top-parent">
                                            </div>';
                                    endif;
                                    echo '<div class="lc-style-box-text">';
                                            if(!empty($classes['leadcapture_title'])):
                                                echo '<h4>'.esc_html($classes['leadcapture_title']);
                                                echo '</h4>';
                                            endif;
                                            if(!empty($classes['leadcapture_desc'])):
                                                echo '<p>'.esc_html($classes['leadcapture_desc']);
                                                echo '</p>';
                                            endif;
                                            if(!empty($classes['leadcapture_link_title'])):
                                                echo '<a href="'.esc_url( $classes['leadcapture_link_url'] ).'">'.esc_html($classes['leadcapture_link_title']);
                                                echo '</a>';
                                            endif;
                                    echo '</div>
                                </div>
                            </div>
                       ';

                    endforeach;
                endif;    
        echo '</div>';
	}
}