<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dancestudio_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dancestudio_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dancestudio Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'Dance Testimonials Settings', 'leadcapture' ),
            ] 
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_data',
            [
				'label'       => esc_html__( 'Testimonial Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,	
			]
        );
        $repeater->add_control(
            'leadcapture_testimonial_username',
            [
                'label'       => esc_html__( 'User Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'User Name', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonial_profession',
            [
                'label'       => esc_html__( 'User Profession', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'User Profession', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
			'entrance_animation',
			[
				'label' => esc_html__( 'Entrance Animation', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
			]
		);
		$this->add_control(
            'leadcapture_testimonial_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_testimonial_data'  => esc_html__('Consectetur adging sed do eiusmod tempor incididunt ut labore et dolore magna aliquauis...', 'leadcapture'),
                    'leadcapture_testimonial_username'  => esc_html__('User Name', 'leadcapture'),
                    'leadcapture_testimonial_profession'  => esc_html__('User Profession', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_username}}',
            ]
        );
		$this->end_controls_section();

        /** 
        * Lead Captur Style Tab
        */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Testimonials Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
		'text_color',
			[
				'label' => esc_html__( 'Testimonial Text Color', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .lc-test-para-style14 p' => 'color: {{VALUE}}',
				],
			]
		);
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Text', 'leadcapture'),
            'name'     => 'lps_testimonial_text_typography',
            'selector' => '{{WRAPPER}} .lc-test-para-style14 p',
            ]
        );
        $this->add_control(
        'username_color',
            [
                'label' => esc_html__( 'Testimonial Username Color', 'leadcapture' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lc-test-name-style14 h6' => 'color: {{VALUE}}',
                ],
            ]
        );
         $this->add_control(
        'username_hover_color',
            [
                'label' => esc_html__( 'Username Hover Color', 'leadcapture' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lc-test-box-style14:hover h6' => 'color: {{VALUE}}',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Username Typography', 'leadcapture'),
            'name'     => 'lps_testimonial_username_typography',
            'selector' => '{{WRAPPER}} .lc-test-name-style14 h6',
            ]
        ); 
        $this->add_control(
            'userprofession_color',
                [
                    'label' => esc_html__( 'Testimonial User Profession  Color', 'leadcapture' ),
                    'type' => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .lc-test-name-style14 p' => 'color: {{VALUE}}',
                    ],
                ]
            );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('User Profession Typography', 'leadcapture'),
            'name'     => 'lps_testimonial_user_profession_typography',
            'selector' => '{{WRAPPER}} .lc-test-name-style14 p',
            ]
        ); 
       	$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
        echo '<div class="row">';
        if(!empty($settings['leadcapture_testimonial_list'])):
            foreach($settings['leadcapture_testimonial_list'] as $testimonial):
		    echo '
                            
                                <div class="col-xl-4 col-lg-4 col-md-6 col-12 '.esc_attr( $testimonial['entrance_animation'] ).'">
                                
                                    <div class="lc-test-box lc-test-box-style14">';
                                        if(!empty($testimonial['leadcapture_testimonial_data'])):
                                            echo '<div class="lc-test-para lc-test-para-style14"><p>'.esc_html($testimonial['leadcapture_testimonial_data']);
                                            echo '</p></div>';
                                        endif;
                                        echo '<div class="lc-quote-line-wrapper">
                                                    <div class="lc-quote-line-style14"></div>
                                                    <div class="lc-test-quote-icon lc-test-quote-icon-style14">
                                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 24" width="32" height="24">
                                                            <title>Shape 3</title>
                                                            <path id="Shape 3" class="s0" d="m25.1 15.2q1 2.4 3 4.8c0.5 0.4 0.5 1.1 0.2 1.7-0.3 0.4-0.7 0.7-1.2 0.7q-0.2 0-0.4-0.1c-2.9-0.8-9.6-3.8-9.8-13.4 0-3.7 2.7-6.9 6.1-7.2 2-0.2 3.9 0.4 5.3 1.7 1.5 1.3 2.3 3.2 2.3 5.1 0 3.2-2.3 6.1-5.5 6.7zm-17.6-13.5c2-0.2 3.9 0.4 5.3 1.7 1.4 1.3 2.3 3.2 2.3 5.1 0 3.2-2.3 6.1-5.5 6.7q1 2.4 3 4.8c0.4 0.4 0.5 1.1 0.2 1.7-0.3 0.4-0.8 0.7-1.3 0.7q-0.2 0-0.4-0.1c-2.8-0.8-9.5-3.8-9.7-13.4v-0.1c0-3.7 2.7-6.8 6.1-7.1z"/>
                                                        </svg>
                                                    </div>
                                                </div>
                                                <div class="lc-test-name lc-test-name-style14">';
                                                    if(!empty($testimonial['leadcapture_testimonial_username'])):
                                                        echo '<h6>'.esc_html($testimonial['leadcapture_testimonial_username']);
                                                        echo '</h6>';
                                                    endif;
                                                    if(!empty($testimonial['leadcapture_testimonial_profession'])):
                                                        echo '<p>'.esc_html($testimonial['leadcapture_testimonial_profession']);
                                                        echo '</p>';
                                                    endif;
                                           echo '</div>
                                    </div>
                                </div>
                        
                ';
            endforeach;
        endif;    
       echo '</div>';  
	}
}