<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dentist_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dentist_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dentist Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}
    
    /**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__( 'Dentist Banner Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'leadcapture_dentist_logo_image',
            [
			'label' => esc_html__('Logo Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_dentist_banner_heading',
            [
            'label' => esc_html__('Dentist Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_dentist_contact_number_image',
            [
			'label' => esc_html__('Contact Number Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_dentist_contact_number_title',
            [
            'label' => esc_html__('Contact Title', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_dentist_contact_number',
            [
            'label' => esc_html__('Contact Number', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_dentist_reviewer_image',
            [
            'label' => esc_html__('Reviewer Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_dentist_reviewer_name',
            [
            'label' => esc_html__('Reviewer Name', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_dentist_reviewer_description',
            [
            'label' => esc_html__('Reviewer Description', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_dentist_banner_form_heading',
            [
            'label' => esc_html__('Dentist Form Heading', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_dentist_banner_formshortcode',
            [
            'label' => esc_html__('Dentist Form Shortcode', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_dentist_form_image',
            [
			'label' => esc_html__('Dentist Form Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_dentist_image_icon_one',
            [
			'label' => esc_html__('Dentist Icon One', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_dentist_image_icon_two',
            [
			'label' => esc_html__('Dentist Icon Two', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        $this->add_control(
            'leadcapture_dentist_image_icon_three',
            [
			'label' => esc_html__('Dentist Icon Three', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,
			]
        );
        
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'  => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'  => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_heading_custom_text_color',
        	[
        	'label' => esc_html__('Heading Custom Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-heading-custom-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_phone_icon_bg_color',
        	[
        	'label' => esc_html__('Phone Icon Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-call-box-style15 > span' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_phone_text_color',
        	[
        	'label' => esc_html__('Phone Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-call-text > p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
        echo '<div class="lc-header-wrapper lc-header-wrapper-style15">';
            if(!empty($settings['leadcapture_dentist_logo_image']['url'])):
                    echo '<div class="lc-header-section lc-header-section-style15">
                            <div class="container-fluid">
                                <div class="row">
                                    <div class="col-lg-5 col-md-5 col-sm-8">
                                        <div class="lc-logo-img lc-logo-img-style15">
                                            <img src="'.esc_url($settings['leadcapture_dentist_logo_image']['url']).'" alt="'.esc_attr__('dentist','leadcapture').'">
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>';
            endif;
            echo '<div class="lc-banner-section lc-banner-section-style14">
                        <div class="container-fluid">
                            <div class="row">
                                <div class="col-lg-6 col-md-12 col-sm-12">
                                    <div class="lc-banner-text lc-banner-text-style15">';
                                        if(!empty($settings['leadcapture_dentist_banner_heading'])):
                                           echo '<h1 class="lps-heading-fontstyle ">'.wp_kses($settings['leadcapture_dentist_banner_heading'],true).'</h1>';
                                        endif;
                                        if(!empty($settings['leadcapture_dentist_contact_number_image']['url'])):
                                            echo '<div class="lc-call-box lc-call-box-style15">
                                                  <span>
                                                   <img src="'.esc_url($settings['leadcapture_dentist_contact_number_image']['url']).'" alt="'.esc_attr__('dentist','leadcapture').'">
                                                 </span>';
                                        endif;
                                        if(!empty($settings['leadcapture_dentist_contact_number_title'])):         
                                            echo '<div class="lc-call-text lc-call-text-style15">';
                                            if(!empty($settings['leadcapture_dentist_contact_number_title'])):
                                               echo '<span>'.esc_html($settings['leadcapture_dentist_contact_number_title']).'</span>';
                                            endif; 
                                            if(!empty($settings['leadcapture_dentist_contact_number'])):
                                               echo '<p>'.esc_html($settings['leadcapture_dentist_contact_number']).'</p>';
                                            endif;        
                                            echo '</div>';
                                        endif;
                                    echo '</div>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-12 col-sm-12">
                                    <div class="lc-banner-img-wrapper lc-banner-img-wrapper-style15">
                                        <div class="lc-banner-image lc-banner-image-style15">';
                                            if(!empty($settings['leadcapture_dentist_form_image']['url'])):
                                               echo '<img src="'.esc_url($settings['leadcapture_dentist_form_image']['url']).'" alt="'.esc_attr__('dentist','leadcapture').'">';
                                            endif;  
                                            echo '<div class="lc-banner-icon lc-banner-icon-style15">';
                                                if(!empty($settings['leadcapture_dentist_image_icon_one']['url'])):
                                                  echo '<img src="'.esc_url($settings['leadcapture_dentist_image_icon_one']['url']).'" alt="'.esc_attr__('banner-icon1','leadcapture').'">';
                                                endif;   
                                                if(!empty($settings['leadcapture_dentist_image_icon_two']['url'])):
                                                   echo '<img src="'.esc_url($settings['leadcapture_dentist_image_icon_two']['url']).'" alt="'.esc_attr__('banner-icon2','leadcapture').'">';
                                                endif;  
                                                if(!empty($settings['leadcapture_dentist_image_icon_three']['url'])):
                                                   echo '<img src="'.esc_url($settings['leadcapture_dentist_image_icon_three']['url']).'" alt="'.esc_attr__('banner-icon3','leadcapture').'">';
                                                endif;    
                                                echo '<div class="lc-banner-box-style15">';
                                                if(!empty($settings['leadcapture_dentist_reviewer_image']['url'])):
                                                   echo '<img src="'.esc_url($settings['leadcapture_dentist_reviewer_image']['url']).'" alt="'.esc_attr__('reviewer image','leadcapture').'">';
                                                endif;   
                                                if(!empty($settings['leadcapture_dentist_reviewer_name'])):
                                                    echo '<h3>'.esc_html($settings['leadcapture_dentist_reviewer_name']).'</h3>';
                                                endif; 
                                                if(!empty($settings['leadcapture_dentist_reviewer_description'])):
                                                    echo '<p>'.esc_html($settings['leadcapture_dentist_reviewer_description']).'</p>';
                                                endif; 
                                             echo '</div>
                                                </div>';
                                        echo '</div>
                                        <div class="lc-newsletter lc-newsletter-style15">';
                                            if(!empty($settings['leadcapture_dentist_banner_form_heading'])):
                                                echo '<p>'.esc_html($settings['leadcapture_dentist_banner_form_heading']).'</p>';
                                            endif; 
                                            echo '<div class="lc-search-wrapper lc-search-wrapper-style15">';
                                            if(!empty($settings['leadcapture_dentist_banner_formshortcode'])):
                                               echo do_shortcode($settings['leadcapture_dentist_banner_formshortcode']);
                                            endif;      
                                            echo '</div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>';
	}
}