<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dentist_Contactform extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dentist_contactform';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dentist Contact Form', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
		$this->start_controls_section(
        	'leadcapture_dentist_contactus',
        	[
        	'label' => esc_html__( 'Contact Us Settings', 'leadcapture'),
        	] 
        );
    	$this->add_control(
            'leadcapture_contactus_main_head',
            [
            'label' => esc_html__('Contact Us Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_contactus_left_image',
            [
			'label' => esc_html__('Contact Us Left Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $this->add_control(
            'leadcapture_contactus_form_heading',
            [
            'label' => esc_html__('Contact Us Form Heading', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_contactus_form_description',
            [
            'label' => esc_html__('Contact Form Description', 'leadcapture'),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_contactus_form_shortcode',
            [
            'label' => esc_html__('Contact Us Form Shortcode', 'leadcapture'),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_contact_form_up_image',
            [
			'label' => esc_html__('Contact Form Up Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_contact_form_dowen_image',
            [
			'label' => esc_html__('Contact Form Dowen Image', 'leadcapture'),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->end_controls_section();
		
		/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'  => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
         $this->add_control(
        	'lps_form_button_text_color',
        	[
        	'label' => esc_html__('Form Button Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-btn.lc-btn-style15' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_form_button_bg_color',
        	[
        	'label' => esc_html__('Form Button Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-btn.lc-btn-style15' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
       	
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-appointment-section">
               <div class="container">';
        if(!empty($settings['leadcapture_contactus_main_head'])):      
            echo '<div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="lc-heading-wrapper lc-heading-wrapper-style15 lc-heading-appointment">
                            <h2 class="lps-heading-fontstyle lps-description-fontstyle">'.esc_html($settings['leadcapture_contactus_main_head']).'</h2>
                        </div>
                    </div>
                </div>';
        endif;        
        echo '<div class="lc-appointment-form-wrapper">
                <div class="row">
                  <div class="col-lg-6 col-md-12 col-sm-12">
                    <div class="lc-form-wrapper">';
                    if(!empty($settings['leadcapture_contact_form_up_image']['url'])):   
                        echo '<img src="'.esc_url($settings['leadcapture_contact_form_up_image']['url']).'" alt="'.esc_attr__('app-img1','leadcapture').'" class="lc-app-img1">';
                    endif;
                    echo '<div class="lc-book-form-heading">';
                    if(!empty($settings['leadcapture_contactus_form_heading'])): echo '<h2>'.esc_html($settings['leadcapture_contactus_form_heading']).'</h2>';
                    endif;
                    if(!empty($settings['leadcapture_contactus_form_description'])):
                    echo '<p>'.esc_html($settings['leadcapture_contactus_form_description']).'</p>';
                    endif;
                    if(!empty($settings['leadcapture_contactus_form_shortcode'])):
                    echo '<div class="lc-book-form-wrapper">';
                    echo do_shortcode($settings['leadcapture_contactus_form_shortcode']);
                    echo '</div>';
                    endif;   
                echo '</div>';
                if(!empty($settings['leadcapture_contact_form_dowen_image']['url'])):      
                  echo '<img src="'.esc_url($settings['leadcapture_contact_form_dowen_image']['url']).'" alt="'.esc_attr__('app-img2','leadcapture').'" class="lc-app-img2">';
                endif;    
                echo '</div>
                </div>';
                echo '<div class="col-lg-6 col-md-12">';
                if(!empty($settings['leadcapture_contactus_left_image']['url'])): 
                echo '<div class="lc-book-img">
                       <img src="'.esc_url($settings['leadcapture_contactus_left_image']['url']).'" alt="'.esc_attr__('A Girl Image','leadcapture').'">
                     </div>';
                endif;      
               echo '</div>
              </div>
            </div>
        </div>
    </div>';
	}
}