<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dentist_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dentist_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dentist Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
		$this->add_control(
            'leadcapture_ab_sub_head',
            [
                'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_main_head',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_divider',
            [
				'label'       => esc_html__( 'Divider Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
		$this->add_control(
            'leadcapture_ab_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Our Salon Service Are sit amet, consectetur adipisicing elit, sed do eiusmod tempor iencididunt uerseit labore et dolore magna aliqua.', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_button',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Read More', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '#', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_extra_text',
            [
                'label'       => esc_html__( 'Extra Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Call To Make An Appointment From Mobile', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_big_text',
            [
                'label'       => esc_html__( 'Big Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__('Since 1995', 'leadcapture' ),
            ]
        );	
		$this->add_control(
            'leadcapture_ab_phone',
            [
                'label'       => esc_html__( 'Phone Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '+(81) 1800-15487', 'leadcapture' ),
            ]
        );	
		$this->add_control(
            'leadcapture_ab_slider_image',
			[
				'label' => esc_html__( 'Add Images', 'leadcapture' ),
				'type' => Controls_Manager::GALLERY,
				'default' => [],
				'show_label' => false,
			]
        );
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-service-section lc-service-section-style15">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-wrapper-style15">
                                <h2>You deserve great dental medical services.</h2>
                            </div>
                        </div>
                    </div>
                    <div class="lc-service-section-box-wrapper">
                        <div class="row">
                            <div class="col-lg-4 col-md-12 col-sm-12">
                                <div class="lc-service-box-wrapper1">
                                    <div class="lc-services-box">
                                        <img src="assets/images/dentist/service-icon1.png">
                                        <h2>General Dentistry</h2>
                                        <p>Esad nibh iudicabit necessitus et, quam inermis and the name voluptatus.</p>
                                        <a href="#">Read More</a>
                                    </div>
                                    <div class="lc-services-box">
                                        <img src="assets/images/dentist/service-icon2.png">
                                        <h2>Dental Surgery</h2>
                                        <p>Esad nibh iudicabit necessitus et, quam inermis and the name voluptatus.</p>
                                        <a href="#">Read More</a>
                                    </div>
                                </div>
                            </div>
                            <div class="col-lg-4 col-md-12 col-sm-12">
                                <div class="lc-service-box-img lc-service-box-img-style15">
                                    <img src="assets/images/dentist/service-girl.png">
                                </div>
                            </div>
                            <div class="col-lg-4 col-md-12 col-sm-12">
                                <div class="lc-service-box-wrapper2">
                                    <div class="lc-services-box">
                                        <img src="assets/images/dentist/service-icon3.png">
                                        <h2>Teeth Protection</h2>
                                        <p>Esad nibh iudicabit necessitus et, quam inermis and the name voluptatus.</p>
                                        <a href="#">Read More</a>
                                    </div>
                                    <div class="lc-services-box">
                                        <img src="assets/images/dentist/service-icon4.png">
                                        <h2>Alignment</h2>
                                        <p>Esad nibh iudicabit necessitus et, quam inermis and the name voluptatus.</p>
                                        <a href="#">Read More</a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}