<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dentist_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dentist_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dentist Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );
        
		$this->add_control(
            'leadcapture_tm_main_head',
            [
            'label' => esc_html__( 'Heading', 'leadcapture' ),
            'type' => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
            'label' => esc_html__( 'Author Name', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'leadcapture_testimonial_author_image',
            [
			'label' => esc_html__('Author Image', 'leadcapture' ),
            'type' => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__( 'Designnation', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_testi',
            [
            'label' => esc_html__( 'Testimonial', 'leadcapture' ),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'  => esc_html__( '', 'leadcapture' ),
            ]
        );
        
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default'  => [
                [
              'leadcapture_testimonial_rating_image' => esc_html__('', 'leadcapture'),
			  'leadcapture_testimonial_dest' => esc_html__('', 'leadcapture'),
			  'leadcapture_testimonial_testi' => esc_html__('', 'leadcapture'),
              ]
            ],
            'fields' => $repeater->get_controls(),
            'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'  => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .lps-description-fontstyle',
            ]
        ); 
        $this->add_control(
        	'lps_quote_icon_bg_color',
        	[
        	'label' => esc_html__('Quote Icon Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-test-quote-icon-style15' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_pagination_icon_bg_color',
        	[
        	'label' => esc_html__('Pagination Icon Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testimonial-slider-style15 > .swiper-pagination > .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-testimonial-wrapper lc-testimonial-style15">
                <div class="container">';
                    if(!empty($settings['leadcapture_tm_main_head'])):
                    echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                             <div class="lc-heading-wrapper lc-heading-wrapper-style15 lc-testhead-style15">';
                    echo '<h2 class="lps-heading-fontstyle">'.$settings['leadcapture_tm_main_head'].'</h2>';
                    echo '</div>
                        </div>
                    </div>';
                    endif;
                    if(!empty($settings['leadcapture_testimonial_list'])):
                    echo '<div class="lc-testimonial-slider-wrapper-style15">
                           <div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-testimonial-slider-wrapper">
                                    <div class="swiper lc-testimonial-slider-style15">
                                      <div class="swiper-wrapper">';
                                       foreach($settings['leadcapture_testimonial_list'] as $testi):
                                        echo '<div class="swiper-slide">
                                        <div class="lc-testimonial-box-wrapper">';
                                        if(!empty($testi['leadcapture_testimonial_author_image']['url'])):
                                        echo '<img src="'.esc_url($testi['leadcapture_testimonial_author_image']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">';
                                        endif;
                                        echo '<div class="lc-testimonial-box-text">
                                        <div class="lc-test-name lc-testname-style15">';
                                        if(!empty($testi['leadcapture_testimonial_author'])):
                                        echo '<h6 class="lps-heading-fontstyle">'.esc_html($testi['leadcapture_testimonial_author']).'</h6>';
                                        endif;
                                        if(!empty($testi['leadcapture_testimonial_dest'])):
                                        echo '<p class="lps-description-fontstyle">'.esc_html($testi['leadcapture_testimonial_dest']).'</p>';
                                        endif;
                                        echo '</div>';
                                        if(!empty($testi['leadcapture_testimonial_testi'])):
                                        echo '<p class="lps-description-fontstyle">'.esc_html($testi['leadcapture_testimonial_testi']).'</p>';
                                        endif;
                                        echo '</div>
                                        <div class="lc-test-quote-icon lc-test-quote-icon-style15">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 32 24" width="32" height="24">
                                        <path id="Shape 3" class="s0" d="m25.1 15.2q1 2.4 3 4.8c0.5 0.4 0.5 1.1 0.2 1.7-0.3 0.4-0.7 0.7-1.2 0.7q-0.2 0-0.4-0.1c-2.9-0.8-9.6-3.8-9.8-13.4 0-3.7 2.7-6.9 6.1-7.2 2-0.2 3.9 0.4 5.3 1.7 1.5 1.3 2.3 3.2 2.3 5.1 0 3.2-2.3 6.1-5.5 6.7zm-17.6-13.5c2-0.2 3.9 0.4 5.3 1.7 1.4 1.3 2.3 3.2 2.3 5.1 0 3.2-2.3 6.1-5.5 6.7q1 2.4 3 4.8c0.4 0.4 0.5 1.1 0.2 1.7-0.3 0.4-0.8 0.7-1.3 0.7q-0.2 0-0.4-0.1c-2.8-0.8-9.5-3.8-9.7-13.4v-0.1c0-3.7 2.7-6.8 6.1-7.1z" /></svg>
                                                </div>
                                            </div>
                                       </div>'; 
                                    endforeach; 
                                    echo '</div>
                                    <div class="swiper-pagination"></div>
                                    </div>
                                </div>
                            </div>
                         </div>
                       </div>';
                    endif;
                echo'</div>
            </div>';
	}
}