<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Digitalmarketing_Banner_Image extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_digitalmarketing_banner_image';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Digitalmarketing Banner Image', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $this->start_controls_section(
            'lcp_dgm_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_dgm_banner_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_dgm_banner_scocial_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Facebook', 'leadcapture'),
            ]
        );
        $repeater->add_control(
            'lcp_dgm_banner_scocial_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_dgm_banner_scocial_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_dgm_banner_scocial_title'  => esc_html__( 'Facebook', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_dgm_banner_scocial_title}}',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'lcp_dgm_banner_form',
            [
                'label' => esc_html__( 'Form Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_dgm_banner_form_icon',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_dgm_banner_form_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_dgm_banner_form_shortcode',
            [
                'label'       => esc_html__( 'Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        // Widget Style
        $this->start_controls_section(
            'lcp_dgm_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_dgm_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_dgm_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subscribe-form h2'
            ]
        );
        $this->add_control(
            'lcp_dgm_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-subscribe-form h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Extra Style
        $this->add_control(
			'lcp_dgm_banner_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_dgm_banner_style_extra_icon_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-sub-icon' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-banner-img-wrapper zoomIn wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: zoomIn;">
		        <div class="lc-banner-image">';
		            if(!empty($settings['lcp_dgm_banner_image']['url'])){
		                echo '<img src="'.esc_url($settings['lcp_dgm_banner_image']['url']).'" attr="'.esc_attr('Image', 'leadcapture').'" class="dm-img1">';
		            }
		            echo '<div class="lc-banner-icon">';
		                if(!empty($settings['lcp_dgm_banner_scocial_list'])){
		                    foreach($settings['lcp_dgm_banner_scocial_list'] as $list){
		                        echo '<img src="'.esc_url($list['lcp_dgm_banner_scocial_image']['url']).'" attr="'.esc_html($list['lcp_dgm_banner_scocial_title']).'">';
		                    }
		                }
		            echo '</div>
		        </div>
		    </div>
		    <div class="lc-subscribe pulse wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: pulse;">
		        <div class="lc-sub-icon">';
		            if(!empty($settings['lcp_dgm_banner_form_icon']['url'])){
		                echo '<img src="'.esc_url($settings['lcp_dgm_banner_form_icon']['url']).'" alt="'.esc_attr('sub-icon', 'leadcapture').'">';
		            }
                echo '</div>
                <div class="lc-subscribe-form lcp-digital-subscribe-form">';
                    if($settings['lcp_dgm_banner_form_title']){
                        echo '<h2>'.esc_html($settings['lcp_dgm_banner_form_title']).'</h2>';
                    }
                    echo '<div class="lc-sub-form">';
                        if($settings['lcp_dgm_banner_form_shortcode']){
                            echo do_shortcode($settings["lcp_dgm_banner_form_shortcode"]);
                        }
                    echo '</div>
                </div>
		    </div>';
		}
    }
}