<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dry_Cleaning_About extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dry_cleaning_about';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dry Cleaning About', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_dry_cleaning_about_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
         'lcp_dry_cleaning_about_image',
            [
                'label'       => esc_html__( 'Select Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
        $this->add_control(
            'lcp_dry_cleaning_about_year',
            [
                'label'       => esc_html__( 'Year Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_about_text',
            [
                'label'       => esc_html__( 'Year Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
       
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_dry_cleaning_about_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Number Style
        $this->add_control(
			'lcp_dry_cleaning_about_number_heading',
			[
				'label' => esc_html__( 'Number Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_dry_cleaning_about_number_heading_typography',
                'label'       => esc_html__( 'Number Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-about-imgbox-style39 h3'
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_about_number_heading_color',
            [
                'label'     => esc_html__( 'Number Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-imgbox-style39 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_dry_cleaning_about_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_dry_cleaning_about_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-about-imgbox-style39 p'
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_about_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-imgbox-style39 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_about_style_box_color',
            [
                'label'     => esc_html__( 'Box Bg Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-imgbox-style39' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
    	echo ' <div class="lc-about-image-style39">';
            if(!empty($settings['lcp_dry_cleaning_about_image']['url'])):
                echo '<img src="'.esc_url($settings['lcp_dry_cleaning_about_image']['url']).'" alt="'.esc_attr__('left-image', 'leadcapture').'">';
            endif;
             echo '<div class="lc-about-imgbox-style39">';
            if(!empty($settings['lcp_dry_cleaning_about_year'])):
                echo '<h3>'.esc_html($settings['lcp_dry_cleaning_about_year']).'</h3>';
            endif;
            if(!empty($settings['lcp_dry_cleaning_about_text'])):
                echo '<p>'.esc_html($settings['lcp_dry_cleaning_about_text']).'</p>';
            endif;
            echo '</div>
        </div>';
	}
	}
}