<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Dry_Cleaning_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_dry_cleaning_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Dry Cleaning Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_dry_cleaning_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_dry_cleaning_banner_subtitle',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_banner_newsletter_head',
            [
                'label'       => esc_html__( 'News Letter Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_newsletter_form',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
         'lcp_dry_cleaning_left_text_image',
            [
                'label'       => esc_html__( 'Banner Right Text Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
		);
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_dry_cleaning_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Sub Heading Style
        $this->add_control(
			'lcp_dry_cleaning_banner_style_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_dry_cleaning_banner_style_subheading_typography',
                'label'       => esc_html__( 'Sub Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style39 span'
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_banner_style_subheading_color',
            [
                'label'     => esc_html__( 'Sub Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style39 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_dry_cleaning_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_dry_cleaning_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style39 h1'
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style39 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // NewsLetter Heading Style
        $this->add_control(
			'lcp_dry_cleaning_banner_style_news_heading',
			[
				'label' => esc_html__( 'News Letter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_dry_cleaning_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subupdate-form-style39 h2'
            ]
        );
        $this->add_control(
            'lcp_dry_cleaning_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subupdate-form-style39 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
	echo '<!-- Add HTML Here  -->
        <div class="lc-banner-section-style39">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-lg-6 col-md-12 col-sm-12">
                        <div class="lc-banner-text-style39">';
                        if(!empty($settings['lcp_dry_cleaning_banner_subtitle'])):
                            echo '<span>'.esc_html($settings['lcp_dry_cleaning_banner_subtitle']).'</span>';
                        endif;
                        if(!empty($settings['lcp_dry_cleaning_banner_title'])):
                            echo '<h1>'.esc_html($settings['lcp_dry_cleaning_banner_title']).'</h1>';
                        endif;
                        echo '</div>';
                        if(!empty($settings['lcp_dry_cleaning_banner_newsletter_head'])):
                        echo '<div class="lc-subscribe-wrapper-style39">
                            <div class="lc-subupdate-form-style39">
                                <h2>'.esc_html($settings['lcp_dry_cleaning_banner_newsletter_head']).'</h2>
                            </div>
                        </div>';
                        endif;
                        if(!empty($settings['lcp_dry_cleaning_newsletter_form'])):
                            echo do_shortcode($settings['lcp_dry_cleaning_newsletter_form']);
                        endif;
                    echo '</div>
                    <div class="col-lg-6">';
                    if(!empty($settings['lcp_dry_cleaning_left_text_image']['url'])):
                        echo '<div class="lc-banner-rightimg-style39">
                            <img src="'.esc_url($settings['lcp_dry_cleaning_left_text_image']['url']).'" alt="'.esc_attr__('left-image', 'leadcapture').'">
                        </div>';
                    endif;
                   echo '</div>
                </div>
            </div>
        </div>';
	}
	}
}