<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Ebook_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_ebook_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.Leadcapture Ebook Banner
	 */
	public function get_title() {
		return __( 'Leadcapture Ebook Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_ebook_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_highlight_text',
            [
                'label'       => esc_html__( 'HighLight Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_maintitle',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_newstitle',
            [
                'label'       => esc_html__( 'NewsLetter Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_newstitle_form',
            [
                'label'       => esc_html__( 'NewsLetter Form', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_left_image',
            [
				'label'       => esc_html__( 'Left Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_ebook_banner_right_image',
            [
				'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        
        // Widget Style
        $this->start_controls_section(
            'lcp_ebook_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Highlight Text Style 
        $this->add_control(
			'lcp_ebook_banner_style_highlight_text',
			[
				'label' => esc_html__( 'Highlight Text', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_banner_style_highlight_text_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-para-text-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_style_highlight_text_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-para-text-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_style_highlight_text_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-para-text-style17 p' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        
        // Main Title Style 
        $this->add_control(
			'lcp_ebook_banner_style_main_text',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_banner_style_main_text_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-text-style17 h1'
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_style_main_text_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style17 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Newsletter Title Style 
        $this->add_control(
			'lcp_ebook_banner_style_newsletter',
			[
				'label' => esc_html__( 'Newsletter Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_banner_style_newsletter_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-form-para-text-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_banner_style_newsletter_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-form-para-text-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_control(
			'lcp_ebook_banner_news_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_banner_news_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style17 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_banner_news_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style17 button'
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-banner-section lc-banner-section-style17" style="overflow-x:hidden">
    			<div class="container-fluid">
    				<div class="row">
    					<div class="col-lg-7 col-sm-12 col-md-12">
    						<div class="row">
    							<div class="col-lg-6 col-md-6 col-sm-12">
    								<div class="lc-banner-img-wrapper lc-banner-img-wrapper-style17 aos-init aos-animate" data-aos="fade-right" data-aos-duration="2000">';
    								    if(!empty($settings['lcp_ebook_banner_left_image']['url'])){
    								        echo '<img src="'.esc_url($settings['lcp_ebook_banner_left_image']['url']).'" alt="">';
    								    }
    								echo '</div>
    							</div>
    							<div class="col-lg-6 col-md-6 col-sm-12">
    								<div class="lc-banner-text lc-banner-text-style17 ">
    									<div class="lc-para-text-style17 aos-init aos-animate" data-aos="zoom-in" data-aos-duration="2000">';
    									    if(!empty($settings['lcp_ebook_banner_highlight_text'])){
    									        echo '<p>'.esc_html($settings['lcp_ebook_banner_highlight_text']).'</p>';
    									    }
    									echo '</div>
    									<div class="lc-banner-heading-text-style17 aos-init aos-animate" data-aos="zoom-out" data-aos-duration="3000">';
    									    if(!empty($settings['lcp_ebook_banner_maintitle'])){
    									        echo '<h1>'.esc_html($settings['lcp_ebook_banner_maintitle']).'</h1>';
    									    }
    									echo '</div>
    									<div class="lc-form-para-text-style17 aos-init aos-animate" data-aos="zoom-out" data-aos-duration="2000">';
    									    if(!empty($settings['lcp_ebook_banner_newstitle'])){
    									        echo '<p>'.esc_html($settings['lcp_ebook_banner_newstitle']).'</p>';
    									    }
    									    if(!empty($settings['lcp_ebook_banner_newstitle_form'])){
    									        echo '<div class="lc-search-wrapper lc-search-wrapper-style17 ">';
    										        echo do_shortcode($settings['lcp_ebook_banner_newstitle_form']);
    										    echo '</div>';
    									    }
    									echo '</div>
    								</div>
    							</div>
    						</div>
    					</div>
    					<div class="col-lg-5 col-md-12 col-sm-12">
    						<div class="lc-banner-img-wrapper lc-banner-img-style17 aos-init aos-animate" data-aos="fade-left" data-aos-duration="2000">';
    						    if(!empty($settings['lcp_ebook_banner_right_image']['url'])){
    						        echo '<img src="'.esc_url($settings['lcp_ebook_banner_right_image']['url']).'" alt="">';
    						    }
    						echo '</div>
    					</div>
    				</div>
    			</div>
    		</div>';
		}
		
	}
}