<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Ebook_BestSeller extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_ebook_bestseller';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Ebook Best Seller', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_ebook_best_seller_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_subheading',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        //List
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_ebook_best_seller_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'The Struggle Of Life', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_best_seller_list_category',
            [
                'label'       => esc_html__( 'Category', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Study Book', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_best_seller_list_rating',
            [
                'label'   => __( 'Rating', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '2',
                'options' => [
                    '1'   => __( '1 Star', 'leadcapture' ),
                    '2'   => __( '2 Star', 'leadcapture' ),
					'3'   => __( '3 Star', 'leadcapture' ),
					'4'   => __( '4 Star', 'leadcapture' ),
					'5'   => __( '5 Star', 'leadcapture' ),
                ],
            ]
        );
        $repeater->add_control(
            'lcp_ebook_best_seller_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_ebook_best_seller_list_himage',
            [
				'label'       => esc_html__( 'Hover Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_ebook_best_seller_list_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_ebook_best_seller_list_title'  => esc_html__('The Struggle Of Life', 'leadcapture' ),
						'lcp_ebook_best_seller_list_category'  => esc_html__('Study Book', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_ebook_best_seller_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_ebook_best_seller_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_ebook_best_seller_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_best_seller_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style17 h3'
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // SubHeading Style
        $this->add_control(
			'lcp_ebook_best_seller_style_subheading',
			[
				'label' => esc_html__( 'SubHeading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_best_seller_style_subheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_style_subheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_style_subheading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 p' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // List Style
        $this->start_controls_section(
            'lcp_ebook_best_seller_list_style_tab', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // List Title
        $this->add_control(
			'lcp_ebook_best_seller_list_style_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_best_seller_list_style_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-top-box-text-style17 h2'
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_list_style_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-top-box-text-style17 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // List Category
        $this->add_control(
			'lcp_ebook_best_seller_list_style_category',
			[
				'label' => esc_html__( 'Category', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_best_seller_list_style_category_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-top-box-text-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_list_style_category_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-top-box-text-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // List Rating
        $this->add_control(
			'lcp_ebook_best_seller_list_style_rating',
			[
				'label' => esc_html__( 'Rating', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_ebook_best_seller_list_style_category_acolor',
            [
                'label'     => esc_html__( 'First Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-top-box-star-rating-style17 .s0.active' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_ebook_best_seller_list_style_category_dcolor',
            [
                'label'     => esc_html__( 'Second Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-top-box-star-rating .s0' => 'fill: {{VALUE}};',
                ],
            ]
        );
        
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-highlight-wrapper lc-highlight-wrapper-style17">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-wrapper-style17">';
                                if(!empty($settings['lcp_ebook_best_seller_subheading'])){
                                    echo '<p>'.esc_html($settings['lcp_ebook_best_seller_subheading']).'</p>'; 
                                }
                                if(!empty($settings['lcp_ebook_best_seller_heading'])){
                                    echo '<h3>'.esc_html($settings['lcp_ebook_best_seller_heading']).'</h3>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="row">';
                    if(!empty($settings['lcp_ebook_best_seller_list'])){
                        foreach($settings['lcp_ebook_best_seller_list'] as $list){
                            echo '<div class="col-lg-3 col-md-6 col-sm-6 col-sm-12">
                                <div class="lc-top-box-wrapper lc-top-box-wrapper-style17 aos-init aos-animate" data-aos="zoom-out-up" data-aos-duration="2000">';
                                    echo !empty($list['lcp_ebook_best_seller_list_link']) ? '<a href="'.esc_url($list['lcp_ebook_best_seller_list_link']).'">' : '';
                                        if(!empty($list['lcp_ebook_best_seller_list_image']['url'])){
                                            echo '<img src="'.esc_url($list['lcp_ebook_best_seller_list_image']['url']).'" alt="" class="lc-top-parent-style17">';
                                        }
                                        if(!empty($list['lcp_ebook_best_seller_list_himage']['url'])){
                                            echo '<img src="'.esc_url($list['lcp_ebook_best_seller_list_himage']['url']).'" alt="" class="lc-top-child-style17">';
                                        }
                                    echo !empty($list['lcp_ebook_best_seller_list_link']) ? '</a>' : '';
                                    echo '<div class="lc-top-box-text lc-top-box-text-style17">
                                        <div class="lc-top-box-star-rating lc-top-box-star-rating-style17">';
                                            if(!empty($list['lcp_ebook_best_seller_list_rating'])){
                                                $rating = $list['lcp_ebook_best_seller_list_rating'];
                                                for($i=1; $i<=$rating; $i++){
                                                    echo '<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 13 14" width="13" height="14">
                                                        <title>Shape 10</title>
                                                        <path id="Shape 10" class="s0 active"
                                                            d="m12.9 5.7l-2.9 3.2 0.7 4.6c0 0.1-0.1 0.3-0.2 0.4-0.1 0.1-0.2 0.1-0.4 0l-3.6-2.1-3.6 2.1q-0.1 0.1-0.2 0.1-0.1 0-0.2-0.1c-0.1-0.1-0.2-0.3-0.2-0.4l0.7-4.6-2.9-3.2c-0.1-0.1-0.1-0.2-0.1-0.4 0.1-0.1 0.2-0.3 0.3-0.3l4.1-0.6 1.8-4.2c0-0.1 0.2-0.2 0.3-0.2 0.2 0 0.3 0.1 0.4 0.2l1.8 4.2 4 0.6c0.1 0 0.3 0.2 0.3 0.3 0.1 0.2 0 0.3-0.1 0.4z" />
                                                    </svg>';
                                                }
                                                $j = 5 - $rating;
                                                if($j != 0){
                                                    for($i=1; $i<=$j; $i++){
                                                        echo '<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 14 14" width="14" height="14">
                                                            <title>Shape 10</title>
                                                            <path id="Shape 10" class="s0"
                                                                d="m13.1 5.7l-2.9 3.2 0.7 4.6c0 0.1 0 0.3-0.1 0.4-0.2 0.1-0.3 0.1-0.5 0l-3.6-2.1-3.6 2.1q-0.1 0.1-0.2 0.1-0.1 0-0.2-0.1c-0.1-0.1-0.2-0.3-0.1-0.4l0.7-4.6-3-3.2c-0.1-0.1-0.1-0.2-0.1-0.4 0.1-0.1 0.2-0.3 0.4-0.3l4-0.6 1.8-4.2c0.1-0.1 0.2-0.2 0.3-0.2 0.2 0 0.3 0.1 0.4 0.2l1.8 4.2 4 0.6c0.2 0 0.3 0.2 0.3 0.3 0.1 0.2 0 0.3-0.1 0.4z" />
                                                        </svg>';
                                                    }
                                                }
                                            }
                                        echo '</div>';
                                        if(!empty($list['lcp_ebook_best_seller_list_title'])){
                                            echo '<h2>'.esc_html($list['lcp_ebook_best_seller_list_title']).'</h2>';
                                        }
                                        if(!empty($list['lcp_ebook_best_seller_list_category'])){
                                            echo '<p>'.esc_html($list['lcp_ebook_best_seller_list_category']).'</p>';
                                        }
                                    echo '</div>
                                </div>
                            </div>';
                        }
                    }
                echo '</div>
            </div>';
		}
		
		
	}
}