<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Ebook_Library extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_ebook_library';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Ebook Library', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_ebook_library_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_ebook_library_subheading',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_library_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        //List
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_ebook_library_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'E-Book', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_library_list_desc',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'consectetur adipiscing elit sed do eiusmodempor incididunt ut labore eteses dolore magna aliqua.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_library_list_link_title',
            [
                'label'       => esc_html__( 'Link Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Read More', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_library_list_link_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_ebook_library_list_icon_image',
            [
				'label'       => esc_html__( 'Icon Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_ebook_library_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_ebook_library_list_title'  => esc_html__( 'E-Book', 'leadcapture' ),
						'lcp_ebook_library_list_desc'  => esc_html__( 'consectetur adipiscing elit sed do eiusmodempor incididunt ut labore eteses dolore magna aliqua.', 'leadcapture' ),
						'lcp_ebook_library_list_link_title'  => esc_html__( 'Read More', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_ebook_library_list_title}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_ebook_library_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_ebook_library_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_library_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style17 h3'
            ]
        );
        $this->add_control(
            'lcp_ebook_library_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // SubHeading Style
        $this->add_control(
			'lcp_ebook_library_style_subheading',
			[
				'label' => esc_html__( 'SubHeading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_library_style_subheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_library_style_subheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_ebook_library_style_subheading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 p' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // List Style
        $this->start_controls_section(
            'lcp_ebook_library_list_style_tab', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        //List Title
        $this->add_control(
			'lcp_ebook_library_style_list_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_library_style_list_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-shipping-text-style17 h2'
            ]
        );
        $this->add_control(
            'lcp_ebook_library_style_list_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-shipping-text-style17 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_ebook_library_style_list_title_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-shipping-box-wrapper:hover h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        //List Description
        $this->add_control(
			'lcp_ebook_library_style_list_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_library_style_list_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-shipping-text-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_library_style_list_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-shipping-text-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //List Title
        $this->add_control(
			'lcp_ebook_library_style_list_link',
			[
				'label' => esc_html__( 'Link', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_library_style_list_link_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-shipping-text-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_library_style_list_link_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-shipping-text-style17 a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-shipping-text-style17 a:before' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        //List Extra
        $this->add_control(
			'lcp_ebook_library_style_list_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_ebook_library_style_list_himage_color',
            [
                'label'     => esc_html__( 'Hover Image Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-shipping-icon-style17:before' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-shipping-wrapper lc-shipping-wrapper-style17">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-wrapper-style17">';
                                if(!empty($settings['lcp_ebook_library_subheading'])){
                                    echo '<p>'.esc_html($settings['lcp_ebook_library_subheading']).'</p>';
                                } 
                                if(!empty($settings['lcp_ebook_library_heading'])){
                                    echo '<h3>'.esc_html($settings['lcp_ebook_library_heading']).'</h3>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="row">';
                        if(!empty($settings['lcp_ebook_library_list'])){
                            foreach($settings['lcp_ebook_library_list'] as $list){
                                echo '<div class="col-lg-3 col-md-6 col-sm-6 col-12">
                                    <div class="lc-shipping-box-wrapper lc-shipping-box-wrapper-style17 aos-init aos-animate" data-aos="flip-left" data-aos-duration="2000">
                                        <div class="lc-shipping-icon lc-shipping-icon-style17">';
                                            if(!empty($list['lcp_ebook_library_list_icon_image']['url'])){
                                                echo '<img src="'.esc_url($list['lcp_ebook_library_list_icon_image']['url']).'" alt="">';
                                            }
                                        echo '</div>
                                        <div class="lc-shipping-text lc-shipping-text-style17">';
                                            if(!empty($list['lcp_ebook_library_list_title'])){
                                                echo '<h2>'.esc_html($list['lcp_ebook_library_list_title']).'</h2>';
                                            }
                                            if(!empty($list['lcp_ebook_library_list_desc'])){
                                                echo '<p>'.esc_html($list['lcp_ebook_library_list_desc']).'</p>';
                                            }
                                            if(!empty($list['lcp_ebook_library_list_link_title'])){
                                                echo '<a href="'.esc_url($list['lcp_ebook_library_list_link_link']).'">'.esc_html($list['lcp_ebook_library_list_link_title']).'</a>';
                                            }
                                        echo '</div>
                                    </div>
                                </div>';
                            }
                        }
                    echo '</div>
                </div>
            </div>'; 
		}
	}
}