<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Ebook_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_ebook_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Ebook Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_ebook_testi_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_subheading',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        
        //List
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_ebook_testi_list_author',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Jessica Vanessa', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_testi_list_postion',
            [
                'label'       => esc_html__( 'Designation', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'UI/UX Designer', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_testi_list_testi',
            [
                'label'       => esc_html__( 'Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliquese endese uis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan lacus vel facilisis and the part of new company and many people are working on that.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_ebook_testi_list_image',
            [
				'label'       => esc_html__( 'Author Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_ebook_testi_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_ebook_testi_list_author'  => esc_html__( 'Jessica Vanessa', 'leadcapture' ),
						'lcp_ebook_testi_list_postion'  => esc_html__( 'UI/UX Designer', 'leadcapture' ),
						'lcp_ebook_testi_list_testi'  => esc_html__( 'Consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliquese endese uis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan lacus vel facilisis and the part of new company and many people are working on that.', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_ebook_testi_list_author}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_ebook_testi_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_ebook_testi_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_testi_style_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style17 h3'
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_style_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // SubHeading Style
        $this->add_control(
			'lcp_ebook_testi_style_subheading',
			[
				'label' => esc_html__( 'SubHeading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_testi_style_subheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_style_subheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_style_subheading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style17 p' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // List Style
        $this->start_controls_section(
            'lcp_ebook_testi_list_style_tab', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        //List Author
        $this->add_control(
			'lcp_ebook_testi_list_style_author',
			[
				'label' => esc_html__( 'Author', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_testi_list_style_author_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-testimonial-box-img .btest-box-text > h4'
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_list_style_author_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-img .btest-box-text > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        //List Title
        $this->add_control(
			'lcp_ebook_testi_list_style_designation',
			[
				'label' => esc_html__( 'Designation', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_testi_list_style_designation_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-testimonial-box-img-style17 .btest-box-text-style17 p'
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_list_style_designation_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-img-style17 .btest-box-text-style17 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //List Testimonial
        $this->add_control(
			'lcp_ebook_testi_list_style_testi',
			[
				'label' => esc_html__( 'Testimonial', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ebook_testi_list_style_testi_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-testimonial-box-style17>p'
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_list_style_testi_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-style17>p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // List Style
        $this->start_controls_section(
            'lcp_ebook_testi_list_style_page', 
            [
                'label' => esc_html__( 'Pagination', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_list_style_page_acolor',
            [
                'label'     => esc_html__( 'Active Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-slider-wrapper-style17 .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_ebook_testi_list_style_page_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-slider-wrapper-style17 .swiper-pagination-bullet' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-testimonial-wrapper lc-testimonial-wrapper-style17">
    			<div class="container">
    				<div class="row">
    					<div class="col-lg-12 col-md-12 col-sm-12">
    						<div class="lc-heading-wrapper lc-heading-wrapper-style17">';
    						    if(!empty($settings['lcp_ebook_testi_subheading'])){
    						        echo '<p>'.$settings['lcp_ebook_testi_subheading'].'</p>';
    						    }
    						    if(!empty($settings['lcp_ebook_testi_heading'])){
    						        echo '<h3>'.$settings['lcp_ebook_testi_subheading'].'</h3>';
    						    }
    						echo '</div>
    					</div>
    				</div>
    				<div class="row">
    				    <div class="col-lg-12 col-md-12 col-sm-12">
    				        <div class="lc-testimonial-slider-wrapper lc-testimonial-slider-wrapper-style17 aos-init aos-animate" data-aos="fade-down" data-aos-duration="2000">
    				            <div class="swiper lc-testimonial-slider-style17">
								    <div class="swiper-wrapper">';
								        if(!empty($settings['lcp_ebook_testi_list'])){
								            foreach($settings['lcp_ebook_testi_list'] as $list){
								                echo '<div class="swiper-slide">
        								            <div class="lc-testimonial-box lc-testimonial-box-style17">
            											<div class="lc-testimonial-box-img-wrapper lc-testimonial-box-img-wrapper-style17">
            												<div class="lc-testimonial-box-img lc-testimonial-box-img-style17">';
            												    if(!empty($list['lcp_ebook_testi_list_image']['url'])){
            												        echo '<img src="'.esc_url($list['lcp_ebook_testi_list_image']['url']).'" alt="'.esc_attr('testimonial-img', 'leadcapture').'">'; 
            												    }
            													echo '<div class="btest-box-text btest-box-text-style17">';
                													if(!empty($list['lcp_ebook_testi_list_author'])){
                													    echo '<h4>'.esc_html($list['lcp_ebook_testi_list_author']).'</h4>';
                													}
                													if(!empty($list['lcp_ebook_testi_list_postion'])){
                													    echo '<p>'.esc_html($list['lcp_ebook_testi_list_postion']).'</p>';
                													}
            													echo '</div>
            												</div>
            												<div class="lc-testimonial-box-star">
            													<img src="'.LEAD_CAPTURE_URL.'/public/images/quotes.png" alt="'.esc_html('quotes', 'leadcapture').'">
            												</div>
            											</div>';
            											if(!empty($list['lcp_ebook_testi_list_testi'])){
            											    echo '<p>'.esc_html($list['lcp_ebook_testi_list_testi']).'</p>';
            											}
            										echo '</div>
        								        </div>';
								            }
								        }
								    echo '</div>
								</div>
    				            <div class="swiper-pagination "></div>
    				        </div>
    				    </div>
    				</div>
    			</div>
    		</div>';
		}
	}
}