<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Education_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_education_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Education Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_education_banner_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_education_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_banner_desc',
            [
                'label'       => esc_html__( 'Decription', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_banner_fbtn_title',
            [
                'label'       => esc_html__( 'First Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_banner_fbtn_link',
            [
                'label'       => esc_html__( 'First Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_banner_sbtn_title',
            [
                'label'       => esc_html__( 'Second Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_banner_sbtn_link',
            [
                'label'       => esc_html__( 'Second Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_banner_logo',
            [
				'label'       => esc_html__( 'Logo', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_education_banner_image',
            [
				'label'       => esc_html__( 'Big Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_education_banner_bimage',
            [
				'label'       => esc_html__( 'Bottom Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_education_banner_section_image',
            [
				'label'       => esc_html__( 'Section Background Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_education_banner_icons',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::GALLERY,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		$this->start_controls_section(
            'lcp_education_banner_newsletter', 
            [
               'label' => esc_html__( 'NewsLetter Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_education_banner_newsletter_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_banner_newsletter_shortcode',
            [
                'label'       => esc_html__( 'Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_banner_newsletter_icon',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_education_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_education_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-header-text-style-26 h1'
            ]
        );
        $this->add_control(
            'lcp_education_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-header-text-style-26 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_banner_style_heading_extra_color',
            [
                'label'     => esc_html__( 'Extra Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-header-text-style-26 h1>span:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_education_banner_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_banner_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-header-text.lc-header-text-style-26 p'
            ]
        );
        $this->add_control(
            'lcp_education_banner_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-header-text.lc-header-text-style-26 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_education_banner_style_button', 
            [
                'label' => esc_html__( 'Button Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Button One Style
        $this->add_control(
			'lcp_education_banner_style_fbutton',
			[
				'label' => esc_html__( 'First Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_banner_style_fbutton_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-btn-join-style26 a'
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_education_banner_style_fbutton_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_education_banner_style_fbutton_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-btn-join-style26 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_fbutton_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-btn-join-style26' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_education_banner_style_fbutton_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-btn-join-style26',
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_fbutton_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-btn-join-style26' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_education_banner_style_fbutton_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_education_banner_style_fbutton_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-btn-join-style26:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_fbutton_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-btn-join-style26::before' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_education_banner_style_fbutton_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-btn-join-style26:hover',
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_fbutton_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-btn-join-style26:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
		
		// Button Two Style
        $this->add_control(
			'lcp_education_banner_style_sbutton',
			[
				'label' => esc_html__( 'Second Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_banner_style_sbutton_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-explore-style26 a'
            ]
        );
        
        $this->start_controls_tabs( 'button_colors' );
		$this->start_controls_tab(
			'lcp_education_banner_style_sbutton_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_education_banner_style_sbutton_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-explore-style26 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_sbutton_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-explore-style26' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_education_banner_style_sbutton_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-explore-style26',
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_sbutton_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-explore-style26' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_education_banner_style_sbutton_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_education_banner_style_sbutton_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-explore-style26:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_sbutton_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-explore-style26::before' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_education_banner_style_sbutton_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-explore-style26:hover',
            ]
        );
		$this->add_control(
            'lcp_education_banner_style_sbutton_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-explore-style26:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
        $this->end_controls_section();
        
        // NewsLetter Style
        $this->start_controls_section(
            'lcp_education_banner_news_style', 
            [
                'label' => esc_html__( 'NewsLetter Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Button One Style
        $this->add_control(
			'lcp_education_banner_news_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_banner_news_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-newsletter.lc-newsletter-style26 p'
            ]
        );
        $this->add_control(
            'lcp_education_banner_news_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-newsletter.lc-newsletter-style26 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'lcp_education_banner_news_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_banner_news_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style26 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_banner_news_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style26 button'
            ]
        );
		
        // Button One Style
        $this->add_control(
			'lcp_education_banner_news_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_education_banner_news_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-icon-img-style26' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_banner_news_style_extra_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bg-email-box' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		$style = !empty($settings['lcp_education_banner_section_image']['url']) ? 'style="background: url('.esc_url($settings['lcp_education_banner_section_image']['url']).');background-size:cover!important;background-position:top!important"' : '';
		if(!empty($settings)){
		    echo '<div class="lc-banner-section lc-banner-section-style26" '.$style.'>
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 col-sm-12 col-md-12">
                            <div class="lc-header-text-wrapper lc-header-text-wrapper-style26">';
                                if(!empty($settings['lcp_education_banner_logo']['url'])){
                                    echo '<div class="lc-logo-img lc-logo-img-style26">
                                        <img src="'.esc_url($settings['lcp_education_banner_logo']['url']).'" alt="'.esc_attr('logo-img', 'leadcapture').'">
                                    </div>';
                                }
                                echo '<div class="lc-header-text lc-header-text-style-26">';
                                    if(!empty($settings['lcp_education_banner_title'])){
                                        echo '<h1>';
                                        print($settings['lcp_education_banner_title']);
                                        echo '</h1>';
                                    }
                                    if(!empty($settings['lcp_education_banner_desc'])){
                                        echo '<p>'.esc_html($settings['lcp_education_banner_desc']).'</p>';
                                    }
                                echo '</div>
                                <div class="lc-education-flex">';
                                    if(!empty($settings['lcp_education_banner_fbtn_title'])){
                                        echo '<div class="lc-btn lc-btn-join-style26">
                                            <a href="'.esc_url($settings['lcp_education_banner_fbtn_link']).'">'.esc_html($settings['lcp_education_banner_fbtn_title']).'</a>
                                        </div>';
                                    }
                                    if(!empty($settings['lcp_education_banner_sbtn_title'])){
                                        echo '<div class="lc-btn lc-btn-join-style26 lc-explore-style26">
                                            <a href="'.esc_url($settings['lcp_education_banner_sbtn_link']).'">'.esc_html($settings['lcp_education_banner_sbtn_title']).'</a>
                                        </div>';
                                    }
                                echo '</div>
                                <div class="lc-newsletter lc-newsletter-style26">';
                                    if(!empty($settings['lcp_education_banner_newsletter_title'])){
                                        echo '<p>'.esc_html($settings['lcp_education_banner_newsletter_title']).'</p>';
                                    }
                                    if(!empty($settings['lcp_education_banner_newsletter_shortcode'])){
                                        echo '<div class="lc-bg-email-box">
                                            <div class="lc-search-wrapper lc-search-wrapper-style26">';
                                                echo do_shortcode($settings['lcp_education_banner_newsletter_shortcode']);
                                            echo '</div>';
                                            if(!empty($settings['lcp_education_banner_newsletter_icon']['url'])){
                                                echo '<div class="lc-icon-img-style26">
                                                    <img src="'.esc_url($settings['lcp_education_banner_newsletter_icon']['url']).'" alt="">
                                                </div>';
                                            }
                                        echo '</div>';
                                    }
                                echo '</div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">';
                            if(!empty($settings['lcp_education_banner_image']['url'])){
                                echo '<div class="lc-banner-img-wrapper lc-banner-img-style26">
                                    <img src="'.esc_url($settings['lcp_education_banner_image']['url']).'" alt="">';
                                    if(!empty($settings['lcp_education_banner_icons'])){
                                        echo '<div class="lc-banner-icon lc-banner-icon-style26">';
                                            foreach($settings['lcp_education_banner_icons'] as $img){
                                                echo '<img src="'.esc_url($img['url']).'">';
                                            }
                                        echo '</div>';
                                    }
                                echo '</div>';
                            }
                        echo '</div>
                    </div>
                </div>';
                if(!empty($settings['lcp_education_banner_bimage']['url'])){
                    echo '<div class="lc-bottom-style26">
                        <a href="#courses"><img src="'.esc_html($settings['lcp_education_banner_bimage']['url']).'" alt=""></a>
                    </div>';
                }
            echo '</div>';
		}
	}
}