<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Eduction_Courseprice extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_eduction_courseprice';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Eduction Course Price', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_education_course_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_education_course_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_course_desc',
            [
                'label'       => esc_html__( 'Decription', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_icon',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		// Price Plan One
		$this->start_controls_section(
            'lcp_education_course_price_one', 
            [
               'label' => esc_html__( 'Course Plan One', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_education_course_price_one_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_one_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_one_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_one_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_one_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater_one = new Repeater();
        $repeater_one->add_control(
            'lcp_education_course_price_one_list_text',
            [
                'label'       => esc_html__( 'Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_education_course_price_one_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_education_course_price_one_list_text'  => esc_html__( 'Get latest news', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater_one->get_controls(),
                'title_field' => '{{lcp_education_course_price_one_list_text}}',
            ]
        );
        $this->end_controls_section();
        
        // Price Plan Two
		$this->start_controls_section(
            'lcp_education_course_price_two', 
            [
               'label' => esc_html__( 'Course Plan Two', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_education_course_price_two_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_two_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_two_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_two_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_two_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater_two = new Repeater();
        $repeater_two->add_control(
            'lcp_education_course_price_two_list_text',
            [
                'label'       => esc_html__( 'Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_education_course_price_two_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_education_course_price_two_list_text'  => esc_html__( 'Get latest news', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater_two->get_controls(),
                'title_field' => '{{lcp_education_course_price_two_list_text}}',
            ]
        );
        $this->end_controls_section();
        
        // Price Plan Three
		$this->start_controls_section(
            'lcp_education_course_price_three', 
            [
               'label' => esc_html__( 'Course Plan Three', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_education_course_price_three_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_three_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_three_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_three_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_education_course_price_three_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater_three = new Repeater();
        $repeater_three->add_control(
            'lcp_education_course_price_three_list_text',
            [
                'label'       => esc_html__( 'Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_education_course_price_three_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_education_course_price_three_list_text'  => esc_html__( 'Get latest news', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater_three->get_controls(),
                'title_field' => '{{lcp_education_course_price_three_list_text}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_education_course_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_education_course_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_course_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing-heading.lc-pricing-heading-style26 h2'
            ]
        );
        $this->add_control(
            'lcp_education_course_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-heading.lc-pricing-heading-style26 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_course_heading_extra_color',
            [
                'label'     => esc_html__( 'Extra Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-heading.lc-pricing-heading-style26 h2>span::before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_education_course_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_course_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing-heading.lc-pricing-heading-style26 p'
            ]
        );
        $this->add_control(
            'lcp_education_course_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-heading.lc-pricing-heading-style26 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Description Style
        $this->add_control(
			'lcp_education_course_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_education_course_style_extra_bg_color',
            [
                'label'     => esc_html__( 'Course Bg Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box.lc-plan-box-style26' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_course_style_extra_border_color',
            [
                'label'     => esc_html__( 'Course Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box.lc-plan-box-style26::after' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_education_course_course_style', 
            [
                'label' => esc_html__( 'Course Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_education_course_course_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_course_course_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-course-box.lc-course-box-style26 p'
            ]
        );
        $this->add_control(
            'lcp_education_course_course_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-course-box.lc-course-box-style26 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_course_course_style_heading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-course-box.lc-course-box-style26' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Symbol & Price Style
        $this->add_control(
			'lcp_education_course_course_style_symbol',
			[
				'label' => esc_html__( 'Symbol & Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_course_course_style_symbol_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box.lc-plan-box-style26 h2, .lc-plan-box.lc-plan-box-style26 h2>sub'
            ]
        );
        $this->add_control(
            'lcp_education_course_course_style_symbol_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box.lc-plan-box-style26 h2' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-plan-box.lc-plan-box-style26 h2>sub' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Text Style
        $this->add_control(
			'lcp_education_course_course_style_list',
			[
				'label' => esc_html__( 'List Text', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_course_course_style_list_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box.lc-plan-box-style26 ul li'
            ]
        );
        $this->add_control(
            'lcp_education_course_course_style_list_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box.lc-plan-box-style26 ul li' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button Style
        $this->add_control(
			'lcp_education_course_course_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_course_course_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn-style26 a'
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_education_course_course_style_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_education_course_course_style_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn-style26 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_education_course_course_style_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn-style26' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_education_course_course_style_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn-style26',
            ]
        );
		$this->add_control(
            'lcp_education_course_course_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn-style26' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_education_course_course_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_education_course_course_style_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn-style26:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_education_course_course_style_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn-style26::before' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_education_course_course_style_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn-style26:hover',
            ]
        );
		$this->add_control(
            'lcp_education_course_course_style_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn-style26:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-pricing-table-wrapper lc-pricing-table-wrapper-style26" id="courses">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12">
                            <div class="lc-pricing-heading lc-pricing-heading-style26">';
                                if(!empty($settings['lcp_education_course_title'])){
                                    echo '<h2>';
                                        printf($settings['lcp_education_course_title']);
                                    echo '</h2>';
                                }
                                if(!empty($settings['lcp_education_course_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_education_course_desc']).'</p>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-4 col-md-6 col-sm-12">
                            <div class="lc-plan-box lc-plan-box-style26">';
                                if(!empty($settings['lcp_education_course_price_one_title'])){
                                    echo '<div class="lc-course-box lc-course-box-style26">
                                        <p>'.esc_html($settings['lcp_education_course_price_one_title']).'</p>
                                    </div>';
                                }
                                if(!empty($settings['lcp_education_course_price_one_symbol']) || !empty($settings['lcp_education_course_price_one_price'])){
                                    echo '<h2>'.esc_html($settings['lcp_education_course_price_one_symbol']).'<sub>'.esc_html($settings['lcp_education_course_price_one_price']).'</sub></h2>';
                                }
                                if(!empty($settings['lcp_education_course_price_one_list'])){
                                    echo '<ul>';
                                        foreach($settings['lcp_education_course_price_one_list'] as $list){
                                            echo '<li>';
                                                if($settings['lcp_education_course_price_icon']['url']){
                                                    echo '<img src="'.esc_html($settings['lcp_education_course_price_icon']['url']).'">'.$list['lcp_education_course_price_one_list_text'];
                                                }
                                            echo '</li>';
                                        }
                                    echo '</ul>';
                                }
                                if(!empty($settings['lcp_education_course_price_one_btn_title'])){
                                    echo '<div class="lc-plan-btn-style26">
                                        <a href="'.esc_url($settings['lcp_education_course_price_one_btn_link']).'">'.esc_html($settings['lcp_education_course_price_one_btn_title']).'</a>
                                    </div>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-4 col-md-6 col-sm-12">
                            <div class="lc-plan-box lc-plan-box-style26">';
                                if(!empty($settings['lcp_education_course_price_two_title'])){
                                    echo '<div class="lc-course-box lc-course-box-style26">
                                        <p>'.esc_html($settings['lcp_education_course_price_two_title']).'</p>
                                    </div>';
                                }
                                if(!empty($settings['lcp_education_course_price_two_symbol']) || !empty($settings['lcp_education_course_price_two_price'])){
                                    echo '<h2>'.esc_html($settings['lcp_education_course_price_two_symbol']).'<sub>'.esc_html($settings['lcp_education_course_price_two_price']).'</sub></h2>';
                                }
                                if(!empty($settings['lcp_education_course_price_two_list'])){
                                    echo '<ul>';
                                        foreach($settings['lcp_education_course_price_two_list'] as $list){
                                            echo '<li>';
                                                if($settings['lcp_education_course_price_icon']['url']){
                                                    echo '<img src="'.esc_html($settings['lcp_education_course_price_icon']['url']).'">'.$list['lcp_education_course_price_two_list_text'];
                                                }
                                            echo '</li>';
                                        }
                                    echo '</ul>';
                                }
                                if(!empty($settings['lcp_education_course_price_two_btn_title'])){
                                    echo '<div class="lc-plan-btn-style26">
                                        <a href="'.esc_url($settings['lcp_education_course_price_two_btn_link']).'">'.esc_html($settings['lcp_education_course_price_two_btn_title']).'</a>
                                    </div>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-4 col-md-6 offset-md-3 col-sm-12">
                            <div class="lc-plan-box lc-plan-box-style26">';
                                if(!empty($settings['lcp_education_course_price_three_title'])){
                                    echo '<div class="lc-course-box lc-course-box-style26">
                                        <p>'.esc_html($settings['lcp_education_course_price_three_title']).'</p>
                                    </div>';
                                }
                                if(!empty($settings['lcp_education_course_price_three_symbol']) || !empty($settings['lcp_education_course_price_three_price'])){
                                    echo '<h2>'.esc_html($settings['lcp_education_course_price_three_symbol']).'<sub>'.esc_html($settings['lcp_education_course_price_three_price']).'</sub></h2>';
                                }
                                if(!empty($settings['lcp_education_course_price_three_list'])){
                                    echo '<ul>';
                                        foreach($settings['lcp_education_course_price_three_list'] as $list){
                                            echo '<li>';
                                                if($settings['lcp_education_course_price_icon']['url']){
                                                    echo '<img src="'.esc_html($settings['lcp_education_course_price_icon']['url']).'">'.$list['lcp_education_course_price_three_list_text'];
                                                }
                                            echo '</li>';
                                        }
                                    echo '</ul>';
                                }
                                if(!empty($settings['lcp_education_course_price_three_btn_title'])){
                                    echo '<div class="lc-plan-btn-style26">
                                        <a href="'.esc_url($settings['lcp_education_course_price_three_btn_link']).'">'.esc_html($settings['lcp_education_course_price_three_btn_title']).'</a>
                                    </div>';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}