<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Education_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_education_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Education Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon. 
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_education_testi_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_education_testi_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_education_testi_desc',
            [
                'label'       => esc_html__( 'Decription', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_education_testi_list_author',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_education_testi_list_postion',
            [
                'label'       => esc_html__( 'Designation', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_education_testi_list_testimonial',
            [
                'label'       => esc_html__( 'Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_education_testi_list_rating',
            [
                'label'   => __( 'Rating', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '4',
                'options' => [
                    '1'   => __( '1 Star', 'leadcapture' ),
                    '2'   => __( '2 Star', 'leadcapture' ),
					'3'   => __( '3 Star', 'leadcapture' ),
					'4'   => __( '4 Star', 'leadcapture' ),
					'5'   => __( '5 Star', 'leadcapture' ),
                ]
            ]
        );
        $repeater->add_control(
            'lcp_education_testi_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
		$this->add_control(
            'lcp_education_testi_list',
            [
                'label'       => esc_html__( 'Add Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_education_testi_list_author}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_education_testi_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_education_testi_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_testi_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style26 h2'
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style26 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_heading_extra_color',
            [
                'label'     => esc_html__( 'Extra Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style26 h2>span::before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_education_testi_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_testi_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style26 p'
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style26 p' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_education_testi_style_testi', 
            [
                'label' => esc_html__( 'Testimonial Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_education_testi_style_testi_author',
			[
				'label' => esc_html__( 'Author', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_testi_style_testi_author_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-para-style26 h4'
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_testi_author_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-para-style26 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_education_testi_style_testi_postion',
			[
				'label' => esc_html__( 'Designation', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before', 
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_testi_style_testi_postion_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-para-style26 p'
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_testi_postion_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-para-style26 p' => 'color: {{VALUE}}!important;',
                ],
            ]
        );
        
        // Rating Style
        $this->add_control(
			'lcp_education_testi_style_testi_rating',
			[
				'label' => esc_html__( 'Rating Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before', 
			]
		);
        $this->add_control(
            'lcp_education_testi_style_testi_rating_acivecolor',
            [
                'label'     => esc_html__( 'Active Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-stare-img-style26 svg .s0' => 'fill: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_testi_rating_dectivecolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-stare-img-style26 span svg .s0' => 'fill: {{VALUE}}!important;',
                ],
            ]
        );
        
        // Desription Style
        $this->add_control(
			'lcp_education_testi_style_testi_desc',
			[
				'label' => esc_html__( 'Designation', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before', 
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_education_testi_style_testi_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-text-style26 p'
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_testi_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-text-style26 p' => 'color: {{VALUE}}!important;',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_education_testi_style_nav', 
            [
                'label' => esc_html__( 'Navigation Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Desription Style
        $this->add_control(
			'lcp_education_testi_style_nav_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before', 
			]
		);
		$this->add_control(
            'lcp_education_testi_style_nav_normal_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-prev>svg>.s0' => 'fill: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-next>svg>.s0' => 'fill: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_nav_normal_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-prev' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-next' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        
        // Desription Style
        $this->add_control(
			'lcp_education_testi_style_nav_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before', 
			]
		);
		$this->add_control(
            'lcp_education_testi_style_nav_normal_Hcolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-prev:hover >svg>.s0' => 'fill: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-next:hover >svg>.s0' => 'fill: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_education_testi_style_nav_normal_Hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-next:hover' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-wrapper-style26 .lc-testimonial-slider-btn-style26>.swiper-button-prev:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
		
		
        
        
        $this->end_controls_section();
		
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-testimonial-wrapper lc-testimonial-wrapper-style26">
                <div class="container">
                    <div class="row"> 
                        <div class="col-lg-4 col-md-12 col-sm-12">
                            <div class="lc-test-head-wrapper lc-test-head-wrapper-style26">
                                <div class="lc-heading-wrapper lc-heading-style26">';
                                    if(!empty($settings['lcp_education_testi_title'])){
                                        echo '<h2>'; 
                                            printf($settings['lcp_education_testi_title']);
                                        echo '</h2>';
                                    }
                                    if(!empty($settings['lcp_education_testi_desc'])){
                                        echo '<p>'.esc_html($settings['lcp_education_testi_desc']).'</p>';
                                    }
                                echo '</div>
                                <div class="lc-testimonial-slider-btn lc-testimonial-slider-btn-style26">
                                    <div class="swiper-button-next">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 13 20" width="13"
                                            height="20">
                                            <title>Shape 7 copy</title>
                                            <path id="Shape 7 copy" class="s0"
                                                d="m0 17.2l7.3-7.2-7.3-7.2 2.9-2.8 10.1 10-10.1 10z" />
                                        </svg>
                                    </div>
                                    <div class="swiper-button-prev">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 13 20" width="13"
                                            height="20">
                                            <title>Shape 7</title>
                                            <path id="Shape 7" class="s0"
                                                d="m13 3.3l-7.1 7 7.1 7.1-2.8 2.8-9.9-9.9 9.9-9.8z" />
                                        </svg>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-8 col-md-12 col-sm-12">
                            <div class="lc-testimonial-slider-wrapper lc-testimonial-slider-wrapper-style26">
                                <div class="swiper lc-testimonial-slider-style26">
                                    <div class="swiper-wrapper">';
                                        if(!empty($settings['lcp_education_testi_list'])){
                                            foreach($settings['lcp_education_testi_list'] as $list){
                                                echo '<div class="swiper-slide">
                                                    <div class="lc-test-box-style26">
                                                        <div class="lc-test-text-style26 ">
                                                            <div class="lc-flex-text-style26">
                                                                <div class="lc-test-para-style26">';
                                                                    if(!empty($list['lcp_education_testi_list_author'])){
                                                                        echo '<h4>'.esc_html($list['lcp_education_testi_list_author']).'</h4>';  
                                                                    }
                                                                    if(!empty($list['lcp_education_testi_list_postion'])){
                                                                        echo '<p>'.esc_html($list['lcp_education_testi_list_postion']).'</p>';
                                                                    }
                                                                echo '</div>
                                                                <div class="lc-stare-img-style26">';
                                                                    if(!empty($list['lcp_education_testi_list_rating'])){
                                                                        $rating = $list['lcp_education_testi_list_rating'];
                                                                        for($i=1; $i<=$rating; $i++){
                                                                            echo '<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 21 20" width="21" height="20">
                                                                                <title>Polygon 1 copy 2</title>
                                                                                <path id="Polygon 1 copy 2" class="s0"
                                                                                    d="m10.5-0.2l3 6.6 6.8 0.9-5 5 1.3 7.2-6.1-3.5-6.1 3.5 1.3-7.2-5-5 6.9-0.9z" />
                                                                            </svg>';
                                                                        }
                                                                        $j = 5 - $rating;
                                                                        if($j != 0){
                                                                            for($i=1; $i<=$j; $i++){
                                                                                echo '<span><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 21 20" width="21" height="20">
                                                                                    <title>Polygon 1 copy 3</title>
                                                                                    <path id="Polygon 1 copy 3" class="s0"
                                                                                        d="m10.5-0.2l3 6.6 6.8 0.9-5 5 1.3 7.2-6.1-3.5-6.1 3.5 1.3-7.2-5-5 6.9-0.9z" />
                                                                                </svg></span>';
                                                                            }
                                                                        }
                                                                    }
                                                                echo '</div>
                                                            </div>';
                                                            if(!empty($list['lcp_education_testi_list_testimonial'])){
                                                                echo '<p>'.esc_html($list['lcp_education_testi_list_testimonial']).'</p>';
                                                            }
                                                            if(!empty($list['lcp_education_testi_list_image']['url'])){
                                                                echo '<div class=" lc-test-img-style26">
                                                                    <img src="'.esc_url($list['lcp_education_testi_list_image']['url']).'" alt="">
                                                                </div>';
                                                            }
                                                        echo '</div>
                                                    </div>
                                                </div>';       
                                            }
                                        }
                                    echo '</div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}