<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Electronic_Adds extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_electronic_adds';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Electronic Adds', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_electronic_adds_one_general', 
            [
               'label' => esc_html__( 'Add One', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_ads_one_stitle',
            [
                'label'       => esc_html__( 'Small Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_one_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_one_currency',
            [
                'label'       => esc_html__( 'Currency', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_one_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_one_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_one_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_ads_one_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		$this->start_controls_section(
            'lcp_electronic_adds_two_general', 
            [
               'label' => esc_html__( 'Add Two', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_ads_two_stitle',
            [
                'label'       => esc_html__( 'Small Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_two_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_two_currency',
            [
                'label'       => esc_html__( 'Currency', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_two_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_two_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_ads_two_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_ads_two_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		// Widget Style
        $this->start_controls_section(
            'lcp_electronic_adds_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_electronic_adds_style_sheading',
			[
				'label' => esc_html__( 'Small Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-collection-box-text > span'
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-collection-box-text > span' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_electronic_adds_style_heading',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-collection-box-text > h2'
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-collection-box-text > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_electronic_adds_style_price',
			[
				'label' => esc_html__( 'Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_textprice_typography',
                'label'       => esc_html__( 'Text Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-collection-box-text > p'
            ]
        );
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_price_typography',
                'label'       => esc_html__( 'Price Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-collection-box-text > p > span.lc-price'
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_style_price_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-collection-box-text > p' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-collection-box-text > p > span.lc-price' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button One Style
        $this->add_control(
			'lcp_electronic_adds_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_electronic_adds_style_ads_one_bgcolor',
            [
                'label'     => esc_html__( 'Ads One Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-collection-box1' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_electronic_adds_style_ads_two_bgcolor',
            [
                'label'     => esc_html__( 'Ads Two Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-collection-box2' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_electronic_adds_style_btn', 
            [
                'label' => esc_html__( 'Button Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Button One Style
        $this->add_control(
			'lcp_electronic_adds_style_one_button',
			[
				'label' => esc_html__( 'Button One', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_one_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-buybtn-style18 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_electronic_adds_style_one_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_electronic_adds_style_one_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn-style18 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_style_one_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn-style18' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_one_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-buybtn-style18',
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_style_one_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn-style18' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_electronic_adds_style_one_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_electronic_adds_style_one_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn-style18:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_style_one_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn-style18:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_one_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-buybtn-style18:hover',
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_button_one_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn-style18:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
		
		// Button Two Style
        $this->add_control(
			'lcp_electronic_adds_style_two_button',
			[
				'label' => esc_html__( 'Button Two', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_two_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-buybtn2-style18 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_colors' );
		$this->start_controls_tab(
			'lcp_electronic_adds_style_two_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_electronic_adds_style_two_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn2-style18 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_style_two_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn2-style18' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_two_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-buybtn2-style18',
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_style_two_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn2-style18' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_electronic_adds_style_two_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_electronic_adds_style_two_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn2-style18:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_style_two_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn2-style18:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_electronic_adds_style_two_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-buybtn2-style18:hover',
            ]
        );
		$this->add_control(
            'lcp_electronic_adds_button_two_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-buybtn2-style18:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();  
		
		$this->end_controls_section();
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-collection-wrapper">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-collection-box lc-collection-box1">';
                                if(!empty($settings['lcp_electronic_adds_ads_one_image']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_electronic_adds_ads_one_image']['url']).'" alt="'.esc_attr('sales-img1', 'leadcapture').'">';
                                }
                                echo '<div class="lc-collection-box-text">';
                                    if(!empty($settings['lcp_electronic_adds_ads_one_stitle'])){
                                        echo '<span>'.esc_html($settings['lcp_electronic_adds_ads_one_stitle']).'</span>';
                                    }
                                    if(!empty($settings['lcp_electronic_adds_ads_one_title'])){
                                        echo '<h2>'.esc_html($settings['lcp_electronic_adds_ads_one_title']).'</h2>';
                                    }
                                    if(!empty($settings['lcp_electronic_adds_ads_one_price'])){
                                        echo '<p>'.esc_html__('Start from', 'leadcapture').' <span class="lc-price">'.esc_html($settings['lcp_electronic_adds_ads_one_currency']).esc_html($settings['lcp_electronic_adds_ads_one_price']).'</span></p>';
                                    }
                                    if(!empty($settings['lcp_electronic_adds_ads_one_btn_title'])){
                                        echo '<div class="lc-btn lc-buybtn-style18">
                                            <a href="'.esc_url($settings['lcp_electronic_adds_ads_one_btn_link']).'">'.esc_html($settings['lcp_electronic_adds_ads_one_btn_title']).'</a>
                                        </div>';        
                                    }
                                echo '</div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-collection-box lc-collection-box2">
                                <div class="lc-collection-box-text">';
                                    if(!empty($settings['lcp_electronic_adds_ads_two_stitle'])){
                                        echo '<span>'.esc_html($settings['lcp_electronic_adds_ads_two_stitle']).'</span>';
                                    }
                                    if(!empty($settings['lcp_electronic_adds_ads_two_title'])){
                                        echo '<h2>'.esc_html($settings['lcp_electronic_adds_ads_two_title']).'</h2>';
                                    }
                                    if(!empty($settings['lcp_electronic_adds_ads_two_price'])){
                                        echo '<p>'.esc_html__('Start from', 'leadcapture').' <span class="lc-price">'.esc_html($settings['lcp_electronic_adds_ads_two_currency']).esc_html($settings['lcp_electronic_adds_ads_two_price']).'</span></p>';
                                    }
                                    if(!empty($settings['lcp_electronic_adds_ads_two_btn_title'])){
                                        echo '<div class="lc-btn lc-buybtn2-style18">
                                            <a href="'.esc_url($settings['lcp_electronic_adds_ads_two_btn_link']).'">'.esc_html($settings['lcp_electronic_adds_ads_two_btn_title']).'</a>
                                        </div>';        
                                    }
                                echo '</div>';
                                if(!empty($settings['lcp_electronic_adds_ads_two_image']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_electronic_adds_ads_two_image']['url']).'" alt="'.esc_attr('sales-img2', 'leadcapture').'">';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>';    
		}
	}
}