<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Event_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_Event_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Event Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_event_banner_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_banner_small_heading',
            [
                'label'       => esc_html__( 'Small Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_banner_big_heading',
            [
                'label'       => esc_html__( 'Big Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_banner_decs',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_banner_image',
            [
				'label'       => esc_html__( 'Section Bg Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        //NewsLetter
        $this->start_controls_section(
            'lcp_event_banner_newsletter', 
            [
               'label' => esc_html__( 'NewsLetter', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_banner_newsletter_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_banner_newsletter_shortcode',
            [
                'label'       => esc_html__( 'Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        //NewsLetter
        $this->start_controls_section(
            'lcp_event_banner_right_side', 
            [
               'label' => esc_html__( 'Right Side Banner', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_banner_right_image',
            [
				'label'       => esc_html__( 'Big Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_event_banner_top_section',
			[
				'label' => esc_html__( 'Top Section', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_event_banner_top_section_image',
            [
				'label'       => esc_html__( 'Icon Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_event_banner_top_section_heading',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_banner_top_section_decs',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        
        // Bottom Section Style
        $this->add_control(
			'lcp_event_banner_bottom_section',
			[
				'label' => esc_html__( 'Top Section', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_event_banner_bottom_section_image',
            [
				'label'       => esc_html__( 'Icon Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_event_banner_bottom_section_heading',
            [
                'label'       => esc_html__( 'Big Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_banner_bottom_section_decs',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_event_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Small Heading Style
        $this->add_control(
			'lcp_event_banner_style_sheading',
			[
				'label' => esc_html__( 'Small Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_style_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style21 > h2'
            ]
        );
        $this->add_control(
            'lcp_event_banner_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style21 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_event_banner_style_bheading',
			[
				'label' => esc_html__( 'Big Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_style_bheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style21 > h1'
            ]
        );
        $this->add_control(
            'lcp_event_banner_style_bheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style21 > h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_event_banner_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style21 > p'
            ]
        );
        $this->add_control(
            'lcp_event_banner_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style21 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_event_banner_news_style_tab', 
            [
                'label' => esc_html__( 'NewsLetter Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_event_banner_news_style_bheading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( 
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_news_style_bheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-newsletter-style21 >h3'
            ]
        );
        $this->add_control(
            'lcp_event_banner_news_style_bheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-newsletter-style21 >h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_control(
			'lcp_event_banner_news_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_news_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style21 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_news_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style21 button'
            ]
        );
        
        
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_event_banner_right_style_tab', 
            [
                'label' => esc_html__( 'Right Side Section ', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_event_banner_right_style_bheading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( 
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_right_style_bheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-bannericon-text-style21 > h3'
            ]
        );
        $this->add_control(
            'lcp_event_banner_right_style_bheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannericon-text-style21 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_event_banner_desc_style_bheading',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( 
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_banner_desc_style_bheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-bannericon-text-style21 > p'
            ]
        );
        $this->add_control(
            'lcp_event_banner_desc_style_bheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannericon-text-style21 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Extra Style
        $this->add_control(
			'lcp_event_banner_right_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_event_banner_right_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannerdots-style21 > .lc-bannerdot-style21' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .lc-banner-image.lc-banner-image-style21:after' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .lc-banner-image.lc-banner-image-style21::before' => 'border-top: 2px dashed {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    $style = !empty($settings['lcp_event_banner_image']['url']) ?  'style="background: url('.esc_url($settings['lcp_event_banner_image']['url']).');"' : '';
		    echo '<div class="lc-banner-section lc-banner-section-style21" '.$style.'>
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-text lc-banner-text-style21">';
                                if(!empty($settings['lcp_event_banner_small_heading'])){
                                    echo'<h2>'.esc_html($settings['lcp_event_banner_small_heading']).'</h2>';
                                }
                                if(!empty($settings['lcp_event_banner_big_heading'])){
                                    echo '<h1>';
                                        printf($settings['lcp_event_banner_big_heading']);
                                    echo '</h1>';
                                }
                                if(!empty($settings['lcp_event_banner_decs'])){
                                    echo '<p>'.esc_html($settings['lcp_event_banner_decs']).'</p>';
                                }
                                echo '<div class="lc-newsletter lc-newsletter-style21">';
                                    if(!empty($settings['lcp_event_banner_newsletter_heading'])){
                                        echo '<h3>'.esc_html($settings['lcp_event_banner_newsletter_heading']).'</h3>';
                                    }
                                    echo '<div class="lc-search-wrapper lc-search-wrapper-style21">';
                                        if(!empty($settings['lcp_event_banner_newsletter_shortcode'])){
                                            echo do_shortcode($settings['lcp_event_banner_newsletter_shortcode']);
                                        }
                                    echo '</div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-img-wrapper lc-banner-img-wrapper-style21">
                                <div class="lc-banner-image lc-banner-image-style21">';
                                    if(!empty($settings['lcp_event_banner_right_image']['url'])){
                                        echo '<img src="'.esc_url($settings['lcp_event_banner_right_image']['url']).'" class="right-img">';
                                    }
                                    echo '<div class="lc-banner-icon lc-banner-icon-style21">';
                                        if(!empty($settings['lcp_event_banner_top_section_image']['url']) || !empty($settings['lcp_event_banner_top_section_heading']) || !empty($settings['lcp_event_banner_top_section_decs'])){
                                            echo '<div class="lc-bannericon-bg-style21">';
                                                if(!empty($settings['lcp_event_banner_top_section_image']['url'])){
                                                    echo '<img src="'.esc_url($settings['lcp_event_banner_top_section_image']['url']).'" alt="'.esc_attr('gard-banner-icon3', 'leadcapture').'" class="lc-eventbanner-icon3">';
                                                }
                                                echo '<div class="lc-bannericon-text-style21">';
                                                    if(!empty($settings['lcp_event_banner_top_section_heading'])){
                                                        echo '<h3>'.esc_html($settings['lcp_event_banner_top_section_heading']).'</h3>';
                                                    }
                                                    if(!empty($settings['lcp_event_banner_top_section_decs'])){
                                                        echo '<p>'.esc_html($settings['lcp_event_banner_top_section_decs']).'</p>';
                                                    }
                                                echo '</div>
                                            </div>';
                                        }
                                        if(!empty($settings['lcp_event_banner_bottom_section_image']['url']) || !empty($settings['lcp_event_banner_bottom_section_heading']) || !empty($settings['lcp_event_banner_bottom_section_decs'])){
                                             echo '<div class="lc-bannericon-bg-style21">';
                                                if(!empty($settings['lcp_event_banner_bottom_section_image']['url'])){
                                                    echo '<img src="'.esc_html($settings['lcp_event_banner_bottom_section_image']['url']).'" alt="'.esc_html('gard-banner-icon3','leadcapture').'"
                                                    class="lc-eventbanner-icon3">';
                                                }
                                                echo '<div class="lc-bannericon-text-style21">';
                                                    if(!empty($settings['lcp_event_banner_bottom_section_heading'])){
                                                        echo '<h3>'.esc_html($settings['lcp_event_banner_bottom_section_heading']).'</h3>';
                                                    }
                                                    if(!empty($settings['lcp_event_banner_bottom_section_decs'])){
                                                        echo '<p>'.esc_html($settings['lcp_event_banner_bottom_section_decs']).'</p>';
                                                    }
                                                echo '</div>
                                            </div>';
                                        }
                                        echo '<div class="lc-bannerdots-style21">
                                            <div class="lc-bannerdot-style21"></div>
                                            <div class="lc-bannerdot-style21"></div>
                                            <div class="lc-bannerdot-style21"></div>
                                            <div class="lc-bannerdot-style21"></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}