<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Event_Priceplan extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_event_priceplan';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Event Price Plan', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_event_price_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_price_tagline',
            [
                'label'       => esc_html__( 'Tagline', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_price_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        //Pricing Plan One
        $this->start_controls_section(
            'lcp_event_price_general_one', 
            [
               'label' => esc_html__( 'Pricing Plan One', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_price_priceing_title_one',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_price_symbol_one',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '$', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_price_one',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '20.50', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_time_one',
            [
                'label'       => esc_html__( 'Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Month', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_btn_one',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Month', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_btn_link_one',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_event_price_image_one',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        //List
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_event_price_list_title_one',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'It is a long established fact that a', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_event_price_list_image_one',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_event_price_list_one',
            [
                'type'        => Controls_Manager::REPEATER, 
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_event_price_list_title_one'  => esc_html__( 'It is a long established fact that a', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_event_price_list_title_one}}',
            ]
        );
		$this->end_controls_section();
		
		//Pricing Plan Two
        $this->start_controls_section(
            'lcp_event_price_general_two', 
            [
               'label' => esc_html__( 'Pricing Plan Two', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_price_priceing_title_two',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_price_symbol_two',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '$', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_price_two',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '20.50', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_time_two',
            [
                'label'       => esc_html__( 'Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Month', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_btn_two',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Month', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_btn_link_two',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_event_price_image_two',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        //List
        $repeaters = new Repeater();
		$repeaters->add_control(
            'lcp_event_price_list_title_two',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'It is a long established fact that a', 'leadcapture' ),
            ]
        );
        $repeaters->add_control(
            'lcp_event_price_list_image_two',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_event_price_list_two',
            [
                'type'        => Controls_Manager::REPEATER, 
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_event_price_list_title_two'  => esc_html__( 'It is a long established fact that a', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeaters->get_controls(),
                'title_field' => '{{lcp_event_price_list_title_two}}',
            ]
        );
		$this->end_controls_section();
		
		//Pricing Plan Three
        $this->start_controls_section(
            'lcp_event_price_general_three', 
            [
               'label' => esc_html__( 'Pricing Plan Three', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_price_priceing_title_three',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_price_symbol_three',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '$', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_price_three',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '20.50', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_time_three',
            [
                'label'       => esc_html__( 'Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Month', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_btn_three',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Choose This Plan', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_event_price_btn_link_three',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_event_price_image_three',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        //List
        $repeaterss = new Repeater();
		$repeaterss->add_control(
            'lcp_event_price_list_title_three',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'It is a long established fact that a', 'leadcapture' ),
            ]
        );
        $repeaterss->add_control(
            'lcp_event_price_list_image_three',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_event_price_list_three',
            [
                'type'        => Controls_Manager::REPEATER, 
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_event_price_list_title_three'  => esc_html__( 'It is a long established fact that a', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeaterss->get_controls(),
                'title_field' => '{{lcp_event_price_list_title_three}}',
            ]
        );
		$this->end_controls_section();
		
		
		// Widget Style
        $this->start_controls_section(
            'lcp_event_price_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_event_price_style_tagline',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_price_style_tagline_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style21 > h3'
            ]
        );
        $this->add_control(
            'lcp_event_price_style_tagline_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Tagline Style
        $this->add_control(
			'lcp_event_price_style_style_heading',
			[
				'label' => esc_html__( 'Tegline', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_price_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style21 > h2'
            ]
        );
        $this->add_control(
            'lcp_event_price_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_event_price_heading_extra',
            [
                'label'     => esc_html__( 'Extra', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h2:after' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .lc-heading-style21 > h2:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        // Widget Style
        $this->start_controls_section(
            'lcp_event_price_list_style_tab', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_event_price_list_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_price_list_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box-style21 > h4'
            ]
        );
        $this->add_control(
            'lcp_event_price_list_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box-style21 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Price & Symbol Style
        $this->add_control(
			'lcp_event_price_list_style_psymbol',
			[
				'label' => esc_html__( 'Price & Symbol', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_price_list_style_psymbol_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box-style21 > h2'
            ]
        );
        $this->add_control(
            'lcp_event_price_list_style_psymbol_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box-style21 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Time Style
        $this->add_control(
			'lcp_event_price_list_style_time',
			[
				'label' => esc_html__( 'Time', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_price_list_style_time_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box-style21 > h2 > sub'
            ]
        );
        $this->add_control(
            'lcp_event_price_list_style_time_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box-style21 > h2 > sub' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // List Style
        $this->add_control(
			'lcp_event_price_list_style_list',
			[
				'label' => esc_html__( 'List', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_price_list_style_list_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-box-style21 > ul > li > p'
            ]
        );
        $this->add_control(
            'lcp_event_price_list_style_list_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-box-style21 > ul > li > p' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_event_price_style_btn_tab', 
            [
                'label' => esc_html__( 'Button Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_price_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21 a'
            ]
        );
        
        
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_event_price_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_event_price_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_event_price_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_event_price_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21',
            ]
        );
		$this->add_control(
            'lcp_event_price_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_event_price_style_btn_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_event_price_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_event_price_style_btn_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_event_price_style_btn_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21:hover',
            ]
        );
		$this->add_control(
            'lcp_event_price_style_btn_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style21.lc-pricebtn-style21:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
        
        
        
        
        
        
        
        
        $this->end_controls_section();
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-pricing-table-wrapper lc-pricingtable-wrapper-style21">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-style21">';
                                if($settings['lcp_event_price_tagline']){
                                    echo '<h3>'.esc_html($settings['lcp_event_price_tagline']).'</h3>';
                                }
                                if($settings['lcp_event_price_title']){
                                    echo '<h2>'.esc_html($settings['lcp_event_price_title']).'</h2>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="lc-plan-box-wrapper">
                        <div class="row">
                            <div class="col-lg-4 col-md-6 col-sm-12">
                                <div class="lc-plan-box lc-plan-box-style21">';
                                    if(!empty($settings['lcp_event_price_image_one']['url'])){
                                        echo '<div class="lc-planbox-img lc-planbox-img-style21">';
                                            echo '<img src="'.esc_url($settings['lcp_event_price_image_one']['url']).'" alt="'.esc_attr('plan-img', 'leadcapture').'">';
                                            
                                        echo '</div>';
                                    }
                                    if(!empty($settings['lcp_event_price_priceing_title_one'])){
                                        echo '<h4>'.esc_html($settings['lcp_event_price_priceing_title_one']).'</h4>';
                                    }
                                    if(!empty($settings['lcp_event_price_symbol_one']) || !empty($settings['lcp_event_price_price_one']) || !empty($settings['lcp_event_price_time_one'])){
                                        echo '<h2>'.esc_html($settings['lcp_event_price_symbol_one']).''.esc_html($settings['lcp_event_price_price_one']).' <sub>/'. esc_html($settings['lcp_event_price_time_one']).'</sub></h2>';
                                    }
                                    echo '<ul>';
                                        if(!empty($settings['lcp_event_price_list_one'])){
                                            foreach($settings['lcp_event_price_list_one'] as $list){
                                                 echo '<li>';
                                                    if(!empty($list['lcp_event_price_list_image_one']['url'])){
                                                        echo '<img src="'.esc_url($list['lcp_event_price_list_image_one']['url']).'" alt="">';
                                                    }
                                                    if(!empty($list['lcp_event_price_list_title_one'])){
                                                        echo '<p>'.esc_html($list['lcp_event_price_list_title_one']).'</p>';
                                                    }
                                                echo '</li>';
                                            }
                                        }
                                    echo '</ul>';
                                    if(!empty($settings['lcp_event_price_btn_one'])){
                                        echo '<div class="lc-btn lc-btn-style21 lc-pricebtn-style21">
                                            <a href="'.esc_url($settings['lcp_event_price_btn_link_one']).'">'.esc_html($settings['lcp_event_price_btn_one']).'</a>
                                        </div>';
                                    }
                                echo '</div>
                            </div>
                            <div class="col-lg-4 col-md-6 col-sm-12">
                                <div class="lc-plan-box lc-plan-box-style21">';
                                    if(!empty($settings['lcp_event_price_image_two']['url'])){
                                        echo '<div class="lc-planbox-img lc-planbox-img-style21">
                                            <img src="'.esc_url($settings['lcp_event_price_image_two']['url']).'" alt="'.esc_html('plan-img', 'leadcapture').'">
                                        </div>';
                                    }
                                    if(!empty($settings['lcp_event_price_priceing_title_two'])){
                                        echo '<h4>'.esc_html($settings['lcp_event_price_priceing_title_two']).'</h4>';
                                    }
                                    if(!empty($settings['lcp_event_price_symbol_two']) || !empty($settings['lcp_event_price_price_two']) || !empty($settings['lcp_event_price_time_two'])){
                                        echo '<h2>'.esc_html($settings['lcp_event_price_symbol_two']).''.esc_html($settings['lcp_event_price_price_two']).' <sub>/'. esc_html($settings['lcp_event_price_time_two']).'</sub></h2>';
                                    }
                                    echo '<ul>';
                                        if(!empty($settings['lcp_event_price_list_two'])){
                                            foreach($settings['lcp_event_price_list_two'] as $list){
                                                 echo '<li>';
                                                    if(!empty($list['lcp_event_price_list_image_two']['url'])){
                                                        echo '<img src="'.esc_url($list['lcp_event_price_list_image_two']['url']).'" alt="">';
                                                    }
                                                    if(!empty($list['lcp_event_price_list_title_two'])){
                                                        echo '<p>'.esc_html($list['lcp_event_price_list_title_two']).'</p>';
                                                    }
                                                echo '</li>';
                                            }
                                        }
                                    echo '</ul>';
                                    if(!empty($settings['lcp_event_price_btn_two'])){
                                        echo '<div class="lc-btn lc-btn-style21 lc-pricebtn-style21">
                                            <a href="'.esc_url($settings['lcp_event_price_btn_link_two']).'">'.esc_html($settings['lcp_event_price_btn_two']).'</a>
                                        </div>';
                                    }
                                echo '</div>
                            </div>
                            <div class="col-lg-4 col-md-6 offset-md-3 col-sm-12">
                                <div class="lc-plan-box lc-plan-box-style21">';
                                    if(!empty($settings['lcp_event_price_image_three']['url'])){
                                        echo '<div class="lc-planbox-img lc-planbox-img-style21">
                                            <img src="'.esc_url($settings['lcp_event_price_image_three']['url']).'" alt="'.esc_html('plan-img', 'leadcapture').'">
                                        </div>';
                                    }
                                    if(!empty($settings['lcp_event_price_priceing_title_three'])){
                                        echo '<h4>'.esc_html($settings['lcp_event_price_priceing_title_three']).'</h4>';
                                    }
                                    if(!empty($settings['lcp_event_price_symbol_three']) || !empty($settings['lcp_event_price_price_three']) || !empty($settings['lcp_event_price_time_three'])){
                                        echo '<h2>'.esc_html($settings['lcp_event_price_symbol_three']).''.esc_html($settings['lcp_event_price_price_three']).' <sub>/'. esc_html($settings['lcp_event_price_time_three']).'</sub></h2>';
                                    }
                                    echo '<ul>';
                                        if(!empty($settings['lcp_event_price_list_three'])){
                                            foreach($settings['lcp_event_price_list_three'] as $list){
                                                 echo '<li>';
                                                    if(!empty($list['lcp_event_price_list_image_three']['url'])){
                                                        echo '<img src="'.esc_url($list['lcp_event_price_list_image_three']['url']).'" alt="">';
                                                    }
                                                    if(!empty($list['lcp_event_price_list_title_three'])){
                                                        echo '<p>'.esc_html($list['lcp_event_price_list_title_three']).'</p>';
                                                    }
                                                echo '</li>';
                                            }
                                        }
                                    echo '</ul>';
                                    if(!empty($settings['lcp_event_price_btn_three'])){
                                        echo '<div class="lc-btn lc-btn-style21 lc-pricebtn-style21">
                                            <a href="'.esc_url($settings['lcp_event_price_btn_link_three']).'">'.esc_html($settings['lcp_event_price_btn_three']).'</a>
                                        </div>';
                                    }
                                echo '</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}