<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Event_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_Event_Services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Event Services', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_event_services_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_event_services_tagline',
            [
                'label'       => esc_html__( 'Tagline', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_event_services_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'lcp_event_services_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        
        //List
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_event_services_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Friendly Team', 'leadcapture' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_event_services_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'There are many variations of passages of Lorem.', 'leadcapture' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_event_services_list_image',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
			]
        );
        $this->add_control(
            'lcp_event_services_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'default'     => [
                    [
                        'lcp_event_services_list_title'  => esc_html__( 'Friendly Team', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_event_services_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_event_services_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Tegline Style
        $this->add_control(
			'lcp_event_services_style_tegline',
			[
				'label' => esc_html__( 'Tegline', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_event_services_tegline_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style21 > h3'
            ]
        );
        $this->add_control(
            'lcp_event_services_style_tegline_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_gardener_services_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style21 > h2'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_heading_extra',
            [
                'label'     => esc_html__( 'Extra', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21 > h2:after' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .lc-heading-style21 > h2:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardener_services_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style21.lc-serhead-style21 > p'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style21.lc-serhead-style21 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_event_services_style_list_tab', 
            [
                'label' => esc_html__( 'Services Item', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_gardener_services_list_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_list_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-serbox-textstyle21 > h4'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_list_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-serbox-textstyle21 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_list_style_hover_heading',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-wrapper:hover .lc-serbox-text > h4' => 'color: {{VALUE}};',
                ],
            ] 
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardener_services_list_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_list_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-serbox-textstyle21 > p'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_list_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-serbox-textstyle21 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Description Style
        $this->add_control(
			'lcp_gardener_services_list_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_gardener_services_list_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-wrapper:after' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .lc-service-box-wrapper.lc-service-box-wrapper-style21::before' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .lc-ourservices-section-style21:before' => 'border: 35px solid {{VALUE}};',
                    '{{WRAPPER}} .lc-ourservices-section-style21::after' => 'border: 35px solid {{VALUE}};',
                ], 
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-our-services-section lc-ourservices-section-style21">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-3 col-md-4 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-style21 lc-serhead-style21">';
                                if(!empty($settings['lcp_event_services_tagline'])){
                                    echo '<h3>'.esc_html($settings['lcp_event_services_tagline']).'</h3>';
                                }
                                if(!empty($settings['lcp_event_services_title'])){
                                    echo '<h2>'.esc_html($settings['lcp_event_services_title']).'</h2>';
                                }
                                if(!empty($settings['lcp_event_services_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_event_services_desc']).'</p>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-9 col-md-8 col-sm-12">
                            <div class="lc-service-wrapper lc-servicewrapper-style21 ">
                                <div class="row">';
                                    if(!empty($settings['lcp_event_services_list'])){
                                        foreach($settings['lcp_event_services_list'] as $list){
                                            echo '<div class="col-lg-4 col-md-6 col-sm-6">
                                                <div class="lc-service-box-wrapper lc-service-box-wrapper-style21">
                                                    <div class="lc-serbox-icon lc-serbox-icon-style21">';
                                                        if(!empty($list['lcp_event_services_list_image']['url'])){
                                                            echo '<img src="'.esc_url($list['lcp_event_services_list_image']['url']).'" alt="'.esc_attr('ser-icon1', 'leadcapture').'">';
                                                        }
                                                    echo '</div>
                                                    <div class="lc-serbox-text lc-serbox-textstyle21">';
                                                        if(!empty($list['lcp_event_services_list_title'])){
                                                            echo '<h4>'.esc_html($list['lcp_event_services_list_title']).'</h4>';
                                                        }
                                                        if(!empty($list['lcp_event_services_list_desc'])){
                                                            echo '<p>'.esc_html($list['lcp_event_services_list_desc']).'</p>';
                                                        }
                                                    echo '</div>
                                                </div>
                                            </div>';
                                        }
                                    }
                                echo '</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}