<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fashion_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fashion_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture fashion Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fashion_banner_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_stitle',
            [
                'label'       => esc_html__( 'Small Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_desc',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_video_text',
            [
                'label'       => esc_html__( 'Video Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_video_link',
            [
                'label'       => esc_html__( 'Video Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_video_image',
            [
				'label'       => esc_html__( 'Video Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		
		$this->start_controls_section(
            'lcp_fashion_banner_newsletter', 
            [
               'label' => esc_html__( 'NewsLetter Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_ns_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_ns_shortcode',
            [
                'label'       => esc_html__( 'Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'lcp_fashion_banner_product', 
            [
               'label' => esc_html__( 'Product Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_product_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_product_currency',
            [
                'label'       => esc_html__( 'Currency', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_product_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_product_shipping',
            [
                'label'       => esc_html__( 'Shipping', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_product_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'lcp_fashion_banner_img', 
            [
               'label' => esc_html__( 'Image', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_img_image',
            [
				'label'       => esc_html__( 'Image One', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_fashion_banner_img_two',
            [
				'label'       => esc_html__( 'Image Two', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true, 
			]
        );
        $this->end_controls_section();
        // Widget Style
        $this->start_controls_section(
            'lcp_fashion_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_banner_style_sheading',
			[
				'label' => esc_html__( 'Small Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_style_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-text-style22 h5'
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style22 h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_sheading_extra_color',
            [
                'label'     => esc_html__( 'Extra Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style22 h5:before' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_banner_style_heading',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [ 
                'name'     => 'lcp_fashion_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ), 
                'selector' => '{{WRAPPER}} .lc-banner-heading-text-style22 h1'
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style22 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_banner_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [ 
                'name'     => 'lcp_fashion_banner_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ), 
                'selector' => '{{WRAPPER}} .lc-banner-heading-text-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_desc_extra_color',
            [
                'label'     => esc_html__( 'Extra Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style22 p:before' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_fashion_banner_style_btn_tab', 
            [
                'label' => esc_html__( 'Button Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Button One Style
        $this->add_control(
			'lcp_fashion_banner_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-get-style22 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_fashion_banner_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_fashion_banner_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_fashion_banner_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_btn_icon_bg',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22 a span' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_fashion_banner_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-get-style22',
            ]
        );
		$this->add_control(
            'lcp_fashion_banner_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_fashion_banner_style_btn_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_fashion_banner_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_fashion_banner_style_btn_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_btn_icon_hbg',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22:hover a span' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_fashion_banner_style_btn_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-get-style22:hover',
            ]
        );
		$this->add_control(
            'lcp_fashion_banner_style_btn_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style22:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
		
		
		// Button One Style
        $this->add_control(
			'lcp_fashion_banner_style_video_btn',
			[
				'label' => esc_html__( 'Video Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_style_video_btn_typography',
                'label'       => esc_html__( 'Text Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-video-img-style22 span' 
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_video_btn_text_color',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-video-img-style22 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_video_btn_icon_bgcolor',
            [
                'label'     => esc_html__( 'Video Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-img-style22' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_video_btn_icon_hbgcolor',
            [
                'label'     => esc_html__( 'Video Icon Hover Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-img-style22:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_fashion_banner_style_nsletter', 
            [
                'label' => esc_html__( 'NewsLetter Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Button One Style
        $this->add_control(
			'lcp_fashion_banner_style_nsletter_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_style_nsletter_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-Newsletter-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_style_nsletter_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-Newsletter-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'lcp_fashion_banner_news_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ), 
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_news_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style22 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_news_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style22 button'
            ]
        );
        $this->end_controls_section();
        // Widget Style
        $this->start_controls_section(
            'lcp_fashion_banner_product_style', 
            [
                'label' => esc_html__( 'Product Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_banner_product_style_heading',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_product_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-fashion-box-style22 h5'
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_product_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-box-style22 h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_banner_product_style_price',
			[
				'label' => esc_html__( 'Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_product_style_price_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-shipping-style22 h6'
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_product_style_price_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-shipping-style22 h6' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_banner_product_style_shipping',
			[
				'label' => esc_html__( 'Shipping', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_banner_product_style_shipping_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-shipping-style22 p'
            ]
        );
        $this->add_control( 
            'lcp_fashion_banner_product_style_shipping_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-shipping-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        // Widget Style
        $this->start_controls_section(
            'lcp_fashion_banner_extra_style', 
            [
                'label' => esc_html__( 'Extra Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'lcp_fashion_banner_extra_style_bgcolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heart-img' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-banner-section lc-banner-section-style22">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-heading-text-style22">';
                                if(!empty($settings['lcp_fashion_banner_stitle'])){
                                    echo '<h5>'.esc_html($settings['lcp_fashion_banner_stitle']).'</h5>';
                                }
                                if(!empty($settings['lcp_fashion_banner_title'])){
                                    echo '<h1>'.esc_html($settings['lcp_fashion_banner_title']).'</h1>';
                                }
                                if(!empty($settings['lcp_fashion_banner_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_fashion_banner_desc']).'</p>';
                                }
                                echo '<div class="lc-flex-text-style25 ">';
                                    if(!empty($settings['lcp_fashion_banner_btn_title'])){
                                        echo '<div class="lc-btn lc-get-style22">
                                            <a href="'.esc_url($settings['lcp_fashion_banner_btn_link']).'">'.esc_html($settings['lcp_fashion_banner_btn_title']).'
                                                <span><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 6 11"
                                                        width="6" height="11">
                                                        <title>Shape 1</title>
                                                        <style>
                                                            .s0 {
                                                                fill: #ac73f5
                                                            }
                                                        </style>
                                                        <path id="Shape 1" class="s0"
                                                            d="m0.2 10.7c-0.3-0.3-0.3-0.8 0-1.1l4.1-4-4.1-4.1c-0.2-0.3-0.2-0.7 0-1 0.3-0.3 0.8-0.3 1.1-0.1l4.6 4.6c0.3 0.3 0.3 0.8 0 1.1l-4.6 4.6q-0.2 0.3-0.6 0.3-0.3 0-0.5-0.3z" />
                                                    </svg>
                                                </span>
                                            </a>
                                        </div>';
                                    }
                                    echo '<div class="lc-video-img-style22">';
                                        if(!empty($settings['lcp_fashion_banner_video_link']) || !empty($settings['lcp_fashion_banner_video_image']['url'])){
                                            echo '<div class="lc-img-style22">
                                                <a href="'.esc_url($settings['lcp_fashion_banner_video_link']).'">
                                                    <img src="'.esc_url($settings['lcp_fashion_banner_video_image']['url']).'" alt="">
                                                </a>
                                            </div>';
                                        }
                                        if(!empty($settings['lcp_fashion_banner_video_text'])){
                                            echo '<span>'.esc_html($settings['lcp_fashion_banner_video_text']).'</span>';
                                        }
                                    echo '</div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-img-wrapper lc-banner-img-style22">';
                                if(!empty($settings['lcp_fashion_banner_img_image']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_fashion_banner_img_image']['url']).'" alt="">';
                                }
                                echo '<div class="lc-fashion-box-style22">';
                                    if(!empty($settings['lcp_fashion_banner_product_image']['url'])){
                                        echo '<img src="'.esc_url($settings['lcp_fashion_banner_product_image']['url']).'" alt="">';
                                    }
                                    echo '<div class="lc-shipping-style22">';
                                        if(!empty($settings['lcp_fashion_banner_product_price']) || !empty($settings['lcp_fashion_banner_product_currency'])){
                                            echo '<h6>'.esc_html($settings['lcp_fashion_banner_product_currency']).esc_html($settings['lcp_fashion_banner_product_price']).'<h6>';
                                        }
                                        if(!empty($settings['lcp_fashion_banner_product_shipping'])){
                                            echo '<p>('.esc_html($settings['lcp_fashion_banner_product_shipping']).')</p>';
                                        }
                                    echo '</div>';
                                    if(!empty($settings['lcp_fashion_banner_product_title'])){
                                        echo '<h5>'.esc_html($settings['lcp_fashion_banner_product_title']).'</h5>';
                                    }
                                echo '</div>
                                <div class="lc-Newsletter lc-Newsletter-style22">';
                                    if(!empty($settings['lcp_fashion_banner_ns_title'])){
                                        echo '<p>'.esc_html($settings['lcp_fashion_banner_ns_title']).'</p>';
                                    }
                                    if(!empty($settings['lcp_fashion_banner_ns_shortcode'])){
                                        echo '<div class="lc-search-wrapper lc-search-wrapper-style22">';
                                            echo do_shortcode($settings['lcp_fashion_banner_ns_shortcode']);
                                        echo '</div>';
                                    }
                                echo '</div>';
                                if(!empty($settings['lcp_fashion_banner_img_two']['url'])){
                                    echo '<div class="lc-heart-img">
                                        <img src="'.esc_html($settings['lcp_fashion_banner_img_two']['url']).'" alt="">
                                    </div>';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}