<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fashion_Blogs extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fashion_blogs';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fashion Blogs', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $categories = get_categories();
		$cats = array();
		foreach( $categories as $terms ){
			$cats[$terms->term_id] = $terms->name;
		}
	    $this->start_controls_section(
            'lcp_fashion_blogs_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_fashion_blogs_post_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_post_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_post_show',
            [
                'label'       => esc_html__( 'Number of Post', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '3', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_category',
            [
                'label'   => __( 'Select Categories', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT2,
				'multiple' => true,
                'options' => $cats
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_order_by',
            [
                'label'   => __( 'Order By', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'   => __( 'None', 'leadcapture' ),
                    'id'   => __( 'Id', 'leadcapture' ),					
					'title'   => __( 'Title', 'leadcapture' ),
					'date'   => __( 'Date', 'leadcapture' ),
                ],
            ]
        );
		$this->add_control(
            'lcp_fashion_blogs_sort',
            [
                'label'   => __( 'Sort Order', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC'   => __( 'Ascending', 'leadcapture' ),
                    'DESC'   => __( 'Descending', 'leadcapture' ),
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_fashion_blogs_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_blogs_style_sheading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style22 h2'
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style22 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_blogs_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_fashion_blogs_style_post', 
            [
                'label' => esc_html__( 'Post Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_blogs_style_post_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_post_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style22 h4'
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_post_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style22 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_post_heading_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-box-wrapper:hover .lc-blog-text >h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
         // Heading Style
        $this->add_control(
			'lcp_fashion_blogs_style_post_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_post_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_post_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_blogs_style_post_date',
			[
				'label' => esc_html__( 'Date', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_post_date_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-fashion-date p'
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_post_date_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-date p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_post_date_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-date' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        // Button One Style
        $this->add_control(
			'lcp_fashion_blogs_style_post_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_post_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-red-style22 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_fashion_blogs_style_post_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_fashion_blogs_style_post_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_fashion_blogs_style_post_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_post_btn_icon_bg',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22 a span' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_post_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-red-style22',
            ]
        );
		$this->add_control(
            'lcp_fashion_blogs_style_post_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_fashion_blogs_style_post_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_fashion_blogs_style_post_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_fashion_blogs_style_post_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_blogs_style_post_btn_icon_hbg',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22:hover a span' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_fashion_blogs_style_post_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-red-style22:hover',
            ]
        );
		$this->add_control(
            'lcp_fashion_blogs_style_post_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-red-style22:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    if(!empty($settings['lcp_fashion_blogs_category'])){
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_fashion_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_fashion_blogs_sort'],
    				'orderby'         => $settings['lcp_fashion_blogs_order_by'],
    				'tax_query' => array(
    				array(
    					'taxonomy'  => 'category',
    					'field'     => 'ID',
    					'terms'     => $settings['lcp_fashion_blogs_category'],
    					),
    				),	
    			));
    		} else {
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_fashion_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_fashion_blogs_sort'],
    				'orderby'         => $settings['lcp_fashion_blogs_order_by'],
    			));
    		}
		    echo '<div class="lc-blog-wrapper lc-blog-wrapper-style22">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-wrapper-style22">';
                                if(!empty($settings['lcp_fashion_blogs_post_heading'])){
                                    echo '<h2>'.esc_html($settings['lcp_fashion_blogs_post_heading']).'</h2>';
                                }
                                if(!empty($settings['lcp_fashion_blogs_post_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_fashion_blogs_post_desc']).'</p>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="row">';
                        if($query->have_posts() ) {
    		                while($query->have_posts()): $query->the_post();
    		                    echo '<div class="col-lg-4 col-md-6 col-sm-12">
                                    <div class="lc-blog-box-wrapper lc-blog-box-wrapper-style22">';
                                        $attach_id = get_post_thumbnail_id(get_the_ID());
                        				$thumbnail_url = wp_get_attachment_url($attach_id, 'full');
                        				if(!empty($thumbnail_url)){
                        				    echo '<div class="lc-blog-img lc-blog-img-style22">
                                                <img src="'.esc_html($thumbnail_url).'" alt="">
                                            </div>';
                        				}
                                        echo '<div class="lc-blog-text lc-blog-text-style22">
                                            <h4>'. substr(get_the_title(),0,100).'</h4>     
                                            <p>'. substr(get_the_excerpt(),0,147).'</p>
                                            <div class="lc-btn lc-red-style22 ">
                                                <a href="'. esc_url(get_permalink()).'">'.esc_html('Read More', 'leadcapture').'
                                                    <span><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 6 11"
                                                            width="6" height="11">
                                                            <title>Shape 1</title>
                                                            <style>
                                                                .s0 {
                                                                    fill: #ac73f5
                                                                }
                                                            </style>
                                                            <path id="Shape 1" class="s0"
                                                                d="m0.2 10.7c-0.3-0.3-0.3-0.8 0-1.1l4.1-4-4.1-4.1c-0.2-0.3-0.2-0.7 0-1 0.3-0.3 0.8-0.3 1.1-0.1l4.6 4.6c0.3 0.3 0.3 0.8 0 1.1l-4.6 4.6q-0.2 0.3-0.6 0.3-0.3 0-0.5-0.3z" />
                                                        </svg></span>
                                                </a>
                                            </div>
                                        </div>
                                        <div class="lc-fashion-date">
                                            <p>'.esc_html(get_the_date('M d, Y')).'</p>
                                        </div>
                                    </div>
                                </div>';
    		                endwhile;
                            wp_reset_query();
                        }
                    echo '</div>
                </div>
            </div>';
		}
	}
}