<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fashion_Discount extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fashion_discount';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fashion Discount', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fashion_discount_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_stitle',
            [
                'label'       => esc_html__( 'Small Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_left_image',
            [
				'label'       => esc_html__( 'Left Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_fashion_discount_right_image',
            [
				'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_fashion_discount_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_discount_style_sheading',
			[
				'label' => esc_html__( 'Small Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_discount_style_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-discount-text-box h5'
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-discount-text-box h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_discount_style_heading',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_discount_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-discount-text-box h2'
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-discount-text-box h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_discount_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_discount_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-discount-text-box p'
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_style_desc_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-discount-text-box p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Button One Style
        $this->add_control(
			'lcp_fashion_discount_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_discount_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-view-style22 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_fashion_discount_style_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_fashion_discount_style_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_fashion_discount_style_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_style_btn_icon_bg',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22 a span' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_fashion_discount_style_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-view-style22',
            ]
        );
		$this->add_control(
            'lcp_fashion_discount_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_fashion_discount_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_fashion_discount_style_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_fashion_discount_style_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_discount_style_btn_icon_hbg',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22:hover a span' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_fashion_discount_style_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-view-style22:hover',
            ]
        );
		$this->add_control(
            'lcp_fashion_discount_style_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-view-style22:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
        $this->end_controls_section();
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-discount-wrapper">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-4 col-md-6 col-sm-12">';
                            if(!empty($settings['lcp_fashion_discount_left_image']['url'])){
                                echo '<div class="lc-discount-img-box ">
                                    <img src="'.esc_url($settings['lcp_fashion_discount_left_image']['url']).'" alt="">
                                </div>';
                            }
                        echo '</div>
                        <div class="col-lg-4 col-md-6 col-sm-12">
                            <div class="lc-discount-text-box">';
                                if(!empty($settings['lcp_fashion_discount_stitle'])){
                                    echo '<h5>'.esc_html($settings['lcp_fashion_discount_stitle']).'</h5>';
                                }                                                                                                                                                           
                                if(!empty($settings['lcp_fashion_discount_title'])){
                                    echo '<h2>';
                                        print($settings['lcp_fashion_discount_title']);
                                    echo '</h2>';                                                                                                               
                                }
                                if(!empty($settings['lcp_fashion_discount_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_fashion_discount_desc']).'</p>';
                                }
                                if(!empty($settings['lcp_fashion_discount_btn_title'])){
                                    echo '<div class="lc-btn lc-view-style22">
                                        <a href="'.esc_url($settings['lcp_fashion_discount_btn_link']).'">'.esc_html($settings['lcp_fashion_discount_btn_title']).'
                                            <span><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 6 11"
                                                    width="6" height="11">
                                                    <title>Shape 1</title>
                                                    <style>
                                                        .s0 {
                                                            fill: #ac73f5
                                                        }
                                                    </style>
                                                    <path id="Shape 1" class="s0"
                                                        d="m0.2 10.7c-0.3-0.3-0.3-0.8 0-1.1l4.1-4-4.1-4.1c-0.2-0.3-0.2-0.7 0-1 0.3-0.3 0.8-0.3 1.1-0.1l4.6 4.6c0.3 0.3 0.3 0.8 0 1.1l-4.6 4.6q-0.2 0.3-0.6 0.3-0.3 0-0.5-0.3z" />
                                                </svg>
                                            </span>
                                        </a>
                                    </div>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-4 col-md-6 offset-md-3 col-sm-12">';
                            if(!empty($settings['lcp_fashion_discount_right_image']['url'])){
                                echo '<div class="lc-discount-img-box lc-discount-img-box-style22">
                                    <img src="'.esc_url($settings['lcp_fashion_discount_right_image']['url']).'" alt="">
                                </div>';
                            }
                        echo '</div>
                    </div>
                </div>
            </div>';    
		}
	}
}