<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fashion_Products extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fashion_product';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fashion Products', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fashion_products_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fashion_products_stitle',
            [
                'label'       => esc_html__( 'Small Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_products_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fashion_products_currency',
            [
                'label'       => esc_html__( 'Currency', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_fashion_products_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_fashion_products_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_products_list_category',
            [
                'label'       => esc_html__( 'Category', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_products_list_r_price',
            [
                'label'       => esc_html__( 'Regular Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_products_list_s_price',
            [
                'label'       => esc_html__( 'Sale Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_products_list_rating',
            [
                'label'   => __( 'Rating', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '4',
                'options' => [
                    '1'   => __( '1 Star', 'leadcapture' ),
                    '2'   => __( '2 Star', 'leadcapture' ),
					'3'   => __( '3 Star', 'leadcapture' ),
					'4'   => __( '4 Star', 'leadcapture' ),
					'5'   => __( '5 Star', 'leadcapture' ),
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_products_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_fashion_products_list_title'  => esc_html__( 'Product', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_fashion_products_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_fashion_products_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_products_style_stitle',
			[
				'label' => esc_html__( 'Small Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_products_style_stitle_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style22 h2'
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_stitle_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style22 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_products_style_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_products_style_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_fashion_products_style_product', 
            [
                'label' => esc_html__( 'Product Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_products_style_product_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_products_style_product_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-fashion-text-style22 h5'
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_product_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-text-style22 h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_products_style_product_price',
			[
				'label' => esc_html__( 'Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_products_style_product_price_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-fashion-text-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_product_rprice_color',
            [
                'label'     => esc_html__( 'Regular Price Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-text-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_product_sprice_color',
            [
                'label'     => esc_html__( 'Sale Price Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-text-style22 p span' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_products_style_product_category',
			[
				'label' => esc_html__( 'Category', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_products_style_product_category_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-fashion-flex p'
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_product_category_color',
            [
                'label'     => esc_html__( 'Regular Price Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-flex p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_products_style_product_icon',
			[
				'label' => esc_html__( 'Icon', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_fashion_products_style_product_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-arrival-icons.lc-arrival-icons-style22 span>svg .s0' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_product_arating',
            [
                'label'     => esc_html__( 'Active Rating Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-flex span > svg > .s0' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fashion_products_style_product_inrating',
            [
                'label'     => esc_html__( 'Inactive Rating Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-fashion-flex span > svg > .s1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-highlight-wrapper lc-highlight-wrapper-style22">
                <div class="container">
                    <div class="row">
                        <div class="lc-heading-wrapper lc-heading-wrapper-style22">';
                            if(!empty($settings['lcp_fashion_products_stitle'])){
                                echo '<h2>'.esc_html($settings['lcp_fashion_products_stitle']).'</h2>';
                            }
                            if(!empty($settings['lcp_fashion_products_title'])){
                                echo '<p>'.esc_html($settings['lcp_fashion_products_title']).'</p>';
                            }
                        echo '</div>
                    </div>
                    <div class="row">';
                        if(!empty($settings['lcp_fashion_products_list'])){
                            foreach($settings['lcp_fashion_products_list'] as $list){
                                echo '<div class="col-lg-3 col-md-6 col-sm-12">
                                    <div class="lc-top-box-wrapper lc-top-box-wrapper-style22">';
                                        if(!empty($list['lcp_fashion_products_list_image']['url'])){
                                            echo '<img src="'.esc_url($list['lcp_fashion_products_list_image']['url']).'" alt="">';
                                        }
                                        echo '<div class="lc-top-box-text lc-top-box-text-style22">
                                            <div class="lc-fashion-flex">';
                                                if(!empty($list['lcp_fashion_products_list_category'])){
                                                    echo '<p>'.esc_html($list['lcp_fashion_products_list_category']).'</p>';
                                                }
                                                if(!empty($list['lcp_fashion_products_list_rating'])){
                                                    $rating = $list['lcp_fashion_products_list_rating'];
                                                    echo '<span>';
                                                        for($i=1; $i<=$rating; $i++){
                                                            echo '<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 13 14" width="13" height="14">
                                                                <title>Shape 10</title>
                                                                <path id="Shape 10" class="s0 active"
                                                                    d="m12.9 5.7l-2.9 3.2 0.7 4.6c0 0.1-0.1 0.3-0.2 0.4-0.1 0.1-0.2 0.1-0.4 0l-3.6-2.1-3.6 2.1q-0.1 0.1-0.2 0.1-0.1 0-0.2-0.1c-0.1-0.1-0.2-0.3-0.2-0.4l0.7-4.6-2.9-3.2c-0.1-0.1-0.1-0.2-0.1-0.4 0.1-0.1 0.2-0.3 0.3-0.3l4.1-0.6 1.8-4.2c0-0.1 0.2-0.2 0.3-0.2 0.2 0 0.3 0.1 0.4 0.2l1.8 4.2 4 0.6c0.1 0 0.3 0.2 0.3 0.3 0.1 0.2 0 0.3-0.1 0.4z" />
                                                            </svg>';
                                                        }
                                                        $j = 5 - $rating;
                                                        if($j != 0){
                                                            for($i=1; $i<=$j; $i++){
                                                                echo '<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 14 14" width="14" height="14">
                                                                    <title>Shape 10</title>
                                                                    <path id="Shape 10" class="s1"
                                                                        d="m13.1 5.7l-2.9 3.2 0.7 4.6c0 0.1 0 0.3-0.1 0.4-0.2 0.1-0.3 0.1-0.5 0l-3.6-2.1-3.6 2.1q-0.1 0.1-0.2 0.1-0.1 0-0.2-0.1c-0.1-0.1-0.2-0.3-0.1-0.4l0.7-4.6-3-3.2c-0.1-0.1-0.1-0.2-0.1-0.4 0.1-0.1 0.2-0.3 0.4-0.3l4-0.6 1.8-4.2c0.1-0.1 0.2-0.2 0.3-0.2 0.2 0 0.3 0.1 0.4 0.2l1.8 4.2 4 0.6c0.2 0 0.3 0.2 0.3 0.3 0.1 0.2 0 0.3-0.1 0.4z" />
                                                                </svg>';
                                                            }
                                                        }
                                                    
                                                        
                                                    echo '</span>';
                                                }
                                            echo '</div>
                                        </div>
                                        <div class="lc-fashion-text-style22">';
                                            if(!empty($list['lcp_fashion_products_list_title'])){
                                                echo '<h5>'.esc_html($list['lcp_fashion_products_list_title']).'</h5>';
                                            }
                                            if(!empty($list['lcp_fashion_products_list_s_price'])){
                                                echo '<p>';
                                                    if(!empty($list['lcp_fashion_products_list_r_price'])){
                                                        echo '<span>'.esc_html($settings['lcp_fashion_products_currency'].$list['lcp_fashion_products_list_s_price']).'</span><del>'.esc_html($settings['lcp_fashion_products_currency'].$list['lcp_fashion_products_list_r_price']).'</del>';
                                                    }
                                                echo '</p>';
                                            } else {
                                                if(!empty($list['lcp_fashion_products_list_r_price'])){
                                                    echo '<p>'.esc_html($settings['lcp_fashion_products_currency'].$list['lcp_fashion_products_list_r_price']).'</p>';
                                                }
                                            }
                                        echo '</div>
                                        <div class="lc-arrival-icon-wrapper lc-arrival-icon-wrapper-style22">
                                            <div class="lc-arrival-icons lc-arrival-icons-style22"><span><svg
                                                        xmlns="http://www.w3.org/2000/svg" width="18" height="15"
                                                        viewBox="0 0 18 15">
                                                        <defs>
                                                            <style>
                                                                .cls-1 {
                                                                    fill: #ac73f5;
                                                                    fill-rule: evenodd;
                                                                }
                                                            </style>
                                                        </defs>
                                                        <path class="cls-1"
                                                            d="M5.416,11.611a0.524,0.524,0,1,1,0-1.047c2.011,0.007,7.314,0,9.389,0a1.2,1.2,0,0,0,1.181-.9l1.178-4.9a0.91,0.91,0,0,0-.187-0.8,0.987,0.987,0,0,0-.765-0.357c-0.835,0-7.919-.031-11.548-0.045L4.089,1.514A1.168,1.168,0,0,0,2.957.682H1.114a0.476,0.476,0,0,0-.485.467,0.476,0.476,0,0,0,.485.466H2.957a0.2,0.2,0,0,1,.195.143L5.361,9.632a1.534,1.534,0,0,0-1.025.433A1.416,1.416,0,0,0,3.9,11.112a1.5,1.5,0,0,0,1.516,1.431H6.124a1.57,1.57,0,0,0-.164.7,1.7,1.7,0,0,0,3.4,0,1.57,1.57,0,0,0-.164-0.7h3.065a1.57,1.57,0,0,0-.164.7,1.7,1.7,0,0,0,3.4,0,1.571,1.571,0,0,0-.177-0.724,0.469,0.469,0,0,0,.331-0.442,0.476,0.476,0,0,0-.485-0.466H5.416Zm2.971,1.632a0.729,0.729,0,1,1-.729-0.7h0A0.715,0.715,0,0,1,8.386,13.243Zm5.407,0.7a0.7,0.7,0,1,1-.012-1.4H13.8a0.7,0.7,0,1,1-.012,1.4h0Zm2.422-9.4a0.007,0.007,0,0,1,0,.008l-0.5,2.065H14.04l0.286-2.084,1.882,0.007a0.008,0.008,0,0,1,.007,0h0Zm-5,5.089V7.551h1.722L12.647,9.634H11.211Zm-2.407,0L8.516,7.551H10.24V9.634H8.8Zm-2.235,0h0a0.262,0.262,0,0,1-.253-0.186l-0.532-1.9H7.536L7.825,9.634H6.569ZM8.386,6.619L8.095,4.511,10.24,4.519v2.1H8.386Zm2.825,0v-2.1l2.137,0.008L13.061,6.619h-1.85Zm-4.1-2.112L7.407,6.619H5.521L4.926,4.5ZM14.8,9.634H13.626l0.286-2.083H15.5l-0.457,1.9A0.238,0.238,0,0,1,14.8,9.634Z" />
                                                    </svg></span>
                                            </div>
                                            <div class="lc-arrival-icons lc-arrival-icons-style22"><span><svg
                                                        xmlns="http://www.w3.org/2000/svg" width="14" height="13"
                                                        viewBox="0 0 14 13">
                                                        <defs>
                                                            <style>
                                                                .cls-1 {
                                                                    fill: #ac73f5;
                                                                    fill-rule: evenodd;
                                                                }
                                                            </style>
                                                        </defs>
                                                        <path class="cls-1"
                                                            d="M5.724-.006a5.73,5.73,0,1,0,5.73,5.73A5.736,5.736,0,0,0,5.724-.006Zm0,10.4A4.672,4.672,0,1,1,10.4,5.724,4.677,4.677,0,0,1,5.724,10.4ZM12.85,12.1L9.818,9.07a0.529,0.529,0,1,0-.748.748L12.1,12.85A0.529,0.529,0,0,0,12.85,12.1Z" />
                                                    </svg>
                                                </span>
                                            </div>
                                            <div class="lc-arrival-icons  lc-arrival-icons-style22"><span><svg version="1.2"
                                                        xmlns="http://www.w3.org/2000/svg" viewBox="0 0 18 16" width="18"
                                                        height="16">
                                                        <title>Shape 13</title>
                                                        <style>
                                                            .s0 {
                                                                fill: #04ad90;
                                                                stroke: #ffffff;
                                                                stroke-linejoin: round;
                                                                stroke-opacity: .7
                                                            }
                                                        </style>
                                                        <path id="Shape 13" class="s0"
                                                            d="m12 1.6c2.3 0 4 1.9 4.1 4.3 0 4.4-7.4 8.8-7.4 8.8 0 0-7.4-4.4-7.4-8.8 0-2.4 1.8-4.3 4-4.3 1.4 0 2.6 0.7 3.4 1.9 0.7-1.2 2-1.9 3.3-1.9z" />
                                                    </svg></span>
                                            </div>
                                        </div>
                                    </div>
                                </div>';
                            }
                        }
                    echo '</div>
                </div>
            </div>';
		}
	}
}