<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fashion_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fashion_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fashion Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fashion_services_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_fashion_services_number',
            [
                'label'       => esc_html__( 'Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_services_suffix',
            [
                'label'       => esc_html__( 'Suffix', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_services_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_services_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_services_icon_bg',
            [
                'label'       => esc_html__( 'Icon Background Color Code', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fashion_services_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control( 
            'lcp_fashion_services_list',
            [ 
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_fashion_services_title}}',
            ]
        );
		$this->end_controls_section();
		// Widget Style
        $this->start_controls_section(
            'lcp_fashion_services_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fashion_services_style_number',
			[
				'label' => esc_html__( 'Number', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_services_style_number_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-box-text-style22 h3'
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_services_style_title',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_services_style_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-box-text-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_services_style_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-box-text-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fashion_services_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fashion_services_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-para-text-style22 p'
            ]
        );
        $this->add_control(
            'lcp_fashion_services_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-para-text-style22 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
	    if(!empty($settings)){
	        echo '<div class="lc-service-section lc-service-section-style22">
                <div class="container">
                    <div class="lc-service-section-box-style22">
                        <div class="row">';
                            if(!empty($settings['lcp_fashion_services_list'])){
                                foreach($settings['lcp_fashion_services_list'] as $list){
                                    echo '<div class="col-lg-4 col-md-6 col-sm-12">
                                        <div class="lc-service-box-wrapper-style22">
                                            <div class="lc-flex-box-style22">';
                                                if(!empty($list['lcp_fashion_services_image']['url'])){
                                                    echo '<div class="lc-icon-img-style22"  style="background: '.esc_attr($list['lcp_fashion_services_icon_bg']).';">
                                                        <img src="'.esc_url($list['lcp_fashion_services_image']['url']).'" alt="">
                                                    </div>';
                                                }
                                                echo '<div class="lc-box-text-style22">';
                                                    if(!empty($list['lcp_fashion_services_number']) || !empty($list['lcp_fashion_services_suffix'])){
                                                        echo '<h3 style="color: '.esc_attr($list['lcp_fashion_services_icon_bg']).';">'.esc_html($list['lcp_fashion_services_number']).esc_html($list['lcp_fashion_services_suffix']).'</h3>';
                                                    }
                                                    if(!empty($list['lcp_fashion_services_title'])){
                                                        echo '<p>'.esc_html($list['lcp_fashion_services_title']).'</p>';
                                                    }
                                                echo '</div>
                                            </div>';
                                            if(!empty($list['lcp_fashion_services_desc'])){
                                                echo '<div class="lc-para-text-style22">
                                                    <p>'.esc_html($list['lcp_fashion_services_desc']).'</p>
                                                </div>';    
                                            }
                                        echo '</div>
                                    </div>';       
                                }
                            }
                        echo '</div>
                    </div>
                </div>
            </div>';   
	    }
	}
}