<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fitness_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fitness_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fitness Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fitness_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_fitness_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_newsletter_heading',
            [
                'label'       => esc_html__( 'NewsLetter Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_newsletter_form',
            [
                'label'       => esc_html__( 'NewsLetter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_section_image',
            [
				'label'       => esc_html__( 'Section Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		$this->start_controls_section(
            'lcp_fitness_banner_statics',
            [
                'label' => esc_html__( 'Fitness Statistics', 'leadcapture' ),
            ] 
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_fitness_banner_statics_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fitness_banner_statics_list_number',
            [ 
                'label'       => esc_html__( 'Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fitness_banner_statics_list_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_statics_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_fitness_banner_statics_list_title}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_fitness_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fitness_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-text-style23 h1'
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style23 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fitness_banner_style_news_heading',
			[
				'label' => esc_html__( 'NewsLetter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-form-para-text-style23 p'
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-form-para-text-style23 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        
        $this->add_control(
			'lcp_fitness_banner_news_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_banner_news_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style23 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_banner_news_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style23 button'
            ]
        );
        
        
        
        
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_fitness_banner_style_list', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fitness_banner_style_list_heading',
			[
				'label' => esc_html__( 'Number Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_banner_style_list_number_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-client-box-style23 h4'
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_style_list_number_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-client-box-style23 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style 
        $this->add_control(
			'lcp_fitness_banner_style_list_title',
			[
				'label' => esc_html__( 'Title Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_banner_style_list_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-client-box-style23 p'
            ]
        );
        $this->add_control(
            'lcp_fitness_banner_style_list_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-client-box-style23 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    $style = !empty($settings['lcp_fitness_banner_section_image']['url']) ? 'style="background: url('.esc_url($settings['lcp_fitness_banner_section_image']['url']).');"' : '';

		    echo '<div class="lc-banner-section lc-banner-section-style23" '.$style.'>
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-heading-text-style23 aos-init aos-animate" data-aos="zoom-in" data-aos-duration="2000">';
                                if(!empty($settings['lcp_fitness_banner_title'])){
                                    echo '<h1>'.esc_html($settings['lcp_fitness_banner_title']).'</h1>';
                                }
                                echo '<div class="lc-form-para-text-style23 ">';
                                    if(!empty($settings['lcp_fitness_banner_newsletter_heading'])){
                                        echo '<p>'.esc_html($settings['lcp_fitness_banner_newsletter_heading']).'</p>';
                                    }
                                    if(!empty($settings['lcp_fitness_banner_newsletter_form'])){
                                        echo '<div class="lc-Newsletter lc-Newsletter-style23">
                                            <div class="lc-search-wrapper lc-search-wrapper-style23">';
                                                echo do_shortcode($settings['lcp_fitness_banner_newsletter_form']);
                                            echo '</div>
                                        </div>';
                                    }
                                echo '</div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-img-wrapper lc-banner-img-style23">';
                                if(!empty($settings['lcp_fitness_banner_statics_list'])){
                                    echo '<div class="lc-client-style23">';
                                    foreach($settings['lcp_fitness_banner_statics_list'] as $list){
                                        echo '<div class="lc-client-box-style23">';
                                            if(!empty($list['lcp_fitness_banner_statics_list_number']) || !empty($list['lcp_fitness_banner_statics_list_symbol'])){
                                                echo '<h4>'.esc_html($list['lcp_fitness_banner_statics_list_number']).' '.$list['lcp_fitness_banner_statics_list_symbol'].'</h4>';
                                            }
                                            if(!empty($list['lcp_fitness_banner_statics_list_title'])){
                                                echo '<p>'.esc_html($list['lcp_fitness_banner_statics_list_title']).'</p>';
                                            }
                                        echo '</div>';
                                    }
                                    echo '</div>';
                                }
                                echo '<div class="lc-box-style23">
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}