<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fitness_Personal extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fitness_personal';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fitness Personal', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() { 
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fitness_personal_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_fitness_personal_list_day',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Monday', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_fitness_personal_list_mtime',
            [
                'label'       => esc_html__( 'Morning Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '5:30am to 9:30am', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_fitness_personal_list_etime',
            [
                'label'       => esc_html__( 'Evening Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '5:30am to 9:30am', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_fitness_personal_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_fitness_personal_list_day'  => esc_html__( 'Monday', 'leadcapture' ),
						'lcp_fitness_personal_list_mtime'  => esc_html__( '5:30am to 9:30am', 'leadcapture' ),
						'lcp_fitness_personal_list_etime'  => esc_html__( '5:30am to 9:30am', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_fitness_personal_list_day}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_fitness_personal_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fitness_personal_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_personal_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-table-heading thead tr th'
            ]
        );
        $this->add_control(
            'lcp_fitness_personal_style_heading_color', 
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-table-heading thead tr th' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fitness_personal_style_heading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-table-heading thead' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        // Text Style
        $this->add_control(
			'lcp_fitness_personal_style_text',
			[
				'label' => esc_html__( 'Text', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_personal_style_text_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-table-heading .table tbody'
            ]
        );
        $this->add_control(
            'lcp_fitness_personal_style_text_color', 
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-table-heading .table tbody' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fitness_personal_style_text_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-table-heading .table' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        // Text Style
        $this->add_control(
			'lcp_fitness_personal_style_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_fitness_personal_style_text_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-table-heading .table tbody tr:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-table-heading aos-init aos-animate" data-aos="fade-up" data-aos-duration="700">
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th scope="col">'.esc_html('Day','leadcapture').'</th>
                                <th scope="col">'.esc_html('Morning Time','leadcapture').'</th>
                                <th scope="col">'.esc_html('Evening Time','leadcapture').'</th>
                            </tr>
                        </thead>
                        <tbody>';
                        if(!empty($settings['lcp_fitness_personal_list'])){
                            foreach($settings['lcp_fitness_personal_list'] as $list){
                                echo '<tr>
                                    <td scope="row">'.esc_html($list['lcp_fitness_personal_list_day']).'</td>
                                    <td>'.esc_html($list['lcp_fitness_personal_list_mtime']).'</td>
                                    <td>'.esc_html($list['lcp_fitness_personal_list_etime']).'</td>
                                </tr>';
                            }
                        }
                        echo '</tbody>
                    </table>
                </div>
            </div>';
		}
		
	}
}