<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fitness_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fitness_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fitness Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fitness_services_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_fitness_services_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_fitness_services_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Gym Class', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_fitness_services_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Consectetur adipiscing elit esed do eiusmod tempor incididunt ut labore et dolore magna.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_fitness_services_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_fitness_services_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_fitness_services_list_title'  => esc_html__( 'Gym Class', 'leadcapture' ),
						'lcp_fitness_services_list_desc'  => esc_html__( 'Consectetur adipiscing elit esed do eiusmod tempor incididunt ut labore et dolore magna.', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_fitness_services_list_title}}',
            ]
        );
		$this->end_controls_section();
		// Widget Style
        $this->start_controls_section(
            'lcp_fitness_services_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_fitness_services_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_services_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper-style23 h4'
            ]
        );
        $this->add_control(
            'lcp_fitness_services_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper-style23 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Services Style
        $this->add_control(
			'lcp_fitness_services_style_serv_title',
			[
				'label' => esc_html__( 'Service Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( 
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_services_style_serv_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-box-wrapper-style23 h4'
            ]
        );
        $this->add_control(
            'lcp_fitness_services_style_serv_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-wrapper-style23 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Services  Description Style
        $this->add_control(
			'lcp_fitness_services_style_serv_dec',
			[
				'label' => esc_html__( 'Service Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( 
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_services_style_serv_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-box-wrapper-style23 p'
            ]
        );
        $this->add_control(
            'lcp_fitness_services_style_serv_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-wrapper-style23 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_fitness_services_style_serv_desc_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-wrapper-style23:hover p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Services  Description Style
        $this->add_control(
			'lcp_fitness_services_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_fitness_services_style_extra_border_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-section-box-style23' => 'border: 1px solid {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-service-section lc-service-section-style23">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-wrapper-style23 aos-init aos-animate" data-aos="fade-up" data-aos-duration="700">';
                                if(!empty($settings['lcp_fitness_services_title'])){
                                    echo '<h4>'.esc_html($settings['lcp_fitness_services_title']).'</h4>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="lc-service-section-box-style23 aos-init aos-animate" data-aos="fade-up" data-aos-duration="700">
                        <div class="row">';
                            if(!empty($settings['lcp_fitness_services_list'])){
                                foreach($settings['lcp_fitness_services_list'] as $list){
                                    echo '<div class="col-lg-3 col-md-3 col-sm-6">
                                        <div class="lc-service-box-wrapper lc-service-box-wrapper-style23">';
                                            if(!empty($list['lcp_fitness_services_list_image']['url'])){
                                                echo '<span>
                                                    <img src="'.esc_url($list['lcp_fitness_services_list_image']['url']).'">
                                                </span>';
                                            }
                                            if(!empty($list['lcp_fitness_services_list_title'])){
                                                echo '<h4>'.esc_html($list['lcp_fitness_services_list_title']).'</h4>'; 
                                            }
                                            if(!empty($list['lcp_fitness_services_list_desc'])){
                                                echo '<p>'.esc_html($list['lcp_fitness_services_list_desc']).'</p>';
                                            }
                                        echo '</div>
                                    </div>';
                                }
                            }
                        echo '</div>
                    </div>
                </div>
            </div>';
		}
	}
}