<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Fitness_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_fitness_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Fitness Testimonials', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_fitness_testi_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_fitness_testi_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
		$repeater = new Repeater();
		$repeater->add_control(
            'lcp_fitness_testi_list_author',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
		$repeater->add_control(
            'lcp_fitness_testi_list_postion',
            [
                'label'       => esc_html__( 'Designation', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fitness_testi_list_testi_title',
            [
                'label'       => esc_html__( 'Testimonial Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fitness_testi_list_testi',
            [
                'label'       => esc_html__( 'Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_fitness_testi_list_author_image',
            [
				'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_fitness_testi_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_fitness_testi_list_author}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_fitness_testi_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_fitness_testi_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_testi_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style23 h4'
            ]
        );
        $this->add_control(
            'lcp_fitness_testi_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style23 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Author Style
        $this->add_control(
			'lcp_fitness_testi_style_list_author',
			[
				'label' => esc_html__( 'Author', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_testi_style_list_author_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-clint-img.lc-clint-img-style23 h4'
            ]
        );
        $this->add_control(
            'lcp_fitness_testi_style_list_author_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-clint-img.lc-clint-img-style23 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Postion Style
        $this->add_control(
			'lcp_fitness_testi_style_list_desiganation',
			[
				'label' => esc_html__( 'Desiganation', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_testi_style_list_desiganation_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-clint-img.lc-clint-img-style23 p'
            ]
        );
        $this->add_control(
            'lcp_fitness_testi_style_list_desiganation_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-clint-img.lc-clint-img-style23 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Title Style
        $this->add_control(
			'lcp_fitness_testi_style_list_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_testi_style_list_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-box-style23 h3'
            ]
        ); 
        $this->add_control(
            'lcp_fitness_testi_style_list_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-box-style23 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Title Style
        $this->add_control(
			'lcp_fitness_testi_style_list_testi',
			[
				'label' => esc_html__( 'Testimonial', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_fitness_testi_style_list_testi_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-box-style23 p'
            ]
        ); 
        $this->add_control(
            'lcp_fitness_testi_style_list_testi_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-box-style23 p' => 'color: {{VALUE}}!important;',
                ],
            ]
        );
        $this->end_controls_section();
        
        
       // $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-testimonial-wrapper lc-testimonial-style23">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-style23 aos-init aos-animate" data-aos="fade-up" data-aos-duration="700">';
                                if(!empty($settings['lcp_fitness_testi_title'])){
                                    echo '<h4>'.esc_html($settings['lcp_fitness_testi_title']).'</h4>';
                                }
                            echo '</div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-testimonials-slider ">
                                <div class="swiper lc-test-contant-style23 aos-init aos-animate" data-aos="fade-up" data-aos-duration="700">
                                    <div class="swiper-wrapper ">';
                                        if(!empty($settings['lcp_fitness_testi_list'])){
                                            foreach($settings['lcp_fitness_testi_list'] as $list){
                                                echo '<div class="swiper-slide lc-swiper-header-style23">
                                                    <div class="lc-main-testimonials lc-main-testimonials-style23">
                                                        <div class="lc-clint-img lc-clint-img-style23">';
                                                            if(!empty($list['lcp_fitness_testi_list_author_image']['url'])){
                                                                echo '<img src="'.esc_url($list['lcp_fitness_testi_list_author_image']['url']).'">';
                                                            }
                                                            if(!empty($list['lcp_fitness_testi_list_author'])){
                                                                echo '<h4>'.esc_html($list['lcp_fitness_testi_list_author']).'</h4>';
                                                            }
                                                            if(!empty($list['lcp_fitness_testi_list_postion'])){
                                                                echo '<p>'.esc_html($list['lcp_fitness_testi_list_postion']).'</p>';
                                                            }
                                                        echo '</div>
                                                        <div class="lc-test-box-style23">';
                                                            if(!empty($list['lcp_fitness_testi_list_testi_title'])){
                                                                echo '<h3>'.esc_html($list['lcp_fitness_testi_list_testi_title']).'</h3>';
                                                            }
                                                            if(!empty($list['lcp_fitness_testi_list_testi'])){
                                                                echo '<p>'.esc_html($list['lcp_fitness_testi_list_testi']).'</p>';
                                                            }
                                                            echo '<div class="lc-quots-style23">
                                                                <img src="'.LEAD_CAPTURE_URL.'/public/images/quots.png" alt="">
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>';
                                            }
                                        }
                                    echo '</div>
                                    <div class="swiper-button-next ">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 7 14" width="7"
                                            height="14">
                                            <title>Shape 12</title>
                                            <path id="Shape 12" class="s0"
                                                d="m7 7q0 0.3-0.2 0.5l-5.3 6.3q-0.2 0.2-0.5 0.2-0.2 0-0.4-0.2l-0.4-0.5q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.6l4.4-5.2-4.4-5.2c-0.3-0.3-0.3-0.8 0-1.1l0.4-0.5q0.2-0.2 0.4-0.2 0.3 0 0.5 0.2l5.3 6.3q0.2 0.2 0.2 0.5z" />
                                        </svg>
                                    </div>
                                    <div class="swiper-button-prev ">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 7 14" width="7"
                                            height="14">
                                            <title>Shape 12</title>
                                            <path id="Shape 12" class="s0"
                                                d="m0.2 6.5l5.3-6.3q0.2-0.2 0.5-0.2 0.2 0 0.4 0.2l0.4 0.5c0.3 0.3 0.3 0.8 0 1.1l-4.4 5.2 4.4 5.2q0.2 0.3 0.2 0.6 0 0.3-0.2 0.5l-0.4 0.5q-0.2 0.2-0.4 0.2-0.3 0-0.5-0.2l-5.3-6.3q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.5z" />
                                        </svg>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}