<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Flower_Aboutus extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_flower_aboutus';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Flower Aboutus', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_flower_ab_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_flower_ab_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_ab_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_ab_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_ab_btn_link',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_ab_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        ); 
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_flower_ab_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
		
		// Heading Style
        $this->add_control(
			'lcp_flower_ab_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_ab_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-text-offer-style19 h4'
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-text-offer-style19 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_heading_color_bottom',
            [
                'label'     => esc_html__( 'Bottom Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-text-offer-style19 h4:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Description Style
        $this->add_control(
			'lcp_flower_ab_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_ab_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-para-offer-style19 p'
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-para-offer-style19 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button Style
        $this->add_control(
			'lcp_flower_ab_style_btn',
			[
				'label' => esc_html__( 'Button Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_ab_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-read-btn-style19 a'
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_btn_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-read-btn-style19 a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_btn_border_color',
            [
                'label'     => esc_html__( 'Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-read-btn-style19' => 'border: 2px solid {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_btn_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-read-btn-style19' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-read-btn-style19:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_btn_hbgcolor',
            [
                'label'     => esc_html__( 'Background Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-read-btn-style19:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_ab_style_btn_border_hcolor',
            [
                'label'     => esc_html__( 'Border Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-read-btn-style19:hover' => 'border: 2px solid {{VALUE}};',
                ],
            ]
        );
        
        
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-offer-wrapper-style19">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6 col-md-6 col-sm-12">
                            <div class="lc-offer-box-wrapper">
                                <div class="lc-text-offer lc-text-offer-style19">';
                                    if(!empty($settings['lcp_flower_ab_heading'])){
                                        echo '<h4>'.esc_html($settings['lcp_flower_ab_heading']).'</h4>';
                                    }
                                echo '</div>
                                <div class="lc-para-offer-style19">';
                                    if(!empty($settings['lcp_flower_ab_desc'])){ 
                                        echo '<p>'.esc_html($settings['lcp_flower_ab_desc']).'</p>';
                                    }
                                echo '</div>';
                                if(!empty($settings['lcp_flower_ab_btn_title'])){ 
                                    echo '<div class="lc-btn lc-read-btn-style19">
                                        <a href="'.esc_url($settings['lcp_flower_ab_btn_link']).'">'.esc_html($settings['lcp_flower_ab_btn_title']).'</a>
                                    </div>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-6 col-md-6 col-sm-12">
                            <div class="lc-flower-img" data-tilt data-tilt-max="20" data-tilt-speed="100" data-tilt-perspective="1000">';
                                if(!empty($settings['lcp_flower_ab_image']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_flower_ab_image']['url']).'" class="lc-flower" alt="'.esc_attr('About Image', 'leadcapture' ).'">';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}