<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Flower_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_flower_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Flower Banner', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_flower_banner_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_flower_banner_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_banner_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_banner_btn_name',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_banner_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_banner_news_letter_title',
            [
                'label'       => esc_html__( 'NewsLetter Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_banner_form_shortcode',
            [
                'label'       => esc_html__( 'Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_banner_logo_image',
            [
				'label'       => esc_html__( 'Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_flower_banner_left_image',
            [
				'label'       => esc_html__( 'Left Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_flower_banner_right_image',
            [
				'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        ); 
        $this->add_control(
            'lcp_flower_banner_section_image',
            [
				'label'       => esc_html__( 'Section Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_flower_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_flower_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-flower-heading h1'
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-flower-heading h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_flower_banner_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_banner_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-flower-para-heading p'
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-flower-para-heading p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Newsletter Style
        $this->add_control(
			'lcp_flower_banner_style_news',
			[
				'label' => esc_html__( 'NewsLetter Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subscribe-form-style19 h2'
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subscribe-form-style19 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button Style
        $this->add_control(
			'lcp_flower_banner_style_btn',
			[
				'label' => esc_html__( 'Button Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_banner_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-get-style19 a'
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_btn_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style19 a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_btn_border_color',
            [
                'label'     => esc_html__( 'Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style19' => 'border: 2px solid {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_btn_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style19' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style19:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_btn_hbgcolor',
            [
                'label'     => esc_html__( 'Background Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style19:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_banner_style_btn_border_hcolor',
            [
                'label'     => esc_html__( 'Border Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style19:hover' => 'border: 2px solid {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    $bg_image = !empty($settings['lcp_flower_banner_section_image']['url']) ?  'style="background: url('.esc_url($settings['lcp_flower_banner_section_image']['url']).');"' : '';
		    echo '<div class="lc-banner-section lc-banner-section-style19" '.$bg_image.'>
		        <div class="container-fluid">
    				<div class="row">
    					<div class="col-lg-3 col-md-6 col-sm-12 p-0">
    						<div class="lc-banner-img-wrapper lc-banner-img-style19">';
    						    if($settings['lcp_flower_banner_left_image']['url']){
    						        echo '<img src="'.esc_url($settings['lcp_flower_banner_left_image']['url']).'" alt="'.esc_attr('Left Image', 'leadcapture').'">';
    						    }
    						echo '</div>
    					</div>
    					<div class="col-lg-6 col-md-6 col-sm-12 p-0">
    					    <div class="lc-banner-text lc-banner-text-style19">
    							<div class="lc-flower-heading fadeInDown wow" data-wow-delay=".1s" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 0.1s; animation-name: fadeInDown;">
    								<div class="lc-logo-img-style19">';
    								    if(!empty($settings['lcp_flower_banner_logo_image']['url'])){
    								        echo '<img src="'.esc_url($settings['lcp_flower_banner_logo_image']['url']).'" alt="'.esc_attr('Logo Image', 'leadcapture').'">';
    								    }
    								echo '</div>';
    								if(!empty($settings['lcp_flower_banner_heading'])){
    								    echo '<h1>'.esc_html($settings['lcp_flower_banner_heading']).'</h1>';
    								}
    							echo '</div>
    							<div class="lc-flower-para-heading fadeInDown wow" data-wow-delay=".2s" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 0.2s; animation-name: fadeInDown;">';
    								if(!empty($settings['lcp_flower_banner_desc'])){
    								    echo '<p>'.esc_html($settings['lcp_flower_banner_desc']).'</p>';
    								}
    							echo '</div>
    							<div class="lc-btn lc-get-style19">';
    							    if(!empty($settings['lcp_flower_banner_btn_name'])){
    							        echo '<a href="'.esc_url($settings['lcp_flower_banner_btn_link']).'">'.esc_html($settings['lcp_flower_banner_btn_name']).'</a>';
    							    }
    							echo '</div>
    						</div>
    						<div class="lc-subscribe lc-subscribe-style19 " >
    							<div class="lc-subscribe-form lc-subscribe-form-style19">';
    							    if(!empty($settings['lcp_flower_banner_news_letter_title'])){
    							        echo '<h2>'.esc_html($settings['lcp_flower_banner_news_letter_title']).'</h2>';
    							    }
    								echo '<div class="lc-sub-form lc-sub-form-style19">';
    								    if(!empty($settings['lcp_flower_banner_form_shortcode'])){
    								        echo do_shortcode($settings['lcp_flower_banner_form_shortcode']);
    								    }
    								echo '</div>
    							</div>
    						</div>
    					</div>
    					<div class="col-lg-3 col-md-12 col-sm-12 p-0">
    						<div class="lc-banner-img-wrapper lc-banner-img2-style19">';
    						    if(!empty($settings['lcp_flower_banner_right_image']['url'])){
    						        echo '<img src="'.esc_url($settings['lcp_flower_banner_right_image']['url']).'" alt="'.esc_attr('Right Image', 'leadcapture').'">';
    						    }
    						echo '</div>
    					</div>
				    </div>
				</div>
		    </div>';
		}
	}
}