<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Flower_Popular extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_flower_popular';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Flower Popular', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_flower_popular_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_flower_popular_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_popular_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_popular_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
        $this->add_control(
			'lcp_flower_popular_show_image',
			[
				'label' => esc_html__( 'Show Other Image', 'leadcapture' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'leadcapture' ),
				'label_off' => esc_html__( 'Hide', 'leadcapture' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
        
        //List
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_flower_popular_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Perfect Gifts', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_flower_popular_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_flower_popular_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_flower_popular_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_flower_popular_list_title'  => esc_html__( 'Perfect Gifts', 'leadcapture' ),
						'lcp_flower_popular_list_desc'  => esc_html__( 'There are many variations of passages', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_flower_popular_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_flower_popular_style_tab', 
            [
                'label' => esc_html__('Style', 'leadcapture'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_flower_popular_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_popular_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-popular-heading h4'
            ]
        );
        $this->add_control(
            'lcp_flower_popular_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-popular-heading h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_flower_popular_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_popular_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-popular-heading p'
            ]
        );
        $this->add_control(
            'lcp_flower_popular_style_desc_color',
            [ 
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-popular-heading p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_flower_popular_style_list', 
            [
                'label' => esc_html__('List Style', 'leadcapture'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_flower_popular_list_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_popular_list_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-popular-text h4'
            ]
        );
        $this->add_control(
            'lcp_flower_popular_list_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-popular-text h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_flower_popular_list_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_popular_list_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-popular-text p'
            ]
        );
        $this->add_control(
            'lcp_flower_popular_list_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-popular-text p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_flower_popular_list_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_flower_popular_list_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-popular-text' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    $style = !empty($settings['lcp_flower_popular_image']['url']) ? 'style="background: url('.esc_url($settings['lcp_flower_popular_image']['url']).');"' : '';
		    echo '<div class="lc-popular-wrapper" '.$style.'>
                <div class="container">
                    <div class="lc-popular-heading">';
                        if(!empty($settings['lcp_flower_popular_heading'])){
                            echo '<h4>'.esc_html($settings['lcp_flower_popular_heading']).'</h4>';
                        }
                        if(!empty($settings['lcp_flower_popular_desc'])){
                            echo '<p>'.esc_html($settings['lcp_flower_popular_desc']).'</p>';
                        }
                    echo '</div>
                    <div class="row">';
                        if(!empty($settings['lcp_flower_popular_list'])){
                            foreach($settings['lcp_flower_popular_list'] as $list){
                                echo '<div class="col-lg-4 col-md-6 col-sm-12">
                                    <div class="lc-popular-box">';
                                        if(!empty($list['lcp_flower_popular_list_image']['url'])){
                                            echo '<img src="'.esc_url($list['lcp_flower_popular_list_image']['url']).'">';
                                        }
                                        echo '<div class="lc-popular-text">';
                                            if(!empty($list['lcp_flower_popular_list_title'])){
                                                echo '<h4>'.esc_html($list['lcp_flower_popular_list_title']).'</h4>';
                                            }
                                            if(!empty($list['lcp_flower_popular_list_desc'])){
                                                echo '<p>'.esc_html($list['lcp_flower_popular_list_desc']).'</p>';
                                            }
                                        echo '</div>
                                    </div>
                                </div>';
                            }
                        }
                    echo '</div>
                </div>';
                if($settings['lcp_flower_popular_show_image'] == 'yes'){
                    echo '<div class="lc-flower-one">
                        <img src="'.LEAD_CAPTURE_URL.'/public/images/img1.png" alt="">
                    </div>
                    <div class="lc-flower-one lc-flower-two">
                        <img src="'.LEAD_CAPTURE_URL.'/public/images/img2.png" alt="">
                    </div>
                    <div class="lc-flower-three">
                        <img src="'.LEAD_CAPTURE_URL.'/public/images/img3.png" alt="">
                    </div>
                    <div class="lc-flower-four">
                        <img src="'.LEAD_CAPTURE_URL.'/public/images/img4.png" alt="">
                    </div>';
                }
            echo '</div>';
		}
	}
}