<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Flower_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_flower_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Flower Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_flower_testi_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_flower_testi_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_flower_testi_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        
        //List
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_flower_testi_list_author',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Raymond Galario', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_flower_testi_list_place',
            [
                'label'       => esc_html__( 'Place', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Sydney, Australia', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_flower_testi_list_testi',
            [
                'label'       => esc_html__( 'Place', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_flower_testi_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_flower_testi_list_rating',
            [
                'label'   => __( 'Rating', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '4',
                'options' => [
                    '1'   => __( '1 Star', 'leadcapture' ),
                    '2'   => __( '2 Star', 'leadcapture' ),
                    '3'   => __( '3 Star', 'leadcapture' ),
                    '4'   => __( '4 Star', 'leadcapture' ),
                    '5'   => __( '5 Star', 'leadcapture' ),
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_testi_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_flower_testi_list_author'  => esc_html__( 'Raymond Galario', 'leadcapture' ),
                        'lcp_flower_testi_list_place'  => esc_html__( 'Sydney, Australia', 'leadcapture' ),
						'lcp_flower_testi_list_testi'  => esc_html__( 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed.', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_flower_testi_list_author}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_flower_testi_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_flower_testi_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_testi_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style19 h2'
            ]
        );
        $this->add_control(
            'lcp_flower_testi_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style19 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_testi_style_heading_bordercolor',
            [
                'label'     => esc_html__( 'Bottom Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style19 h2:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_flower_testi_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_testi_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style19 p'
            ]
        );
        $this->add_control(
            'lcp_flower_testi_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-wrapper.lc-heading-style19 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_flower_testi_list_style_tab', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_flower_testi_list_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_testi_list_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-para-style19 h4'
            ]
        );
        $this->add_control(
            'lcp_flower_testi_list_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-para-style19 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Place Style
        $this->add_control(
			'lcp_flower_testi_list_style_place',
			[
				'label' => esc_html__( 'Place', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_testi_list_style_place_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-para-style19 p'
            ]
        );
        $this->add_control(
            'lcp_flower_testi_list_style_place_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-para-style19 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Testimonial Style
        $this->add_control(
			'lcp_flower_testi_testi_style_place',
			[
				'label' => esc_html__( 'Place', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_flower_testi_testi_style_place_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-test-text-style19 > p'
            ]
        );
        $this->add_control(
            'lcp_flower_testi_testi_style_place_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-text-style19 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_flower_testi_nav_style_tab', 
            [
                'label' => esc_html__( 'Navigation', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Normal Style
        $this->add_control(
			'lcp_flower_testi_nav_style_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_flower_testi_style_normal_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-prev>svg>.s0' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-next>svg>.s0' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_testi_style_normal_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-next' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-prev' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        
        // Hover Style
        $this->add_control(
			'lcp_flower_testi_nav_style_hover',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ), 
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_flower_testi_style_hover_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-prev:hover >svg>.s0' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-next:hover >svg>.s0' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_flower_testi_style_hover_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-next:hover' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-testimonial-wrapper.lc-testimonial-style19 .lc-testimonial-slider-btn-style19>.swiper-button-prev:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-testimonial-wrapper lc-testimonial-style19">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-4 col-md-12 col-sm-12">
                            <div class="lc-test-head-wrapper">
                                <div class="lc-heading-wrapper lc-heading-style19 lc-test-heading">';
                                    if(!empty($settings['lcp_flower_testi_heading'])){
                                        echo '<h2>'.esc_html($settings['lcp_flower_testi_heading']).'</h2>';
                                    }
                                    if(!empty($settings['lcp_flower_testi_desc'])){
                                        echo '<p>'.esc_html($settings['lcp_flower_testi_desc']).'</p>';
                                    }
                                echo '</div>
                                <div class="lc-testimonial-slider-btn lc-testimonial-slider-btn-style19">
                                    <div class="swiper-button-next">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 11 17" width="11"
                                            height="17">
                                            <title>Shape 12</title>
                                            <path id="Shape 12" class="s0"
                                                d="m9 9q0 0.3-0.2 0.5l-5.3 6.3q-0.2 0.2-0.5 0.2-0.2 0-0.4-0.2l-0.4-0.5q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.6l4.4-5.2-4.4-5.2c-0.3-0.3-0.3-0.8 0-1.1l0.4-0.5q0.2-0.2 0.4-0.2 0.3 0 0.5 0.2l5.3 6.3q0.2 0.2 0.2 0.5z" />
                                        </svg>
                                    </div>
                                    <div class="swiper-button-prev">
                                        <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 11 17" width="11"
                                            height="17">
                                            <title>Shape 12</title>
                                            <path id="Shape 12" class="s0"
                                                d="m2.2 8.5l5.3-6.3q0.2-0.2 0.5-0.2 0.2 0 0.4 0.2l0.4 0.5c0.3 0.3 0.3 0.8 0 1.1l-4.4 5.2 4.4 5.2q0.2 0.3 0.2 0.6 0 0.3-0.2 0.5l-0.4 0.5q-0.2 0.2-0.4 0.2-0.3 0-0.5-0.2l-5.3-6.3q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.5z" />
                                        </svg>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-8 col-md-12 col-sm-12">
                            <div class="lc-testimonial-slider-wrapper lc-testimonial-slider-wrapper-style19">
                                <div class="swiper lc-testimonial-slider-style19">
                                    <div class="swiper-wrapper">';
                                        if(!empty($settings['lcp_flower_testi_list'])){
                                            foreach($settings['lcp_flower_testi_list'] as $list){
                                                echo '<div class="swiper-slide">
                                                    <div class="lc-test-box-style19">';
                                                        if(!empty($list['lcp_flower_testi_list_image']['url'])){
                                                            echo '<img src="'.esc_url($list['lcp_flower_testi_list_image']['url']).'" alt="'.esc_html('Testimonial', 'leadcapture').'">';
                                                        }
                                                        echo '<div class="lc-test-text-style19 ">';
                                                            if(!empty($list['lcp_flower_testi_list_testi'])){
                                                                echo '<p>'.esc_html($list['lcp_flower_testi_list_testi']).'</p>';
                                                            }
                                                            echo '<div class="lc-flex-text-style19">
                                                                <div class="lc-test-para-style19">';
                                                                    if(!empty($list['lcp_flower_testi_list_author'])){
                                                                        echo '<h4>'.esc_html($list['lcp_flower_testi_list_author']).'</h4>';
                                                                    }
                                                                    if(!empty($list['lcp_flower_testi_list_place'])){
                                                                        echo '<p>'.esc_html($list['lcp_flower_testi_list_place']).'</p>';
                                                                    }
                                                                echo '</div>
                                                                <div class="lc-stare-img-style19">';
                                                                    if(!empty($list['lcp_flower_testi_list_rating'])){
                                                                        $count = $list['lcp_flower_testi_list_rating'];
                                                                        for($i=1; $i<=$count; $i++){
                                                                            echo '<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 25 25" width="25" height="25">
                                                                                <title>Shape 2</title>
                                                                                <style>
                                                                                    .s0 {
                                                                                        fill: #ffc107
                                                                                    }
                                                                                </style>
                                                                                <path id="Shape2" class="s0"
                                                                                    d="m22.6 11.2l-4.6 4.2 1.4 6.2c0.1 0.4-0.1 0.9-0.4 1.2-0.4 0.3-0.9 0.3-1.3 0l-5.2-3.2-5.2 3.2q-0.3 0.2-0.6 0.2-0.4 0-0.7-0.2c-0.3-0.3-0.5-0.8-0.4-1.2l1.4-6.2-4.6-4.2c-0.4-0.3-0.5-0.8-0.3-1.3 0.1-0.4 0.5-0.7 0.9-0.8l6.1-0.5 2.4-5.9c0.2-0.4 0.6-0.7 1-0.7 0.4 0 0.8 0.3 1 0.7l2.4 5.9 6.1 0.5c0.4 0.1 0.8 0.4 0.9 0.8 0.2 0.5 0.1 1-0.3 1.3z" />
                                                                            </svg>';
                                                                        }
                                                                        $total  = 5 - $count;
                                                                        if($total != 0){
                                                                            for($j=1; $j<=$total; $j++){
                                                                                echo '<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 25 25" width="25" height="25">
                                                                                    <title>Shape 2</title>
                                                                                    <path id="Shape3" d="m22.6 11.2l-4.6 4.2 1.4 6.2c0.1 0.4-0.1 0.9-0.4 1.2-0.4 0.3-0.9 0.3-1.3 0l-5.2-3.2-5.2 3.2q-0.3 0.2-0.6 0.2-0.4 0-0.7-0.2c-0.3-0.3-0.5-0.8-0.4-1.2l1.4-6.2-4.6-4.2c-0.4-0.3-0.5-0.8-0.3-1.3 0.1-0.4 0.5-0.7 0.9-0.8l6.1-0.5 2.4-5.9c0.2-0.4 0.6-0.7 1-0.7 0.4 0 0.8 0.3 1 0.7l2.4 5.9 6.1 0.5c0.4 0.1 0.8 0.4 0.9 0.8 0.2 0.5 0.1 1-0.3 1.3z" />
                                                                                </svg>';
                                                                            }
                                                                        }
                                                                    }
                                                                echo '</div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>';
                                            }
                                        }
                                    echo '</div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>'; 
		}
	}
}