<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Gardeners_Blogs extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_gardeners_blogs';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Gardeners Blogs', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $categories = get_categories();
		$cats = array();
		foreach( $categories as $terms ){
			$cats[$terms->term_id] = $terms->name;
		}
		
		
	    $this->start_controls_section(
            'lcp_gardener_blog_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_gardener_blog_post_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_post_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_post_show',
            [
                'label'       => esc_html__( 'Number of Post', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '3', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_category',
            [
                'label'   => __( 'Select Categories', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT2,
				'multiple' => true,
                'options' => $cats
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_order_by',
            [
                'label'   => __( 'Order By', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'   => __( 'None', 'leadcapture' ),
                    'id'   => __( 'Id', 'leadcapture' ),					
					'title'   => __( 'Title', 'leadcapture' ),
					'date'   => __( 'Date', 'leadcapture' ),
                ],
            ]
        );
		$this->add_control(
            'lcp_gardener_blog_sort',
            [
                'label'   => __( 'Sort Order', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC'   => __( 'Ascending', 'leadcapture' ),
                    'DESC'   => __( 'Descending', 'leadcapture' ),
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_gardener_blog_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_gardener_blog_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control( 
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_blog_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style20.lc-bloghead-style20 >h2'
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style20.lc-bloghead-style20 >h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Tagline Style
        $this->add_control(
			'lcp_gardener_blog_style_style_tegline',
			[
				'label' => esc_html__( 'Tegline', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_blog_style_tegline_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style20 > h3'
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_style_tegline_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style20 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_style_tegline_extra',
            [
                'label'     => esc_html__( 'Extra', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style20 > h3::after' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_gardener_blog_blog_style_tab', 
            [
                'label' => esc_html__( 'Blog Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_gardener_blog_blog_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_blog_blog_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-box-wrapper:hover .lc-blog-text >h4'
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_blog_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-box-wrapper:hover .lc-blog-text >h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_gardener_blog_blog_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_blog_blog_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style20 > p'
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_blog_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style20 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Link Style
        $this->add_control(
			'lcp_gardener_blog_blog_style_link',
			[
				'label' => esc_html__( 'Link', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_blog_blog_style_link_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-readbtn-style20 > a'
            ] 
        );
        $this->add_control(
            'lcp_gardener_blog_blog_style_link_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-readbtn-style20 > a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-readbtn-style20 > a svg path' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_blog_blog_style_hlink_color',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-readbtn-style20:hover > a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-readbtn-style20:hover > a svg path' => 'fill: {{VALUE}};',
                ],
            ]
        );
        
        // Link Style
        $this->add_control(
			'lcp_gardener_blog_blog_style_meta',
			[
				'label' => esc_html__( 'Metabox', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_blog_blog_style_meta_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-comments-style20 > .lc-comment-text > p'
            ] 
        );
        $this->add_control(
            'lcp_gardener_blog_blog_style_meta_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-comments-style20 > .lc-comment-text > p' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-comments-style20 > .lc-comment-text > span > svg .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_gardener_services_nav_style_tab', 
            [
                'label' => esc_html__( 'Navigation Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'lcp_gardener_services_style_nav_color',
            [ 
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 > .swiper-button-prev > svg .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 > .swiper-button-next > svg .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-prev' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-next' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_border_color',
            [
                'label'     => esc_html__( 'Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-prev' => 'border: 1px solid {{VALUE}};',
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-next' => 'border: 1px solid {{VALUE}};',
                ],
            ]
        );
        
        
        $this->add_control(
            'lcp_gardener_services_style_nav_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-prev:hover svg .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-next:hover svg .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_hbgcolor',
            [
                'label'     => esc_html__( 'Hover Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-prev:hover' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-blog-sliderbtn-style20 .swiper-button-next:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_hborder_color',
            [
                'label'     => esc_html__( 'Hover Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-prev:hover' => 'border: 1px solid {{VALUE}};',
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-next:hover' => 'border: 1px solid {{VALUE}};',
                ],
            ]
        );
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    if(!empty($settings['lcp_gardener_blog_category'])){
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_gardener_blog_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_gardener_blog_sort'],
    				'orderby'         => $settings['lcp_gardener_blog_order_by'],
    				'tax_query' => array(
    				array(
    					'taxonomy'  => 'category',
    					'field'     => 'ID',
    					'terms'     => $settings['lcp_gardener_blog_category'],
    					),
    				),	
    			));
    		} else {
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_gardener_blog_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_gardener_blog_sort'],
    				'orderby'         => $settings['lcp_gardener_blog_order_by'],
    			));
    		}
		    echo '<div class="lc-blog-wrapper lc-blog-wrapper-style20">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6 col-md-6 col-sm-6">
                            <div class="lc-heading-wrapper lc-heading-style20 lc-bloghead-style20">';
                                if(!empty($settings['lcp_gardener_blog_post_heading'])){
                                    echo '<h3>'.esc_html($settings['lcp_gardener_blog_post_heading']).'</h3>';
                                }
                                if(!empty($settings['lcp_gardener_blog_post_desc'])){
                                    echo '<h2>'.esc_html($settings['lcp_gardener_blog_post_desc']).'</h2>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-6 col-md-6 col-sm-6">
                            <div class="lc-blog-sliderbtn-style20">
                                <div class="swiper-button-next">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="8" height="15" viewBox="0 0 8 15">
                                        <path class="cls-1"
                                            d="M0.993,14.993A1,1,0,0,0,1.7,14.7l6-6.028a1.008,1.008,0,0,0,0-1.417l-6-6.028a1,1,0,0,0-1.41.109,1.008,1.008,0,0,0,0,1.307L5.585,7.96,0.293,13.275A1,1,0,0,0,.993,14.993Z" />
                                    </svg>
                                </div>
                                <div class="swiper-button-prev">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="8" height="15" viewBox="0 0 8 15">
                                        <path class="cls-1"
                                            d="M7.007,14.993A1,1,0,0,1,6.3,14.7l-6-6.028a1.008,1.008,0,0,1,0-1.417l6-6.028a1,1,0,0,1,1.41.109,1.008,1.008,0,0,1,0,1.307L2.415,7.96l5.292,5.315A1,1,0,0,1,7.007,14.993Z" />
                                    </svg>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="lc-blogslider-wrapper lc-blogslider-wrapper-style20">
                        <div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12 p-0">
                                <div class="lc-blogslider-wrappers lc-blogslider-style20 fadeInDown wow"
                                data-wow-delay="200ms" data-wow-duration="1000ms"
                                style="visibility: visible; animation-duration: 1000ms; animation-delay: 200ms; animation-name: fadeInDown;">
                                    <div class="swiper lc-blogslider-style20">
                                        <div class="swiper-wrapper">';
                                            if($query->have_posts() ) {
    		                                    while($query->have_posts()): $query->the_post();
        		                                    $attach_id = get_post_thumbnail_id(get_the_ID());
                        				            $thumbnail_url = wp_get_attachment_url($attach_id, 'full');
                                                    echo '<div class="swiper-slide">
                                                        <div class="lc-blog-box-wrapper lc-blog-box-style20">
                                                            <div class="lc-blog-img lc-blog-img-style20">';
                                                                if(!empty($thumbnail_url)){
                                                                    echo '<img src="'.esc_url($thumbnail_url).'" alt="'.esc_attr('blog-img', 'leadcapture').'">';
                                                                }
                                                            echo '</div>
                                                            <div class="lc-comments lc-comments-style20">
                                                                <div class="lc-comment-text">
                                                                    <span>
                                                                        <svg xmlns="http://www.w3.org/2000/svg" width="17"
                                                                            height="17" viewBox="0 0 17 17">
                                                                            <path class="cls-1"
                                                                                d="M16.136,13.6l-0.929-2.748a6.976,6.976,0,0,0,.686-3.006,6.881,6.881,0,0,0-1.941-4.819,6.676,6.676,0,0,0-9.6-.047A6.863,6.863,0,0,0,2.376,7.75a5.031,5.031,0,0,0-1.97,4.008A5.089,5.089,0,0,0,.882,13.9L0.241,15.79a0.9,0.9,0,0,0,.21.922,0.864,0.864,0,0,0,.907.213l1.863-.65a4.882,4.882,0,0,0,2.105.483H5.335A4.893,4.893,0,0,0,9.311,14.7a6.693,6.693,0,0,0,2.793-.695l2.7,0.944a1.027,1.027,0,0,0,1.078-.253A1.066,1.066,0,0,0,16.136,13.6ZM5.335,15.79H5.328a3.931,3.931,0,0,1-1.85-.466,0.469,0.469,0,0,0-.377-0.03l-1.91.667,0.656-1.94a0.491,0.491,0,0,0-.029-0.383,4.084,4.084,0,0,1,.647-4.677A6.861,6.861,0,0,0,4.4,12.734,6.683,6.683,0,0,0,8.12,14.629,3.929,3.929,0,0,1,5.335,15.79Zm9.878-1.774a0.085,0.085,0,0,1-.1.022l-2.9-1.011a0.47,0.47,0,0,0-.377.03,5.747,5.747,0,0,1-2.7.681H9.134A5.918,5.918,0,0,1,5.029,3.669a5.716,5.716,0,0,1,4.2-1.727A5.877,5.877,0,0,1,14.94,7.849a5.983,5.983,0,0,1-.671,2.744,0.491,0.491,0,0,0-.029.383l0.995,2.941A0.089,0.089,0,0,1,15.213,14.015Zm-3.242-8.74H6.3a0.484,0.484,0,0,0,0,.968h5.674A0.484,0.484,0,0,0,11.971,5.276Zm0,1.99H6.3a0.484,0.484,0,0,0,0,.967h5.674A0.484,0.484,0,0,0,11.971,7.265ZM9.787,9.255H6.3a0.484,0.484,0,0,0,0,.968h3.49A0.484,0.484,0,0,0,9.787,9.255Z" />
                                                                        </svg>
                                                                    </span>
                                                                    <p>Comments : ';
                                                                        echo get_comments_number(get_the_ID());
                                                                    echo '</p>
                                                                </div>
                                                                <div class="lc-comment-text lc-likes-text">
                                                                    <span class="likes_btn" data-id="'.get_the_ID().'">
                                                                        <svg xmlns="http://www.w3.org/2000/svg" width="17"
                                                                            height="15" viewBox="0 0 17 15">
                                                                            <path class="cls-1"
                                                                                d="M8.193,14.974a0.949,0.949,0,0,1-.619-0.229c-0.646-.556-1.269-1.078-1.819-1.539l0,0A33.61,33.61,0,0,1,1.78,9.537,5.8,5.8,0,0,1,.193,5.7,4.871,4.871,0,0,1,1.462,2.344a4.336,4.336,0,0,1,3.2-1.37,4.068,4.068,0,0,1,2.514.854A5.094,5.094,0,0,1,8.193,2.871,5.094,5.094,0,0,1,9.21,1.827,4.068,4.068,0,0,1,11.724.974a4.336,4.336,0,0,1,3.2,1.37A4.871,4.871,0,0,1,16.193,5.7a5.8,5.8,0,0,1-1.587,3.834A33.586,33.586,0,0,1,10.634,13.2c-0.551.461-1.175,0.985-1.823,1.542A0.949,0.949,0,0,1,8.193,14.974ZM4.663,1.9A3.4,3.4,0,0,0,2.151,2.969,3.963,3.963,0,0,0,1.13,5.7,4.886,4.886,0,0,0,2.5,8.949,33.065,33.065,0,0,0,6.36,12.5l0,0c0.552,0.463,1.177.987,1.829,1.547,0.655-.561,1.282-1.086,1.835-1.55a33.073,33.073,0,0,0,3.858-3.553A4.886,4.886,0,0,0,15.256,5.7a3.963,3.963,0,0,0-1.021-2.734A3.4,3.4,0,0,0,11.724,1.9a3.141,3.141,0,0,0-1.941.661A4.494,4.494,0,0,0,8.7,3.787a0.6,0.6,0,0,1-1.016,0A4.488,4.488,0,0,0,6.6,2.556,3.141,3.141,0,0,0,4.663,1.9Z" />
                                                                        </svg>
                                                                    </span>';
                                                                    $likes = get_post_meta( get_the_ID(), 'leadcapture_post_likes',false);
                                                                    $like = !empty($likes[0]) ? $likes[0] : 0;
                                                                    echo '<p>Likes : <span class="lc_post_likes">'.$like.'</span></p>
                                                                </div>
                                                            </div>
                                                            <div class="lc-blog-text lc-blog-text-style20">
                                                                <h4>'. substr(get_the_title(),0,100).'</h4>
                                                                <p>'. substr(get_the_excerpt(),0,110).'</p>
                                                                <div class="lc-btn lc-readbtn-style20">
                                                                    <a href="'. esc_url(get_permalink()).'">'.esc_html('Read More', 'leadcapture').'
                                                                        <svg xmlns="http://www.w3.org/2000/svg" width="22"
                                                                            height="11" viewBox="0 0 22 11">
                                                                            <path id="Arrow" class="cls-1"
                                                                                d="M1.061,6.405H18.578L15.3,9.415c-0.943.864,0.471,2.161,1.414,1.3L19.7,7.966l2-1.833a0.862,0.862,0,0,0,0-1.289L16.71,0.268a1.045,1.045,0,0,0-.723-0.277A0.907,0.907,0,0,0,15.3,1.565l3.29,3.01H1.009a0.921,0.921,0,1,0,.052,1.831h0Z" />
                                                                        </svg>
                                                                    </a>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>';
                                                endwhile;
                            					wp_reset_query();
                            		        }
                                        echo '</div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}