<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Gardeners_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_gardeners_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Gardeners Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_flower_services_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_gardener_services_tagline',
            [
                'label'       => esc_html__( 'Tagline', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardener_services_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_gardener_services_image',
            [
				'label'       => esc_html__( 'Section Bg Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
        //List
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_gardener_services_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Tree Plantation', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_gardener_services_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Established fact that a reader will be distracted by ', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_gardener_services_list_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_gardener_services_list_image',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_gardener_services_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_gardener_services_list_title'  => esc_html__( 'Tree Plantation', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_gardener_services_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_gardener_services_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_gardener_services_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style20 > h2'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style20 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Tagline Style
        $this->add_control(
			'lcp_gardener_services_style_style_tegline',
			[
				'label' => esc_html__( 'Tegline', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_style_tegline_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style20 > h3'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_tegline_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style20 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_tegline_extra',
            [
                'label'     => esc_html__( 'Extra', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style20 > h3::after' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_gardener_services_ser_style_tab', 
            [
                'label' => esc_html__( 'Services Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
		// Heading Style
        $this->add_control(
			'lcp_gardener_services_ser_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_ser_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-serbox-text-style20 > h4'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_ser_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-serbox-text-style20 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_ser_style_heading_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-wrapper-style20:hover .lc-serbox-text-style20 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Description Style
        $this->add_control(
			'lcp_gardener_services_ser_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_ser_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-serbox-text-style20 > p'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_ser_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-serbox-text-style20 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // ReadMore Style
        $this->add_control(
			'lcp_gardener_services_ser_style_btn',
			[
				'label' => esc_html__( 'Link', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_gardener_services_ser_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-readbtn-style20 > a'
            ]
        );
        $this->add_control(
            'lcp_gardener_services_ser_style_btn_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-readbtn-style20 > a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-servicebox-wrapper-style20 .lc-serbox-text-style20 .lc-readbtn-style20 > a > svg .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_control(
            'lcp_gardener_services_ser_style_hbtn_color',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-serbox-text-style20 .lc-readbtn-style20:hover > a, .lc-readbtn-style20:hover > a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-serbox-text-style20 .lc-readbtn-style20:hover a > svg .cls-1, .lc-readbtn-style20:hover a > svg .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_gardener_services_nav_style_tab', 
            [
                'label' => esc_html__( 'Navigation Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'lcp_gardener_services_style_nav_color',
            [ 
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-prev > svg .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-next > svg .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-next' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-prev' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_border_color',
            [
                'label'     => esc_html__( 'Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-next' => 'border: 1px solid {{VALUE}};',
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-prev' => 'border: 1px solid {{VALUE}};',
                ],
            ]
        );
        
        
        $this->add_control(
            'lcp_gardener_services_style_nav_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-next:hover svg .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-prev:hover svg .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_hbgcolor',
            [
                'label'     => esc_html__( 'Hover Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-prev:hover' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-next:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
            'lcp_gardener_services_style_nav_hborder_color',
            [
                'label'     => esc_html__( 'Hover Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-prev:hover' => 'border: 1px solid {{VALUE}};',
                    '{{WRAPPER}} .lc-servicebox-sliderbtn-style20 .swiper-button-next:hover' => 'border: 1px solid {{VALUE}};',
                ],
            ]
        );
        
        
        
        
        
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    $style = !empty($settings['lcp_gardener_services_image']['url']) ? 'style="background: url('.esc_url($settings['lcp_gardener_services_image']['url']).');"' : '';
		    echo '<div class="lc-services-wrapper lc-services-wrapper-style20" '.$style.'>
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6 col-md-6 col-sm-6">
                            <div class="lc-heading-wrapper lc-heading-style20">';
                                if(!empty($settings['lcp_gardener_services_tagline'])){
                                    echo '<h3>'.esc_html($settings['lcp_gardener_services_tagline']).'</h3>';
                                }
                                if(!empty($settings['lcp_gardener_services_title'])){
                                    echo '<h2>'.esc_html($settings['lcp_gardener_services_title']).'</h2>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-6 col-md-6 col-sm-6">
                            <div class="lc-servicebox-sliderbtn-style20">
                                <div class="swiper-button-next">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="8" height="15" viewBox="0 0 8 15">
                                        <path class="cls-1"
                                            d="M0.993,14.993A1,1,0,0,0,1.7,14.7l6-6.028a1.008,1.008,0,0,0,0-1.417l-6-6.028a1,1,0,0,0-1.41.109,1.008,1.008,0,0,0,0,1.307L5.585,7.96,0.293,13.275A1,1,0,0,0,.993,14.993Z" />
                                    </svg>
                                </div>
                                <div class="swiper-button-prev">
                                    <svg xmlns="http://www.w3.org/2000/svg" width="8" height="15" viewBox="0 0 8 15">
                                        <path class="cls-1"
                                            d="M7.007,14.993A1,1,0,0,1,6.3,14.7l-6-6.028a1.008,1.008,0,0,1,0-1.417l6-6.028a1,1,0,0,1,1.41.109,1.008,1.008,0,0,1,0,1.307L2.415,7.96l5.292,5.315A1,1,0,0,1,7.007,14.993Z" />
                                    </svg>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="lc-servicebox-slider lc-servicebox-slider20">
                        <div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12 p-0">
                                <div class="lc-serviceslider-wrappers lc-serviceslider-style20">
                                    <div class="swiper lc-serviceslider-style20">
                                        <div class="swiper-wrapper">';
                                            if(!empty($settings['lcp_gardener_services_list'])){
                                                foreach($settings['lcp_gardener_services_list'] as $list){
                                                    echo '<div class="swiper-slide">
                                                        <div class="lc-service-box-wrapper lc-servicebox-wrapper-style20">
                                                            <div class="lc-serbox-text lc-serbox-text-style20">';
                                                                if(!empty($list['lcp_gardener_services_list_title'])){
                                                                    echo '<h4>'.esc_html($list['lcp_gardener_services_list_title']).'</h4>';
                                                                }
                                                                if(!empty($list['lcp_gardener_services_list_desc'])){
                                                                    echo '<p>'.esc_html($list['lcp_gardener_services_list_desc']).'</p>';
                                                                }
                                                                if(!empty($list['lcp_gardener_services_list_link'])){
                                                                    echo '<div class="lc-btn lc-readbtn-style20">
                                                                        <a href="'.esc_url($list['lcp_gardener_services_list_link']).'">'.esc_html('Read More', 'leadcapture').'
                                                                            <svg xmlns="http://www.w3.org/2000/svg" width="22"
                                                                                height="11" viewBox="0 0 22 11">
                                                                                <path id="Arrow" class="cls-1"
                                                                                    d="M1.061,6.405H18.578L15.3,9.415c-0.943.864,0.471,2.161,1.414,1.3L19.7,7.966l2-1.833a0.862,0.862,0,0,0,0-1.289L16.71,0.268a1.045,1.045,0,0,0-.723-0.277A0.907,0.907,0,0,0,15.3,1.565l3.29,3.01H1.009a0.921,0.921,0,1,0,.052,1.831h0Z" />
                                                                            </svg>
                                                                        </a>
                                                                    </div>';
                                                                }
                                                            echo '</div>';
                                                            if(!empty($list['lcp_gardener_services_list_image']['url'])){
                                                                echo '<div class="lc-serbox-icon lc-serbox-icon-style20">
                                                                    <img src="'.esc_url($list['lcp_gardener_services_list_image']['url']).'" alt="'.esc_attr('ser-icon', 'leadcapture').'">
                                                                </div>';
                                                            }
                                                        echo '</div>
                                                    </div>';
                                                }
                                            }
                                        echo '</div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}