<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Testmonials_Style1 extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_testimonials_style1';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __('Leadcapture Wedding Testimonials', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Wedding Testimonials ', 'leadcapture'),
            ] 
        );
		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_testi',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_testimonial_quote',
            [
			'label'       => esc_html__( 'Quote Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );

		$this->end_controls_section();
		
		/** 
        * Lead Captur Style Tab
        */
        $this->start_controls_section(
            'lps_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Name Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .title-color-update',
            ]
        );
        $this->add_control(
			'lps_heading_text_color',
    			[
    			'label' => esc_html__('Name Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .title-color-update' => 'color: {{VALUE}}',
    			],
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_description_typography',
            'selector' => '{{WRAPPER}} .text-color-update',
            ]
        ); 
        $this->add_control(
			'lps_text_color',
    			[
    			'label' => esc_html__('Description Text Color', 'leadcapture' ),
    			'type' => \Elementor\Controls_Manager::COLOR,
    			'selectors' => [
    				'{{WRAPPER}} .text-color-update' => 'color: {{VALUE}}',
    			],
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => esc_html__( 'Background', 'leadcapture' ),
				'types' => [ 'classic'],
				'selector' => '{{WRAPPER}} .lc-testimonial-wedding .swiper-pagination span.swiper-pagination-bullet-active',
			]
		);
        
       	$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-testimonial-wrapper lc-testimonial-wedding">';
        echo '<div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-testimonial-slider-wrapper">
                                <div class="swiper lc-testimonial-slider-wedding">
                                    <div class="swiper-wrapper ">';
                                    if(!empty($settings['leadcapture_testimonial_list'])):
                                           foreach($settings['leadcapture_testimonial_list'] as $testi):
                                                echo '<div class="swiper-slide">
                                                   <div class="lc-testimonial-box lc-testimonial-box-wedding">';
                                                    if(!empty($testi['leadcapture_testimonial_image']['url'])):
                                                        echo '<div class="testimonial-img"><img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr($testi['leadcapture_testimonial_image']['alt']).'"></div>';
                                                    endif;
                                                echo '<div class="lc-testimonial-text">';
                                                    if(!empty($testi['leadcapture_testimonial_testi'])):
                                                       echo '<p class="lps-description-fontstyle text-color-update"><span>'.esc_html($testi['leadcapture_testimonial_testi']).'</span><b class="quote-icon"><img src="'.esc_url($testi['leadcapture_testimonial_quote']['url']).'" alt="'.esc_attr($testi['leadcapture_testimonial_quote']['alt']).'"></b></p>';
                                                    endif;
                                                if(!empty($testi['leadcapture_testimonial_author'])):
                                                echo '<h4 class="title-color-update">'.esc_html($testi['leadcapture_testimonial_author']);
                                                echo '</h4>';
                                                endif;
                                                echo '</div>
                                                     </div>
                                                   </div>'; 
                                            endforeach;
                                echo '</div>';
                                endif;      
                            echo '</div><div class="swiper-pagination "></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}