<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Hotel_And_Resort_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_hotel_and_resort_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Hotel And Resort', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_hotel_and_resort_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_logo_image',
            [
				'label'       => esc_html__( 'Section Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_sub_title',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_newsletter_title',
            [
                'label'       => esc_html__( 'NewsLetter Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_newsletter_sub_title',
            [
                'label'       => esc_html__( 'NewsLetter Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_newsletter_form_id',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_small_img',
            [
				'label'       => esc_html__( 'Small Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_small_heading',
            [
				'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		
		// Box One setting
		$this->start_controls_section(
            'lcp_banner_box_setting',
            [
                'label' => esc_html__( 'Box Setting 1', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_banner_img_box_one',
            [
				'label'       => esc_html__( 'Box Image 1', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_title_box_one',
            [
                'label'       => esc_html__( 'Box Title 1', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_desc_box_one',
            [
                'label'       => esc_html__( 'Box Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_small_img_box_one',
            [
				'label'       => esc_html__( 'Small Image 1', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_small_head_one',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        // Box Two Setting
        $this->start_controls_section(
            'lcp_banner_box_two_setting',
            [
                'label' => esc_html__( 'Box Setting 2', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_banner_img_box_two',
            [
				'label'       => esc_html__( 'Box Image 2', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_title_box_two',
            [
                'label'       => esc_html__( 'Box Title 2', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_desc_box_two',
            [
                'label'       => esc_html__( 'Box Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_small_img_box_two',
            [
				'label'       => esc_html__( 'Small Box Image 2', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_small_head_two',
            [
				'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        // Box Three Setting
        $this->start_controls_section(
            'lcp_banner_box_three_setting',
            [
                'label' => esc_html__( 'Box Setting 3', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_banner_img_box_three',
            [
				'label'       => esc_html__( 'Box Image 3', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_title_box_three',
            [
                'label'       => esc_html__( 'Box Title 3', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_desc_box_three',
            [
                'label'       => esc_html__( 'Box Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_small_img_box_three',
            [
				'label'       => esc_html__( 'Small Image 3', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_small_head_three',
            [
				'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        
        
        // Widget Style
        $this->start_controls_section(
            'lcp_property_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_property_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style34 h1'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style34 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_sub_heading_typography',
                'label'       => esc_html__( 'Sub Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style34 span'
            ]
        );
        $this->add_control(
            'lcp_sub_heading_color',
            [
                'label'     => esc_html__( 'Sub Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style34 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_banner_newsletter_heading',
			[
				'label' => esc_html__( 'NewsLetter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_newsletter_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subupdate-texthead-style34 h3'
            ]
        );
        $this->add_control(
            'lcp_banner_newsletter_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subupdate-texthead-style34 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_newsletter_sub_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subupdate-texthead-style34 p'
            ]
        );
        $this->add_control(
            'lcp_banner_newsletter_sub_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subupdate-texthead-style34 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_box_banner_style', 
            [
                'label' => esc_html__( 'Box Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_banner_box_style',
			[
				'label' => esc_html__( 'Box Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_box_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-rimgtext-style34 h3'
            ]
        );
        $this->add_control(
            'lcp_banner_box_heading_typography_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-rimgtext-style34 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_box_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-rimgtext-style34 p'
            ]
        );
        $this->add_control(
            'lcp_banner_box_desc_typography_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-rimgtext-style34 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	    $settings = $this->get_settings_for_display();
	    if(!empty($settings)){
        echo '<!-- Add HTML Here  -->
        <div class="lc-banner-section-style34">';
		if(!empty($settings['lcp_logo_image']['url'])):
			echo '<div class="lc-banner-logo-wrapper-style34">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="lc-logo-style34">
                            <img src="'.esc_url($settings['lcp_logo_image']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
                        </div>
                    </div>
                </div>
            </div>
            </div>';
		endif;
		echo '<div class="container-fluid">
            <div class="row">
                <div class="col-lg-6 col-md-12 col-sm-12">
                    <div class="lc-banner-heading-wrapper-style34">
                        <div class="lc-banner-text-style34">';
                                if(!empty($settings['lcp_banner_sub_title'])):
								    echo '<span>'.esc_html($settings['lcp_banner_sub_title']).'</span>';
							    endif;
								if(!empty($settings['lcp_banner_title'])):
								    echo '<h1>'.esc_html($settings['lcp_banner_title']).'</h1>';
							    endif;
						echo '</div>
                        <div class="lc-subscribe-wrapper-style34">
                            <div class="lc-subupdate-text-style34">
                                <div class="lc-subupdate-texthead-style34">';
                                	if(!empty($settings['lcp_banner_title'])):
                                    echo '<h3>'.esc_html($settings['lcp_newsletter_title']).'</h3>';
                                    endif;
                                    if(!empty($settings['lcp_newsletter_sub_title'])):
                                    echo '<p>'.esc_html($settings['lcp_newsletter_sub_title']).'</p>';
                                    endif;
                                echo '</div>
                            </div>';
                            if(!empty($settings['lcp_newsletter_form_id'])):	
						        echo do_shortcode($settings['lcp_newsletter_form_id']);
						    endif;
                        echo '</div>
                    </div>
                </div>
                <div class="col-lg-6 col-md-12 col-sm-12">
                    <div class="lc-banner-rightimg-wrapper-style34">';
                    if(!empty($settings['lcp_banner_img_box_one']['url'])):	
    						echo '<div class="lc-banner-rimg-style34">
                        <div class="lc-banner-rimage-style34">
                            <img src="'.esc_url($settings['lcp_banner_img_box_one']['url']).'" alt="'.esc_attr__('box-image', 'leadcapture').'">
                        </div>
                        <div class="lc-banner-rimgtext-style34">';
                            if(!empty($settings['lcp_banner_title_box_one'])):
                                echo '<h3>'.esc_html($settings['lcp_banner_title_box_one']).'</h3>';
                            endif;    
                            if(!empty($settings['lcp_banner_desc_box_one'])):  
                                echo '<p>'.esc_html($settings['lcp_banner_desc_box_one']).'</p>';
                            endif;  
                        echo '</div>
                        </div>';
					endif;
                    if(!empty($settings['lcp_banner_img_box_two']['url'])):
                        echo '<div class="lc-banner-rimg-style34">
                            <div class="lc-banner-rimage-style34">
                              <img src="'.esc_url($settings['lcp_banner_img_box_two']['url']).'" alt="'.esc_attr__('box-image-two', 'leadcapture').'">
                            </div>
                            <div class="lc-banner-rimgtext-style34">';
                                if(!empty($settings['lcp_banner_title_box_two'])):
                                    echo '<h3>'.esc_html($settings['lcp_banner_title_box_two']).'</h3>';
                                endif;
                                if(!empty($settings['lcp_banner_desc_box_two'])):  
                                    echo '<p>'.esc_html($settings['lcp_banner_desc_box_two']).'</p>';
                                endif;  
                            echo '</div>
                        </div>';   
                    endif;
                    if(!empty($settings['lcp_banner_img_box_three']['url'])):
                        echo '<div class="lc-banner-rimg-style34">
                            <div class="lc-banner-rimage-style34">
                                <img src="'.esc_url($settings['lcp_banner_img_box_three']['url']).'" alt="'.esc_attr__('box-image-three', 'leadcapture').'">
                            </div>
                            <div class="lc-banner-rimgtext-style34">';
                                if(!empty($settings['lcp_banner_title_box_three'])):
                                    echo '<h3>'.esc_html($settings['lcp_banner_title_box_three']).'</h3>';
                                endif;
                                if(!empty($settings['lcp_banner_desc_box_three'])):  
                                    echo '<p>'.esc_html($settings['lcp_banner_desc_box_three']).'</p>';
                                endif;  
                            echo '</div>
                        </div>';
                    endif;
                echo '</div>
                </div>
            </div>
        </div>
        <div class="lc-banner-iconbox-style34">';
            if(!empty($settings['lcp_banner_small_img_box_one']['url'])):
                echo '<div class="lc-iconbox-spa-style34">
                <img src="'.esc_url($settings['lcp_banner_small_img']['url']).'" alt="'.esc_attr__('image', 'leadcapture').'">
                    <p>'.esc_html($settings['lcp_banner_small_heading']).'</p>
                </div>';
            endif; 
            if(!empty($settings['lcp_banner_small_img']['url'])):
                echo '<div class="lc-iconbox-spa-style34">
                 <img src="'.esc_url($settings['lcp_banner_small_img_box_one']['url']).'" alt="'.esc_attr__('spa', 'leadcapture').'">
                 <p>'.esc_html($settings['lcp_banner_small_head_one']).'</p>    
                </div>';
            endif;  
            if(!empty($settings['lcp_banner_small_img_box_two']['url'])):   
                echo '<div class="lc-iconbox-spa-style34">
                    <img src="'.esc_url($settings['lcp_banner_small_img_box_two']['url']).'" alt="'.esc_attr__('Swimming-Pool', 'leadcapture').'">
                    <p>'.esc_html($settings['lcp_banner_small_head_two']).'</p>
                </div>';    
            endif;     
            if(!empty($settings['lcp_banner_small_img_box_three']['url'])): 
                echo '<div class="lc-iconbox-spa-style34">
                    <img src="'.esc_url($settings['lcp_banner_small_img_box_three']['url']).'" alt="'.esc_attr__('fitness', 'leadcapture').'">
                    <p>'.esc_html($settings['lcp_banner_small_head_three']).'</p>
                </div>';
            endif; 
        echo '</div>
    </div>';
	    }
	}
}