<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Hotel_Type extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_hotel_type_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Hotel Type Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_hotel_type_general',
            [
                'label' => esc_html__( 'Hotel General Settings', 'leadcapture' ),
            ]
        );
        
        $this->add_control(
            'lcp_hotel_type_image',
            [
				'label'       => esc_html__( 'Section Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_hotel_type_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_hotel_type_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Price starts at.', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_hotel_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '$50', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_hotel_location',
            [
                'label'       => esc_html__( 'Location', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'California', 'leadcapture' ),
            ]
        );
       $this->add_control(
            'lcp_hotel_member',
            [
                'label'       => esc_html__( 'Member', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Couple friendly', 'leadcapture' ),
            ]
        );
        
        $this->end_controls_section();
        
        // Widget Style
		$this->start_controls_section(
            'leadcapture_ab_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'leadcapture_ab_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_heading_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-dest-boxtext-style34 h4'
            ]
        );
        $this->add_control(
            'leadcapture_ab_heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-dest-boxtext-style34 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'heading_control',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-dest-boxtext-style34 p',
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-dest-boxtext-style34 p' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        $this->add_control(
            'leadcapture_location_color',
            [
                'label'     => esc_html__( 'Location Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-dest-loctext-style34 p' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_location_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-dest-location-style34',
            ]
        );
      
		$this->end_controls_section();
        // Services Link style
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
		if(!empty($settings)):
		echo '<div class="lc-destination-section-style34">
			<div class="container">
				<div class="lc-destination-box-wrapper-style34">
					<div class="row">
						<div class="col-lg-12 col-md-12 col-sm-12">
							<div class="lc-dest-box-wrapper-style34">';
    							if(!empty($settings['lcp_hotel_type_image']['url'])):
    							    echo '<div class="lc-dest-boximg-style34">
    									<img src="'.esc_url($settings['lcp_hotel_type_image']['url']).'" alt="'.esc_attr__('hotel', 'leadcapture').'">
    								</div>';
    							endif;
								echo '<div class="lc-dest-boxtext-style34">
									<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 81 18" width="81" height="18">
                                    	<title>Star</title>
                                    	<style>
                                    		.s0 { fill: #ff7c8f } 
                                    		.s1 { fill: #e1e1e1 } 
                                    	</style>
                                    	<g id="Star">
                                    		<path id="Shape 12" class="s0" d="m15.8 8.1l-3.1 2.8 0.9 4.2c0.1 0.3 0 0.6-0.3 0.8-0.2 0.1-0.5 0.1-0.8 0l-3.5-2.2-3.5 2.2q-0.1 0.1-0.3 0.1-0.3 0-0.5-0.1c-0.2-0.2-0.3-0.5-0.3-0.8l0.9-4.2-3-2.8c-0.2-0.2-0.3-0.5-0.2-0.8 0.1-0.3 0.3-0.5 0.6-0.5l4-0.4 1.6-3.9c0.2-0.3 0.4-0.5 0.7-0.5 0.3 0 0.6 0.2 0.7 0.5l1.6 3.9 4.1 0.4c0.3 0 0.5 0.2 0.6 0.5 0.1 0.3 0 0.6-0.2 0.8z"/>
                                    		<path id="Shape 12" class="s0" d="m31.5 8.1l-3 2.8 0.9 4.2c0 0.3-0.1 0.6-0.3 0.8-0.3 0.1-0.6 0.1-0.8 0l-3.5-2.2-3.5 2.2q-0.2 0.1-0.4 0.1-0.2 0-0.4-0.1c-0.3-0.2-0.4-0.5-0.3-0.8l0.9-4.2-3.1-2.8c-0.2-0.2-0.3-0.5-0.2-0.8 0.1-0.3 0.4-0.5 0.7-0.5l4-0.4 1.6-3.9c0.1-0.3 0.4-0.5 0.7-0.5 0.3 0 0.5 0.2 0.7 0.5l1.6 3.9 4 0.4c0.3 0 0.6 0.2 0.6 0.5 0.1 0.3 0.1 0.6-0.2 0.8z"/>
                                    		<path id="Shape 12" class="s0" d="m47.3 8.1l-3.1 2.8 0.9 4.2c0.1 0.3 0 0.6-0.3 0.8-0.2 0.1-0.5 0.1-0.8 0l-3.5-2.2-3.5 2.2q-0.1 0.1-0.3 0.1-0.3 0-0.5-0.1c-0.2-0.2-0.3-0.5-0.3-0.8l0.9-4.2-3-2.8c-0.2-0.2-0.3-0.5-0.2-0.8 0.1-0.3 0.3-0.5 0.6-0.5l4-0.4 1.6-3.9c0.2-0.3 0.4-0.5 0.7-0.5 0.3 0 0.6 0.2 0.7 0.5l1.6 3.9 4.1 0.4c0.3 0 0.5 0.2 0.6 0.5 0.1 0.3 0 0.6-0.2 0.8z"/>
                                    		<path id="Shape 12" class="s1" d="m63 8.1l-3 2.8 0.9 4.2c0 0.3-0.1 0.6-0.3 0.8-0.3 0.1-0.6 0.1-0.8 0l-3.5-2.2-3.5 2.2q-0.2 0.1-0.4 0.1-0.2 0-0.4-0.1c-0.3-0.2-0.4-0.5-0.3-0.8l0.9-4.2-3.1-2.8c-0.2-0.2-0.3-0.5-0.2-0.8 0.1-0.3 0.4-0.5 0.7-0.5l4-0.4 1.6-3.9c0.1-0.3 0.4-0.5 0.7-0.5 0.3 0 0.5 0.2 0.7 0.5l1.6 3.9 4 0.4c0.3 0 0.6 0.2 0.6 0.5 0.1 0.3 0.1 0.6-0.2 0.8z"/>
                                    		<path id="Shape 12" class="s1" d="m78.8 8.1l-3.1 2.8 0.9 4.2c0.1 0.3 0 0.6-0.3 0.8-0.2 0.1-0.5 0.1-0.8 0l-3.5-2.2-3.5 2.2q-0.1 0.1-0.3 0.1-0.3 0-0.5-0.1c-0.2-0.2-0.3-0.5-0.3-0.8l0.9-4.2-3-2.8c-0.2-0.2-0.3-0.5-0.2-0.8 0.1-0.3 0.3-0.5 0.6-0.5l4-0.4 1.6-3.9c0.2-0.3 0.4-0.5 0.7-0.5 0.3 0 0.6 0.2 0.7 0.5l1.6 3.9 4.1 0.4c0.3 0 0.5 0.2 0.6 0.5 0.1 0.3 0 0.6-0.2 0.8z"/>
                                    	</g>
                                    </svg>';
									if(!empty($settings['lcp_hotel_type_heading'])):
									echo '<h4>'.esc_html($settings['lcp_hotel_type_heading']).'</h4>';
									endif;
									if(!empty($settings['lcp_hotel_type_description'])):
									echo '<p>'.esc_html($settings['lcp_hotel_type_description']).'<span>'.esc_html($settings['lcp_hotel_price']).'</span></p>';
									endif;
									echo '<div class="lc-dest-location-style34">
										<div class="lc-dest-loctext-style34">
											<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 14 19" width="14" height="19">
                                            	<style>
                                            		.s0 { fill: #ff7c8f } 
                                            	</style>
                                            	<path id="Shape 10" fill-rule="evenodd" class="s0" d="m13 8c0 4.8-5.4 9.7-5.7 9.9q-0.1 0.1-0.3 0.1-0.2 0-0.3-0.1c-0.3-0.2-5.7-5.1-5.7-9.9 0-3.3 2.7-6 6-6 3.3 0 6 2.7 6 6zm-6 3.3c-1.8 0-3.3-1.5-3.3-3.3 0-1.8 1.5-3.3 3.3-3.3 1.8 0 3.3 1.5 3.3 3.3 0 1.8-1.5 3.3-3.3 3.3z"/>
                                            </svg>';
											if(!empty($settings['lcp_hotel_location'])):
											echo '<p>'.esc_html($settings['lcp_hotel_location']).'</p>';
											endif;
										echo '</div>
										<div class="lc-dest-loctext-style34 lc-dest-coutext-style34">
											<svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 18 19" width="18" height="19">
                                            	<style>
                                            		.s0 { fill: #ff7c8f } 
                                            	</style>
                                            	<path id="Shape 11" class="s0" d="m3.2 10c0-1.7 1.3-3.1 3-3.1 1.6 0 2.9 1.4 2.9 3.1 0 2.6-2.7 4.1-4.7 2.6q0 0 0 0c-0.7-0.6-1.2-1.5-1.2-2.6zm10.1-1.7c1.5 0 2.6 1.2 2.6 2.7 0 1.5-1.1 2.8-2.6 2.8-1.4 0-2.5-1.3-2.5-2.8 0-1.5 1.1-2.7 2.5-2.7zm3.7 8v1.6h-15v-1.8c0-1.2 0.6-2.3 1.6-3.1 1.5 1.4 3.7 1.4 5.1 0 0.6 0.5 1.1 1.1 1.4 1.8q0.3-0.7 0.8-1.1c1.4 1.4 3.5 1.4 4.8 0 0.8 0.6 1.3 1.6 1.3 2.6zm-9.6-11.3c-0.7-0.7-0.7-1.9 0-2.6 0.6-0.6 1.5-0.7 2.1-0.2 0.6-0.5 1.5-0.4 2.1 0.2 0.7 0.7 0.7 1.9 0 2.6l-2.1 2.3z"/>
                                            </svg>';
											if(!empty($settings['lcp_hotel_member'])):
											    echo '<p>'.esc_html($settings['lcp_hotel_member']).'</p>';
											endif;
										echo '</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>';
	endif;
    }
}