<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Hotel_And_Resort_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_hotel_and_resort_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Hotel and Resort Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_desc',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Satr Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Typography', 'leadcapture'),
            'name'     => 'lps_meetup_testi_typography',
            'selector' => '{{WRAPPER}} .lps-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_descs_typography',
            'selector' => '{{WRAPPER}} .lps-desc-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_designation_typography',
            'selector' => '{{WRAPPER}} .lps-designation-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
		$this->add_control(
        	'lps_cons_testi_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-description-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
		$this->add_control(
        	'lps_cons_testi_designation_text_color',
        	[
        	'label' => esc_html__('Testimonial Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-designation-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
          
        $this->add_control(
        	'lps_cons_testi_pagination_color',
        	[
        	'label' => esc_html__('Testimonial Pagination Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testimonial-slider-style11 .swiper-pagination  .swiper-pagination-bullet-active' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-testmonial-section-style34">
			<div class="container">
				<div class="container">
					<div class="lc-testimonialslider-wrapper-style34">
						<div class="row">
							<div class="col-lg-12">
								<div class="swiper lc-testimonialslider-style34">
									<div class="swiper-wrapper">';
									if(!empty($settings['leadcapture_testimonial_list'])):
                                        foreach($settings['leadcapture_testimonial_list'] as $testi):
										echo '<div class="swiper-slide">
											<div class="lc-testimonial-slidebox-style34">';
												if($testi['leadcapture_testimonial_desc']):
                								    echo '<p class="lps-desc-typography add-description-colors">'.esc_html($testi['leadcapture_testimonial_desc']).'</p>';
                								endif;
												echo '<div class="lc-test-slidename-style34">
													<div class="lc-testslide-star-style34">';
														if(!empty($testi['leadcapture_testimonial_image']['url'])):  
                        									echo '<img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr('rating','leadcapture').'">';
                        								endif;
													echo '</div>
													<div class="lc-testslide-namewrapper-style34">
														<div class="lc-testslide-name-style34">';
														if($testi['leadcapture_testimonial_author']):
                    									    echo '<h3 class="lps-typography add-author-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h3>';
                    									endif;
														if($testi['leadcapture_testimonial_dest']):
                    										echo '<p class="lps-designation-typography add-designation-colors">'.esc_html($testi['leadcapture_testimonial_dest']).'</p>';
                    									endif;
													    echo '</div>
														<div class="lc-testslide-svg-style34">
															<svg xmlns="http://www.w3.org/2000/svg" width="56" height="41" viewBox="0 0 56 41">
																<path class="cls-1" d="M10.453,26.753A32.08,32.08,0,0,1,4.685,35.97a2.812,2.812,0,0,0-.261,3.362,2.7,2.7,0,0,0,2.315,1.285A2.251,2.251,0,0,0,7.523,40.5c5.488-1.624,18.312-7.385,18.667-25.859C26.32,7.524,21.168,1.4,14.467.7A13.14,13.14,0,0,0,4.312,4.048,13.365,13.365,0,0,0,0,13.89,13.054,13.054,0,0,0,10.453,26.753ZM44.259,0.7A13.122,13.122,0,0,0,34.123,4.048a13.364,13.364,0,0,0-4.312,9.841A13.054,13.054,0,0,0,40.264,26.753,32.083,32.083,0,0,1,34.5,35.97a2.812,2.812,0,0,0-.261,3.362,2.7,2.7,0,0,0,2.315,1.285,2.25,2.25,0,0,0,.784-0.113C42.821,38.879,55.645,33.118,56,14.645V14.38C56,7.373,50.9,1.4,44.259.7Z" />
															</svg>
														</div>
													</div>
												</div>
											</div>
										</div>';
                					    endforeach;
                					endif; 
                					echo '</div>
									<div class="swiper-pagination"></div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>';
    }
}