<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Interiordesign_Aboutus extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_interiordesign_aboutus';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Interiordesign Aboutus', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_interiordesign_aboutus_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_interiordesign_aboutus_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_stitle',
            [
                'label'       => esc_html__( 'Small Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_phone',
            [
                'label'       => esc_html__( 'Phone', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_fimage',
            [
				'label'       => esc_html__( 'First Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_simage',
            [
				'label'       => esc_html__( 'Second Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_interiordesign_aboutus_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_interiordesign_aboutus_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_aboutus_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-about-heading-style24 > h3'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-heading-style24 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_interiordesign_aboutus_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_aboutus_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-about-heading-style24 > p'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-heading-style24 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Small Title Style
        $this->add_control(
			'lcp_interiordesign_aboutus_style_stitle',
			[
				'label' => esc_html__( 'Small Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_aboutus_style_stitle_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-enquiry-box-text-style24 > span'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_style_stitle_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-enquiry-box-text-style24 > span' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Phone Style
        $this->add_control(
			'lcp_interiordesign_aboutus_style_phone',
			[
				'label' => esc_html__( 'Phone', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_aboutus_style_phone_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-enquiry-box-text-style24 > p'
            ] 
        );
        $this->add_control(
            'lcp_interiordesign_aboutus_style_phone_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-enquiry-box-text-style24 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button Style
        $this->add_control(
			'lcp_interiordesign_aboutus_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_aboutus_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style24 > a'
            ] 
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_interiordesign_aboutus_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_interiordesign_aboutus_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24 > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_interiordesign_aboutus_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_interiordesign_aboutus_style_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style24',
            ]
        );
		$this->add_control(
            'lcp_interiordesign_aboutus_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_interiordesign_aboutus_style_btn_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_interiordesign_aboutus_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24:hover > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_interiordesign_aboutus_style_btn_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} div#lc-style24-translate' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_interiordesign_aboutus_style_btn_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style24:hover',
            ]
        );
		$this->add_control(
            'lcp_interiordesign_aboutus_style_btn_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
        
        // Extra Style
        $this->add_control(
			'lcp_interiordesign_aboutus_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_interiordesign_aboutus_style_extra_color',
            [
                'label'     => esc_html__( 'Extra Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-enquiry-style24:after' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-about-section lc-about-section-style24">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6">
                            <div class="lc-about-img lc-about-img-style24">';
                                if(!empty($settings['lcp_interiordesign_aboutus_fimage']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_interiordesign_aboutus_fimage']['url']).'" alt="'.esc_attr('about-img', 'leadcapture').'" class="lc-aboutleft-style24">';
                                }
                            echo '</div>
                            <div class="lc-enquiry-style24">
                                <div class="lc-enquiry-box-style24">
                                    <img src="'.LEAD_CAPTURE_URL.'/public/images/call.png">
                                    <div class="lc-enquiry-box-text-style24">';
                                        if(!empty($settings['lcp_interiordesign_aboutus_stitle'])){
                                            echo '<span>'.esc_html($settings['lcp_interiordesign_aboutus_stitle']).'</span>';
                                        }
                                        if(!empty($settings['lcp_interiordesign_aboutus_phone'])){
                                            echo '<p>'.esc_html($settings['lcp_interiordesign_aboutus_phone']).'</p>';
                                        }
                                    echo '</div>
                                </div>';
                                if(!empty($settings['lcp_interiordesign_aboutus_btn_title'])){
                                    echo '<div class="lc-btn lc-btn-style24 lc-btnview-style24">
                                        <div id="lc-style24-translate"></div>
                                        <a href="'.esc_url($settings['lcp_interiordesign_aboutus_btn_link']).'">'.esc_html($settings['lcp_interiordesign_aboutus_btn_title']).'</a>
                                    </div>';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-6">
                            <div class="lc-about-heading lc-about-heading-style24">';
                                if(!empty($settings['lcp_interiordesign_aboutus_title'])){
                                    echo '<h3>'.esc_html($settings['lcp_interiordesign_aboutus_title']).'</h3>';
                                }
                                if(!empty($settings['lcp_interiordesign_aboutus_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_interiordesign_aboutus_desc']).'</p>';
                                }
                                if(!empty($settings['lcp_interiordesign_aboutus_simage']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_interiordesign_aboutus_simage']['url']).'" alt="'.esc_attr('about-img', 'leadcapture').'">';
                                }
                            echo '</div>
                        </div> 
                    </div>
                </div>
            </div>';
		}
	}
}