<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Interiordesign_Achievements extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_interiordesign_achievements';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Interiordesign Achievements', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'lcp_interiordesign_achievements_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_interiordesign_achievements_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_achievements_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_interiordesign_achievements_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Happy Customer', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_interiordesign_achievements_list_number',
            [
                'label'       => esc_html__( 'Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '24', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_interiordesign_achievements_list_prifix',
            [
                'label'       => esc_html__( 'Prifix', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '+', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_interiordesign_achievements_list_image',
            [
				'label'       => esc_html__( 'Icon', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_interiordesign_achievements_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_interiordesign_achievements_list_title'  => esc_html__( 'Happy Customer', 'leadcapture' ),
						'lcp_interiordesign_achievements_list_number'  => esc_html__( '24', 'leadcapture' ),
						'lcp_interiordesign_achievements_list_prifix'  => esc_html__( '+', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_interiordesign_achievements_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_interiordesign_achievements_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_interiordesign_achievements_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_achievements_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style24 > h3'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_achievements_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style24 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_interiordesign_achievements_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_achievements_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style24 > p'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_achievements_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style24 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_interiordesign_achievements_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_interiordesign_achievements_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-section.lc-service-section-style24' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_interiordesign_achievements_style_list', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_interiordesign_achievements_style_list_number_prifix',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_achievements_style_list_number_prifix_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-box-style24 > h4'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_achievements_style_list_number_prifix_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-style24 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_interiordesign_achievements_style_list_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_achievements_style_list_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-box-style24 > p'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_achievements_style_list_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-style24 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-service-section lc-service-section-style24">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-heading-wrapper lc-heading-style24 lc-headservice-style24">';
                                if(!empty($settings['lcp_interiordesign_achievements_title'])){
                                    echo '<h3>'.esc_html($settings['lcp_interiordesign_achievements_title']).'</h3>';
                                }
                                if(!empty($settings['lcp_interiordesign_achievements_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_interiordesign_achievements_desc']).'</p>';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="lc-service-box-wrapper lc-service-box-wrapper-style24">
                <div class="container">
                    <div class="row">';
                        if(!empty($settings['lcp_interiordesign_achievements_list'])){
                            foreach($settings['lcp_interiordesign_achievements_list'] as $list){
                                echo '<div class="col-lg-3 col-md-6 col-sm-6">
                                    <div class="lc-service-box lc-service-box-style24">';
                                        if(!empty($list['lcp_interiordesign_achievements_list_image']['url'])){
                                            echo '<img src="'.esc_url($list['lcp_interiordesign_achievements_list_image']['url']).'" alt="'.esc_attr('ser-img', 'leadcapture').'" class="lc-ser-style24">';
                                        }
                                        echo '<img src="'.PIXELFORM_URL.'/public/images/line.png" alt="'.esc_attr('line-img', 'leadcapture').'" class="lc-line-img">';
                                        if(!empty($list['lcp_interiordesign_achievements_list_number'])){
                                            echo '<h4><span class="lc-counter" data-count="'.esc_attr($list['lcp_interiordesign_achievements_list_number']).'">0</span>'.$list['lcp_interiordesign_achievements_list_prifix'].'</h4>';
                                        }
                                        if(!empty($list['lcp_interiordesign_achievements_list_title'])){
                                            echo '<p>'.esc_html($list['lcp_interiordesign_achievements_list_title']).'</p>';
                                        }
                                    echo '</div>
                                </div>';
                            }
                        }
                    echo '</div>
                </div>
            </div>';
		}
	}
}