<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Interiordesign_banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_interiordesign_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Interiordesign Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public 
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_interiordesign_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
		$this->add_control(
            'lcp_interiordesign_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_btn_links',
            [
                'label'       => esc_html__( 'Button Links', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_images',
            [
                'label'       => esc_html__( 'Add Image', 'leadcapture' ),
                'type'        => Controls_Manager::GALLERY,
                'label_block' => true,
            ]
        );
		$this->end_controls_section();
		
		$this->start_controls_section(
            'lcp_interiordesign_newsletter', 
            [
               'label' => esc_html__( 'NewsLetter Settings', 'leadcapture' ),
            ]
        ); 
		$this->add_control(
            'lcp_interiordesign_newsletter_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_newsletter_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_interiordesign_newsletter_form_shortcode',
            [
                'label'       => esc_html__( 'Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_interiordesign_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_interiordesign_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style24 > h1'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style24 > h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_interiordesign_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style24 > p'
            ]
        );
        $this->add_control(
            'lcp_interiordesign_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style24 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button Style
        $this->add_control(
			'lcp_interiordesign_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style24 > a'
            ]
        );
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_interiordesign_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_interiordesign_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24 > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_interiordesign_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style24',
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_interiordesign_style_btn_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_interiordesign_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} #lc-style24-translate' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_interiordesign_style_btn_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style24:hover',
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style24:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
		
		$this->add_control(
			'lcp_interiordesign_banner_news_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_banner_news_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style24 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_banner_news_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style24 button'
            ]
        );
		
		
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_interiordesign_style_nav', 
            [
                'label' => esc_html__( 'Navigation', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'lcp_interiordesign_style_nav_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_interiordesign_style_nav_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-next' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-prev' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_interiordesign_style_nav_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-next' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-prev' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        $this->add_control(
			'lcp_interiordesign_style_nav_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_interiordesign_style_nav_hcolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-next:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-prev:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_interiordesign_style_nav_hbgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-next:hover' => 'background: {{VALUE}}!important;',
                    '{{WRAPPER}} .lc-bannerslider-style24-button .swiper-button-prev:hover' => 'background: {{VALUE}}!important;',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-banner-section lc-banner-section-style24">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-7 col-md-12 col-sm-12">
                            <div class="lc-banner-text lc-banner-text-style24">';
                                if(!empty($settings['lcp_interiordesign_heading'])){
                                    echo '<h1>'.esc_html($settings['lcp_interiordesign_heading']).'</h1>';
                                }
                                if(!empty($settings['lcp_interiordesign_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_interiordesign_desc']).'</p>';
                                }
                                if(!empty($settings['lcp_interiordesign_btn_title'])){
                                    echo '<div class="lc-btn lc-btn-style24">
                                        <div id="lc-style24-translate"></div>
                                        <a href="'.esc_url($settings['lcp_interiordesign_btn_links']).'">'.esc_html($settings['lcp_interiordesign_btn_title']).'</a>
                                    </div>';
                                }
                                echo '<div class="lc-newsletter lc-newsletter-style24">';
                                    if(!empty($settings['lcp_interiordesign_newsletter_heading'])){
                                        echo '<h3>'.esc_html($settings['lcp_interiordesign_newsletter_heading']).'</h3>';
                                    }
                                    if(!empty($settings['lcp_interiordesign_newsletter_desc'])){
                                        echo '<p>'.esc_html($settings['lcp_interiordesign_newsletter_desc']).'</p>';
                                    }
                                    echo '<div class="lc-search-wrapper lc-search-wrapper-style24">';
                                        if(!empty($settings['lcp_interiordesign_newsletter_form_shortcode'])){
                                            echo do_shortcode($settings['lcp_interiordesign_newsletter_form_shortcode']);
                                        }
                                    echo '</div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-5 col-md-12 col-sm-12">
                            <div class="lc-banner-img-wrapper lc-banner-img-wrapper-style24">
                                <div class="swiper lc-bannerslider-style24">
                                    <div class="swiper-wrapper">';
                                        if(!empty($settings['lcp_interiordesign_images'])){
                                            foreach($settings['lcp_interiordesign_images'] as $images){
                                                echo '<div class="swiper-slide">
                                                    <div class="lc-bannerslider-img">
                                                        <img src="'.esc_url($images['url']).'">
                                                    </div>
                                                </div>';
                                            }
                                        }
                                    echo '</div>
                                </div>
                                <div class="lc-bannerslider-style24-button">
                                    <div class="swiper-button-next">next</div>
                                    <div class="swiper-button-prev">Prev</div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}