<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Internetmarketing_Aboutus extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_internetmarketing_aboutus';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Internetmarketing Aboutus', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_marketing_about_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_marketing_about_image',
            [
				'label'       => esc_html__( 'Big Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_marketing_about_image_one',
            [
				'label'       => esc_html__( 'Image One', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_marketing_about_image_two',
            [
				'label'       => esc_html__( 'Image Two', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_marketing_about_image_three',
            [
				'label'       => esc_html__( 'Image Three', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_marketing_about_image_four',
            [
				'label'       => esc_html__( 'Image Four', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true, 
			]
        );
        
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-service-img-wrapper lc-service-img-wrapper-style25 aos-init aos-animate" data-aos="fade-up" data-aos-duration="2000">';
		        if(!empty($settings['lcp_marketing_about_image']['url'])){
		            echo '<img src="'.esc_url($settings['lcp_marketing_about_image']['url']).'" alt="">';
		        }
		        if(!empty($settings['lcp_marketing_about_image_one']['url'])){
		            echo '<div class="lc-service-flex-img">
		                <img src="'.esc_url($settings['lcp_marketing_about_image_one']['url']).'" alt="">
		            </div>';
		        }
		        if(!empty($settings['lcp_marketing_about_image_two']['url'])){
		            echo '<div class="lc-cup-img">
		                <img src="'.esc_url($settings['lcp_marketing_about_image_two']['url']).'" alt="">
		            </div>';
		        }
		        if(!empty($settings['lcp_marketing_about_image_three']['url'])){
		            echo '<div class="lc-cup-img-style25">
		                <img src="'.esc_url($settings['lcp_marketing_about_image_three']['url']).'" alt="">
		            </div>';
		        }
		        if(!empty($settings['lcp_marketing_about_image_four']['url'])){
		            echo '<div class="lc-service-flex-img-style25">
		                <img src="'.esc_url($settings['lcp_marketing_about_image_four']['url']).'" alt="">
		            </div>';
		        }
            echo '</div>'; 
		}
	}
}