<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Internetmarketing_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_internetmarketing_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Internetmarketing Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_marketing_banner_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_marketing_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_desc',
            [
                'label'       => esc_html__( 'Decription', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_vtitle',
            [
                'label'       => esc_html__( 'Video Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_image',
            [
				'label'       => esc_html__( 'Big Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		
		// NewsLetter 
		$this->start_controls_section(
            'lcp_marketing_banner_newsletter', 
            [
               'label' => esc_html__( 'NewsLetter Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_marketing_banner_newsletter_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_newsletter_shortcode',
            [
                'label'       => esc_html__( 'Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        // Extra
		$this->start_controls_section(
            'lcp_marketing_banner_extra', 
            [
               'label' => esc_html__( 'Extra Settings', 'leadcapture' ),
            ]
        ); 
        // First Extra
        $this->add_control(
			'lcp_marketing_banner_first',
			[
				'label' => esc_html__( 'First Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_control(
            'lcp_marketing_banner_first_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
        // Second Extra
        $this->add_control(
			'lcp_marketing_banner_second',
			[
				'label' => esc_html__( 'Second Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_marketing_banner_second_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_marketing_banner_second_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_second_stitle',
            [
                'label'       => esc_html__( 'Small Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        
        // Third Extra
        $this->add_control(
			'lcp_marketing_banner_third',
			[
				'label' => esc_html__( 'Third Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_marketing_banner_third_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_marketing_banner_third_other_image',
            [
				'label'       => esc_html__( 'Second Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
        // Fourth Extra
        $this->add_control(
			'lcp_marketing_banner_fourth',
			[
				'label' => esc_html__( 'Fourth Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_marketing_banner_fourth_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_fourth_year',
            [
                'label'       => esc_html__( 'Year', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
		$repeater = new Repeater();
		$repeater->add_control(
            'lcp_marketing_banner_fourth_list_report_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'Services #', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_marketing_banner_fourth_list_report_per',
            [
                'label'       => esc_html__( 'Percentage', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '50', 'leadcapture' ),
            ]
        );
		
		$this->add_control(
            'lcp_marketing_banner_fourth_list_report',
            [
                'label' => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_marketing_banner_fourth_list_report_title'  => esc_html__( 'JAN', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_marketing_banner_fourth_list_report_title}}', 
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_marketing_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_marketing_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-text-style25 h1'
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style25 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_marketing_banner_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-text-style25 > p'
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-text-style25 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_marketing_banner_style_video',
			[
				'label' => esc_html__( 'Video Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_style_video_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-video-img.lc-video-img-style25 span'
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_style_video_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-video-img.lc-video-img-style25 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button Style
        $this->add_control(
			'lcp_marketing_banner_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_style_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-get-style25 > a'
            ] 
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_marketing_banner_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_marketing_banner_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style25 > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_marketing_banner_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style25' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_marketing_banner_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-get-style25',
            ]
        );
		$this->add_control(
            'lcp_marketing_banner_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style25' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_marketing_banner_style_btn_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_marketing_banner_style_btn_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style25 > a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_marketing_banner_style_btn_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style25:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_marketing_banner_style_btn_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn.lc-get-style25:hover',
            ]
        );
		$this->add_control(
            'lcp_marketing_banner_style_btn_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn.lc-get-style25:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_marketing_banner_newsletter_style', 
            [
                'label' => esc_html__( 'NewsLetter Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_marketing_banner_newsletter_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_newsletter_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-form-para-text-style25 p'
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_newsletter_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-form-para-text-style25 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_control(
			'lcp_marketing_banner_newsletter_style_form',
			[
				'label' => esc_html__( 'Form Settings', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_newsletter_style_input_typography',
                'label'       => esc_html__( 'Input Type Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style25 input'
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_newsletter_style_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-search-wrapper-style25 button'
            ]
        );
        
        
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_marketing_banner_extra_style', 
            [
                'label' => esc_html__( 'Extra Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_marketing_banner_extra_second_style',
			[
				'label' => esc_html__( 'Second Extra Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_extra_second_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-bannericon-two-style25 h4'
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_extra_second_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-bannericon-two-style25 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_marketing_banner_extra_ssecond_style',
			[
				'label' => esc_html__( 'Second Extra Small Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_extra_ssecond_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-sale-btn a'
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_extra_ssecond_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-sale-btn a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_extra_ssecond_style_heading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-sale-btn' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_control(
            'lcp_marketing_banner_extra_ssecond_style_heading_hcolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-sale-btn:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_extra_ssecond_style_heading_hbgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-sale-btn:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_marketing_banner_extra_fourth_style',
			[
				'label' => esc_html__( 'Fourth Extra Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_extra_fourth_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-overview-text p'
            ] 
        );
        $this->add_control(
            'lcp_marketing_banner_extra_fourth_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-overview-text p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_marketing_banner_extra_sfourth_style',
			[
				'label' => esc_html__( 'Fourth Extra Small Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_banner_extra_fourth_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-overview-text span'
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_extra_fourth_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-overview-text span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_marketing_banner_extra_fourth_style_sheading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-overview-text span' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_marketing_banner_extra_sfourth_graph_style',
			[
				'label' => esc_html__( 'Graph Color', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_marketing_banner_extra_sfourth_graph_style_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .graph1' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .graph2' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .graph3' => 'background: {{VALUE}};',
                    '{{WRAPPER}} .graph4' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display(); 
		if(!empty($settings)){
		    echo '<div class="lc-banner-section lc-banner-section-style25">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-heading-text-style25 aos-init aos-animate" data-aos="fade-up-right" data-aos-duration="2000">';
                                if(!empty($settings['lcp_marketing_banner_title'])){
                                    echo '<h1>'.esc_html($settings['lcp_marketing_banner_title']).'</h1>';
                                }
                                if(!empty($settings['lcp_marketing_banner_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_marketing_banner_desc']).'</p>';
                                }
                                echo '<div class="lc-flex-text-style25 " >';
                                    if(!empty($settings['lcp_marketing_banner_btn_title'])){
                                        echo '<div class="lc-btn lc-get-style25">
                                            <a href="'.esc_url($settings['lcp_marketing_banner_btn_link']).'">'.esc_html($settings['lcp_marketing_banner_btn_title']).'</a>
                                        </div>';
                                    }
                                    echo '<div class="lc-video-img lc-video-img-style25">
                                        <a href=""><img src="'.LEAD_CAPTURE_URL.'/public/images/video-icon.png" alt=""></a>';
                                        if(!empty($settings['lcp_marketing_banner_vtitle'])){
                                            echo '<span>'.esc_html($settings['lcp_marketing_banner_vtitle']).'</span>';
                                        }
                                    echo '</div>
                                </div>
                                <div class="lc-form-para-text-style25">';
                                    if(!empty($settings['lcp_marketing_banner_newsletter_title'])){
                                        echo '<p>'.esc_html($settings['lcp_marketing_banner_newsletter_title']).'</p>';
                                    }
                                    if(!empty($settings['lcp_marketing_banner_newsletter_shortcode'])){
                                        echo '<div class="lc-search-wrapper lc-search-wrapper-style25">';
                                            echo do_shortcode($settings['lcp_marketing_banner_newsletter_shortcode']);
                                        echo '</div>';
                                    }
                                echo '</div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-banner-img-wrapper lc-banner-img-style25 aos-init aos-animate" data-aos="zoom-in-up" data-aos-duration="2000">';
                                if(!empty($settings['lcp_marketing_banner_image']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_marketing_banner_image']['url']).'">';
                                }
                                echo '<div class="lc-bannericon-one-style25">';
                                    if(!empty($settings['lcp_marketing_banner_first_image']['url'])){
                                        echo '<img src="'.esc_url($settings['lcp_marketing_banner_first_image']['url']).'">';
                                    }
                                echo '</div>
                                <div class="lc-bannericon-two-style25">';
                                    if(!empty($settings['lcp_marketing_banner_second_image']['url'])){
                                        echo '<img src="'.esc_url($settings['lcp_marketing_banner_second_image']['url']).'">';
                                    }
                                    if(!empty($settings['lcp_marketing_banner_second_title'])){
                                        echo '<h4>'.esc_html($settings['lcp_marketing_banner_second_title']).'</h4>';
                                    }
                                    if(!empty($settings['lcp_marketing_banner_second_stitle'])){
                                        echo '<div class="lc-sale-btn">
                                            <a href="">'.esc_html($settings['lcp_marketing_banner_second_stitle']).'</a>
                                        </div>';
                                    }
                                echo '</div>
                                <div class="lc-bannericon-three-style25">
                                    <div class="lc-overview-text">';
                                        if(!empty($settings['lcp_marketing_banner_fourth_title'])){
                                            echo '<p>'.esc_html($settings['lcp_marketing_banner_fourth_title']).'</p>';
                                        }
                                        if(!empty($settings['lcp_marketing_banner_fourth_year'])){
                                            echo '<span>'.esc_html($settings['lcp_marketing_banner_fourth_year']).'</span>';
                                        }
                                    echo '</div>
                                    <div class="lc-graph-flex">';
                                        if(!empty($settings['lcp_marketing_banner_fourth_list_report'])){
                                            $i = 1;
                                            foreach($settings['lcp_marketing_banner_fourth_list_report'] as $list){
                                                $margin = 150 - (int)$list['lcp_marketing_banner_fourth_list_report_per'];
                                                echo '<div class="lc-inner-box-style25">
                                                    <div class="graph'.esc_attr($i).'" style="height: '.esc_attr($list['lcp_marketing_banner_fourth_list_report_per']).'px;margin-top: '.esc_attr($margin).'px;"></div>
                                                    <p>'.esc_html($list['lcp_marketing_banner_fourth_list_report_title']).'</p>
                                                </div>';
                                                $i++;
                                            }
                                        }
                                    echo '</div>
                                </div>';
                                if(!empty($settings['lcp_marketing_banner_third_image']['url'])){
                                    echo '<div class="lc-bannericon-four-style25">
                                        <img src="'.esc_url($settings['lcp_marketing_banner_third_image']['url']).'" alt="">
                                    </div>';
                                }  
                                if(!empty($settings['lcp_marketing_banner_third_other_image']['url'])){
                                    echo '<div class="lc-bannericon-five-style25">
                                        <img src="'.esc_url($settings['lcp_marketing_banner_third_other_image']['url']).'" alt="">
                                    </div>';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}