<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Internetmarketing_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_internetmarketing_testimonial';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Internetmarketing Testimonial', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_marketing_testimonial_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_marketing_testimonial_list_title',
            [
                'label'       => esc_html__( 'Author', 'invory' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Natalie Katherine', 'invory' ),
            ]
        );
        $repeater->add_control(
            'lcp_marketing_testimonial_list_postion',
            [
                'label'       => esc_html__( 'Designation', 'invory' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'UI/UX Designer', 'invory' ),
            ]
        );
        $repeater->add_control(
            'lcp_marketing_testimonial_list_testi',
            [
                'label'       => esc_html__( 'Designation', 'invory' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_marketing_testimonial_list_image',
            [
				'label'       => esc_html__( 'Image', 'invory' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_marketing_testimonial_list',
            [
                'label'       => esc_html__( 'Add Item', 'invory' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_marketing_testimonial_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_marketing_testimonial_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Author Style
        $this->add_control(
			'lcp_marketing_testimonial_style_heading',
			[
				'label' => esc_html__( 'Author', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_testimonial_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .btest-box-text.btest-box-text-style25 > h4'
            ]
        );
        $this->add_control(
            'lcp_marketing_testimonial_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .btest-box-text.btest-box-text-style25 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Designation Style
        $this->add_control(
			'lcp_marketing_testimonial_style_postion',
			[
				'label' => esc_html__( 'Designation', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_testimonial_style_postion_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .btest-box-text.btest-box-text-style25 > p'
            ]
        );
        $this->add_control(
            'lcp_marketing_testimonial_style_postion_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .btest-box-text.btest-box-text-style25 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Testimonial Style
        $this->add_control(
			'lcp_marketing_testimonial_style_testi',
			[
				'label' => esc_html__( 'Testimonial', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_marketing_testimonial_style_testi_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-testimonial-box-style25 p'
            ]
        );
        $this->add_control(
            'lcp_marketing_testimonial_style_testi_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-style25 p' => 'color: {{VALUE}};',
                ],
            ]
        ); 
        
        // Testimonial Style
        $this->add_control(
			'lcp_marketing_testimonial_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_marketing_testimonial_style_extra_quots_color',
            [
                'label'     => esc_html__( 'Quots Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-boxquote-style25>svg>.cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        ); 
        
        $this->add_control(
            'lcp_marketing_testimonial_style_extra_quots_hcolor',
            [
                'label'     => esc_html__( 'Quots Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-style25:hover .lc-testimonial-boxquote-style25>svg>.cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        ); 
		$this->end_controls_section();
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-testimonial-slider-wrapper-style25">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <section class="lc-services-testimonials aos-init aos-animate" data-aos="zoom-in" data-aos-duration="2000">
                            <div class="lc-services-inner-testimonials">
                                <div class="swiper lc-services-testimonial">
                                    <div class="swiper-wrapper">';
                                        if(!empty($settings['lcp_marketing_testimonial_list'])){
                                            foreach($settings['lcp_marketing_testimonial_list'] as $list){
                                                echo '<div class="swiper-slide">
                                                    <div class="lc-services-test-img">
                                                        <div class="lc-testimonial-box lc-testimonial-box-style25">
                                                            <div class="lc-testimonial-box-img lc-testimonial-box-img-style25">
                                                                <div class="lc-testimonial-boximage-style25">';
                                                                    if(!empty($list['lcp_marketing_testimonial_list_image']['url'])){
                                                                        echo '<img src="'.esc_url($list['lcp_marketing_testimonial_list_image']['url']).'" alt="'.esc_attr('testimonial-img', 'leadcapture').'">';
                                                                    }
                                                                    echo '<div class="btest-box-text btest-box-text-style25">';
                                                                        if(!empty($list['lcp_marketing_testimonial_list_title'])){
                                                                            echo '<h4>'.esc_html($list['lcp_marketing_testimonial_list_title']).'</h4>'; 
                                                                        }
                                                                        if(!empty($list['lcp_marketing_testimonial_list_postion'])){
                                                                            echo '<p>'.esc_html($list['lcp_marketing_testimonial_list_postion']).'</p>';
                                                                        }
                                                                    echo '</div>
                                                                </div>
                                                                <div class="lc-testimonial-boxquote-style25">
                                                                    <svg id="Quote" xmlns="http://www.w3.org/2000/svg" width="72"
                                                                        height="51" viewBox="0 0 72 51">
                                                                        <path class="cls-1"
                                                                            d="M13.865,33.139A39.89,39.89,0,0,1,6.589,44.62a3.468,3.468,0,0,0-.33,4.188,3.411,3.411,0,0,0,2.92,1.6,2.873,2.873,0,0,0,.989-0.141c6.923-2.023,23.1-9.2,23.546-32.209C33.879,9.188,27.38,1.565,18.927.694A16.709,16.709,0,0,0,6.118,4.859,16.551,16.551,0,0,0,.679,17.117,16.311,16.311,0,0,0,13.865,33.139ZM56.507,0.694A16.5,16.5,0,0,0,38.282,17.117,16.311,16.311,0,0,0,51.468,33.139,39.891,39.891,0,0,1,44.192,44.62a3.468,3.468,0,0,0-.33,4.188,3.41,3.41,0,0,0,2.92,1.6,2.874,2.874,0,0,0,.989-0.141c6.922-2.023,23.1-9.2,23.546-32.209V17.728C71.318,9,64.89,1.565,56.507.694Z" />
                                                                    </svg>
                                                                </div>
                                                            </div>';
                                                            if(!empty($list['lcp_marketing_testimonial_list_testi'])){
                                                                echo '<p>'.esc_html($list['lcp_marketing_testimonial_list_testi']).'</p>';
                                                            }
                                                        echo '</div>
                                                    </div> 
                                                </div>';
                                            }
                                        }
                                    echo '</div>
                                </div>
                                <div class="swiper-button-next lc-internet-testimonia-next">
                                        <div class="lc-testimonial-boxquote-style25">
                                            <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 7 14" width="7" height="14"><path id="Shape 12" class="s0" d="m7 7q0 0.3-0.2 0.5l-5.3 6.3q-0.2 0.2-0.5 0.2-0.2 0-0.4-0.2l-0.4-0.5q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.6l4.4-5.2-4.4-5.2c-0.3-0.3-0.3-0.8 0-1.1l0.4-0.5q0.2-0.2 0.4-0.2 0.3 0 0.5 0.2l5.3 6.3q0.2 0.2 0.2 0.5z"></path></svg>
                                        </div>
                                    </div>
                                    <div class="swiper-button-prev lc-internet-testimonia-prev">
                                        <div class="lc-testimonial-boxquote-style25">
                                         <svg version="1.2" viewBox="0 0 7 14" width="7" height="14"><path id="Shape 12" class="s0" d="m0.2 6.5l5.3-6.3q0.2-0.2 0.5-0.2 0.2 0 0.4 0.2l0.4 0.5c0.3 0.3 0.3 0.8 0 1.1l-4.4 5.2 4.4 5.2q0.2 0.3 0.2 0.6 0 0.3-0.2 0.5l-0.4 0.5q-0.2 0.2-0.4 0.2-0.3 0-0.5-0.2l-5.3-6.3q-0.2-0.2-0.2-0.5 0-0.3 0.2-0.5z"></path></svg>
                                        </div>
                                    </div>
                            </div>
                        </section>
                    </div>
                </div>
            </div>';
		}
	}
}