<?php
/**
 * Widgets class.
 */
namespace ElementorLeadcapture;
// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();
/**
 * Class Plugin
 *
 * Main Plugin class
 *
 * @since 1.0.0
 */
class Widgets {

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.0.0
	 * @access private
	 */
	private function include_widgets_files() {
		// 1 App Landing
		require_once 'app-landing/lead-capture-aap-banner.php';
		require_once 'app-landing/lead-capture-aap-aboutus.php';
		require_once 'app-landing/lead-capture-aap-features.php';
       // 2 Auto Insurance
		require_once 'auto-insurance/lead-capture-auto-banner.php'; 
		require_once 'auto-insurance/lead-capture-auto-insurance-section.php'; 
		require_once 'auto-insurance/lead-capture-auto-services.php';
		require_once 'auto-insurance/lead-capture-auto-testimonials.php';
       // 3 Bakery
		require_once 'bakery/lead-capture-bakery-about.php';
		require_once 'bakery/lead-capture-bakery-banner.php';
		require_once 'bakery/lead-capture-bakery-products.php';
		require_once 'bakery/lead-capture-bakery-testimonials.php';
       // 4 Barclub
		require_once 'barclub/lead-capture-barclub-about.php';
		require_once 'barclub/lead-capture-barclub-banner.php';
		require_once 'barclub/lead-capture-barclub-booking-form.php';
		require_once 'barclub/lead-capture-barclub-booking.php';
		require_once 'barclub/lead-capture-barclub-form.php';
		require_once 'barclub/lead-capture-barclub-testimonials.php';
        // 5 Cardealer
		require_once 'cardealer/lead-capture-cardealer-banner.php';
		require_once 'cardealer/lead-capture-cardealer-blogs.php';
		require_once 'cardealer/lead-capture-cardealer-products.php';
        // 6 Charity
		require_once 'charity/lead-capture-charity-banner.php';
		require_once 'charity/lead-capture-charity-service.php';
		require_once 'charity/lead-capture-charity-team.php';
		require_once 'charity/lead-capture-charity-testimonials.php';
        // 7 Clothing
		require_once 'clothing/lead-capture-clothing-banner.php';
		require_once 'clothing/lead-capture-clothing-highlight.php';
		require_once 'clothing/lead-capture-clothing-offer.php';
		require_once 'clothing/lead-capture-clothing-shipping.php';
        // 8 Construction
		require_once 'construction/lead-capture-construction-banner.php';
		require_once 'construction/lead-capture-construction-abouts.php';
		require_once 'construction/lead-capture-construction-project.php';
		require_once 'construction/lead-capture-construction-testimonials.php';
        // 9 Corporate
		require_once 'corporate/lead-capture-corporate-banner.php';
		require_once 'corporate/lead-capture-corporate-services.php';
		require_once 'corporate/lead-capture-corporate-project.php';
		require_once 'corporate/lead-capture-corporate-contactform.php';
        // 10 Creative Agency
		require_once 'creative-agency/lead-capture-creativeagency-services.php';
		require_once 'creative-agency/lead-capture-creativeagency-finestwork.php';
		require_once 'creative-agency/lead-capture-creativeagency-pricingplan.php'; 
        // 11 Dance Studio
		require_once 'dance-studio/lead-capture-dancestudio-classes.php';
		require_once 'dance-studio/lead-capture-dancestudio-testimonials.php';
        // 12 Dentist
		require_once 'dentist/lead-capture-dentist-banner.php';
		require_once 'dentist/lead-capture-dentist-contactform.php';
		require_once 'dentist/lead-capture-dentist-testimonials.php';
        // 13 Digital Marketing
		require_once 'digital-marketing/lead-capture-digitalmarketing-banner-image.php';
		require_once 'digital-marketing/lead-capture-digitalmarketing-feature.php';
		require_once 'digital-marketing/lead-capture-digitalmarketing-testimonials.php';
        // 14 E Book
		require_once 'e-book/lead-capture-ebook-banner.php';
		require_once 'e-book/lead-capture-ebook-bestseller.php';
		require_once 'e-book/lead-capture-ebook-library.php';
		require_once 'e-book/lead-capture-ebook-testimonials.php';
        // 15 Education
		require_once 'education/lead-capture-education-banner.php';
		require_once 'education/lead-capture-education-services.php';
		require_once 'education/lead-capture-education-coursesprice.php';
		require_once 'education/lead-capture-education-testimonials.php';
        // 16 Electronic
		require_once 'electronic/lead-capture-electronic-banner.php';
		require_once 'electronic/lead-capture-electronic-services.php';
		require_once 'electronic/lead-capture-electronic-products.php';
		require_once 'electronic/lead-capture-electronic-productslider.php';
		require_once 'electronic/lead-capture-electronic-adds.php';
        // 17 Event
		require_once 'event/lead-capture-event-banner.php';
		require_once 'event/lead-capture-event-services.php';
		require_once 'event/lead-capture-event-upcomingevent.php';
		require_once 'event/lead-capture-event-priceplan.php';
        // 18 Fashion
		require_once 'fashion/lead-capture-fashion-banner.php';
		require_once 'fashion/lead-capture-fashion-blogs.php';
		require_once 'fashion/lead-capture-fashion-product.php';
		require_once 'fashion/lead-capture-fashion-discount.php';
		require_once 'fashion/lead-capture-fashion-services.php';
        // 19 Fitness
		require_once 'fitness/lead-capture-fitness-banner.php';
		require_once 'fitness/lead-capture-fitness-services.php';
		require_once 'fitness/lead-capture-fitness-personal.php';
		require_once 'fitness/lead-capture-fitness-testimonials.php';
        // 20 Flower
		require_once 'flower/lead-capture-flower-banner.php';
		require_once 'flower/lead-capture-flower-aboutus.php';
		require_once 'flower/lead-capture-flower-popular.php';
		require_once 'flower/lead-capture-flower-testimonials.php';
        // 21 Gardeners
		require_once 'gardeners/lead-capture-gardeners-banner.php';
		require_once 'gardeners/lead-capture-gardeners-services.php';
		require_once 'gardeners/lead-capture-gardeners-aboutus.php';
		require_once 'gardeners/lead-capture-gardeners-blogs.php';
        // 22 Interior Design
		require_once 'interior-design/lead-capture-interiordesign-banner.php';
		require_once 'interior-design/lead-capture-interiordesign-achievements.php';
		require_once 'interior-design/lead-capture-interiordesign-aboutus.php';
		require_once 'interior-design/lead-capture-interiordesign-testimonials.php';
        // 23 Internet Marketing
		require_once 'internet-marketing/lead-capture-internetmarketing-banner.php';
		require_once 'internet-marketing/lead-capture-internetmarketing-services.php';
		require_once 'internet-marketing/lead-capture-internetmarketing-aboutus.php';
		require_once 'internet-marketing/lead-capture-internetmarketing-testimonials.php';
        // 24 Medical
		require_once 'medical/lead-capture-medical-abouts.php';
		require_once 'medical/lead-capture-medical-banner.php';
		require_once 'medical/lead-capture-medical-specialist.php';
		require_once 'medical/lead-capture-medical-testimonials.php';
        // 25 Pest Control
		require_once 'pest-control/lead-capture-pestcontrol-banner.php';
		require_once 'pest-control/lead-capture-pestcontrol-blogs.php';
		require_once 'pest-control/lead-capture-pestcontrol-problems.php';
		require_once 'pest-control/lead-capture-pestcontrol-testimonials.php';
		require_once 'pest-control/lead-capture-pestcontrol-heading.php';
		
        // 26 Real Estate
		require_once 'real-estate/lead-capture-realestate-banner.php';
		require_once 'real-estate/lead-capture-realestate-locations.php';
		require_once 'real-estate/lead-capture-realestate-portfolio.php';
		require_once 'real-estate/lead-capture-realestate-testimonials.php';
        // 27 Restaurant
		require_once 'restaurant/lead-capture-restaurant-banner.php';
		require_once 'restaurant/lead-capture-restaurant-contact.php';
		require_once 'restaurant/lead-capture-restaurant-menu.php';
		require_once 'restaurant/lead-capture-restaurant-testimonials.php';
        // 28 Security
		require_once 'security/lead-capture-security-banner.php';
		require_once 'security/lead-capture-security-abouts.php';
		require_once 'security/lead-capture-security-video.php';
		require_once 'security/lead-capture-security-testimonials.php'; 
        // 29 Tattoo
		require_once 'tattoo/lead-capture-tattoo-blog.php';
		require_once 'tattoo/lead-capture-tattoo-pricelist.php';
		require_once 'tattoo/lead-capture-tattoo-testimonials.php';

		// 30 Barber
        require_once 'barber/lead-capture-barber-banner.php';
		require_once 'barber/lead-capture-barber-services.php';
		require_once 'barber/lead-capture-barber-specialist.php';
		require_once 'barber/lead-capture-barber-testimonials.php';
		
		// 31 Startup 
        require_once 'startup/lead-capture-startup-testimonials.php';
        
        // 32 meetUp 
        require_once 'meetup/lead-capture-meetup-banner.php';
        require_once 'meetup/lead-capture-meetup-about.php';
        require_once 'meetup/lead-capture-meetup-testimonials.php';
        require_once 'meetup/lead-capture-meetup-pricingplan.php';
        
        // 33 pet Shop 
        require_once 'pet-shop/lead-capture-pet-shop-banner.php';
        require_once 'pet-shop/lead-capture-pet-shop-about.php';
        require_once 'pet-shop/lead-capture-pet-shop-services.php';
        require_once 'pet-shop/lead-capture-pet-shop-testimonials.php';
        
        // 34 Photographer
        require_once 'photographer/lead-capture-photographer-banner.php';
        require_once 'photographer/lead-capture-photographer-testimonials.php';
        require_once 'photographer/lead-capture-photographer-team.php';
		// Global
		
		// 35 Single Property
		require_once 'single-property/lead-capture-single-property-banner.php';
		require_once 'single-property/lead-capture-single-property-services.php';
		require_once 'single-property/lead-capture-single-property-testimonials.php';

        // 36 Hotel and Resort
        require_once 'hotel-and-resort/lead-capture-hotel-and-resort-banner.php';
        require_once 'hotel-and-resort/lead-capture-hotel-and-resort-properties.php';
        require_once 'hotel-and-resort/lead-capture-hotel-and-resort-testimonials.php';
        
        // 37 solar
        require_once 'solar/lead-capture-solar-testimonials.php';
        require_once 'solar/lead-capture-solar-progress-bar.php';
        
        // 38 Spa Center
        require_once 'spa-center/lead-capture-spa-center-banner.php';
        require_once 'spa-center/lead-capture-spa-center-services.php';
        require_once 'spa-center/lead-capture-spa-center-pricing-plan.php';
        
        // 39 Plumber
        require_once 'plumber/lead-capture-plumber-banner.php';
        require_once 'plumber/lead-capture-plumber-services.php';
        require_once 'plumber/lead-capture-plumber-blogs.php';
        
        
        // 40 Pool Cleaning
        require_once 'pool-cleaning/lead-capture-pool-cleaning-banner.php';
        require_once 'pool-cleaning/lead-capture-pool-cleaning-about.php';
        require_once 'pool-cleaning/lead-capture-pool-cleaning-testimonials.php';
        require_once 'pool-cleaning/lead-capture-pool-cleaning-contact-info.php';
        
        // 41 Roof Constructions
        require_once 'roof-constructions/lead-capture-roof-constructions-banner.php';
        require_once 'roof-constructions/lead-capture-roof-constructions-team.php';
        require_once 'roof-constructions/lead-capture-roof-constructions-blogs.php';
        
         // 42 yoga classes
        require_once 'yoga-classes/lead-capture-yoga-classes-banner.php';
        require_once 'yoga-classes/lead-capture-yoga-classes-time-table.php';
        require_once 'yoga-classes/lead-capture-yoga-classes-testimonials.php';
        
         // 43 painter
        require_once 'painter/lead-capture-painter-banner.php';
        require_once 'painter/lead-capture-painter-counter.php';
        require_once 'painter/lead-capture-painter-services.php';
        require_once 'painter/lead-capture-painter-blogs.php';
        
        // 43 Sea Food Restaurant
        require_once 'sea-food-restaurant/lead-capture-sea-food-restaurant-banner.php';
        require_once 'sea-food-restaurant/lead-capture-sea-food-restaurant-products.php';
        require_once 'sea-food-restaurant/lead-capture-sea-food-restaurant-blogs.php';
        
        // 44 Auto Repair
        require_once 'auto-repair/lead-capture-auto-repair-banner.php';
        require_once 'auto-repair/lead-capture-auto-repair-services.php';
        require_once 'auto-repair/lead-capture-auto-repair-features.php';
        require_once 'auto-repair/lead-capture-auto-repair-blog.php';
        
       // Business marketing
        require_once 'business-marketing/lead-capture-business-marketing-banner.php';
        require_once 'business-marketing/lead-capture-business-marketing-service.php';
        require_once 'business-marketing/lead-capture-business-marketing-blogs.php';
        
        //45 Dry Cleaning
        require_once 'dry-cleaning/lead-capture-dry-cleaning-banner.php';
        require_once 'dry-cleaning/lead-capture-dry-cleaning-about.php';
        require_once 'dry-cleaning/lead-capture-dry-cleaning-service.php';
        require_once 'dry-cleaning/lead-capture-dry-cleaning-pricingplan.php';

        //46 Moving
         require_once 'moving/lead-capture-moving-banner.php';
         require_once 'moving/lead-capture-moving-about.php';
         require_once 'moving/lead-capture-moving-services.php';
         require_once 'moving/lead-capture-moving-blogs.php';
         
         
       // Global
        require_once 'global/lead-capture-testimonials-style1.php';
    }

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *  
	 * @since 1.0.0
	 * @access public 
	 */
	public function register_widgets() {
		// It's now safe to include Widgets files.
		$this->include_widgets_files();
       // Register the plugin widget classes.
        
		// 1 App Landing
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_App_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_App_Aboutus());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_App_Feature());
        
        // 2 Auto Insurance
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Auto_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Auto_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Insurance_Section());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Auto_Testimonials());
        // 3 Bakery
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Bakery_about());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Bakery_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Bakery_Products());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Bakery_Testimonials());
		// 4 Barclub
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barclub_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barclub_Form());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barclub_About());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barclub_Booking());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barclub_Booking_form());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barclub_Testimonials());
		// 5 Cardealer
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Cardealer_Blogs());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Cardealer_Products());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Cardealer_Banner());
        // 6 Charity
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Charity_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Charity_Team());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Charity_Testimonials());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Charity_Service());
        // 7 Clothing
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Clothing_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Clothing_Highlight());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Clothing_Offer());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Clothing_Shipping());
        // 8 Construction
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Construction_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Construction_Abouts());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Construction_Project());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Construction_Testimonials());
        // 9 Corporate
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Corporate_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Corporate_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Corporate_Project());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Corporate_Contactform());
        // 10 Creative Agency
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Creativeagency_Pricingplan());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Creativeagency_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Creativeagency_Finestwork());
        // 11 Dance Studio
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dancestudio_Classes());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dancestudio_Testimonials());
        // 12 Dentist
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dentist_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dentist_Contactform());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dentist_Testimonials());
        
        // 13 Digital Marketing
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Digitalmarketing_Banner_Image());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Digitalmarketing_Feature());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Digitalmarketing_Testimonials());
        // 14 E Book
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Ebook_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Ebook_Library());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Ebook_BestSeller());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Ebook_Testimonials());
        // 15 Education
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Education_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Eduction_Courseprice());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Education_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Education_Testimonials());
        // 16 Electronic
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Electronic_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Electronic_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Electronic_Products());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Electronic_Productslider());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Electronic_Adds());
        // 17 Event
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Event_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Event_Upcomingevent());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Event_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Event_Priceplan());
        // 18 Fashion
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fashion_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fashion_Products());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fashion_Blogs());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fashion_Discount());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fashion_Services());

		
        // 19 Fitness
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fitness_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fitness_Personal());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fitness_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Fitness_Testimonials());
        // 20 Flower
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Flower_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Flower_Aboutus());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Flower_Popular());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Flower_Testimonials());
        // 21 Gardeners
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Gardeners_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Gardeners_Aboutus());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Gardeners_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Gardeners_Blogs());
        // 22 Interior Design
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Interiordesign_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Interiordesign_Aboutus());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Interiordesign_Achievements());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Interiordesign_Testimonials());
        // 23 Internet Marketing
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Internetmarketing_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Internetmarketing_Aboutus());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Internetmarketing_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Internetmarketing_Testimonials());
        // 24 Medical
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Medical_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Medical_Abouts());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Medical_Specialist());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Medical_Testimonials());
        // 25 Pest Control
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pestcontrol_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pestcontrol_Blogs());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pestcontrol_Problems());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pest_Control_Testimonials());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pest_Control_Heading());
        // 26 Real Estate
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Realestate_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Realestate_Locations());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Realestate_Portfolio());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Realestate_Testimonials());
        // 27 Restaurant
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Restaurant_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Restaurant_Menu());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Restaurant_Contact());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Restaurant_Testimonials());
        // 28 Security
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Security_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Security_Abouts());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Security_Video());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Security_Testimonials());
        // 29 Tattoo
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Tatto_Pricelist());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Tatto_Testimonials());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Tatto_Blog());
        // 30 Barber
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barber_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barber_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barber_Specialist());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Barber_Testimonials());
		
		// 31 Statup
	    \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Startup_Testimonials());
		// 32 Meetup
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Meetup_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Meetup_About());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Meetup_Testimonials());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Meetup_Pricingplan());
		
		// 33 Pet Shop
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pet_Shop_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pet_Shop_About());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pet_Shop_Services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pet_Shop_Testimonials());
		
		// 34 Photographer
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Photographer_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Photographer_Testimonials());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Photographer_Team());
		
		// 35 Single Property
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Single_Property_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new leadcapture_single_property_services());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Single_Property_Testimonials());
		
		// 36 Hotel And Resort
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Hotel_And_Resort_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Hotel_Type());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Hotel_And_Resort_Testimonials());
		
        // 37 Solar
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Solar_Testimonials());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Solar_Progress_Bar());
        
        // 38 Spa Center
        \Elementor\Plugin::instance()->widgets_manager->register( new leadcapture_spa_center_banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Spa_Center_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Spa_Center_Pricing_plan());
		
        // 38 Plumber
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Plumber_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Plumber_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Plumber_Blogs());
        
		// 39 Pool Cleaning 
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pool_Cleaning_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pool_Cleaning_About());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pool_Cleaning_Testimonials());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Pool_Cleaning_Contact_Info());
		
		// 40 Roof Constructions
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Roof_Constructions_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Roof_Constructions_Team());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Roof_Constructions_Blogs());
		
	    // 41 yoga classes
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Yoga_Classes_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Yoga_Classes_Time_Table());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Yoga_Classes_Testimonials());

		// 42 Painter
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Painter_Banner());
		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Painter_Counter());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Painter_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Painter_Blogs());
        
        // 43 Sea Food
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Sea_Food_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Sea_Food_Products());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Sea_Food_Blogs());
        
        // 44 Auto_Repair
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Auto_Repair_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Auto_Repair_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Auto_Repair_Features());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Auto_Repair_Blogs());
        
        
        // 44 Business Marketing
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Business_Marketing_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Business_Marketing_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Business_Marketing_Blogs());
        
        
        // 45 Dry Cleaning
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dry_Cleaning_Banner());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dry_Cleaning_About());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dry_Cleaning_Services());
        \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Dry_Cleaning_Pricingplan());
        
        // 46 Moving
         \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Moving_Banner());
         \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Moving_About());
         \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Moving_Services());
         \Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Moving_Blogs());
         
         
		// Global 
 		\Elementor\Plugin::instance()->widgets_manager->register( new Leadcapture_Testmonials_Style1());
 		
 
 		
		  
    }  
	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		// Register the widgets.
		add_action( 'elementor/widgets/register', array( $this, 'register_widgets' ) );
	}
}

// Instantiate the Widgets class.
Widgets::instance();