<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Medical_Abouts extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_medical_about';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Medical About', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_medical_about_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_medical_about_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_medical_about_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_medical_about_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_medical_about_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Quality Care Services', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_medical_about_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Consectetur adipiscing elitdsed do eiusmod tempor incididunt ut labore et dolore.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_medical_about_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_medical_about_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_medical_about_list_title'  => esc_html__( 'Quality Care Services', 'leadcapture' ),
						'lcp_medical_about_list_desc'  => esc_html__( 'Consectetur adipiscing elitdsed do eiusmod tempor incididunt ut labore et dolore.', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_medical_about_list_title}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_medical_about_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heding Style
        $this->add_control(
			'lcp_medical_about_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_medical_about_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-heading > h2'
            ]
        );
        $this->add_control(
            'lcp_medical_about_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-heading > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_medical_about_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_medical_about_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-heading > p'
            ]
        );
        $this->add_control(
            'lcp_medical_about_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-heading > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_medical_about_list_style_tab', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heding Style
        $this->add_control(
			'lcp_medical_about_list_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_medical_about_list_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-ser-box-text > h3'
            ]
        );
        $this->add_control(
            'lcp_medical_about_style_list_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-ser-box-text > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_medical_about_style_list_heading_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-ser-box-wrapper:hover .lc-ser-box-text > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_medical_about_list_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_medical_about_list_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-ser-box-text > p'
            ]
        );
        $this->add_control(
            'lcp_medical_about_style_list_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-ser-box-text > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
        
        
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		   echo '<div class="lc-service-section lc-service-section-style16">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-service-img-wrapper FadeInLeft wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: fadeInLeft;">';
                                if(!empty($settings['lcp_medical_about_image']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_medical_about_image']['url']).'">';
                                }
                            echo '</div>
                        </div>
                        <div class="col-lg-6 col-md-12 col-sm-12">
                            <div class="lc-service-heading fadeInRight wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: fadeInRight;">';
                                if(!empty($settings['lcp_medical_about_heading'])){
                                    echo '<h2>'.esc_html($settings['lcp_medical_about_heading']).'</h2>';
                                }
                                if(!empty($settings['lcp_medical_about_desc'])){
                                    echo '<p>'.esc_html($settings['lcp_medical_about_desc']).'</p>';
                                }
                            echo '</div>
                            <div class="lc-service-box-wrapper-style16 fadeInRight wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: fadeInRight;">
                                <div class="row">';
                                    if(!empty($settings['lcp_medical_about_list'])){
                                        foreach($settings['lcp_medical_about_list'] as $list){
                                            echo '<div class="col-lg-6 col-md-6 col-sm-6">
                                                <div class="lc-ser-box-wrapper">';
                                                    if($list['lcp_medical_about_list_image']['url']){
                                                        echo '<img src="'.esc_url($list['lcp_medical_about_list_image']['url']).'">';
                                                    }
                                                    echo '<div class="lc-ser-box-text">';
                                                        if(!empty($list['lcp_medical_about_list_title'])){
                                                            echo '<h3>'.esc_html($list['lcp_medical_about_list_title']).'</h3>';
                                                        }
                                                        if(!empty($list['lcp_medical_about_list_desc'])){
                                                            echo '<p>'.$list['lcp_medical_about_list_desc'].'</p>';
                                                        }
                                                    echo '</div>
                                                </div>
                                            </div>';
                                        }
                                    }
                                echo '</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>'; 
		}
	}
}