<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Medical_Specialist extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_medical_specialist';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Medical Specialist', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_medical_team_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_medical_team_name',
            [
                'label'       => esc_html__( 'Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_medical_team_specialist',
            [
                'label'       => esc_html__( 'Specialist', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_medical_team_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_medical_team_facebook',
            [
                'label'       => esc_html__( 'Facebook Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_medical_team_linkedin',
            [
                'label'       => esc_html__( 'Linkedin Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_medical_team_twitter',
            [
                'label'       => esc_html__( 'Twitter Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_medical_team_youtube',
            [
                'label'       => esc_html__( 'Youtube Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_medical_team_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Title Style
        $this->add_control(
			'lcp_medical_team_style_heading',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_medical_team_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-team-box-text-style16 > h4'
            ]
        );
        $this->add_control(
            'lcp_medical_team_style_heading_color',
            [ 
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-team-box-text-style16 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Specialist Style
        $this->add_control(
			'lcp_medical_team_style_specialist',
			[
				'label' => esc_html__( 'Specialist', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_medical_team_style_specialist_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-team-box-text-style16 >p'
            ]
        );
        
        $this->add_control(
            'lcp_medical_team_style_specialist_color',
            [ 
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-team-box-text-style16 >p' => 'color: {{VALUE}};',
                ],
            ]
        );
         // Specialist Style
        $this->add_control(
			'lcp_medical_team_style_social',
			[
				'label' => esc_html__( 'Social Icon', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_medical_team_style_social_color',
            [ 
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-team-icons > a > .lc-facebook-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-team-icons > a > .lc-linkin-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-team-icons > a > .lc-twitter-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-team-icons > a > .lc-you-tube-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        // Specialist Style
        $this->add_control(
			'lcp_medical_team_style_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_medical_team_style_specialist_hcolor',
            [ 
                'label'     => esc_html__( 'Hover Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-team-box-wrapper-style16:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_medical_team_style_social_hTcolor',
            [ 
                'label'     => esc_html__( 'Social Icon Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-team-box-wrapper:hover .lc-team-icons > a > .lc-facebook-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-team-box-wrapper:hover .lc-team-icons > a > .lc-linkin-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-team-box-wrapper:hover .lc-team-icons > a > .lc-twitter-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-team-box-wrapper:hover .lc-team-icons > a > .lc-you-tube-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_medical_team_style_specialist_hTcolor',
            [ 
                'label'     => esc_html__( 'Hover Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-team-box-wrapper:hover .lc-team-box-text-style16 >p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-team-box-wrapper lc-team-box-wrapper-style16">';
		        if(!empty($settings['lcp_medical_team_image']['url'])){
		            echo '<img src="'.esc_url($settings['lcp_medical_team_image']['url']).'">';
		        }
                echo '<div class="lc-team-box-text lc-team-box-text-style16">';
                    if(!empty($settings['lcp_medical_team_specialist'])){
                        echo '<p>'.esc_html($settings['lcp_medical_team_specialist']).'</p>';
                    }
                    if(!empty($settings['lcp_medical_team_name'])){
                        echo '<h4>'.esc_html($settings['lcp_medical_team_name']).'</h4>';
                    }
                echo '</div>
                <div class="lc-team-style16-line"></div>
                <div class="lc-team-icons">';
                    if(!empty($settings['lcp_medical_team_facebook'])){
                        echo '<a href="'.esc_url($settings['lcp_medical_team_facebook']).'">
                            <span class="lc-facebook-icon">
                                <svg xmlns="http://www.w3.org/2000/svg" width="8" height="16"viewBox="0 0 8 16">
                                    <path class="cls-1" d="M7.7,0L5.78,0C3.624,0,2.231,1.545,2.231,3.937V5.752H0.3a0.315,0.315,0,0,0-.3.326V8.709a0.315,0.315,0,0,0,.3.326H2.231v6.638a0.315,0.315,0,0,0,.3.326H5.05a0.315,0.315,0,0,0,.3-0.326V9.036H7.607a0.315,0.315,0,0,0,.3-0.326V6.079a0.341,0.341,0,0,0-.088-0.231,0.291,0.291,0,0,0-.214-0.1H5.351V4.214A0.9,0.9,0,0,1,6.406,3.1H7.7A0.315,0.315,0,0,0,8,2.771V0.329A0.315,0.315,0,0,0,7.7,0Z" />
                                </svg>
                            </span>
                        </a>';
                    }
                    if(!empty($settings['lcp_medical_team_linkedin'])){
                        echo '<a href="'.esc_url($settings['lcp_medical_team_linkedin']).'">
                            <div class="lc-linkin-icon">
                                <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"
                                    viewBox="0 0 16 16">
                                    <path class="cls-1"
                                        d="M1.94,0A1.826,1.826,0,0,0,0,1.865,1.814,1.814,0,0,0,1.9,3.73H1.918A1.826,1.826,0,0,0,3.858,1.865,1.82,1.82,0,0,0,1.94,0ZM0.2,5.2h3.43V16H0.2V5.2Zm11.849-.253A4.279,4.279,0,0,0,8.96,6.77V5.2H5.53V16H8.96V9.971A2.565,2.565,0,0,1,9.073,9.1a1.889,1.889,0,0,1,1.76-1.312c1.241,0,1.738.99,1.738,2.441V16H16V9.81C16,6.494,14.308,4.951,12.051,4.951Z" />
                                </svg>
                            </div>
                        </a>';
                    } 
                    if(!empty($settings['lcp_medical_team_twitter'])){
                        echo '<a href="'.esc_url($settings['lcp_medical_team_twitter']).'">
                            <div class="lc-twitter-icon">
                                <svg xmlns="http://www.w3.org/2000/svg" width="19" height="17"
                                    viewBox="0 0 19 17">
                                    <path class="cls-1"
                                        d="M18.609,3.082a0.533,0.533,0,0,0-.5-0.259l-0.9.08,0.858-1.767A0.558,0.558,0,0,0,17.965.5,0.528,0.528,0,0,0,17.348.4L15.077,1.535a3.773,3.773,0,0,0-4.362.59A4.8,4.8,0,0,0,9.278,5.94,7.816,7.816,0,0,1,3.1,1.646a0.531,0.531,0,0,0-.9-0.065,3.832,3.832,0,0,0-.234,3.945C1.79,5.48,1.6,5.418,1.394,5.347a0.528,0.528,0,0,0-.518.1,0.555,0.555,0,0,0-.181.507,4.6,4.6,0,0,0,2.564,3.49,4.42,4.42,0,0,1-.563.16,0.541,0.541,0,0,0-.4.372,0.557,0.557,0,0,0,.12.54,7.22,7.22,0,0,0,3.536,1.923c-1.189.951-2.472,1.11-4.337,1.045a0.537,0.537,0,0,0-.505.318,0.558,0.558,0,0,0,.089.6c0.777,0.876,3.609,1.863,6.586,1.937,0.118,0,.238,0,0.36,0a9.416,9.416,0,0,0,6.836-2.484,9.948,9.948,0,0,0,2.79-5.247,10.426,10.426,0,0,0,.018-3.439c-0.006-.045-0.013-0.092-0.019-0.133l0.84-1.383A0.559,0.559,0,0,0,18.609,3.082Z" />
                                </svg>
                            </div>
                        </a>';
                    }
                    if(!empty($settings['lcp_medical_team_youtube'])){
                        echo '<a href="'.esc_url($settings['lcp_medical_team_youtube']).'">
                            <div class="lc-you-tube-icon">
                                <svg xmlns="http://www.w3.org/2000/svg" width="22" height="16"
                                    viewBox="0 0 22 16">
                                    <path class="cls-1"
                                        d="M21.143,1.373C20.348,0.4,18.882,0,16.082,0H5.918C3.054,0,1.562.423,0.771,1.462,0,2.475,0,3.967,0,6.032V9.968C0,13.969.915,16,5.918,16H16.082c2.428,0,3.774-.351,4.644-1.212C21.619,13.9,22,12.464,22,9.968V6.032C22,3.854,21.94,2.353,21.143,1.373Zm-7.018,7.17L9.508,11.036a0.69,0.69,0,0,1-.7-0.023,0.739,0.739,0,0,1-.342-0.627V5.416A0.739,0.739,0,0,1,8.811,4.79a0.69,0.69,0,0,1,.7-0.024l4.615,2.477A0.745,0.745,0,0,1,14.124,8.543Z" />
                                </svg>
                            </div>
                        </a>';
                    }
                echo '</div>
            </div>';
		}
	}
}