<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Meetup_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_meetup_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Meetup Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_meetup',
            [
            'label' => esc_html__('Meetup Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'leadcapture_meetup_logo_image',
            [
			'label' => esc_html__('Meetup Logo Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_meetup_main_head',
            [
            'label' => esc_html__('Meetup Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_meetup_btn',
            [
            'label' => esc_html__('Button', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('Button Text', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_meetup_btn_url',
            [
            'label' => esc_html__('Button URL', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_meetup_form_heading',
            [
            'label' => esc_html__('Form Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
         $this->add_control(
            'leadcapture_meetup_form_desc',
            [
            'label' => esc_html__('Form Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_meetup_form_shortcode',
            [
            'label' => esc_html__('Form Shortcode', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_meetup_right_image',
            [
			'label' => esc_html__('Right Image 1', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_right_image_two',
            [
			'label' => esc_html__('Right Image 2', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_meetup_arrow_img',
            [
			'label' => esc_html__('Arrow Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        
        
        $repeater = new Repeater();
       
        
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
        	'lps_heading_style_tab',
        	[
        	'label' => esc_html__('Style Tab', 'leadcapture'),
        	'tab'   => Controls_Manager::TAB_STYLE,
        	]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Heading Typography', 'leadcapture'),
        	'name'     => 'lps_heading_typography_car',
        	'selector' => '{{WRAPPER}} .lps-heading-fontstyle > h1',
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lps-heading-fontstyle > h1' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       
        $this->add_control(
        	'lps_sub_heading_text_color',
        	[
    		'label' => esc_html__('Form Heading Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .add-news-letter-text-colors > h2' => 'color: {{VALUE}}',
        		],
        	]
        );
        
        $this->add_control(
        	'lps_form_heading_text_color',
        	[
    		'label' => esc_html__('Form Sub Heading Text Color', 'leadcapture'),
    		'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        			'{{WRAPPER}} .subheading-text-colors > p' => 'color: {{VALUE}}',
        		],
        	]
        );
        $this->end_controls_section();
    }
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$id = uniqid();	
        $settings = $this->get_settings_for_display();
		echo '<div class="lc-banner-wrapper-style30">
		<div class="container-fluid">
			<div class="row">
				<div class="col-xl-4 col-lg-6">';
					if(!empty($settings['leadcapture_meetup_logo_image']['url'])):
					    echo '<div class="lc-banner-logo-style30">
						<img src="'.esc_url($settings['leadcapture_meetup_logo_image']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
					</div>';
    					endif;
					echo '<div class="lc-banner-text-style30 lps-heading-fontstyle">';
                        if(!empty($settings['leadcapture_meetup_main_head'])):
                            echo '<h1>'.esc_html($settings['leadcapture_meetup_main_head']).'</h1>';
                        endif;
                        if(!empty($settings['leadcapture_meetup_btn'])):
                            echo '<a href="'.esc_html($settings['leadcapture_meetup_btn_url']).'" class="lc-btn-style30">'.esc_html($settings['leadcapture_meetup_btn']).'</a>';	
                        endif;
						echo '</div>
					    <div class="lc-meetup-newsletter-head add-news-letter-text-colors subheading-text-colors">';
					    if(!empty($settings['leadcapture_meetup_form_heading'])):
                            echo '<h2>'.esc_html($settings['leadcapture_meetup_form_heading']).'</h2>';
                        endif;
                        if(!empty($settings['leadcapture_meetup_form_desc'])):
                            echo '<p>'.esc_html($settings['leadcapture_meetup_form_desc']).'</p>';
                        endif;
                        if(!empty($settings['leadcapture_meetup_form_shortcode'])):
                            echo do_shortcode($settings['leadcapture_meetup_form_shortcode']);
                        endif;
					    echo '</div>	
				</div>
				<div class="col-xl-3 col-lg-6">
					<div class="lc-banner-img-1-style30">';
					    if(!empty($settings['leadcapture_meetup_arrow_img']['url'])):
                            echo '<img src="'.esc_url($settings['leadcapture_meetup_arrow_img']['url']).'" alt="'.esc_attr__('arrow-img', 'leadcapture').'">';
                        endif;
                        if(!empty($settings['leadcapture_meetup_right_image']['url'])):
                            echo '<img src="'.esc_url($settings['leadcapture_meetup_right_image']['url']).'" alt="'.esc_attr__('image1', 'leadcapture').'">';
                        endif;
					echo '</div>
				</div>
				<div class="col-xl-5 col-lg-12 col-md-12">
					<div class="lc-banner-img-2-style30">';
						if(!empty($settings['leadcapture_right_image_two']['url'])):
                            echo '<img src="'.esc_url($settings['leadcapture_right_image_two']['url']).'" alt="'.esc_attr__('image2', 'leadcapture').'">';
                        endif;
					echo '</div>
				</div>
			</div>
		</div>
	</div>';
	}
}