<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Meetup_Pricingplan extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_meetup_pricingplan';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Meetup Pricing Plan', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_meetup_pricing_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        
        $repeater = new Repeater();
         $repeater->add_control(
            'lcp_meetup_pricing_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
       $repeater->add_control(
            'lcp_meetup_pricing_period',
            [
                'label'       => esc_html__( 'Time Period', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_list_one',
            [
                'label'       => esc_html__( 'List 1', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_list_two',
            [
                'label'       => esc_html__( 'List 2', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_list_three',
            [
                'label'       => esc_html__( 'List 3', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_list_four',
            [
                'label'       => esc_html__( 'List 4', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_list_five',
            [
                'label'       => esc_html__( 'List 5', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_list_six',
            [
                'label'       => esc_html__( 'List 6', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_btn_title',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_meetup_pricing_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_meetup_pricing_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_meetup_pricing_heading'  => esc_html__( 'basic', 'leadcapture' ),
                        'lcp_meetup_pricing_symbol'  => esc_html__( '$', 'leadcapture' ),
                        'lcp_meetup_pricing_price'  => esc_html__( '90', 'leadcapture' ),
                        'lcp_meetup_pricing_period'  => esc_html__( 'Monthly', 'leadcapture' ),
                        'lcp_meetup_pricing_btn_title'  => esc_html__( 'Buy Now ', 'leadcapture' ),
                        'lcp_meetup_pricing_list_one'  => esc_html__( 'Service One', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_meetup_pricing_heading}}',
            ]
        );
		$this->end_controls_section();
		
	    
	    //Widget Style Tab
	    $this->start_controls_section(
            'lcp_meetup_pricing_style_tab',
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        //Heading Style 
        $this->add_control(
			'lcp_meetup_pricing_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_meetup_pricing_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing_heading h5'
            ]
        );
        $this->add_control(
            'lcp_meetup_pricing_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing_heading h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Symbol & Price Style 
        $this->add_control(
			'lcp_meetup_pricing_style_symbol',
			[
				'label' => esc_html__( 'Symbol & Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_meetup_pricing_style_symbol_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing_heading h1'
            ]
        );
        $this->add_control(
            'lcp_meetup_pricing_style_symbol_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing_heading h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        //Time Period
        $this->add_control(
			'lcp_meetup_pricing_style_time',
			[
				'label' => esc_html__( 'Time Period', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_meetup_pricing_style_symbol_time',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing_heading h1 span'
            ]
        );
        $this->add_control(
            'lcp_meetup_pricing_style_symbol_time',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing_heading h1 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        //List
        $this->add_control(
			'lcp_meetup_pricing_style_list',
			[
				'label' => esc_html__( 'List', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_meetup_pricing_style_symbol_list',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing_heading ul li'
            ]
        );
        $this->add_control(
            'lcp_meetup_pricing_style_symbol_list',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing_heading ul li' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Button Settings Tab
        $this->add_control(
			'lcp_meetup_pricing_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_meetup_pricing_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn a',
            ]
        );
        $this->add_control(
            'lcp_meetup_pricing_style_button_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-plan-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        // Hover or Normal Tab
        $this->start_controls_tabs( 'button_colors' );
        $this->start_controls_tab(
			'lcp_meetup_pricing_style_button_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_meetup_pricing_style_button_tcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_meetup_pricing_style_button_border',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn',
            ]
        );
		$this->add_control(
            'lcp_meetup_pricing_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lcp_meetup_pricing_style_button_bt_bg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_meetup_pricing_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_meetup_pricing_style_button_htcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_meetup_pricing_style_button_hborder',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-plan-btn:hover',
            ]
        );
		$this->add_control(
            'lcp_meetup_pricing_style_button_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lcp_meetup_pricing_style_button_bt_hbg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$id = uniqid();	
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
	    echo '<!------- pricing Section Start ------>
		<div class="lc-pricing-wrapper-style30">
			<div class="container">
				<div class="row gy-4">
					<div class="col-lg-12 col-md-12">
						<div class="lc-price-table-parent-style30">
							<div class="row gy-4">';
							 if(!empty($settings['lcp_meetup_pricing_list'])){
							  foreach($settings['lcp_meetup_pricing_list'] as $list){
								echo '<div class="col-lg-4 col-md-4">
									<div class="lc-price-table-style30 lc-pricing_heading lc-plan-btn">';
                                        if(!empty($list['lcp_meetup_pricing_heading'])){
                                            echo '<h5>'.esc_html($list['lcp_meetup_pricing_heading']).'</h5>';  
                                        }
                                        if(!empty($list['lcp_meetup_pricing_symbol']) || !empty($list['lcp_meetup_pricing_price']) || !empty($list['lcp_meetup_pricing_period'])){
                                           echo '<h1>'.esc_html($list['lcp_meetup_pricing_symbol'].$list['lcp_meetup_pricing_price']).'<span>/'.esc_html($list['lcp_meetup_pricing_period']).'</span></h1>';
                                        }
                                        echo '<ul>';
                                        if(!empty($list['lcp_meetup_pricing_list_one'])){
                                         echo '<li><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="16" height="16">
                                        	<path  fill-rule="evenodd" class="s0" d="m15 8c0 3.8-3.2 7-7 7-3.8 0-7-3.2-7-7 0-3.8 3.2-7 7-7 3.8 0 7 3.2 7 7zm-7.8 3.2l-3.1-3.1 1.1-1.1 2 1.9 3.9-3.6 1.1 1.3z"/>
                                            </svg>'.esc_html($list['lcp_meetup_pricing_list_one']).'</li>';
                                        }
                                        if(!empty($list['lcp_meetup_pricing_list_two'])){
                                         echo '<li><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="16" height="16">
                                        	<path  fill-rule="evenodd" class="s0" d="m15 8c0 3.8-3.2 7-7 7-3.8 0-7-3.2-7-7 0-3.8 3.2-7 7-7 3.8 0 7 3.2 7 7zm-7.8 3.2l-3.1-3.1 1.1-1.1 2 1.9 3.9-3.6 1.1 1.3z"/>
                                            </svg>'.esc_html($list['lcp_meetup_pricing_list_two']).'</li>';
                                        }
                                        if(!empty($list['lcp_meetup_pricing_list_three'])){
                                         echo '<li><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="16" height="16">
                                        	<path  fill-rule="evenodd" class="s0" d="m15 8c0 3.8-3.2 7-7 7-3.8 0-7-3.2-7-7 0-3.8 3.2-7 7-7 3.8 0 7 3.2 7 7zm-7.8 3.2l-3.1-3.1 1.1-1.1 2 1.9 3.9-3.6 1.1 1.3z"/>
                                            </svg>'.esc_html($list['lcp_meetup_pricing_list_three']).'</li>';
                                        }
                                        if(!empty($list['lcp_meetup_pricing_list_four'])){
                                         echo '<li><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="16" height="16">
                                        	<path  fill-rule="evenodd" class="s0" d="m15 8c0 3.8-3.2 7-7 7-3.8 0-7-3.2-7-7 0-3.8 3.2-7 7-7 3.8 0 7 3.2 7 7zm-7.8 3.2l-3.1-3.1 1.1-1.1 2 1.9 3.9-3.6 1.1 1.3z"/>
                                            </svg>'.esc_html($list['lcp_meetup_pricing_list_four']).'</li>';
                                        }
                                        if(!empty($list['lcp_meetup_pricing_list_five'])){
                                         echo '<li><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="16" height="16">
                                        	<path  fill-rule="evenodd" class="s0" d="m15 8c0 3.8-3.2 7-7 7-3.8 0-7-3.2-7-7 0-3.8 3.2-7 7-7 3.8 0 7 3.2 7 7zm-7.8 3.2l-3.1-3.1 1.1-1.1 2 1.9 3.9-3.6 1.1 1.3z"/>
                                            </svg>'.esc_html($list['lcp_meetup_pricing_list_five']).'</li>';
                                        }
                                        if(!empty($list['lcp_meetup_pricing_list_six'])){
                                         echo '<li><svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="16" height="16">
                                        	<path  fill-rule="evenodd" class="s0" d="m15 8c0 3.8-3.2 7-7 7-3.8 0-7-3.2-7-7 0-3.8 3.2-7 7-7 3.8 0 7 3.2 7 7zm-7.8 3.2l-3.1-3.1 1.1-1.1 2 1.9 3.9-3.6 1.1 1.3z"/>
                                            </svg>'.esc_html($list['lcp_meetup_pricing_list_six']).'</li>';
                                        }
                                        echo '</ul>';
                                        if(!empty($list['lcp_meetup_pricing_btn_title'])){
										 echo '<a href="'.esc_url($list['lcp_meetup_pricing_btn_link']).'" class="lc-btn-style30">'.esc_html($list['lcp_meetup_pricing_btn_title']).'</a>';
										} 
									echo '</div>
								</div>';
								}
							  }
							echo '</div>
						</div>
					</div>
				</div>
			</div>
		</div>
        <!------- pricing Section End ------>';
    }
	   
	}
}