<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Moving_About extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_moving_about';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Moving About', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_moving_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_moving_about_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_about_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_about_tab1',
            [
                'label'       => esc_html__( 'Tab 1', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_about_tab2',
            [
                'label'       => esc_html__( 'Tab 2', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_about_tab3',
            [
                'label'       => esc_html__( 'Tab 3', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_about_button',
            [
                'label'       => esc_html__( 'Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_about_button_url',
            [
                'label'       => esc_html__( 'Button Url', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
	/*	$this->end_controls_section();
		$this->start_controls_section(
            'lcp_moving_about_statics',
            [
                'label' => esc_html__( 'moving Statistics', 'leadcapture' ),
            ] 
        );*/
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_table_active',
            [
                'label'     => esc_html__( 'Table Active', 'leadcapture' ),
                'type'      => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'leadcapture' ),
				'label_off' => esc_html__( 'Hide', 'leadcapture' ),
				'return_value' => 'yes',
				'default' => 'yes',
            ]
        );
        $repeater->add_control(
            'lcp_moving_tab_style',
            [
                'label'   => __( 'Select Tab', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'tab-1',
                'options' => [
                    'tab-1'   => __( 'Tab 1', 'leadcapture' ),
                    'tab-2'   => __( 'Tab 2', 'leadcapture' ),
					'tab-3'   => __( 'Tab 3', 'leadcapture' ),
                ],
            ]
        );
        $repeater->add_control(
            'lcp_moving_statics_list_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        
        
        $this->add_control(
            'lcp_moving_about_statics_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_moving_statics_list_title}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_moving_about_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_moving_about_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_about_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-about-heading-style33 h1'
            ]
        );
        $this->add_control(
            'lcp_moving_about_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-heading-style33 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_moving_about_style_news_heading',
			[
				'label' => esc_html__( 'NewsLetter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_about_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-about-newltr-styl33 h6'
            ]
        );
        $this->add_control(
            'lcp_moving_about_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-newltr-styl33 h6' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_moving_about_style_list', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_moving_about_style_list_heading',
			[
				'label' => esc_html__( 'Number Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_about_style_list_number_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .count-no'
            ]
        );
        $this->add_control(
            'lcp_moving_about_style_list_number_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .count-no' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style 
        $this->add_control(
			'lcp_moving_about_style_list_title',
			[
				'label' => esc_html__( 'Title Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_about_style_list_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-about-info-inner-style33 p'
            ]
        );
        $this->add_control(
            'lcp_moving_about_style_list_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-about-info-inner-style33 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<div class="lc-text-head-style43 lc-about-texthead-style43">';
		if(!empty($settings['lcp_moving_about_heading'])):
		    echo '<h2>'.esc_html($settings['lcp_moving_about_heading']).'</h2>';
		endif;
		if(!empty($settings['lcp_moving_about_description'])):
		    echo '<p>'.esc_html($settings['lcp_moving_about_description']).'</p>';
		endif;
		echo '<div class="lc-about-navbar-style43">
			<ul class="nav nav-tabs" id="myTab" role="tablist">';
		    if(!empty($settings['lcp_moving_about_tab1'])):
			    echo '<li ><a data-bs-toggle="tab" class="active" href="#tab-1" role="tab">'.esc_html($settings['lcp_moving_about_tab1']).'</a></li>';
			endif;
			 if(!empty($settings['lcp_moving_about_tab2'])):
			    echo '<li><a data-bs-toggle="tab" href="#tab-2" role="tab">'.esc_html($settings['lcp_moving_about_tab2']).'</a></li>';
			endif;
			  echo '</ul>
			  <div class="tab-content" id="myTabContent"> ';
				foreach($settings['lcp_moving_about_statics_list'] as $list):
				    if($list['lcp_table_active'] == 'yes'){
                            $active = 'active show';
                        }else{
                            $active = ''; 
                        }
				    if($list['lcp_moving_tab_style'] == 'tab-1'){
                        $tab = 'tab-1';
                    } else if($list['lcp_moving_tab_style'] == 'tab-2'){
                        $tab = 'tab-2';
                    } else {
                        $tab = 'tab-3';
                    } 
				echo '<div class="tab-pane fade '.esc_attr($active).'" id="'.esc_attr($tab).'" role="tabpanel" aria-labelledby="'.esc_attr($tab).'">';
				if(!empty($list['lcp_moving_statics_list_description'])):
					echo '<p>'.esc_html($list['lcp_moving_statics_list_description']).'</p>';
					endif;	
				echo '</div>';
			    endforeach;		
			  	echo '</div>
		</div>';
		if(!empty($list['lcp_moving_about_button'])):
		echo '<div class="lc-btn-style43 lc-aboutbtn-style43">
			<a href="'.esc_url($settings['lcp_moving_about_button_url']).'">'.esc_html($settings['lcp_moving_about_button']).'</a>
		</div>';
		endif;	
	echo '</div>';
	}
	}
}