<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Moving_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_moving_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Moving Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_moving_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_moving_banner_subtitle',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_banner_title1',
            [
                'label'       => esc_html__( 'Heading 1', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_banner_title2',
            [
                'label'       => esc_html__( 'Heading 2', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_banner_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_banner_btn_text',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_banner_btn_url',
            [
                'label'       => esc_html__( 'Button URL', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_banner_newsletter_head',
            [
                'label'       => esc_html__( 'News Letter Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_newsletter_form',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_moving_banner_right_image',
            [
                'label'       => esc_html__( 'Select Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
       
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_moving_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Sub Heading Style
        $this->add_control(
			'lcp_moving_banner_style_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_banner_style_subheading_typography',
                'label'       => esc_html__( 'Sub Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subtitle-style43'
            ]
        );
        $this->add_control(
            'lcp_moving_banner_style_subheading_color',
            [
                'label'     => esc_html__( 'Sub Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subtitle-style43' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_moving_banner_style_heading',
			[
				'label' => esc_html__( 'Heading 1', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style43 h1 span'
            ]
        );
        $this->add_control(
            'lcp_moving_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style43 h1 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading 2 Style
        $this->add_control(
			'lcp_moving_banner_style_heading2',
			[
				'label' => esc_html__( 'Heading 2', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_banner_style_heading2_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style43 h1'
            ]
        );
        $this->add_control(
            'lcp_moving_banner_style_heading2_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style43 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
         // Description Style
        $this->add_control(
			'lcp_moving_banner_style_description',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_banner_style_description_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style43 p'
            ]
        );
        $this->add_control(
            'lcp_moving_banner_style_description_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style43 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button Style
        $this->add_control(
			'lcp_moving_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-aboutbtn-style43 a'
            ]
        );
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_moving_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_moving_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-aboutbtn-style43 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_moving_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-aboutbtn-style43 a' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_moving_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-aboutbtn-style43 a',
            ]
        );
		$this->add_control(
            'lcp_moving_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-aboutbtn-style43 a' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
        
        
        // NewsLetter Heading Style
        $this->add_control(
			'lcp_moving_banner_style_news_heading',
			[
				'label' => esc_html__( 'News Letter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subupdate-form-style43 h2'
            ]
        );
        $this->add_control(
            'lcp_moving_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subupdate-form-style43 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<div class="lc-banner-section-style43">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-lg-6 col-md-12 col-sm-12">
                        <div class="lc-banner-text-style43">';
                        if(!empty($settings['lcp_moving_banner_subtitle'])):
                            echo '<span class="lc-subtitle-style43">'.esc_html($settings['lcp_moving_banner_subtitle']).'</span>';
                        endif;
                        if(!empty($settings['lcp_moving_banner_title1'])):
                            echo '<h1><span>'.esc_html($settings['lcp_moving_banner_title1']).'</span> '.esc_html($settings['lcp_moving_banner_title2']).'</h1>';
                        endif;
                        if(!empty($settings['lcp_moving_banner_description'])): 
                            echo '<p>'.esc_html($settings['lcp_moving_banner_description']).'</p>';
                        endif;
                        if(!empty($settings['lcp_moving_banner_btn_text'])):   
                            echo '<div class="lc-btn-style43 lc-aboutbtn-style43">
                                <a href="'.esc_url($settings['lcp_moving_banner_btn_url']).'">'.esc_html($settings['lcp_moving_banner_btn_text']).'</a>
                            </div>';
                        endif;
                        echo '</div>
                        <div class="lc-subscribe-wrapper-style43">
                            <div class="lc-subupdate-form-style43">';
                            if(!empty($settings['lcp_moving_banner_newsletter_head'])):
                                echo '<h2>'.esc_html($settings['lcp_moving_banner_newsletter_head']).'</h2>';
                            endif; 
                            if(!empty($settings['lcp_moving_newsletter_form'])):
                                echo do_shortcode($settings['lcp_moving_newsletter_form']);
                            endif;
                             echo '</div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="lc-banner-rightimg-style43">';
                            if(!empty($settings['lcp_moving_banner_right_image']['url'])):
                                echo '<img src="'.esc_url($settings['lcp_moving_banner_right_image']['url']).'" alt="'.esc_attr__('left-image', 'leadcapture').'">';
                            endif;  
                        echo '</div>
                    </div>
                </div>
            </div>
        </div>';
	}
	}
}