<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Moving_Blogs extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_moving_blogs';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Moving Blogs', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $categories = get_categories();
		$cats = array();
		foreach( $categories as $terms ){
			$cats[$terms->term_id] = $terms->name;
		}
	    $this->start_controls_section(
            'lcp_moving_blogs_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_moving_blogs_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Our Recent Blogs', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_moving_blogs_post_show',
            [
                'label'       => esc_html__( 'Number of Post', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '3', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_moving_blogs_category',
            [
                'label'   => __( 'Select Categories', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT2,
				'multiple' => true,
                'options' => $cats
            ]
        );
        $this->add_control(
            'lcp_moving_blogs_order_by',
            [
                'label'   => __( 'Order By', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'   => __( 'None', 'leadcapture' ),
                    'id'   => __( 'Id', 'leadcapture' ),					
					'title'   => __( 'Title', 'leadcapture' ),
					'date'   => __( 'Date', 'leadcapture' ),
                ],
            ]
        );
		$this->add_control(
            'lcp_moving_blogs_sort',
            [
                'label'   => __( 'Sort Order', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC'   => __( 'Ascending', 'leadcapture' ),
                    'DESC'   => __( 'Descending', 'leadcapture' ),
                ],
            ]
        );
		$this->end_controls_section();
	
        
        // Widget Style
        $this->start_controls_section(
            'lcp_moving_blogs_style_post', 
            [
                'label' => esc_html__( 'Post Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
         // Heading Style
        $this->add_control(
			'lcp_moving_blogs_style_post_title',
			[
				'label' => esc_html__( 'Blog Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_blogs_style_post_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-textblog-head-style39 h2'
            ]
        );
        $this->add_control(
            'lcp_moving_blogs_style_post_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-textblog-head-style39 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_moving_blogs_style_post_heading',
			[
				'label' => esc_html__( 'Blog Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_blogs_style_post_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blogimg-text-style43 h4'
            ]
        );
        $this->add_control(
            'lcp_moving_blogs_style_post_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blogimg-text-style43 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_moving_blogs_style_post_heading_hcolor',
            [
                'label'     => esc_html__( 'Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blogimg-text-style43 h4:hover .lc-blogimg-text-style43 >h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
         // Heading Style
        $this->add_control(
			'lcp_moving_blogs_style_post_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_moving_blogs_style_post_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blogimg-text-style43 p'
            ]
        );
        $this->add_control(
            'lcp_moving_blogs_style_post_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blogimg-text-style43 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
       
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    if(!empty($settings['lcp_moving_blogs_category'])){
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_moving_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_moving_blogs_sort'],
    				'orderby'         => $settings['lcp_moving_blogs_order_by'],
    				'tax_query' => array(
    				array(
    					'taxonomy'  => 'category',
    					'field'     => 'ID',
    					'terms'     => $settings['lcp_moving_blogs_category'],
    					),
    				),	
    			));
    		} else {
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_moving_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_moving_blogs_sort'],
    				'orderby'         => $settings['lcp_moving_blogs_order_by'],
    			));
    		}
	echo '<div class="lc-blog-section-style39">
		<div class="container">
			<div class="row">
				<div class="col-lg-12">';
				if(!empty($settings['lcp_moving_blogs_heading'])):
					echo '<div class="lc-text-head-style43 lc-textblog-head-style39">
						<h2>'.esc_html($settings['lcp_moving_blogs_heading']).'</h2>
					</div>';
				endif;
				echo '</div>
			</div>
			<div class="row">';
                if($query->have_posts() ):
	                while($query->have_posts()): $query->the_post();
	                    echo '<div class="col-lg-4 col-md-6 col-sm-12">
				   <div class="lc-blog-box-style43">
					<div class="lc-blogimg-style43">
					    '.get_the_post_thumbnail().'
					</div>
					<div class="lc-blogimg-text-style43">
						<div class="lc-blogcomm-style43">
							<span>
								<svg xmlns="http://www.w3.org/2000/svg" width="19" height="15" viewBox="0 0 19 15">
									<path class="cls-1" d="M11.212,10.179a6.731,6.731,0,0,0,2.72-1.987,4.258,4.258,0,0,0,0-5.475A6.734,6.734,0,0,0,11.212.731,9.5,9.5,0,0,0,7.465,0a9.508,9.508,0,0,0-3.748.73A6.735,6.735,0,0,0,1,2.717,4.313,4.313,0,0,0,0,5.455,4.2,4.2,0,0,0,.753,7.841,6.2,6.2,0,0,0,2.821,9.726C2.749,9.9,2.677,10.053,2.6,10.2a2.7,2.7,0,0,1-.266.41q-0.153.2-.238,0.309a4.139,4.139,0,0,1-.276.314q-0.191.2-.244,0.267a0.091,0.091,0,0,0-.042.048,0.133,0.133,0,0,1-.048.054,0.117,0.117,0,0,0-.042.053l-0.037.059-0.027.053a0.242,0.242,0,0,0-.021.064,0.444,0.444,0,0,0-.005.069,0.221,0.221,0,0,0,.01.069,0.356,0.356,0,0,0,.122.224,0.332,0.332,0,0,0,.217.085H1.739A8.588,8.588,0,0,0,2.65,12.1,8.873,8.873,0,0,0,5.6,10.737a10.565,10.565,0,0,0,1.866.171,9.5,9.5,0,0,0,3.748-.729h0Zm-5.932-.89-0.467.33q-0.3.2-.657,0.415L4.528,9.14,3.5,8.544a4.884,4.884,0,0,1-1.58-1.406,2.917,2.917,0,0,1-.562-1.684A3.033,3.033,0,0,1,2.19,3.42a5.678,5.678,0,0,1,2.242-1.5,8.209,8.209,0,0,1,3.032-.554,8.211,8.211,0,0,1,3.032.554,5.682,5.682,0,0,1,2.242,1.5,3.033,3.033,0,0,1,.833,2.034,3.033,3.033,0,0,1-.833,2.034,5.679,5.679,0,0,1-2.242,1.5,8.228,8.228,0,0,1-3.032.553A9.2,9.2,0,0,1,5.842,9.4Zm0,0,12.967,1.283A4.174,4.174,0,0,0,18.2,5.731a6.289,6.289,0,0,0-2.163-1.9,5.5,5.5,0,0,1-.466,4.325,7.117,7.117,0,0,1-2.036,2.258,9.378,9.378,0,0,1-2.8,1.374,11.163,11.163,0,0,1-3.276.479q-0.317,0-.933-0.042a8.88,8.88,0,0,0,5,1.406,10.573,10.573,0,0,0,1.866-.171,8.876,8.876,0,0,0,2.947,1.364,8.923,8.923,0,0,0,.912.171,0.321,0.321,0,0,0,.233-0.075,0.393,0.393,0,0,0,.138-0.234,0.075,0.075,0,0,1,.011-0.069c0.01,0,.008-0.027-0.005-0.069l-0.022-.064-0.026-.054a0.485,0.485,0,0,0-.038-0.057,0.448,0.448,0,0,0-.042-0.054c-0.01-.01-0.026-0.028-0.048-0.053s-0.035-.042-0.042-0.048q-0.053-.064-0.244-0.266a4.1,4.1,0,0,1-.276-0.315q-0.085-.111-0.238-0.308a2.7,2.7,0,0,1-.265-0.411q-0.111-.212-0.217-0.468a6.242,6.242,0,0,0,2.067-1.881h0Zm0,0"/>
								</svg>
							</span>
							<p>'.esc_html(get_comments_number()).' '.esc_html__('comments', 'leadcapture').'</p>
						</div>
						<h4>'. substr(get_the_title(),0,100).'</h4>
						<p>'. substr(get_the_excerpt(),0,147).'</p>
					</div>
				   </div>
				</div>';
                endwhile;
                wp_reset_query();
            endif;
            echo '</div>
		</div>
	</div>';
		}
	}
}