<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Moving_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_moving_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Moving Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_moving_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_moving_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( 'The Best Global Moving', 'leadcapture' ),
                'label_block' => true,
            ]
        );
        //$this->end_controls_section();
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_moving_image',
            [
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_moving_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_moving_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Praesent tincidunt lorem vel augue mollis, sed ultrices dui pretium.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_moving_button',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_moving_btn_url',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        $this->add_control(
            'lcp_moving_services_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'label'       => esc_html__( 'Add Services', 'leadcapture' ),
                        'lcp_moving_heading'  => esc_html__( 'Services', 'leadcapture' ),
						'lcp_moving_description'  => esc_html__( 'Praesent tincidunt lorem vel augue mollis, sed ultrices dui pretium.', 'leadcapture' ),
						'lcp_moving_button'  => esc_html__( 'Read More', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_moving_heading}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
		$this->start_controls_section(
            'leadcapture_ab_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'leadcapture_ab_style_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_title_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-textsolution-head-style43 h2'
            ]
        );
        $this->add_control(
            'leadcapture_ab_titlecolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-textsolution-head-style43 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'leadcapture_ab_style_heading',
			[
				'label' => esc_html__( 'Service Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_heading_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-sol-boxtext-style43 h3'
            ]
        );
        $this->add_control(
            'leadcapture_ab_heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-sol-boxtext-style43 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Description Style
        $this->add_control(
			'heading_control',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-sol-boxtext-style43 p',
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-sol-boxtext-style43 p' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        // Button Style
        $this->add_control(
			'heading_servies_link_control',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_servies_link_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-solution-box-style43 a',
            ]
        );
        $this->add_control(
            'leadcapture_ab_servies_link_color',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-solution-box-style43 a' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        $this->add_control(
            'leadcapture_ab_servies_btn_bg_color',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-solution-box-style43 a' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_servies_hover_link_color',
            [
                'label'     => esc_html__( 'Hover Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-solution-box-style43 a:hover' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        $this->add_control(
            'leadcapture_ab_servies_hover_btn_bg_color',
            [
                'label'     => esc_html__( 'Hover Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-solution-box-style43 a:hover' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
		$this->end_controls_section();
        // Services Link style
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
		if(!empty($settings)):
		 echo '<div class="lc-solution-section-style43">
			<div class="container">
				<div class="row">
					<div class="col-lg-12">';
					if(!empty($settings['lcp_moving_banner_title'])):
						echo '<div class="lc-text-head-style43 lc-textsolution-head-style43">
							<h2>'.esc_html($settings['lcp_moving_banner_title']).'</h2>
						</div>';
					endif;	
					echo '</div>
				</div>
				<div class="row">';
				foreach($settings['lcp_moving_services_list'] as $serv):
					echo '<div class="col-lg-4 col-md-6 col-sm-6">
						<div class="lc-solution-box-style43">';
                            if(!empty($serv['lcp_moving_image']['url'])):
                                echo '<div class="lc-solicon-style43">
                                    <img src="'.esc_html($serv['lcp_moving_image']['url']).'" alt="'.esc_attr__('service', 'leadcapture').'">
                                </div>';
                            endif;
							echo '<div class="lc-sol-boxtext-style43">';
							    if(!empty($serv['lcp_moving_heading'])):
                                    echo '<h3>'.esc_html($serv['lcp_moving_heading']).'</h3>';
                                endif; 
                                if(!empty($serv['lcp_moving_description'])):
                                    echo '<p>'.esc_html($serv['lcp_moving_description']).'</p>';
                                endif;
							echo '</div>';
							if(!empty($serv['lcp_moving_button'])):
								 echo '<a href="'.esc_url($serv['lcp_moving_btn_url']).'">'.esc_html($serv['lcp_moving_button']).'</a>';
							endif;
						echo '</div>
					</div>';
				endforeach;	
				echo'</div>
			</div>
		</div>';
		endif;
    }
}