<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Painter_Blogs extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_painter_blogs';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Painter Blogs', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $categories = get_categories();
		$cats = array();
		foreach( $categories as $terms ){
			$cats[$terms->term_id] = $terms->name;
		}
	    $this->start_controls_section(
            'lcp_Painter_blogs_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_painter_blogs_post_show',
            [
                'label'       => esc_html__( 'Number of Post', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '3', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_painter_blogs_category',
            [
                'label'   => __( 'Select Categories', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT2,
				'multiple' => true,
                'options' => $cats
            ]
        );
        $this->add_control(
            'lcp_painter_blogs_order_by',
            [
                'label'   => __( 'Order By', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'   => __( 'None', 'leadcapture' ),
                    'id'   => __( 'Id', 'leadcapture' ),					
					'title'   => __( 'Title', 'leadcapture' ),
					'date'   => __( 'Date', 'leadcapture' ),
                ],
            ]
        );
		$this->add_control(
            'lcp_painter_blogs_sort',
            [
                'label'   => __( 'Sort Order', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC'   => __( 'Ascending', 'leadcapture' ),
                    'DESC'   => __( 'Descending', 'leadcapture' ),
                ],
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_painter_blogs_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_painter_blogs_style_sheading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_painter_blogs_style_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style42 h4'
            ]
        );
        $this->add_control(
            'lcp_painter_blogs_style_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style42 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_painter_blogs_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_painter_blogs_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style42 p'
            ]
        );
        $this->add_control(
            'lcp_painter_blogs_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style42 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button Style
        $this->add_control(
			'lcp_painter_blogs_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_painter_blogs_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style42 a'
            ]
        );
        $this->add_control(
            'lcp_painter_blogs_style_button_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style42 a' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Date Style
        $this->add_control(
			'lcp_painter_blogs_style_date',
			[
				'label' => esc_html__( 'Date', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_painter_blogs_style_date_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text-style42 h6'
            ]
        );
        $this->add_control(
            'lcp_painter_blogs_style_date_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text-style42 h6' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    if(!empty($settings['lcp_painter_blogs_category'])){
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_painter_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_painter_blogs_sort'],
    				'orderby'         => $settings['lcp_painter_blogs_order_by'],
    				'tax_query' => array(
    				array(
    					'taxonomy'  => 'category',
    					'field'     => 'ID',
    					'terms'     => $settings['lcp_painter_blogs_category'],
    					),
    				),	
    			));
    		} else {
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_painter_blogs_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_painter_blogs_sort'],
    				'orderby'         => $settings['lcp_painter_blogs_order_by'],
    			));
    		}
		echo '<!-- blog section start -->
		<div class="lc-blog-wrapper-style42">
			<div class="container">
				<div class="row gy-4 justify-content-center">';
                if($query->have_posts() ):
	                while($query->have_posts()): $query->the_post();
	                    echo '<div class="col-lg-4 col-md-6">
						<div class="lc-blog-parent-style42">
            				   <div class="lc-blog-img-style42">
            				   '.get_the_post_thumbnail().'
						        </div>
                                <div class="lc-blog-text-style42">
								<h6>'.get_the_date().'</h6>
								<h4>'. substr(get_the_title(),0,100).'</h4>
								<p>'. substr(get_the_excerpt(),0,147).'</p>
								<a href="'.esc_url(get_the_permalink()).'">'.esc_html('read more', 'leadcapture').'</a>
							</div>
						</div>
					  </div>';
	                endwhile;
                    wp_reset_query();
                endif;
                echo '</div>
			</div>
		</div>
		<!-- blog section end -->';
		}
	}
}