<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pestcontrol_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_pestcontrol_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pestcontrol Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'leadcapture_ab_logo_image',
            [
				'label'       => esc_html__( 'Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
		$this->add_control(
            'leadcapture_ab_sub_head',
            [
                'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'leadcapture_ab_main_head',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'About Our Salon', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_ab_main_spanhead',
            [
                'label'       => esc_html__( 'Span Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_ab_newsletter_head',
            [
                'label'       => esc_html__( 'News Letter Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'leadcapture_ab_newsletter_id',
            [
                'label'       => esc_html__( 'News Letter Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
		$this->add_control(
            'leadcapture_ab_left_image',
            [
				'label'       => esc_html__( 'Left Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_ab_right_image',
            [
				'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_ab_phone_image',
            [
				'label'       => esc_html__( 'Phone Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_ab_phone_heading',
            [
				'label'       => esc_html__( 'Phone Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_ab_phone_number',
            [
				'label'       => esc_html__( 'Phone Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,	
			]
        );
		$this->add_control(
            'leadcapture_ab_years_number',
            [
				'label'       => esc_html__( 'Years Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_ab_years_heading',
            [
				'label'       => esc_html__( 'Years heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,	
			]
        );
	    $this->add_control(
            'leadcapture_ab_field_image',
            [
				'label'       => esc_html__( 'Field Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,	
			]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_ab_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_ab_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ab_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style6 h1'
            ]
        );
        $this->add_control(
            'lcp_ab_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style6 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Sub Heading Style
        $this->add_control(
			'lcp_ab_banner_style_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ab_style_subheading_typography',
                'label'       => esc_html__( 'Sub Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style6 h2'
            ]
        );
        $this->add_control(
            'lcp_ab_style_subheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style6 h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // NewsLetter Style
        $this->add_control(
			'lcp_ab_style_news_heading',
			[
				'label' => esc_html__( 'NewsLetter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_ab_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style6 p'
            ]
        );
        $this->add_control(
            'lcp_ab_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style6 p' => 'color: {{VALUE}};',
                ],
            ]
        );
         // NewsLetter Style
        $this->add_control(
			'lcp_ab_style_news_additional',
			[
				'label' => esc_html__( 'Additional Option', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_additional_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-text-typography'
            ]
        );
        $this->add_control(
            'lcp_additional_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-text-color' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '		<!------- Header-Section-Start ------>
        <div class="lc-header-wrapper lc-header-wrapper-style6">
            <div class="container-fluid">
                <div class="lc-header-section lc-header-section-style6">';
                if(!empty($settings['leadcapture_ab_logo_image']['url'])):
                    echo '<div class="lc-logo-img lc-logo-img-style6">
                        <div class="lc-blog-img-style40">
                            <img src="'.esc_url($settings['leadcapture_ab_logo_image']['url']).'" alt="'.esc_attr('blog-image', 'leadcapture').'">
                        </div>
                    </div>';
                endif;
                echo '<div class="lc-banner-section lc-banner-section-style6">
                    <div class="row">
                        <div class="col-lg-5">
                            <div class="lc-banner-img-wrapper lc-banner-img-style6 pulse wow" data-wow-delay="200ms"
                                data-wow-duration="1000ms"
                                style="visibility: visible; animation-duration: 1000ms; animation-delay: 200ms; animation-name: pulse;">';
                                if(!empty($settings['leadcapture_ab_left_image']['url'])):
                                    echo '<img src="'.esc_url($settings['leadcapture_ab_left_image']['url']).'" alt="'.esc_attr('left-image', 'leadcapture').'">';
                                endif;
                                echo '<div class="lc-box-wrapper">';
                                    if(!empty($settings['leadcapture_ab_phone_heading'])):
                                        echo '<div class="lc-call-box">';
                                        if(!empty($settings['leadcapture_ab_phone_image']['url'])):
                                        echo '<span>
                                             <img src="'.esc_url($settings['leadcapture_ab_phone_image']['url']).'" alt="'.esc_attr('phone-image', 'leadcapture').'">
                                        </span>';
                                        endif;
                                        echo '<div class="lc-call-text">
                                        <span class="lc-text-typography">'.esc_html($settings['leadcapture_ab_phone_heading']).'</span>';
                                            if(!empty($settings['leadcapture_ab_phone_number'])):
                                            echo '<p class="lc-text-color">'.esc_html($settings['leadcapture_ab_phone_number']).'</p>';
                                            endif; 
                                        echo '</div>
                                        </div>';
                                    endif; 
                                    if(!empty($settings['leadcapture_ab_years_heading'])):
                                    echo '<div class="lc-year-box">';
                                            if(!empty($settings['leadcapture_ab_years_number'])):
                                            echo '<h3 class="lc-text-color">'.esc_html($settings['leadcapture_ab_years_number']).'</h3>';
                                        endif;   
                                        echo '<p class="lc-text-typography">'.esc_html($settings['leadcapture_ab_years_heading']).'</p>
                                    </div>';
                                    endif; 
                                echo '</div>
                            </div>
                        </div>
                        <div class="col-lg-7">
                            <div class="lc-bannner-expert-wrapper">
                                <div class="lc-banner-text lc-banner-text-style6">';
                                    if(!empty($settings['leadcapture_ab_sub_head'])):
                                    echo '<h2>'.esc_html($settings['leadcapture_ab_sub_head']).'</h2>';
                                    endif;
                                    if(!empty($settings['leadcapture_ab_main_head']|| $settings['leadcapture_ab_main_spanhead'])):
                                       echo '<h1>'.esc_html($settings['leadcapture_ab_main_head']).'<span>'.esc_html($settings['leadcapture_ab_main_spanhead']).'</span></h1>';
                                    endif;  
                                    
                                    if(!empty($settings['leadcapture_ab_newsletter_head'])):
                                    echo '<p>'.esc_html($settings['leadcapture_ab_newsletter_head']).'</p>';
                                    endif;  
                                    if(!empty($settings['leadcapture_ab_newsletter_id'])):
                                        echo do_shortcode($settings['leadcapture_ab_newsletter_id']);
                                    endif;     
                                    if(!empty($settings['leadcapture_ab_field_image']['url'])):
                                        echo '<div class="lc-banner-expertimg">
                                        <img src="'.esc_url($settings['leadcapture_ab_field_image']['url']).'" alt="'.esc_attr('expert-image', 'leadcapture').'">
                                        </div>';
                                    endif; 
                                echo '</div>
                                <div class="lc-banner-expertimg">
                                <div class="lc-banner-manimg backInRight wow" data-wow-delay="200ms" data-wow-duration="1000ms"
                                style="visibility: visible; animation-duration: 1000ms; animation-delay: 200ms; animation-name: backInRight;">';
                                    if(!empty($settings['leadcapture_ab_right_image']['url'])):
                                       echo '<img src="'.esc_url($settings['leadcapture_ab_right_image']['url']).'" alt="'.esc_attr('expert-image', 'leadcapture').'">';
                                    endif;   
                                 echo '</div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!------- Header-Section-End ------>';
	}
}