<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pest_Control_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_pest_control_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pest Control Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_desc',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_description_typogyraphy',
            'selector' => '{{WRAPPER}} .lps-desc-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_description_color',
        	[
        	'label' => esc_html__('Description Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-description-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Auther Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_auther_typogyraphy',
            'selector' => '{{WRAPPER}} .lps-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_auther_color',
        	[
        	'label' => esc_html__('Auther Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_designation_typogyraphy',
            'selector' => '{{WRAPPER}} .lps-designation-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_designation_color',
        	[
        	'label' => esc_html__('Designation Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-designation-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<!------- Testimonial-Section-Start ------>
        <div class="lc-testimonial-wrapper lc-testimonial-style6">
            <div class="container">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="lc-testimonial-slider-wrapper fadeInDown wow" data-wow-delay="200ms"
                            data-wow-duration="1000ms"
                            style="visibility: visible; animation-duration: 1000ms; animation-delay: 200ms; animation-name: fadeInDown;">
                            <div class="swiper lc-testimonial-slider-style6">
                                <div class="swiper-wrapper">';
            					if(!empty($settings['leadcapture_testimonial_list'])):
                                    foreach($settings['leadcapture_testimonial_list'] as $testi):
            						echo '<div class="swiper-slide">
                                        <div class="lc-test-box lc-test-box-style6">
                                            <div class="lc-test-para lc-test-para-style6">';
                                                if($testi['leadcapture_testimonial_desc']):
                                                    echo '<p class="lps-desc-typography add-description-colors">'.esc_html($testi['leadcapture_testimonial_desc']).'</p>';
                                                endif;
                                            echo '</div>
                                            <div class="lc-test-img lc-test-img-style6">';
                                                if(!empty($testi['leadcapture_testimonial_image']['url'])):
                                                    echo '<img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'">';
                                                endif;
                                                echo '<div class="lc-test-name lc-test-name-style6">';
                                                if($testi['leadcapture_testimonial_author']):
                                                   echo '<h4 class="lps-typography add-author-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h4>';
                                                endif;
                                                if($testi['leadcapture_testimonial_dest']):
                                                   echo '<p class="lps-designation-typography add-designation-colors">'.esc_html($testi['leadcapture_testimonial_dest']).'</p>';
                                                endif;
                                                 echo '</div>
                                            </div>
                                            <div class="lc-test-quote-icon lc-test-quote-icon-style6">
                                                <svg version="1.2" xmlns="http://www.w3.org/2000/svg"
                                                    viewBox="0 0 54 48" width="54" height="48">
                                                    <title>Quote Icon</title>
                                                    <g id="Quote Icon">
                                                        <path id="Shape 849" class="s0"
                                                            d="m44.4 1.9c-0.3 0.7-0.6 1.3-1 2-2.2 3.9-4.3 7.8-5.6 12.1-0.7 1.9-1.1 3.9-1.7 5.9 1.7-0.2 3.1-0.4 4.6-0.4 6.1 0.2 11.1 5.5 11.2 11.8 0.2 6.3-4.6 11.8-10.7 12.3-7.1 0.6-13-4.7-13.1-12 0-8 1.5-15.6 5.7-22.5 2.5-4 6-6.7 9.8-9.2 0.2-0.1 0.4-0.1 0.6-0.2q0.1 0.1 0.2 0.2zm-26.1 0c-3.6 6.3-7.1 12.7-8.3 20.2 2.1-0.7 4.1-0.8 6.2-0.4 5.7 1.1 9.8 6.5 9.5 12.5-0.3 6-5 11-10.8 11.4-7 0.6-12.9-4.7-13-11.9 0-8.1 1.5-15.7 5.8-22.6 2.4-4 5.9-6.7 9.6-9.1 0.2-0.2 0.5-0.2 0.7-0.3q0.2 0.1 0.3 0.2z" />
                                                    </g>
                                                </svg>
                                            </div>
                                        </div>
                                    </div>';
            					    endforeach;
            					endif; 
            					echo '</div>
                                <div class="swiper-pagination"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!------- Testimonial-Section-End ------>';
  }
}