<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pet_Shop_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_pet_shop_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pet Shop Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_pet_shop',
            [
            'label' => esc_html__('Pet Shop Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'leadcapture_petshop_logo',
            [
			'label' => esc_html__('Pet Shop Logo', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_petshop_subhead',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_petshop_head',
            [
            'label' => esc_html__('Pet Shop Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_petshop_desc',
            [
            'label' => esc_html__('Pet Shop Description', 'leadcapture'),
            'type'  => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_newsletter_head',
            [
            'label' => esc_html__('Form Heading 1', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_newsletter_headtwo',
            [
            'label' => esc_html__('Form Heading 2', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_petshop_form_shortcode',
            [
            'label' => esc_html__('Form Shortcode', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_petshop_girl_image',
            [
			'label' => esc_html__('girl Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_petshop_dog_image',
            [
			'label' => esc_html__('Man Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_followers_img',
            [
			'label' => esc_html__('Followers Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_followers_heading',
            [
            'label' => esc_html__('Followers Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_followers_number',
            [
            'label' => esc_html__('Followers Number', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_followers_idname',
            [
            'label' => esc_html__('Followers Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        
        $this->add_control(
            'leadcapture_followers_image_two',
            [
			'label' => esc_html__('Followers Star Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_followers_two',
            [
            'label' => esc_html__('Followers 2 Name ', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_followers_designation',
            [
            'label' => esc_html__('Followers Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_support_image',
            [
			'label' => esc_html__('Support Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
         $this->add_control(
            'leadcapture_support_name',
            [
			'label' => esc_html__('Support Name', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_support_service',
            [
			'label' => esc_html__('Support Service', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_dog_image',
            [
			'label' => esc_html__('Dog Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
    
        $repeater = new Repeater();
       
        
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
        	'lps_heading_style_tab',
        	[
        	'label' => esc_html__('Style Tab', 'leadcapture'),
        	'tab'   => Controls_Manager::TAB_STYLE,
        	]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
        	'name'     => 'lps_heading_typography_car',
        	'selector' => '{{WRAPPER}} .lc-logo-style31 > h4',
        	]
        );
        $this->add_control(
        	'lps_subheading_color',
        	[
        	'label' => esc_html__('Sub Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-logo-style31 > h4' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Heading Typography', 'leadcapture'),
        	'name'     => 'lps_heading_typography',
        	'selector' => '{{WRAPPER}} .lc-banner-heading-style31 > h1',
        	]
        );
        $this->add_control(
        	'lps_heading_text_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-banner-heading-style31 > h1' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Description Typography', 'leadcapture'),
        	'name'     => 'lps_description_typography',
        	'selector' => '{{WRAPPER}} .lc-banner-heading-style31 > p',
        	]
        );
        $this->add_control(
        	'lps_heading_desc_color',
        	[
        	'label' => esc_html__('Description Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-banner-heading-style31 > p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->end_controls_section();
    }
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
	    $settings = $this->get_settings_for_display();
	    echo '	<!-- banner section start -->
		<div class="lc-banner-wrapper-style31">
			<div class="container-fluid">
				<div class="row gy-4 align-items-center">
					<div class="col-xl-5 col-lg-12">
						<div class="lc-logo-style31">';
						if(!empty($settings['leadcapture_petshop_logo']['url'])):
							echo '<a href="javascript:;">
								<img src="'.esc_url($settings['leadcapture_petshop_logo']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
							</a>';
					    endif;
					    if(!empty($settings['leadcapture_petshop_subhead'])):
					        echo '<h4>'.esc_html($settings['leadcapture_petshop_subhead']).'</h4>';
					    endif;    
						echo '</div>
						<div class="lc-banner-heading-style31">';
						if(!empty($settings['leadcapture_petshop_head'])):
					        echo '<h1>'.esc_html($settings['leadcapture_petshop_head']).'</h1>';
					    endif;  
					    if(!empty($settings['leadcapture_petshop_desc'])):
					        echo '<p>'.esc_html($settings['leadcapture_petshop_desc']).'</p>';
					    endif;
						echo '</div>
						<div class="lc-banner-subscribe-box-style31">';
						if(!empty($settings['leadcapture_newsletter_head'])):
							echo '<h4>'.esc_html($settings['leadcapture_newsletter_head']).'<span>'.esc_html($settings['leadcapture_newsletter_headtwo']).'</span></h4>';
						endif;
						if(!empty($settings['leadcapture_petshop_form_shortcode'])):
                            echo do_shortcode($settings['leadcapture_petshop_form_shortcode']);
                        endif;
							echo '<span class="lc-newlt-shape-style31 firstshape31"></span>
							<span class="lc-newlt-shape-style31 secondshape31"></span>
							<span class="lc-newlt-shape-style31 thirdshape31"></span>
						</div>
						
					</div>
					<div class="col-xl-7 col-lg-12">
						<div class="lc-banner-right-style-31">';
						if(!empty($settings['leadcapture_petshop_girl_image']['url'])):
    						echo '<div class="lc-banner-main-img">
    						    <img src="'.esc_url($settings['leadcapture_petshop_girl_image']['url']).'" alt="'.esc_attr__('Gril','leadcapture').'">
    						</div>';
						endif;
							if(!empty($settings['leadcapture_followers_heading'])):
							echo '<div class="lc-banner-follow-style31">
								<h6>';
								if(!empty($settings['leadcapture_followers_img']['url'])):
								echo '<img src="'.esc_url($settings['leadcapture_followers_img']['url']).'" alt="'.esc_attr__('followers','leadcapture').'">';
								endif;
								echo '<p>'.esc_html($settings['leadcapture_followers_heading']).'</p>
							    </h6>';
							    if(!empty($settings['leadcapture_followers_number'])):
								echo '<h4>'.esc_html($settings['leadcapture_followers_number']).'</h4>';
								endif;
								if(!empty($settings['leadcapture_followers_idname'])):
								  echo '<p>'.esc_html($settings['leadcapture_followers_idname']).'</p>';
								endif;
								echo '<ul>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>								
									<li>5.0</li>								
								</ul>
							</div>';
							endif;
							if(!empty($settings['leadcapture_petshop_dog_image']['url'])):
							    echo '<div class="lc-banner-men-dog-img">
								<img src="'.esc_url($settings['leadcapture_petshop_dog_image']['url']).'" alt="'.esc_attr__('followers','leadcapture').'">
							</div>';
							endif;
						echo '</div>
						<div class="lc-banner-star-style31">
								<div class="lc-banner-star-img-style31">';
								if(!empty($settings['leadcapture_followers_image_two']['url'])):
								echo '<img src="'.esc_url($settings['leadcapture_followers_image_two']['url']).'" alt="'.esc_attr__('star','leadcapture').'">';
								endif;
								echo '</div>';
								if(!empty($settings['leadcapture_followers_two'])):
								echo '<div class="lc-banner-star-content-style31">
									<h4>'.esc_html($settings['leadcapture_followers_two']).'</h4>
									<p>'.esc_html($settings['leadcapture_followers_designation']).'</p>
									<ul>
										<li><i class="fa fa-star"></i></li>
										<li><i class="fa fa-star"></i></li>
										<li><i class="fa fa-star"></i></li>
										<li><i class="fa fa-star"></i></li>
										<li><i class="fa fa-star"></i></li>
										<li>4.0</li>								
									</ul>
								</div>';
							    endif;	
							echo '</div>';
							if(!empty($settings['leadcapture_support_name'])):
							echo '<div class="lc-banner-comment-style31">';
								if(!empty($settings['leadcapture_support_image']['url'])):
								    echo '<div class="lc-banner-comment-img-style31">
									    <img src="'.esc_url($settings['leadcapture_support_image']['url']).'" alt="'.esc_attr__('Support-image','leadcapture').'">
								    </div>';
								endif;
								if(!empty($settings['leadcapture_support_name'])):
								echo '<div class="lc-banner-comment-content-style31">
									<h4>'.esc_html($settings['leadcapture_support_name']).'</h4>';
									if(!empty($settings['leadcapture_support_service'])):
									echo '<p>'.esc_html($settings['leadcapture_support_service']).'</p>';
									endif;
								echo '</div>';
								endif;
							echo '</div>';
							endif;
							if(!empty($settings['leadcapture_dog_image']['url'])):
							echo '<div class="lc-banner-small-dog-img">
								<img src="'.esc_url($settings['leadcapture_dog_image']['url']).'" alt="'.esc_attr__('dog','leadcapture').'">
							</div>';
							endif;
						echo '</div>
					</div>
				</div>
			</div>
		<!-- banner section end -->';
	}
}