<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;
use Elementor\Global_Colors;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pet_Shop_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_pet_shop_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pet Shop Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_pet_shop',
            [
            'label' => esc_html__('Pet Shop Services', 'leadcapture'),
            ] 
        );
        $this->add_control(
            'leadcapture_pet_shop_image',
            [
			'label' => esc_html__('Select Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $this->add_control(
            'lcp_pet_shop_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_pet_shop_services_desc',
            [
                'label'       => esc_html__( 'Decription', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
         $this->add_control(
            'lcp_pet_shop_btn',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
       $this->add_control(
            'lcp_pet_shop_btn_url',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
	     $repeater = new Repeater();
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_one_style_tab',
            [
            'label' => esc_html__( 'Style Services', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Heading Typography', 'leadcapture'),
        	'name'     => 'lps_heading_typography',
        	'selector' => '{{WRAPPER}} .lps-heading-typography > h4',
        	]
        );
        $this->add_control(
        	'lps_service_head_color',
        	[
        	'label' => esc_html__('Heading Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-service-content-style31 > h4' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Description Typography', 'leadcapture'),
        	'name'     => 'lps_description_typography',
        	'selector' => '{{WRAPPER}} .lc-service-content-style31 > p',
        	]
        );
        $this->add_control(
        	'lps_service_desc_color',
        	[
        	'label' => esc_html__('Description Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-service-content-style31 > p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Button Typography', 'leadcapture'),
        	'name'     => 'lps_button_typography',
        	'selector' => '{{WRAPPER}} .lps-pet-btn-typography',
        	]
        );
        $this->add_control(
        	'lps_service_btn_color',
        	[
        	'label' => esc_html__('Button Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-service-content-style31 > a' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_service_btn_icon_color',
        	[
        	'label' => esc_html__('Button Icon Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}}  .lc-service-content-style31 a span svg' => 'fill: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_service_border_color',
        	[
        	'label' => esc_html__('Bottom Border Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-service-box-style31' => 'border-bottom:2px solid {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_service_box_shadow_color',
        	[
        	'label' => esc_html__('Icon Box Shadow Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-service-icon-style31' => 'box-shadow:0px 0px 0px 15px {{VALUE}}',
        	 ],
           ]
        );
       
       	$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<div class="col-lg-12 col-md-6">
        	<div class="lc-service-box-style31">';
        		if(!empty($settings['leadcapture_pet_shop_image']['url'])):
        			echo '<div class="lc-service-icon-style31">
        			 <img src="'.esc_url($settings['leadcapture_pet_shop_image']['url']).'" alt="'.esc_attr__('about-image','leadcapture').'">
        		</div>';
        		endif;
        		echo '<div class="lc-service-content-style31 lps-heading-typography">';
        		if(!empty($settings['lcp_pet_shop_title'])):
        			echo '<h4>'.esc_html($settings['lcp_pet_shop_title']).'</h4>';
        	    endif;
                if(!empty($settings['lcp_pet_shop_services_desc'])):
                    echo '<p>'.esc_html($settings['lcp_pet_shop_services_desc']).'</p>';
                endif;
                if(!empty($settings['lcp_pet_shop_btn'])):
        		echo '<a href="'.esc_url($settings['lcp_pet_shop_btn_url']).'" class="lps-pet-btn-typography">'.esc_html($settings['lcp_pet_shop_btn']).'<span>
        				<svg version="1.2" viewBox="0 0 16 15" width="16" height="15">																		
        					<path id="icon" d="m7.8 8.2l-5.3 5.7q-0.1 0.1-0.2 0.1-0.1 0-0.2-0.1l-0.5-0.5q-0.1-0.1-0.1-0.2 0-0.2 0.1-0.3l4.6-4.9-4.6-5q-0.1-0.1-0.1-0.2 0-0.1 0.1-0.2l0.5-0.6c0.1-0.1 0.3-0.1 0.4 0l5.3 5.8c0.2 0.1 0.2 0.3 0 0.4z"/>
        					<path id="icon copy 2" d="m14.3 8.2l-5.4 5.7q-0.1 0.1-0.2 0.1-0.1 0-0.2-0.1l-0.5-0.5q-0.1-0.1-0.1-0.2 0-0.2 0.1-0.3l4.6-4.9-4.6-5q-0.1-0.1-0.1-0.2 0-0.1 0.1-0.2l0.5-0.6c0.1-0.1 0.3-0.1 0.4 0l5.4 5.8c0.1 0.1 0.1 0.3 0 0.4z"/>
        				</svg></span></a>';
        		endif;		
        		echo '</div>
        	</div>
        </div>';
		
	}
}