<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pet_Shop_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_Pet_Shop_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pet Shop Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
        	'lps_testi_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'What Clients Say About Us', 'leadcapture'),
            ]
        );
        $this->add_control(
        	'lps_testi_sub_heading',
            [
                'label'       => esc_html__( 'Sub Heading', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Testimonial', 'leadcapture'),
            ]
        );
        $this->add_control(
        	'lps_testi_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture'),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Get latest news in your inbox.', 'leadcapture'),
            ]
        );
		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_desc',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_testimonial_qoute',
            [
			'label'       => esc_html__( 'Qoute Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
		/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_one_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_one_heading_typography',
            'selector' => '{{WRAPPER}} .lps-heading-fontstyle',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_heading_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-heading-style31' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_sub_heading_typography',
            'selector' => '{{WRAPPER}} .lps-sub-heading-fontstyle',
            ]
        );
        	$this->add_control(
        	'lps_cons_testi_sub_heading_color',
        	[
        	'label' => esc_html__('Sub Heading Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-subheading-style31' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_heading_des_typography',
            'selector' => '{{WRAPPER}} .lc-testmnl-heading-style31 > p',
            ]
        );
        	$this->add_control(
        	'lps_cons_testi_description_color',
        	[
        	'label' => esc_html__('Description Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testmnl-heading-style31 > p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_control(
        	'lps_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Name Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Name Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_desc_typography',
            'selector' => '{{WRAPPER}} .lps-meetup-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_description_typography',
            'selector' => '{{WRAPPER}} .lps-petshop-desc-typography',
            ]
        );
		
		$this->add_control(
        	'lps_testi_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-description-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cons_testi_pagination_color',
        	[
        	'label' => esc_html__('Testimonial Pagination Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testimonial-nav-style31 swiper-button-next' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<!-- testimonial section start -->
		<div class="lc-testimonial-wrapper-style31">
			<div class="container">
				<div class="row">
					<div class="col-lg-4">
						<div class="lc-testmnl-heading-style31">';
    						if(!empty($settings['lps_testi_sub_heading'])):
    							echo '<h4 class="lc-subheading-style31 lps-sub-heading-fontstyle">'.esc_html($settings['lps_testi_sub_heading']).'</h4>';
    						endif;
							if(!empty($settings['lps_testi_heading'])):
							    echo '<h1 class="lc-heading-style31 lps-heading-fontstyle">'.esc_html($settings['lps_testi_heading']).'</h1>';
							endif;
							if(!empty($settings['lps_testi_description'])):
							    echo '<p>'.esc_html($settings['lps_testi_description']).'</p>';
							endif;
						echo '</div>
						<div class="lc-testimonial-nav-style31">
							<div class="swiper-button-next"></div>
							<div class="swiper-button-prev"></div>
						</div>
					</div>
					<div class="col-lg-8">
						<div class="swiper lc-test-slider-parent-style31">
							<div class="swiper-wrapper">';
                                if(!empty($settings['leadcapture_testimonial_list'])):
                                foreach($settings['leadcapture_testimonial_list'] as $testi):
                                echo '<div class="swiper-slide">
									<div class="lc-testimonial-slider-box-style31">';
    									if(!empty($testi['leadcapture_testimonial_image']['url'])):  
    										 echo '<div class="lc-testimonial-slider-img-style31">
    										<img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">';
    									endif; 
									echo '</div>
										<div class="lc-testimonial-slider-content-style31">';
											if($testi['leadcapture_testimonial_author']):
												echo '<h4 class="lps-meetup-typography add-author-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h4>';
											endif;
											echo '<ul>
												<li><i class="fa fa-star"></i></li>
												<li><i class="fa fa-star"></i></li>
												<li><i class="fa fa-star"></i></li>
												<li><i class="fa fa-star"></i></li>
												<li><i class="fa fa-star"></i></li>								
											</ul>';
												if($testi['leadcapture_testimonial_desc']):
													echo '<p class="lps-petshop-desc-typography add-description-colors">'.esc_html($testi['leadcapture_testimonial_desc']).'</p>';
												endif;	
											echo '
										</div>';
										if($testi['leadcapture_testimonial_qoute']['url']):
										echo '<div class="lc-testimonial-qoute-style31">
											<img src="'.esc_url($testi['leadcapture_testimonial_qoute']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">
										</div>';
										endif;	
									echo '</div>	
								</div>';
								endforeach;
							endif; 
                            echo '</div>
						</div>					
					</div>
				</div>
			</div>
		</div>
		<!-- testimonial section end -->';
  }
}