<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Photographer_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_photographer_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Photographer Banner', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
        $this->start_controls_section(
            'leadcapture_photographer',
            [
            'label' => esc_html__('Photographer Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'leadcapture_photographer_logo',
            [
			'label' => esc_html__('Photographer Logo', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_photographer_left_image',
            [
			'label' => esc_html__('Left Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_photographer_right_image',
            [
			'label' => esc_html__('Right Image', 'leadcapture'),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,	
			]
        );
        $this->add_control(
            'leadcapture_heading',
            [
            'label' => esc_html__('Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_subheading',
            [
            'label' => esc_html__('Sub Heading', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_news_letter',
            [
            'label' => esc_html__('News Letter', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
        $this->add_control(
            'leadcapture_photographer_form_shortcode',
            [
            'label' => esc_html__('Form Shortcode', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture'),
            ]
        );
        $repeater = new Repeater();
       
        
        $this->end_controls_section();
        /** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
        	'lps_heading_style_tab',
        	[
        	'label' => esc_html__('Style Tab', 'leadcapture'),
        	'tab'   => Controls_Manager::TAB_STYLE,
        	]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Heading Typography', 'leadcapture'),
        	'name'     => 'lps_heading_typography',
        	'selector' => '{{WRAPPER}} .lc-banner-right-content-style35 > h4',
        	]
        );
        $this->add_control(
        	'lps_heading_color',
        	[
        	'label' => esc_html__('Heading color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-banner-right-content-style35 > h4' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('Description Typography', 'leadcapture'),
        	'name'     => 'lps_description_typography',
        	'selector' => '{{WRAPPER}} .lc-banner-right-content-style35 > p',
        	]
        );
        $this->add_control(
        	'lps_description_text_color',
        	[
        	'label' => esc_html__('Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-banner-right-content-style35 > p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
        	Group_Control_Typography::get_type(),
        	[   
        	'label' => esc_html__('News Letter Heading Typography', 'leadcapture'),
        	'name'     => 'lps_newsletter_typography',
        	'selector' => '{{WRAPPER}} .lc-banner-newsltr-box-style35 > h4',
        	]
        );
        $this->end_controls_section();
    }
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();
        echo'	<!-- banner section start -->
        <div class="lc-banner-wrapper-style35">
        	<div class="container-fluid">			
        		<div class="lc-banner-inner-style35">
        			<div class="lc-banner-left-img-style35">
        				<div class="lc-logo-style35">';
        					if(!empty($settings['leadcapture_photographer_logo']['url'])):
        						echo '<a href="javascript:;">
        						<img src="'.esc_url($settings['leadcapture_photographer_logo']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
        					    </a>';
        					endif;
            				echo '</div>';
            				if(!empty($settings['leadcapture_photographer_left_image']['url'])):
            				    echo '<div class="lc-banner-lft-img-style-35">
            						<img src="'.esc_url($settings['leadcapture_photographer_left_image']['url']).'" alt="'.esc_attr__('left-image', 'leadcapture').'">
            				    </div>';
            				endif;
        				echo '<div class="lc-banner-newsltr-box-style35">';
        					if(!empty($settings['leadcapture_news_letter'])):
        					echo '<h4>'.esc_html($settings['leadcapture_news_letter']).'</h4>';
        					endif;
        					if(!empty($settings['leadcapture_photographer_form_shortcode'])):
                            echo do_shortcode($settings['leadcapture_photographer_form_shortcode']);
                        endif;
        				echo '</div>
        			</div>
        			<div class="lc-banner-right-style35">
        				<div class="lc-banner-right-img-style35">';
            				if(!empty($settings['leadcapture_photographer_right_image']['url'])):
            				    echo '<img src="'.esc_url($settings['leadcapture_photographer_right_image']['url']).'" alt="'.esc_attr__('right-image', 'leadcapture').'">';
            				 endif;   
        					echo '<div class="lc-banner-right-content-style35">';
        						if(!empty($settings['leadcapture_heading'])):
        						    echo '<h4>'.esc_html($settings['leadcapture_heading']).'</h4>';
        						endif;
        						if(!empty($settings['leadcapture_subheading'])):
        						   echo '<p>'.esc_html($settings['leadcapture_subheading']).'</p>';
        						endif;   
        					echo '</div>
        				</div>
        			</div>
        		</div>
        	</div>
        </div>
        <!-- banner section end -->';
	}
}