<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Photographer_Team extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_photographer_team';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Photographer Team', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_team',
            [
            'label' => esc_html__('Team Settings', 'leadcapture'),
            ] 
        );
        $this->add_control(
        	'lps_team_heading',
            [
                'label'       => esc_html__('Heading', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__('What Clients Say About Us', 'leadcapture'),
            ]
        );
        $this->add_control(
        	'lps_team_description',
            [
                'label'       => esc_html__('Description', 'leadcapture'),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Get latest news in your inbox.', 'leadcapture'),
            ]
        );
		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_team_author',
            [
                'label'       => esc_html__('Team Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_team_designation',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_team_image',
            [
			'label'       => esc_html__('Team Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_team_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_team_author'  => esc_html__('Team Name #', 'leadcapture'),
					'leadcapture_team_dest'  => esc_html__('Designation #', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_team_author}}',
            ]
        );
        $this->end_controls_section();
		/** 
         * Lead Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_one_style_tab',
            [
            'label' => esc_html__( 'Style Tab', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_one_heading_typography',
            'selector' => '{{WRAPPER}} .lc-team-heading-style35 > h1',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_heading_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-team-heading-style35 > h1' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_heading_des_typography',
            'selector' => '{{WRAPPER}} .lc-team-heading-style35 > p',
            ]
        );
        	$this->add_control(
        	'lps_cons_testi_description_color',
        	[
        	'label' => esc_html__('Description Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-team-heading-style35 > p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
       	
       	/** 
         * Team Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Team Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_control(
        	'lps_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('Team Name Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-team-info-style35 > h4' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Team Name Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_desc_typography',
            'selector' => '{{WRAPPER}} .lc-team-info-style35 > h4',
            ]
        );
		$this->add_control(
        	'lps_testi_designation_text_color',
        	[
        	'label' => esc_html__('Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-team-info-style35 > p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_design_typography',
            'selector' => '{{WRAPPER}} .lc-team-info-style35 > p',
            ]
        );
        $this->add_control(
        	'lps_cons_testi_pagination_color',
        	[
        	'label' => esc_html__('Team Pagination Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .swiper-team-prev' => 'background-color: {{VALUE}}!important',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_cons_testi_pagination_hover_color',
        	[
        	'label' => esc_html__('Team Pagination Hover Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .swiper-team-prev:hover' => 'background-color: {{VALUE}}!important',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	echo '<!-- team section start -->
	<div class="lc-team-wrapper-style35">
		<div class="container">
			<div class="row">
				<div class="col-lg-4">
					<div class="lc-team-left-parent-style35">
						<div class="lc-team-heading-style35">';
						if(!empty($settings['lps_team_heading'])):
						   echo '<h1>'.esc_html($settings['lps_team_heading']).'</h1>';
						endif;
						if(!empty($settings['lps_team_description'])):
						    echo '<p>'.esc_html($settings['lps_team_description']).'</p>';
					    endif;
						echo '</div>
						<div class="lc-team-nav-style35">
							<div class="swiper-button-next swiper-team-prev">
								<span>
									<svg width="16.03" height="14.03" viewBox="0 0 16.03 14.03">  
										<path d="M1437.96,1895.85a1.34,1.34,0,0,1,.2-0.01h11.29l-0.25-.12a2.117,2.117,0,0,1-.65-0.47l-3.16-3.22a1.228,1.228,0,0,1-.17-1.55,1.123,1.123,0,0,1,1.6-.25,1.059,1.059,0,0,1,.12.1l5.72,5.84a1.177,1.177,0,0,1,0,1.65h0l-5.72,5.84a1.141,1.141,0,0,1-1.62,0c-0.03-.04-0.07-0.08-0.1-0.12a1.228,1.228,0,0,1,.17-1.55l3.16-3.23a2.374,2.374,0,0,1,.57-0.43l0.34-.16h-11.24A1.17,1.17,0,0,1,1437.96,1895.85Z" transform="translate(-1437 -1890)"/>
									</svg>
								</span>
							</div>
							<div class="swiper-button-prev swiper-team-prev">
								<span>
									<svg width="15.969" height="14" viewBox="0 0 15.969 14">  
										<path d="M487.04,1895.84a0.651,0.651,0,0,0-.2-0.01H475.577l0.246-.12a2.233,2.233,0,0,0,.645-0.47l3.159-3.22a1.219,1.219,0,0,0,.166-1.54,1.129,1.129,0,0,0-1.6-.26c-0.041.04-.08,0.07-0.117,0.11l-5.713,5.82a1.185,1.185,0,0,0,0,1.65h0l5.713,5.83a1.136,1.136,0,0,0,1.616,0c0.035-.04.068-0.08,0.1-0.12a1.218,1.218,0,0,0-.166-1.54l-3.153-3.23a2.341,2.341,0,0,0-.571-0.43l-0.343-.15h11.22a1.2,1.2,0,0,0,1.205-.98A1.162,1.162,0,0,0,487.04,1895.84Z" transform="translate(-472.031 -1890)"/>
									</svg>
								</span>
							</div>
						</div>
					</div>
				</div>
				<div class="col-lg-8">
					<div class="swiper lc-team-slider-parent-style35">
						<div class="swiper-wrapper">';
						if(!empty($settings['leadcapture_team_list'])):
                            foreach($settings['leadcapture_team_list'] as $list):
							echo '<div class="swiper-slide">
								<div class="lc-team-parent-style35">';
								if(!empty($list['leadcapture_team_image']['url'])):
								    echo '<div class="lc-team-img-style35">
										<img src="'.esc_url($list['leadcapture_team_image']['url']).'" alt="'.esc_attr__('team', 'leadcapture').'">
									</div>';
								endif;
								echo '<div class="lc-team-info-style35">';
									if(!empty($list['leadcapture_team_designation'])):
										echo '<p>'.esc_html($list['leadcapture_team_designation']).'</p>';
									endif;
									if(!empty($list['leadcapture_team_author'])):
									   echo '<h4>'.esc_html($list['leadcapture_team_author']).'</h4>';
									endif;
								echo '</div>
								</div>	
							</div>';
							endforeach;
						endif;
						echo '</div>
					</div>					
				</div>
			</div>
		</div>
	</div>
	<!-- team section end -->';
  }
}