<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Plumber_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_plumber_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Plumber', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_banner_logo',
            [
				'label'       => esc_html__( 'Section Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_title_sub',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_newsletter_title',
            [
                'label'       => esc_html__( 'NewsLetter Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_newsletter_form_shortcode',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_review_rating',
            [
				'label'       => esc_html__( 'Raview Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_review_rating_text',
            [
				'label'       => esc_html__( 'Raview Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
        
		$this->end_controls_section();
	
        // Widget Style
        $this->start_controls_section(
            'lcp_property_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_property_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style40 h1'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style40 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'lcp_property_banner_style_sub_heading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_sub_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style40 h4'
            ]
        );
        $this->add_control(
            'lcp_banner_sub_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style40 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_banner_style_news_heading',
			[
				'label' => esc_html__( 'NewsLetter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_newslateer_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-newltr-box-style40 h4'
            ]
        );
        $this->add_control(
            'lcp_newslateer_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-newltr-box-style40 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
      
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
    if(!empty($settings)){
       
    	echo '<!-- banner section start -->
		<div class="lc-banner-wrapper-style40">
			<div class="container-fluid">
				<div class="row">
					<div class="col-lg-6">
						<div class="lc-banner-left-style40">
							<div class="lc-logo-style40">';
							if(!empty($settings['lcp_banner_logo']['url'])):
							   
							    echo '<a href="javascript:;">
								<img src="'. esc_url($settings['lcp_banner_logo']['url']).'" alt="'. esc_attr__('logo','leadcapture').'"/>
								</a>';
							endif;
							echo '</div>
							<div class="lc-banner-heading-style40">';
    							if(!empty($settings['lcp_banner_title_sub'])):
    								echo '<h4>'.esc_html($settings['lcp_banner_title_sub']).'</h4>';
    							endif;
    							if(!empty($settings['lcp_banner_title'])):
    							    echo '<h1>'.esc_html($settings['lcp_banner_title']).'</h1>';
    							endif;
							echo '</div>
							<div class="lc-banner-newltr-box-style40">';
                                if(!empty($settings['lcp_banner_newsletter_title'])):
                                    echo '<h4>'.esc_html($settings['lcp_banner_newsletter_title']).'</h4>';
                                endif;
                                if(!empty($settings['lcp_newsletter_form_shortcode'])):
                                     echo do_shortcode( $settings['lcp_newsletter_form_shortcode']);
                                endif;

                            echo '</div>						
							<div class="lc-banner-rating-box-style40">
								<ul>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>
									<li><i class="fa fa-star"></i></li>
								</ul>';
								 if(!empty($settings['lcp_review_rating'] || $settings['lcp_review_rating_text'])):
								    echo '<h4> '.esc_html($settings['lcp_review_rating']).'<span>'.esc_html($settings['lcp_review_rating_text']).'</span></h4>';
								 endif;
							echo '</div>						
						</div>
					</div>				
				</div>
			</div>
		</div>	
		<!-- banner section end -->';
    	}
	}
}