<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pool_Cleaning_About extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_Pool_Cleaning_about';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pool Cleaning About', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_about',
            [
            'label' => esc_html__('About Settings', 'leadcapture'),
            ] 
        );
        
       $this->add_control(
            'lcp_about_title_before_subtitle',
            [
				'label'       => esc_html__( 'Before Sub Title', 'leadcapture' ),
                 'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_about_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_about_subtitle',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        $this->add_control(
            'lcp_about_title_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
		//$this->end_controls_section();

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_about_list_text',
            [
                'label'       => esc_html__( 'Text', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_about_list_image',
            [
			'label'       => esc_html__( 'Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_about_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_about_list_text'  => esc_html__('Enter your title #', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_about_list_text}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_about_style_tab',
            [
            'label' => esc_html__('About Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('About Before Heading Typography', 'leadcapture'),
            'name'     => 'lps_before_heading_typography',
            'selector' => '{{WRAPPER}} .lc-heading-style36 h4',
            ]
        );
        $this->add_control(
        	'lps_before_heading_color',
        	[
        	'label' => esc_html__('About Before Heading Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lc-heading-style36 h1',
            ]
        );
        $this->add_control(
        	'lps_heading_color',
        	[
        	'label' => esc_html__('Heading Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .alc-heading-style36 h1' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Sub Heading Typography', 'leadcapture'),
            'name'     => 'lps_sub_heading_typography',
            'selector' => '{{WRAPPER}} .alc-heading-style36 span',
            ]
        );
        $this->add_control(
        	'lps_sub_heading_color',
        	[
        	'label' => esc_html__('Sub Heading Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .alc-heading-style36 span' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_about_descs_typography',
            'selector' => '{{WRAPPER}} .lc-heading-style36 p',
            ]
        );
        $this->add_control(
        	'lps_about_description_color',
        	[
        	'label' => esc_html__('Description Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-heading-style36 p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('List Typography', 'leadcapture'),
            'name'     => 'lps_about_list_typography',
            'selector' => '{{WRAPPER}} .lc-about-list-style36 li',
            ]
        );
        $this->add_control(
        	'lps_about_list_color',
        	[
        	'label' => esc_html__('List Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-about-list-style36 li' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '		<!-- about section start -->	
		<div class="lc-about-wrapper-style36">
			<div class="container">
				<div class="row">
				    <div class="col-xl-12 col-lg-12">
						<div class="lc-about-right-main-style36">
							<div class="lc-heading-style36">';
								if(!empty($settings['lcp_about_title_before_subtitle'])): 
								    echo '<h4>'.esc_html($settings['lcp_about_title_before_subtitle']).'</h4>';
								endif;
								if(!empty($settings['lcp_about_title'] || $settings['lcp_about_subtitle'])): 
								    echo '<h1>'.esc_html($settings['lcp_about_title']).' <span>'.esc_html($settings['lcp_about_subtitle']).'</span> </h1>';
								endif;
								if(!empty($settings['lcp_about_title_description'])): 
								    echo '<p>'.esc_html($settings['lcp_about_title_description']).'</p>';
								endif;
							echo '</div>
							<div class="lc-about-list-style36">
								<ul>';
								if(!empty($settings['leadcapture_about_list'])):
                                    foreach($settings['leadcapture_about_list'] as $testi):
                                        if(!empty($testi['leadcapture_about_list_image']['url'] || $testi['leadcapture_about_list_text'])):  
									    echo '<li><img src="'.esc_html($testi['leadcapture_about_list_image']['url']).'" alt=""><span>'.esc_html($testi['leadcapture_about_list_text']).'</span></li>';
										endif; 
            					    endforeach;
            					endif; 
            					echo '</ul>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<!-- about section end -->	';
    }
}