<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pool_Cleaning_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_pool_cleaning_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pool Cleaning', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_pool_cleaning_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_cleaning_banner_logo',
            [
				'label'       => esc_html__( 'Section Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_cleaning_banner_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_cleaning_banner_subtitle',
            [
				'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                 'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_cleaning_banner_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_cleaning_button',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_cleaning_button_url',
            [
                'label'       => esc_html__( 'Button URL', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        $this->add_control(
            'lcp_cleaning_right_image',
            [
				'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        
		$this->end_controls_section();
	
        
        // Widget Style
        $this->start_controls_section(
            'lcp_cleaning_banner_style_list', 
            [
                'label' => esc_html__( 'Heading Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_cleaning_banner_style_list_heading',
			[
				'label' => esc_html__( 'Heading Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_cleaning_banner_style_list_number_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-left-heading-style36 h1'
            ]
        );
        $this->add_control(
            'lcp_cleaning_banner_style_list_number_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-left-heading-style36 > h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Sub Heading Style 
        $this->add_control(
			'lcp_cleaning_banner_style_list_sub_title',
			[
				'label' => esc_html__( 'Sub Title Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_cleaning_banner_style_list_sub_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-left-heading-style36 > span'
            ]
        );
        $this->add_control(
            'lcp_cleaning_banner_style_list_sub_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-left-heading-style36 > span' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Heading Style 
        $this->add_control(
			'lcp_cleaning_banner_style_list_description',
			[
				'label' => esc_html__( 'Description Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_cleaning_banner_style_list_description_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-left-heading-style36 > p'
            ]
        );
        $this->add_control(
            'lcp_cleaning_banner_style_list_description_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-left-heading-style36 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style 
        $this->add_control(
			'lcp_cleaning_banner_style_list_button',
			[
				'label' => esc_html__( 'Button Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_cleaning_banner_style_list_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style36'
            ]
        );
        $this->add_control(
            'lcp_cleaning_banner_style_list_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style36' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<div class="lc-banner-wrapper-style36">
			<div class="container-fluid">
				<div class="lc-banner-parent-style36">				
					<div class="lc-banner-left-style36">';
    					if(!empty($settings['lcp_cleaning_banner_logo']['url'])):
    						echo '<div class="lc-logo-style36">
    							<a href="jacascript:;">
    							<img src="'.esc_url($settings['lcp_cleaning_banner_logo']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
    							</a>
    						</div>';
    					endif;
						echo '<div class="lc-banner-left-heading-style36">';
    					if(!empty($settings['lcp_cleaning_banner_banner_title'])):
    						echo '<h1>'.esc_html($settings['lcp_cleaning_banner_banner_title']).' <span>'.esc_html($settings['lcp_cleaning_banner_subtitle']).'</span> </h1>';
    					endif;
						echo '<p>'.esc_html($settings['lcp_cleaning_banner_description']).'</p>';
						if(!empty($settings['lcp_cleaning_button'])):
						    echo '<a href="'.esc_url($settings['lcp_cleaning_button_url']).'" class="lc-btn-style36">'.esc_html($settings['lcp_cleaning_button']).'</a>';
						endif;
						echo '</div>
					</div>								
					<div class="lc-banner-right-img-style36">
						<img src="'.esc_url($settings['lcp_cleaning_right_image']['url']).'" alt="'.esc_attr__('image', 'leadcapture').'">
					</div>				
				</div>
			</div>
		</div>';
	    }
	}
}