<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Pool_Cleaning_Contact_Info extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_pool_cleaning_contact_info';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Pool Cleaning Contact Info', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_contactinfo',
            [
            'label' => esc_html__('Contact Info Settings', 'leadcapture'),
            ] 
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_contact_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_contact_details',
            [
            'label' => esc_html__('Details', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_contact_image',
            [
			'label'       => esc_html__( 'Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_contact_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_contact_heading'  => esc_html__('Heading #', 'leadcapture'),
					'leadcapture_contact_details'  => esc_html__('details #', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_contact_heading}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_contact_info_style_tab',
            [
            'label' => esc_html__('Contact Info Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Contact Heading Typography', 'leadcapture'),
            'name'     => 'lps_contact_info_typography',
            'selector' => '{{WRAPPER}} .lc-contct-no-style36 h4',
            ]
        );
        $this->add_control(
        	'lps_contact_info_heading_color',
        	[
        	'label' => esc_html__('Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-contct-no-style36 h4' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Details Typography', 'leadcapture'),
            'name'     => 'lps_contact_info_details_typography',
            'selector' => '{{WRAPPER}} .lc-contct-no-style36 p',
            ]
        );
        $this->add_control(
        	'lps_contact_info_details_color',
        	[
        	'label' => esc_html__('Details Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-contct-no-style36 p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		if(!empty($settings['leadcapture_contact_list'])):
            foreach($settings['leadcapture_contact_list'] as $testi):
            echo '<div class="lc-contact-info-style36">
                <div class="lc-contct-img-style36">';
                    if(!empty($testi['leadcapture_contact_image']['url'])):  
                        echo '<img src="'.esc_url($testi['leadcapture_contact_image']['url']).'" alt="'.esc_attr('testimonial','leadcapture').'">';
                    endif;
                echo '</div>
                <div class="lc-contct-no-style36">';
                    if(!empty($testi['leadcapture_contact_heading'])):  
                        echo '<h4>'.esc_html($testi['leadcapture_contact_heading']).'</h4>';
                    endif;
                    if(!empty($testi['leadcapture_contact_details'])):  
                     echo '<p>'.esc_html($testi['leadcapture_contact_details']).'</p>';
                    endif; 
                echo '</div>
            </div>';
            endforeach; 
        endif;
    }
}