<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Realestate_Locations extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_realestate_locations';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Realestate Locations', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_realestate_locations_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_realestate_protfolio_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_realestate_locations_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_realestate_locations_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_realestate_locations_list_properties',
            [
                'label'       => esc_html__( 'Properties', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_realestate_locations_list_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_realestate_locations_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_realestate_locations_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_realestate_locations_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style28 > h3'
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style28 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button One Style
        $this->add_control(
			'lcp_realestate_locations_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control( 
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_colors' );
		$this->start_controls_tab(
			'lcp_realestate_locations_style_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_realestate_locations_style_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28',
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_realestate_locations_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_realestate_locations_style_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover',
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
        
        // Location Style
        $this->add_control(
			'lcp_realestate_locations_style_location_heading',
			[
				'label' => esc_html__( 'Location Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_location_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-location-box-text > h3'
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_style_location_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-location-box-text > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Location Decription Style
        $this->add_control(
			'lcp_realestate_locations_style_location_decs',
			[
				'label' => esc_html__( 'Location Decription', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_location_decs_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-location-box-text > p'
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_style_location_decs_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-location-box-text > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Location Properties Style
        $this->add_control(
			'lcp_realestate_locations_style_location_properties',
			[
				'label' => esc_html__( 'properties', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_location_properties_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-location-box-text > p'
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_style_location_properties_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-locbox-properties > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_realestate_locations_style_location_properties_bgcolor',
            [
                'label'     => esc_html__( 'Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-locbox-properties' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        //Button
        // Button One Style
        $this->add_control(
			'lcp_realestate_locations_style_locations_button',
			[
				'label' => esc_html__( 'Location Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_locations_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_realestate_locations_style_locations_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_realestate_locations_style_locations_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_locations_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_locations_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28',
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_locations_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_realestate_locations_style_locations_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_realestate_locations_style_locations_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_locations_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28::before' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_realestate_locations_style_locations_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28:hover',
            ]
        );
		$this->add_control(
            'lcp_realestate_locations_style_locations_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-knowbtn-style28:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
        
        
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-location-section lc-location-section-style28">
                <div class="container">';
                    if(!empty($settings['lcp_realestate_locations_title'])){
                        echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-heading-wrapper lc-heading-style28">
                                    <h3>'.esc_html($settings['lcp_realestate_locations_title']).'</h3>
                                </div>
                            </div>
                        </div>';
		            }
		            if(!empty($settings['lcp_realestate_locations_list'])){
		                echo '<div class="row">';
		                    foreach($settings['lcp_realestate_locations_list'] as $list){
		                        echo '<div class="col-lg-4 col-md-6 col-sm-12">
                                    <div class="lc-location-box-wrapper">';
                                        if(!empty($list['lcp_realestate_protfolio_list_image']['url'])){
                                            echo '<div class="lc-locationbox-img">
                                                <img src="'.esc_url($list['lcp_realestate_protfolio_list_image']['url']).'" alt="'.esc_attr('Location-image', 'leadcapture').'">
                                            </div>';
                                        }
                                        if(!empty($list['lcp_realestate_locations_list_properties'])){
                                            echo '<div class="lc-locbox-properties">
                                                <p>'.esc_html($list['lcp_realestate_locations_list_properties'].' Properties', 'leadcapture').'</p>
                                            </div>';
                                        }
                                        echo '<div class="lc-location-box-text">';
                                            if(!empty($list['lcp_realestate_locations_list_title'])){ 
                                                echo '<h3>'.esc_html($list['lcp_realestate_locations_list_title']).'</h3>';
                                            }
                                            if(!empty($list['lcp_realestate_locations_list_desc'])){
                                                echo '<p>'.esc_html($list['lcp_realestate_locations_list_desc']).'</p>';
                                            }
                                        echo '</div>';
                                        if(!empty($list['lcp_realestate_locations_list_link'])){
                                            echo '<div class="lc-btn lc-btn-style28 lc-knowbtn-style28">
                                                <a href="'.esc_url($list['lcp_realestate_locations_list_link']).'">'.esc_html('KNOW MORE', 'leadcapture').'</a>
                                            </div>';
                                        }
                                    echo '</div>
                                </div>';
		                    }
		                echo '</div>';
		            }
		            if(!empty($settings['lcp_realestate_locations_btn_title'])){
		                echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-btn lc-btn-style28 lc-viewbtn-style28">
                                    <a href="'.esc_url($settings['lcp_realestate_locations_btn_link']).'">'.esc_html($settings['lcp_realestate_locations_btn_title']).'</a>
                                </div>
                            </div>
                        </div>';      
		            }
                echo '</div>
            </div>';   
		}
	}
}