<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Realestate_Portfolio extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_realestate_protfolio';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Realestate Protfolio', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_restaurant_protfolio_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_restaurant_protfolio_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$repeater->add_control(
            'lcp_restaurant_protfolio_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_protfolio_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_protfolio_list_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_protfolio_list_size',
            [
                'label'       => esc_html__( 'Size', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_protfolio_list_bed',
            [
                'label'       => esc_html__( 'Bedroom', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_protfolio_list_bathroom',
            [
                'label'       => esc_html__( 'Bathroom', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_restaurant_protfolio_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_restaurant_protfolio_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_restaurant_protfolio_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_protfolio_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style28 > h3'
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style28 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button One Style
        $this->add_control(
			'lcp_restaurant_protfolio_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_protfolio_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28 a' 
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_restaurant_protfolio_style_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_restaurant_protfolio_style_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_restaurant_protfolio_style_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_restaurant_protfolio_style_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28',
            ]
        );
		$this->add_control(
            'lcp_restaurant_protfolio_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_restaurant_protfolio_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_restaurant_protfolio_style_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_restaurant_protfolio_style_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_restaurant_protfolio_style_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover',
            ]
        );
		$this->add_control(
            'lcp_restaurant_protfolio_style_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style28.lc-viewbtn-style28:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_restaurant_protfolio_style_portfolio', 
            [
                'label' => esc_html__( 'Portfolio', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_restaurant_protfolio_style_portfolio_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_protfolio_style_portfolio_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-portfolio-box-text > h3'
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_style_portfolio_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-portfolio-box-text > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_restaurant_protfolio_style_portfolio_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_protfolio_style_portfolio_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-portfolio-box-text >p'
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_style_portfolio_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-portfolio-box-text >p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_restaurant_protfolio_style_portfolio_price',
			[
				'label' => esc_html__( 'Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_protfolio_style_portfolio_price_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-portfolio-box-rs > p'
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_style_portfolio_price_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-portfolio-box-rs > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_restaurant_protfolio_style_portfolio_price_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-portfolio-box-rs' => 'background: {{VALUE}};',
                ],
            ]
        );
        // Description Style
        $this->add_control(
			'lcp_restaurant_protfolio_style_portfolio_meta',
			[
				'label' => esc_html__( 'Meta', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_restaurant_protfolio_style_portfolio_meta_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-portfolioicon-wrapper > ul > li > .lc-portfolio-icon > svg > .cls-1' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-portfolioicon-wrapper > ul > li > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        
        $this->end_controls_section();
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
	        echo '<div class="lc-portfolio-section lc-portfolio-section-style28">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">';
                            if(!empty($settings['lcp_restaurant_protfolio_title'])){
                                echo '<div class="lc-heading-wrapper lc-heading-style28">
                                    <h3>'.esc_html($settings['lcp_restaurant_protfolio_title']).'</h3>
                                </div>';
                            }
                        echo '</div>
                    </div>
                    <div class="row">';
                        if(!empty($settings['lcp_restaurant_protfolio_list'])){
                            foreach($settings['lcp_restaurant_protfolio_list'] as $list){
                                echo '<div class="col-lg-4 col-md-6 col-sm-6">
                                    <div class="lc-portfolio-box lc-portfoliobox-style28">';
                                        if(!empty($list['lcp_restaurant_protfolio_list_image']['url'])){
                                            echo '<div class="lc-portfoliobox-img">
                                                <img src="'.esc_url($list['lcp_restaurant_protfolio_list_image']['url']).'" alt="'.esc_attr('portfolio-image', 'leadcapture').'">
                                            </div>';
                                        }
                                        echo '<div class="lc-portfolio-box-rs">';
                                            if(!empty($list['lcp_restaurant_protfolio_list_price']) || !empty($settings['lcp_restaurant_protfolio_symbol'])){
                                                echo '<p>'.esc_html('From '. $settings['lcp_restaurant_protfolio_symbol'] . $list['lcp_restaurant_protfolio_list_price']).'</p>';
                                            }
                                        echo '</div>
                                        <div class="lc-portfolio-box-text">';
                                            if(!empty($list['lcp_restaurant_protfolio_list_title'])){
                                                echo '<h3>'.esc_html($list['lcp_restaurant_protfolio_list_title']).'</h3>';
                                            }
                                            if(!empty($list['lcp_restaurant_protfolio_list_desc'])){
                                                echo '<p>'.esc_html($list['lcp_restaurant_protfolio_list_desc']).'</p>';
                                            }
                                        echo '</div>
                                        <div class="lc-portfolioicon-wrapper">
                                            <ul>';
                                                if(!empty($list['lcp_restaurant_protfolio_list_size'])){
                                                    echo '<li>
                                                        <span class="lc-portfolio-icon">
                                                            <svg xmlns="http://www.w3.org/2000/svg" width="18" height="18" viewBox="0 0 18 18">
                                                                <path class="cls-1" d="M0,8.94A1.433,1.433,0,0,0,.147,8.826Q1.472,7.5,2.794,6.172A1.387,1.387,0,0,0,2.9,6.035L3.663,6.8,2.024,8.425c0.083,0.009.125,0.018,0.166,0.018q2.347,0,4.693,0a0.174,0.174,0,0,0,.2-0.137A2,2,0,0,1,8.342,7.046,0.153,0.153,0,0,0,8.475,6.88q-0.006-2.4,0-4.794c0-.021,0-0.043-0.007-0.076L6.841,3.643,6.1,2.9,8.989,0l2.9,2.912-0.715.717L9.548,1.987a1.076,1.076,0,0,0-.02.134q0,2.371,0,4.741a0.163,0.163,0,0,0,.133.185,2,2,0,0,1,1.26,1.261,0.154,0.154,0,0,0,.163.139q2.4-.006,4.8,0a0.278,0.278,0,0,0,.052-0.011L14.316,6.816l0.77-.773c0.491,0.5.994,1,1.5,1.511Q17.224,8.2,17.866,8.838a1.233,1.233,0,0,0,.134.1V9.01a1.4,1.4,0,0,0-.147.113q-1.331,1.332-2.66,2.666c-0.044.044-.091,0.084-0.111,0.1L14.3,11.114l1.607-1.608a0.141,0.141,0,0,0-.032,0q-2.4,0-4.8,0a0.154,0.154,0,0,0-.167.134,1.977,1.977,0,0,1-1.228,1.246,0.207,0.207,0,0,0-.164.235c0.006,1.557,0,3.113,0,4.67v0.191l1.642-1.649,0.765,0.768a1.154,1.154,0,0,0-.139.106q-1.325,1.326-2.647,2.654A1.393,1.393,0,0,0,9.035,18H8.965a1.356,1.356,0,0,0-.112-0.148q-1.328-1.335-2.658-2.667c-0.044-.044-0.084-0.091-0.106-0.115l0.78-.781,1.6,1.631a0.174,0.174,0,0,0,.005-0.031q0-2.414,0-4.828a0.153,0.153,0,0,0-.13-0.168A1.971,1.971,0,0,1,7.093,9.649,0.2,0.2,0,0,0,6.865,9.5q-2.328.005-4.656,0c-0.049,0-.1.005-0.184,0.01L3.67,11.148l-0.756.757L0,8.975V8.94Z"/>
                                                            </svg>
                                                        </span>
                                                        <p>'.esc_html($list['lcp_restaurant_protfolio_list_size'].' sqft').'<sup>2</sup></p>
                                                    </li>';
                                                }
                                                if(!empty($list['lcp_restaurant_protfolio_list_bed'])){
                                                    echo '<li>
                                                        <span class="lc-portfolio-icon">
                                                            <svg xmlns="http://www.w3.org/2000/svg" width="21" height="19" viewBox="0 0 21 19">
                                                                <path class="cls-1" d="M20.059,10.1l-0.016-.048a0.638,0.638,0,0,1-.026-0.088,2.909,2.909,0,0,0-1-1.742A0.288,0.288,0,0,1,18.9,7.968c0.005-1.461.006-2.9,0-4.288A3.575,3.575,0,0,0,15.264.032q-0.738,0-1.476,0h-1.07c-0.329,0-.668,0-1,0a0.511,0.511,0,0,0-.389.16,0.459,0.459,0,0,0-.1.363,0.462,0.462,0,0,0,.54.4h1.143c0.763,0,1.552,0,2.328,0a3.023,3.023,0,0,1,.657.064A2.638,2.638,0,0,1,17.976,3.63c0.006,0.952,0,1.921,0,2.858q0,0.549,0,1.1c0,0.016,0,.032,0,0.048l-0.86-.14V7.357q0-.3,0-0.6c0-.435,0-0.884,0-1.326a1.587,1.587,0,0,0-1.648-1.653c-1.077,0-2.172,0-3.231,0h-1a1.634,1.634,0,0,0-.955.284c-0.066.046-.127,0.1-0.19,0.15l-0.038.032A1.828,1.828,0,0,0,8.663,3.77c-0.843.007-1.7,0.006-2.528,0q-0.732,0-1.465,0A1.578,1.578,0,0,0,3.01,5.436c0,0.4,0,.8,0,1.2q0,0.269,0,.537V7.493l-0.86.142c0-.025,0-0.051,0-0.077V6.523c0-.932,0-1.9,0-2.843A2.638,2.638,0,0,1,4.859.958q0.693,0,1.386,0h1.1c0.367,0,.746,0,1.12,0A0.534,0.534,0,0,0,8.891.776,0.454,0.454,0,0,0,8.971.39,0.476,0.476,0,0,0,8.44.032H7.99c-1.047,0-2.13,0-3.195,0a3.651,3.651,0,0,0-.629.058A3.567,3.567,0,0,0,1.227,3.649c0,0.726,0,1.463,0,2.177s0,1.433,0,2.15a0.318,0.318,0,0,1-.079.209A2.958,2.958,0,0,0,.064,10.51c0,1.278,0,2.579,0,3.836v1.017a0.486,0.486,0,0,0,.555.562c0.154,0,.308,0,0.466,0H1.226v0.419c0,0.37,0,.731,0,1.092a0.5,0.5,0,0,0,.583.594H3.592a0.526,0.526,0,0,0,.649-0.644V15.937H15.884q0,0.208,0,.413c0,0.374,0,.761,0,1.14a0.476,0.476,0,0,0,.537.54l0.97,0,0.97,0a0.476,0.476,0,0,0,.537-0.54c0-.338,0-0.681,0-1.013q0-.215,0-0.43V15.925h0.142c0.149,0,.29,0,0.429,0a0.533,0.533,0,0,0,.588-0.361l0-.012V10.111Zm-2.091,5.837V17.1H16.819V15.938h1.149Zm-14.659,0v1.155H2.161V15.934H3.309ZM9.6,6.918c0,0.2,0,.391,0,0.589H3.936a0.413,0.413,0,0,1,0-.056V7.061c0-.543,0-1.1,0-1.657a0.657,0.657,0,0,1,.707-0.7c1.524,0,2.919,0,4.265,0a0.655,0.655,0,0,1,.7.694C9.6,5.9,9.6,6.394,9.6,6.918Zm0.921-.109q0-.681,0-1.361A0.667,0.667,0,0,1,11.265,4.7q2.094,0,4.188,0a0.667,0.667,0,0,1,.741.748q0,0.681,0,1.361v0.7H10.523v-0.7Zm8.617,5.745v0.575H3.863c-0.047,0-.095,0-0.143,0a0.462,0.462,0,1,0,.01.924c0.043,0,.085,0,0.126,0H19.132v0.932H0.988c0-.039,0-0.077,0-0.114V14.206q0-1.82,0-3.641A2.027,2.027,0,0,1,3.093,8.442q6.969,0,13.937,0a2.027,2.027,0,0,1,2.11,2.124Q19.142,11.56,19.14,12.554Zm-9.083-11.6h0.006A0.471,0.471,0,0,0,10.52.5,0.477,0.477,0,0,0,10.068.035,0.455,0.455,0,0,0,9.747.17,0.463,0.463,0,0,0,9.6.49a0.459,0.459,0,0,0,.134.322A0.46,0.46,0,0,0,10.057.954ZM2.151,13.132a0.46,0.46,0,0,0,0,.92h0a0.471,0.471,0,0,0,.453-0.464,0.463,0.463,0,0,0-.141-0.322A0.456,0.456,0,0,0,2.151,13.132Z"/>
                                                            </svg>
                                                            </span>
                                                        <p>'.esc_html($list['lcp_restaurant_protfolio_list_bed']).'</p>
                                                    </li>';
                                                }
                                                if(!empty($list['lcp_restaurant_protfolio_list_bathroom'])){
                                                    echo '<li>
                                                        <span class="lc-portfolio-icon">
                                                            <svg xmlns="http://www.w3.org/2000/svg" width="18" height="19" viewBox="0 0 18 19">
                                                                <path class="cls-1" d="M15.386,15.587a3.938,3.938,0,0,0,1.721-3.349c0-.235,0-0.471,0-0.706a0.771,0.771,0,0,0,.883-0.524L18,10.993V10.337l0-.013a1.358,1.358,0,0,0-1.554-1.061c-0.424.019-.857,0.012-1.277,0l-0.23,0a0.183,0.183,0,0,1-.116-0.054,2.344,2.344,0,0,0-2.09-1.132c-0.379,0-.759,0-1.139,0-0.7,0-1.42,0-2.131,0a2.649,2.649,0,0,0-.465.049,2.282,2.282,0,0,0-1.127.569L7.851,8.682,7.706,8.567a4.379,4.379,0,0,0-1.843-.914,10.429,10.429,0,0,0-1.4-.165c-0.25-.018-0.5-0.013-0.751-0.009l-0.252,0q0-.013,0-0.024V6.929q0-2.326,0-4.653a0.211,0.211,0,0,1,.254-0.247c0.439,0,.959,0,1.476,0a0.321,0.321,0,0,1,.183.053c0.111,0.092.212,0.192,0.319,0.3l0.07,0.07a2.156,2.156,0,0,0-.4,1.126,0.8,0.8,0,0,0,.176.617,0.807,0.807,0,0,0,.616.21h2.73A1.52,1.52,0,0,0,9.115,4.39a0.682,0.682,0,0,0,.569-0.64A2.216,2.216,0,0,0,7.727,1.557a0.3,0.3,0,0,1-.166-0.076c-0.15-.143-0.3-0.293-0.444-0.438S6.847,0.771,6.708.638a1.892,1.892,0,0,0-.937-0.5A3.156,3.156,0,0,0,5.187.067c-0.4-.007-0.816-0.005-1.213,0H3.69a2.158,2.158,0,0,0-2.2,2.193c0,1.191,0,2.4,0,3.572q0,0.761,0,1.523V7.483H1.477c-0.067,0-.131,0-0.194,0a1.268,1.268,0,0,0-1.168.76,1.7,1.7,0,0,0-.079.211c-0.01.03-.02,0.061-0.03,0.091L0,8.56V9.219L0.006,9.235a0.784,0.784,0,0,0,.887.516v0.12c0,0.266,0,.533,0,0.8,0,0.588-.007,1.2.013,1.794a3.813,3.813,0,0,0,1.67,3.088,0.193,0.193,0,0,1,.1.2c-0.008.088-.007,0.177-0.007,0.262,0,0.027,0,.055,0,0.083a1.126,1.126,0,0,0-.9.291,1.148,1.148,0,0,0-.281.9H1.252c-0.261,0-.508,0-0.758,0a0.479,0.479,0,0,0-.484.263L0,17.564v0.5H18v-0.5l-0.011-.02a0.483,0.483,0,0,0-.484-0.262c-0.246.007-.491,0.006-0.749,0H16.521a1.033,1.033,0,0,0-1.2-1.191c0-.021,0-0.041,0-0.062,0-.134,0-0.261,0-0.382A0.178,0.178,0,0,1,15.386,15.587Zm0.347,1.684H13.855l-0.345-.995,1.036-.226c0,0.011,0,.022,0,0.033,0,0.116,0,.237,0,0.358a0.4,0.4,0,0,0,.434.436c0.1,0,.2,0,0.291,0h0.18c0.227,0,.28.054,0.282,0.284C15.733,17.2,15.733,17.233,15.733,17.271ZM6.286,1.921L6.231,1.859c-0.082-.091-0.167-0.186-0.255-0.28A1.022,1.022,0,0,0,5.2,1.249H4.509c-0.27,0-.541,0-0.811,0A0.972,0.972,0,0,0,2.676,2.272q0,1.849,0,3.7v1.5H2.267V5.908q0-1.8,0-3.59A1.387,1.387,0,0,1,3.746.842H4.32c0.29,0,.58,0,0.87,0H5.2a1.429,1.429,0,0,1,1.063.444C6.381,1.4,6.5,1.518,6.625,1.637L6.7,1.708ZM6.435,2.844A1.4,1.4,0,0,1,7.41,2.335,1.458,1.458,0,0,1,8.5,2.74a1.294,1.294,0,0,1,.4.874H6.141A1.168,1.168,0,0,1,6.435,2.844Zm-0.972,13.5A0.229,0.229,0,0,1,5.6,16.287c2.344,0,4.633,0,6.8,0a0.253,0.253,0,0,1,.148.064,1.535,1.535,0,0,1,.482.92H4.969A1.528,1.528,0,0,1,5.463,16.341Zm5.526-3.708q0,0.463,0,.926v0.456a2.069,2.069,0,0,1-.23,0,0.189,0.189,0,0,1-.177-0.22c0-.233,0-0.471,0-0.7,0-.091,0-0.181,0-0.272V12.08q0-.786,0-1.572A1.13,1.13,0,0,0,9.419,9.267a2.675,2.675,0,0,1-.808-0.158A1.5,1.5,0,0,1,10,8.964a1.535,1.535,0,0,1,.992,1.483C10.99,11.176,10.989,11.917,10.989,12.633ZM9.8,10.713v0.032a4.155,4.155,0,0,1-2.96-.969A3.425,3.425,0,0,0,4.6,8.969H4.589c-0.863,0-1.74,0-2.588,0H0.788a0.613,0.613,0,0,1,.09-0.5,0.621,0.621,0,0,1,.513-0.206H2.2c0.8,0,1.618,0,2.426,0a4.046,4.046,0,0,1,2.62.936,3.494,3.494,0,0,0,2.148.846,0.367,0.367,0,0,1,.406.429C9.8,10.554,9.8,10.631,9.8,10.713Zm-8.129-.2q0-.378,0-0.76h2.94a2.62,2.62,0,0,1,1.714.615A4.908,4.908,0,0,0,9.59,11.528H9.8v0.74q0,0.726,0,1.452a0.979,0.979,0,0,0,1.072,1.074q1.609,0,3.219,0a0.982,0.982,0,0,0,1.056-1.056q0-.725,0-1.451V11.541h1.165a3.658,3.658,0,0,1-.754,2.881A3.114,3.114,0,0,1,13.188,15.5c-3.042.036-6.078,0.02-8.383,0a3.151,3.151,0,0,1-3.13-3.156C1.668,11.734,1.67,11.139,1.672,10.509ZM14.37,13.7c0,0.26-.052.312-0.309,0.312q-1.008,0-2.017,0a0.222,0.222,0,0,1-.275-0.274q0-.4,0-0.8c0-.779,0-1.585,0-2.377a2.419,2.419,0,0,0-.593-1.7H11.5c0.412,0,.838,0,1.256,0a1.543,1.543,0,0,1,1.617,1.628q0,1.378,0,2.757V13.7Zm2.851-2.968H15.137V10.049h0.073c0.135,0,.271,0,0.406,0,0.3,0,.613.008,0.919-0.009A0.568,0.568,0,0,1,17.22,10.735ZM3.01,16.876a0.4,0.4,0,0,0,.443-0.446c0-.117,0-0.234,0-0.348,0-.011,0-0.023,0-0.034l1.037,0.228-0.348,1H2.272c0-.006,0-0.012,0-0.018a1.092,1.092,0,0,1,.006-0.225,0.176,0.176,0,0,1,.2-0.151c0.09,0,.18,0,0.27,0S2.921,16.878,3.01,16.876ZM8.88,4.871C8.865,4.86,8.85,4.85,8.844,4.844L8.818,4.819H8.771A0.464,0.464,0,0,0,8.378,5a0.36,0.36,0,0,0-.037.34c0.174,0.455.365,0.931,0.6,1.5a0.379,0.379,0,0,0,.352.239,0.4,0.4,0,0,0,.141-0.026,0.38,0.38,0,0,0,.216-0.2,0.393,0.393,0,0,0,0-.305C9.47,6.067,9.271,5.56,9.058,5.062A0.494,0.494,0,0,0,8.88,4.871Zm-2.895.16C5.729,5.64,5.54,6.113,5.37,6.563a0.354,0.354,0,0,0,.035.33,0.464,0.464,0,0,0,.393.181H5.831l0.026-.021L5.893,7.03a0.427,0.427,0,0,0,.186-0.178c0.23-.54.44-1.077,0.614-1.532A0.383,0.383,0,0,0,5.985,5.031ZM7.13,6.672a0.375,0.375,0,0,0,.37.4H7.516a0.387,0.387,0,0,0,.27-0.1A0.4,0.4,0,0,0,7.9,6.679c0.006-.466.006-0.943,0-1.459a0.408,0.408,0,0,0-.117-0.3,0.392,0.392,0,0,0-.658.306c0,0.168,0,.338,0,0.5,0,0.07,0,.14,0,0.21s0,0.148,0,.222C7.127,6.331,7.127,6.5,7.13,6.672ZM4.778,15.095H4.825a0.394,0.394,0,0,0,.405-0.37,0.383,0.383,0,0,0-.385-0.408l-0.082-.007L4.689,14.3a1.982,1.982,0,0,1-1.828-1.921,0.4,0.4,0,0,0-.391-0.444h0a0.358,0.358,0,0,0-.261.1,0.492,0.492,0,0,0-.124.361A2.781,2.781,0,0,0,4.778,15.095Z"/>
                                                            </svg>
                                                        </span>
                                                        <p>'.esc_html($list['lcp_restaurant_protfolio_list_bathroom']).'</p>
                                                    </li>';
                                                }
                                            echo '</ul>
                                        </div>
                                    </div>
                                </div>';
                            }
                        }
                    echo '</div>';
                    if(!empty($settings['lcp_restaurant_protfolio_btn_title'])){
                        echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-btn lc-btn-style28 lc-viewbtn-style28">
                                    <a href="'.esc_url($settings['lcp_restaurant_protfolio_btn_link']).'">'.esc_html($settings['lcp_restaurant_protfolio_btn_title']).'</a>
                                </div>
                            </div>
                        </div>';
                    }
                echo '</div>
            </div>';   
		}
	}
}