<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Realestate_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_realestate_testimonials';
	}
 
	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Realestate Testimonials', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_realestate_testimonials_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_realestate_testimonials_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_realestate_testimonials_list_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_realestate_testimonials_list_author',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_realestate_testimonials_list_desc',
            [
                'label'       => esc_html__( 'Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_realestate_testimonials_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_realestate_testimonials_list_author}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_realestate_testimonials_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_realestate_testimonials_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_testimonials_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style28 > h3'
            ]
        );
        $this->add_control(
            'lcp_realestate_testimonials_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style28 > h3' => 'color: {{VALUE}};',
                ], 
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_realestate_testimonials_style_author',
			[
				'label' => esc_html__( 'Author', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_testimonials_style_author_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .btest-box-text-style28 > h4'
            ]
        );
        $this->add_control(
            'lcp_realestate_testimonials_style_author_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .btest-box-text-style28 > h4' => 'color: {{VALUE}};',
                ], 
            ]
        );
        
        //  Style
        $this->add_control(
			'lcp_realestate_testimonials_style_testi',
			[
				'label' => esc_html__( 'Testimonial', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_realestate_testimonials_style_testi_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-testimonial-box-style28 > p'
            ]
        );
        $this->add_control(
            'lcp_realestate_testimonials_style_testi_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-style28 > p' => 'color: {{VALUE}};',
                ], 
            ]
        );
        //  Style
        $this->add_control(
			'lcp_realestate_testimonials_style_extra', 
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_realestate_testimonials_style_quote_color',
            [
                'label'     => esc_html__( 'Quote Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-test-quote-icon-style28 > svg > .cls-1' => 'fill: {{VALUE}};',
                ], 
            ]
        );
        $this->add_control(
            'lcp_realestate_testimonials_style_quote_hcolor',
            [
                'label'     => esc_html__( 'Quote Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-style28:hover .lc-test-quote-icon-style28 > svg > .cls-1' => 'fill: {{VALUE}};',
                ], 
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-testimonial-wrapper lc-testimonial-style28">
                <div class="container">';
                    if(!empty($settings['lcp_realestate_testimonials_title'])){
                        echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-heading-wrapper lc-heading-style28 lc-testhead-style28">
                                    <h3>'.esc_html($settings['lcp_realestate_testimonials_title']).'</h3>
                                </div>
                            </div>
                        </div>';
                    }
                    if(!empty($settings['lcp_realestate_testimonials_list'])){
                        echo '<div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-testimonial-slider-wrapper">
                                    <div class="swiper lc-testimonial-slider-style28"> 
                                        <div class="swiper-wrapper">';
                                            foreach($settings['lcp_realestate_testimonials_list'] as $list){
                                                echo '<div class="swiper-slide">
                                                    <div class="lc-testimonial-box lc-testimonial-box-style28">
                                                        <div class="lc-testimonial-box-img-wrapper lc-testimonial-box-img-wrapper-style28">';
                                                            if(!empty($list['lcp_realestate_testimonials_list_image']['url'])){
                                                                echo '<img src="'.esc_url($list['lcp_realestate_testimonials_list_image']['url']).'" alt="'.esc_attr('testimonial-img','leadcapture').'">';
                                                            }
                                                            if(!empty($list['lcp_realestate_testimonials_list_author'])){
                                                                echo '<div class="btest-box-text btest-box-text-style28">
                                                                    <h4>'.esc_html($list['lcp_realestate_testimonials_list_author']).'</h4>
                                                                </div>';
                                                            }
                                                        echo '</div>';
                                                        if(!empty($list['lcp_realestate_testimonials_list_desc'])){
                                                            echo '<p>'.esc_html($list['lcp_realestate_testimonials_list_desc']).'</p>';
                                                        }
                                                        echo '<div class="lc-test-quote-icon lc-test-quote-icon-style28">
                                                            <svg xmlns="http://www.w3.org/2000/svg" width="43" height="31" viewBox="0 0 43 31">
                                                                <path class="cls-1" d="M8.027,20.254A24.03,24.03,0,0,1,3.6,27.178a2.1,2.1,0,0,0,1.577,3.49,1.77,1.77,0,0,0,.6-0.085c4.214-1.22,14.061-5.548,14.333-19.425a10.257,10.257,0,0,0-9-10.472A10.232,10.232,0,0,0,3.311,3.2,9.857,9.857,0,0,0,8.027,20.254ZM33.984,0.686A10.218,10.218,0,0,0,26.2,3.2a9.857,9.857,0,0,0,4.716,17.056,24.031,24.031,0,0,1-4.429,6.924,2.1,2.1,0,0,0,1.577,3.49,1.77,1.77,0,0,0,.6-0.085C32.881,29.363,42.728,25.035,43,11.158v-0.2A10.25,10.25,0,0,0,33.984.686Z"/>
                                                            </svg>
                                                        </div>
                                                    </div>
                                                </div>';
                                            }
                                        echo '</div>
                                        <div class="swiper-pagination"></div>
                                    </div>
                                </div>
                            </div>
                        </div>';    
                    }
                echo '</div>
            </div>';   
		}
	}
}