<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Restaurant_Contact extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_restaurant_contact';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Restaurant Contact', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_restaurant_contact_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
        $this->add_control(
            'lcp_restaurant_contact_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_desc',
            [
                'label'       => esc_html__( 'Decription', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_enquiry',
            [
                'label'       => esc_html__( 'Enquiry Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_phone',
            [
                'label'       => esc_html__( 'Phone', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_shortcode',
            [
                'label'       => esc_html__( 'Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_b_image',
            [
				'label'       => esc_html__( 'Big Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_restaurant_contact_left_image',
            [
				'label'       => esc_html__( 'Left Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_restaurant_contact_right_image',
            [
				'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section(); 
		
		// Widget Style
        $this->start_controls_section(
            'lcp_restaurant_contact_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_restaurant_contact_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_contact_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-book-form-heading-style27 > h2'
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-book-form-heading-style27 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_restaurant_contact_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_contact_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-book-form-heading-style27 > p'
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-book-form-heading-style27 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Heading Style
        $this->add_control(
			'lcp_restaurant_contact_style_enquiry',
			[
				'label' => esc_html__( 'Enquiry Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_contact_style_enquiry_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-bookenquiry-text > span'
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_style_enquiry_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bookenquiry-text > span' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Phone Style
        $this->add_control(
			'lcp_restaurant_contact_style_phone',
			[
				'label' => esc_html__( 'Phone', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_contact_style_phone_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-bookenquiry-text > p'
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_style_phone_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-bookenquiry-text > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Phone Style
        $this->add_control(
			'lcp_restaurant_contact_style_extra',
			[
				'label' => esc_html__( 'extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_restaurant_contact_style_extra_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-form-wrapper.lc-form-wrapper-style27' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_style_extra_icon_color',
            [
                'label'     => esc_html__( 'Icon Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-book-enquiry-call > svg > .cls-1' => 'fill: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_style_extra_icon_bgcolor',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-book-enquiry-call' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_restaurant_contact_style_extra_phone_bgcolor',
            [
                'label'     => esc_html__( 'Phone Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-book-enquiry-style27' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-appointment-section lc-appointment-section-style27">
                <div class="container">';
                    if($settings['lcp_restaurant_contact_left_image']['url']){
                        echo '<div class="lc-plateimg-style27">
                            <img src="'.esc_url($settings['lcp_restaurant_contact_left_image']['url']).'" alt="'.esc_html('food1','leadcapture').'">
                        </div>';
                    }
                    echo '<div class="lc-appointment-form-wrapper lc-appointment-form-wrapper-style27">
                        <div class="row">
                            <div class="col-lg-4 col-md-12 col-sm-12">';
                                if($settings['lcp_restaurant_contact_b_image']['url']){
                                    echo '<div class="lc-book-img lc-book-img-style27">
                                        <img src="'.esc_html($settings['lcp_restaurant_contact_b_image']['url']).'">
                                    </div>';
                                }
                            echo '</div>
                            <div class="col-lg-8 col-md-12 col-sm-12">
                                <div class="lc-form-wrapper lc-form-wrapper-style27">
                                    <div class="lc-book-form-heading lc-book-form-heading-style27">
                                        <div class="lc-book-enquiry-style27">
                                            <div class="lc-book-enquiry-call">
                                                <svg xmlns="http://www.w3.org/2000/svg" width="49" height="50" viewBox="0 0 49 50">
                                                    <path class="cls-1" d="M0,13.767c0.072-.578.111-1.162,0.222-1.731A7.274,7.274,0,0,1,2.116,8.323c1.316-1.373,2.587-2.8,4-4.06,2.158-1.914,4.5-1.9,6.579.082,2.211,2.112,4.33,4.331,6.4,6.591a4.511,4.511,0,0,1,.029,5.982c-1.1,1.281-2.321,2.462-3.507,3.668a0.5,0.5,0,0,0-.123.694,27.46,27.46,0,0,0,4.68,6.51,32.476,32.476,0,0,0,6.207,5.335c0.655,0.426,1.356.778,2.085,1.191,0.893-.921,1.741-1.851,2.649-2.715a11.569,11.569,0,0,1,2.116-1.726,4.108,4.108,0,0,1,4.977.625c2.264,2.223,4.5,4.483,6.65,6.816a4.6,4.6,0,0,1,.066,6.152c-1.357,1.574-2.809,3.069-4.286,4.528a6.979,6.979,0,0,1-4.11,1.913,2.158,2.158,0,0,0-.317.091H34.39c-0.105-.029-0.209-0.067-0.316-0.087-1.033-.192-2.084-0.314-3.1-0.584a35.366,35.366,0,0,1-9.994-4.677,50.415,50.415,0,0,1-18.034-20.2A29.053,29.053,0,0,1,.336,17C0.173,16.162.109,15.3,0,14.451V13.767Zm2.82,0.418c0.052,0.566.1,1.133,0.158,1.7a7.431,7.431,0,0,0,.146.765,31.7,31.7,0,0,0,3.981,9.61A47.282,47.282,0,0,0,26.571,44.572,22.291,22.291,0,0,0,34.6,47.13a5.261,5.261,0,0,0,4.573-1.61c1.037-1.1,2.1-2.187,3.145-3.282a5.831,5.831,0,0,0,.442-0.513,1.929,1.929,0,0,0-.069-2.658c-0.751-.842-1.557-1.633-2.345-2.44-1.228-1.257-2.452-2.517-3.695-3.758a1.823,1.823,0,0,0-2.8-.054c-0.143.129-.279,0.267-0.415,0.4-1.1,1.115-2.185,2.237-3.288,3.344a2.029,2.029,0,0,1-2.536.493,30.021,30.021,0,0,1-2.722-1.526A36.322,36.322,0,0,1,17,28.471,26.3,26.3,0,0,1,12.94,22.41c-0.871-1.9-.755-2.417.74-3.887,1.068-1.05,2.131-2.108,3.148-3.209a1.858,1.858,0,0,0,.022-2.746c-0.093-.112-0.189-0.221-0.29-0.325q-2.79-2.851-5.585-5.7a3.273,3.273,0,0,0-.716-0.563,1.964,1.964,0,0,0-2.5.586C6.7,7.63,5.678,8.729,4.6,9.771A5.6,5.6,0,0,0,2.82,14.185ZM27.258,0c0.587,0.123,1.3.241,1.99,0.42a26.083,26.083,0,0,1,11.29,6.109,26.442,26.442,0,0,1,7.347,11.238,42.7,42.7,0,0,1,1.076,4.24,1.329,1.329,0,0,1-1.044,1.647,1.35,1.35,0,0,1-1.627-1c-0.22-.8-0.352-1.617-0.567-2.415A23.8,23.8,0,0,0,36.966,7.213a22.68,22.68,0,0,0-9.545-4.285,4.687,4.687,0,0,1-.787-0.2,1.412,1.412,0,0,1-.855-1.574A1.452,1.452,0,0,1,27.258,0ZM26.886,9.077a14.038,14.038,0,0,1,3.835,1.16,16.219,16.219,0,0,1,9.37,12.092,1.446,1.446,0,0,1-1.04,1.765,1.428,1.428,0,0,1-1.677-1.087,25.815,25.815,0,0,0-.975-3.2,13.137,13.137,0,0,0-9.749-7.89A1.425,1.425,0,0,1,26.886,9.077Z"/>
                                                  </svg>
                                            </div>
                                            <div class="lc-bookenquiry-text">';
                                                if(!empty($settings['lcp_restaurant_contact_enquiry'])){
                                                    echo '<span>'.esc_html($settings['lcp_restaurant_contact_enquiry']).'</span>';
                                                }
                                                if(!empty($settings['lcp_restaurant_contact_phone'])){
                                                    echo '<p>'.esc_html($settings['lcp_restaurant_contact_phone']).'</p>';
                                                }
                                            echo '</div>
                                        </div>';
                                        if(!empty($settings['lcp_restaurant_contact_title'])){
                                            echo '<h2>'.esc_html($settings['lcp_restaurant_contact_title']).'</h2>';
                                        }
                                        if(!empty($settings['lcp_restaurant_contact_desc'])){
                                            echo '<p>'.esc_html($settings['lcp_restaurant_contact_desc']).'</p>';
                                        }
                                        if(!empty($settings['lcp_restaurant_contact_shortcode'])){
                                            echo '<div class="lc-book-form-wrapper lc-book-form-wrapper-style27">';
                                                echo do_shortcode($settings['lcp_restaurant_contact_shortcode']);
                                            echo '</div>';
                                        }
                                    echo '</div>
                                </div>
                            </div>
                        </div>
                    </div>';
                    if(!empty($settings['lcp_restaurant_contact_right_image'])){
                        echo '<div class="lc-plateimg2-style27">
                            <img src="'.esc_url($settings['lcp_restaurant_contact_right_image']['url']).'" alt="'.esc_attr('food1','leadcapture').'">
                        </div>';
                    }
                echo '</div>
            </div>';   
		}
	}
}