<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Restaurant_Menu extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_restaurant_menu';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Restaurant Menu', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $this->start_controls_section(
            'lcp_restaurant_menu_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
		$this->add_control(
            'lcp_restaurant_menu_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_desc',
            [
                'label'       => esc_html__( 'Decription', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_currency',
            [
                'label'       => esc_html__( 'Currency Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_btn_title',
            [
                'label'       => esc_html__( 'Button Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_title_one',
            [
                'label'       => esc_html__( 'Menu Title One', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_restaurant_menu_list_one_title',
            [
                'label'       => esc_html__( 'Menu Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_menu_list_one_ingredient',
            [
                'label'       => esc_html__( 'Ingredient', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_menu_list_one_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_restaurant_menu_list_one_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_list_one',
            [
                'label'       => esc_html__( 'Menu List One', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_restaurant_menu_list_one_title}}',
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_title_two',
            [
                'label'       => esc_html__( 'Menu Title Two', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeaters = new Repeater();
		$repeaters->add_control(
            'lcp_restaurant_menu_list_two_title',
            [
                'label'       => esc_html__( 'Menu Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeaters->add_control(
            'lcp_restaurant_menu_list_two_ingredient',
            [
                'label'       => esc_html__( 'Ingredient', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeaters->add_control(
            'lcp_restaurant_menu_list_two_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeaters->add_control(
            'lcp_restaurant_menu_list_two_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_list_two',
            [
                'label'       => esc_html__( 'Menu List Two', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeaters->get_controls(),
                'title_field' => '{{lcp_restaurant_menu_list_two_title}}',
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		// Widget Style
        $this->start_controls_section(
            'lcp_restaurant_menu_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_restaurant_menu_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style27 > h3'
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_restaurant_menu_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style27 > p'
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button One Style
        $this->add_control(
			'lcp_restaurant_menu_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27 a'
            ]
        );
        
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_restaurant_menu_style_button_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_restaurant_menu_style_button_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_restaurant_menu_style_button_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_button_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27',
            ]
        );
		$this->add_control(
            'lcp_restaurant_menu_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_restaurant_menu_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_restaurant_menu_style_button_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_restaurant_menu_style_button_hbg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27:hover' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_button_hborder',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27:hover',
            ]
        );
		$this->add_control(
            'lcp_restaurant_menu_style_button_border_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-heading-style27-btn > .lc-btn-style27:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs(); 
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_restaurant_menu_style_menu', 
            [
                'label' => esc_html__( 'Menu Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_restaurant_menu_style_menu_heading',
			[
				'label' => esc_html__( 'Menu List Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_menu_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricelist-wrapper-style27 > h3'
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_menu_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricelist-wrapper-style27 > h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_menu_heading_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricelist-wrapper-style27 > h3' => 'background: {{VALUE}};',
                ],
            ]
        );
        //Menu Title
        $this->add_control(
			'lcp_restaurant_menu_style_menu_mtitle',
			[
				'label' => esc_html__( 'Menu Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_menu_mtitle_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-price-content-style27 > a'
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_menu_mtitle_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-price-content-style27 > a' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Menu Ingredient
        $this->add_control(
			'lcp_restaurant_menu_style_menu_mingredient',
			[
				'label' => esc_html__( 'Menu Ingredient', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_menu_mingredient_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-price-content-style27 > p'
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_menu_mingredient_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-price-content-style27 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Menu Price
        $this->add_control(
			'lcp_restaurant_menu_style_menu_mprice',
			[
				'label' => esc_html__( 'Menu Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_restaurant_menu_style_menu_mprice_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-price-value-style27 > h6'
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_menu_mprice_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-price-value-style27 > h6' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Menu Price
        $this->add_control(
			'lcp_restaurant_menu_style_menu_mextra',
			[
				'label' => esc_html__( 'Menu Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_restaurant_menu_style_menu_mextra_bgcolor',
            [
                'label'     => esc_html__( 'Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricelist-wrapper-style27' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_restaurant_menu_style_menu_mextra_bordercolor',
            [
                'label'     => esc_html__( 'Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricelist-wrapper-style27' => 'border: 2px solid {{VALUE}};',
                ],
            ]
        );
        
        
        
        
        
        
        
        
        
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-price-list-wrapper lc-price-list-wrapper-style27" id="price-list">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-7">
                            <div class="lc-pricebox-style27">
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-6">
                                        <div class="lc-heading-wrapper lc-heading-style27">';
                                            if(!empty($settings['lcp_restaurant_menu_title'])){
                                                echo '<h3>'.esc_html($settings['lcp_restaurant_menu_title']).'</h3>';
                                            }
                                            if(!empty($settings['lcp_restaurant_menu_desc'])){
                                                echo '<p>'.esc_html($settings['lcp_restaurant_menu_desc']).'</p>';
                                            }
                                        echo '</div>
                                    </div>
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-6">
                                        <div class="lc-heading-style27-btn">';
                                            if(!empty($settings['lcp_restaurant_menu_btn_title'])){
                                                echo '<div class="lc-btn lc-btn-style27 lc-view-btn-style27">
                                                    <a href="'.esc_url($settings['lcp_restaurant_menu_btn_link']).'">'.esc_html($settings['lcp_restaurant_menu_btn_title']).'</a>
                                                </div>';
                                            }
                                        echo '</div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-12">
                                        <div class="lc-pricelist-wrapper lc-pricelist-wrapper-style27">';
                                            if(!empty($settings['lcp_restaurant_menu_title_one'])){
                                                echo '<h3>'.esc_html($settings['lcp_restaurant_menu_title_one']).'</h3>';
                                            }
                                            echo '<div class="lc-price-box lc-pricebox-style27">';
                                                if($settings['lcp_restaurant_menu_list_one']){
                                                    foreach($settings['lcp_restaurant_menu_list_one'] as $list){
                                                        echo '<div class="lc-pricebox-content-style27">
                                                            <div class="lc-price-content lc-price-content-style27">';
                                                                if(!empty($list['lcp_restaurant_menu_list_one_title'])){
                                                                    echo '<a href="'.esc_url($list['lcp_restaurant_menu_list_one_link']).'">'.esc_html($list['lcp_restaurant_menu_list_one_title']).'</a>';
                                                                }
                                                                if(!empty($list['lcp_restaurant_menu_list_one_ingredient'])){
                                                                    echo '<p>'.esc_html($list['lcp_restaurant_menu_list_one_ingredient']).'</p>';
                                                                }
                                                            echo '</div>
                                                            <div class="lc-price-value lc-price-value-style27">';
                                                                if(!empty($list['lcp_restaurant_menu_list_one_price'])){
                                                                    echo '<h6>'.esc_html($settings['lcp_restaurant_menu_currency'].$list['lcp_restaurant_menu_list_one_price']).'</h6>';
                                                                }
                                                            echo '</div>
                                                        </div>';
                                                    }
                                                }
                                            echo '</div>
                                        </div>
                                    </div>
                                    <div class="col-lg-6 col-sm-12 col-md-6">
                                        <div class="lc-pricelist-wrapper lc-pricelist-wrapper-style27">';
                                            if(!empty($settings['lcp_restaurant_menu_title_two'])){
                                                echo '<h3>'.esc_html($settings['lcp_restaurant_menu_title_two']).'</h3>';
                                            }
                                            echo '<div class="lc-price-box lc-pricebox-style27">';
                                                if($settings['lcp_restaurant_menu_list_two']){
                                                    foreach($settings['lcp_restaurant_menu_list_two'] as $list){
                                                        echo '<div class="lc-pricebox-content-style27">
                                                            <div class="lc-price-content lc-price-content-style27">';
                                                                if(!empty($list['lcp_restaurant_menu_list_two_title'])){
                                                                    echo '<a href="'.esc_url($list['lcp_restaurant_menu_list_two_link']).'">'.esc_html($list['lcp_restaurant_menu_list_two_title']).'</a>';
                                                                }
                                                                if(!empty($list['lcp_restaurant_menu_list_two_ingredient'])){
                                                                    echo '<p>'.esc_html($list['lcp_restaurant_menu_list_two_ingredient']).'</p>';
                                                                }
                                                            echo '</div>
                                                            <div class="lc-price-value lc-price-value-style27">';
                                                                if(!empty($list['lcp_restaurant_menu_list_two_price'])){
                                                                    echo '<h6>'.esc_html($settings['lcp_restaurant_menu_currency'].$list['lcp_restaurant_menu_list_two_price']).'</h6>';
                                                                }
                                                            echo '</div>
                                                        </div>';
                                                    }
                                                }
                                            echo '</div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-5">';
                            if($settings['lcp_restaurant_menu_image']['url']){
                                echo '<div class="lc-menu-img-wrapper lc-menu-img-wrapper-style27">
                                    <img src="'.esc_url($settings['lcp_restaurant_menu_image']['url']).'" alt="'.esc_attr('menu-man-img', 'leadcapture').'">
                                </div>';
                            }
                        echo '</div>
                    </div>
                </div>
            </div>';
		}
	}
}