<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Roof_Constructions_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_roof_constructions_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Roof Constructions', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_roof_constructions_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_roof_constructions_logo',
            [
				'label'       => esc_html__( 'Section Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_roof_constructions_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_roof_constructions_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_roof_constructions_button',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_roof_constructions_button_url',
            [
                'label'       => esc_html__( 'Button URL', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_roof_constructions_right_heading',
            [
				'label'       => esc_html__( 'Right Title', 'leadcapture' ),
                 'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_roof_constructions_right_description',
            [
                'label'       => esc_html__( 'Right Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_roof_constructions_right_image',
            [
				'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_roof_constructions_newsletter_form',
            [
				'label'       => esc_html__( 'News Letter Shortcode', 'leadcapture' ),
                 'type'        => Controls_Manager::TEXT,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
	
        
        // Widget Style
        $this->start_controls_section(
            'lcp_roof_banner_style_list', 
            [
                'label' => esc_html__( 'Heading Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_roof_banner_style_list_heading',
			[
				'label' => esc_html__( 'Heading Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_roof_banner_style_list_number_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style41 h1'
            ]
        );
        $this->add_control(
            'lcp_roof_banner_style_list_number_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style41 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        
        // Description Heading Style 
        $this->add_control(
			'lcp_roof_banner_style_list_description',
			[
				'label' => esc_html__( 'Description Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_roof_banner_style_list_description_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style41 > p'
            ]
        );
        $this->add_control(
            'lcp_roof_banner_style_list_description_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style41 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Button Style 
        $this->add_control(
			'lcp_roof_banner_style_list_button',
			[
				'label' => esc_html__( 'Button Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_roof_banner_style_list_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style41'
            ]
        );
        $this->add_control(
            'lcp_roof_banner_style_list_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style41' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_roof_banner_style_list_btnbg_color',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style41' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_roof_banner_style_list_btnbg_hover_color',
            [
                'label'     => esc_html__( 'Background Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style41:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Right Heading Style 
        $this->add_control(
			'lcp_roof_banner_right_heading',
			[
				'label' => esc_html__( 'Right Heading Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_roof_banner_right_heading_typography',
                'label'       => esc_html__( 'Right Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-newsltr-text-style41 > h4'
            ]
        );
        $this->add_control(
            'lcp_roof_banner_right_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-newsltr-text-style41 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Right Describtion Style 
        $this->add_control(
			'lcp_roof_banner_right_describtion',
			[
				'label' => esc_html__( 'Right Describtion Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_roof_banner_right_describtion_typography',
                'label'       => esc_html__( 'Right Describtion Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-newsltr-text-style41 > p'
            ]
        );
        $this->add_control(
            'lcp_roof_banner_right_describtion_color',
            [
                'label'     => esc_html__( 'Describtion Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-newsltr-text-style41 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<!-- banner section start -->
			<div class="lc-banner-wrapper-style41">
				<div class="container-fluid">
					<div class="row gy-4 align-items-center">
						<div class="col-lg-4">
							<div class="lc-banner-left-style41">';
    					if(!empty($settings['lcp_roof_constructions_logo']['url'])):
    						echo '<div class="lc-logo-style41">
									<a href="javascript:;">
										<img src="'.esc_url($settings['lcp_roof_constructions_logo']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
									</a>
								</div>';
					    endif;
						echo '<div class="lc-banner-heading-style41">';
						        if(!empty($settings['lcp_roof_constructions_banner_title'])):
						           echo '<h1>'.esc_html($settings['lcp_roof_constructions_banner_title']).'</h1>';
						        endif;   
    								if(!empty($settings['lcp_roof_constructions_description'])):
								 echo '<p>'.esc_html($settings['lcp_roof_constructions_description']).'</p>';
								endif;   
								echo '</div>';
								if(!empty($settings['lcp_roof_constructions_button'])):
								echo '<div class="lc-banner-btn-style41">
									<a href="'.esc_url($settings['lcp_roof_constructions_button_url']).'" class="lc-btn-style41">'.esc_html($settings['lcp_roof_constructions_button']).'</a>
								</div>';
								endif;
							echo '</div>
						</div>
						<div class="col-lg-8">
							<div class="lc-banner-right-style41">';
							if(!empty($settings['lcp_roof_constructions_right_image']['url'])):
							    echo '<img src="'.esc_url($settings['lcp_roof_constructions_right_image']['url']).'" alt="'.esc_attr__('Right-image', 'leadcapture').'">';
							endif;
								echo '<div class="lc-banner-newsltr-box">
									<div class="lc-newsltr-text-style41">';
									if(!empty($settings['lcp_roof_constructions_right_heading'])):
									   echo '<h4>'.esc_html($settings['lcp_roof_constructions_right_heading']).'</h4>';
									endif;
                                    if(!empty($settings['lcp_roof_constructions_right_description'])):
                                        echo '<p>'.esc_html($settings['lcp_roof_constructions_right_description']).'</p>';
                                    endif;
									echo '</div>
									<div class="lc-newsltr-field-style41">';
                                    if(!empty($settings['lcp_roof_constructions_newsletter_form'])):	
            						    echo do_shortcode($settings['lcp_roof_constructions_newsletter_form']);
            						endif;
								echo '</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>	
		<!-- banner section end -->';
	    }
	}
}