<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Roof_Constructions_Team extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_roof_constructions_team';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Roof Constructions Team', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_team',
            [
            'label' => esc_html__('Team Settings', 'leadcapture'),
            ] 
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_team_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_team_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_team_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_team_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_team_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_team_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_team_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_team_author}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * team Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('team Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('team Typography', 'leadcapture'),
            'name'     => 'lps_meetup_testi_typography',
            'selector' => '{{WRAPPER}} .lps-typography',
            ]
        );
        $this->add_control(
        	'lps_cons_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('team Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_designation_typography',
            'selector' => '{{WRAPPER}} .lps-designation-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_designation_text_color',
        	[
        	'label' => esc_html__('Team Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-designation-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<!-- team section start -->
		<div class="lc-team-wrapper-style41">
			<div class="container">
				<div class="row gy-4">';
				if(!empty($settings['leadcapture_team_list'])):
                    foreach($settings['leadcapture_team_list'] as $teams):
					echo '<div class="col-lg-3 col-md-6">
						<div class="lc-team-main-style41">
							<div class="lc-team-img-style41">';
								if(!empty($teams['leadcapture_team_image']['url'])):  
									echo '<img src="'.esc_url($teams['leadcapture_team_image']['url']).'" alt="'.esc_attr__('team','leadcapture').'">';
								endif;
							echo '</div>
							<div class="lc-team-text-style41">';
								if($teams['leadcapture_team_author']):
								    echo '<h4 class="lps-typography add-author-text-colors">'.esc_html($teams['leadcapture_team_author']).'</h4>';
								endif;
								if($teams['leadcapture_team_dest']):
									echo '<p class="lps-designation-typography add-designation-colors">'.esc_html($teams['leadcapture_team_dest']).'</p>';
								endif;
							echo '</div>
						</div>
					</div>';
					endforeach;
				endif; 
			echo '</div>
			</div>
		</div>	
		<!-- team section end -->';
  }
}