<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Sea_Food_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_sea_food_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Sea Food', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_sea_food_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_sea_food_banner_subtitle',
            [
                'label'       => esc_html__( 'Sub Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_btn_text',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_btn_url',
            [
                'label'       => esc_html__( 'Button URL', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_newsletter_head',
            [
                'label'       => esc_html__( 'News Letter Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_sea_food_newsletter_desrcription',
            [
                'label'       => esc_html__( 'News Letter Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_sea_food_newsletter_form',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
       
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_sea_food_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Sub Heading Style
        $this->add_control(
			'lcp_sea_food_banner_style_subheading',
			[
				'label' => esc_html__( 'Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_sea_food_banner_style_subheading_typography',
                'label'       => esc_html__( 'Sub Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style45 p'
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_style_subheading_color',
            [
                'label'     => esc_html__( 'Sub Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style45 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_sea_food_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_sea_food_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style45 h1'
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style45 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button Style
        $this->add_control(
			'lcp_sea_food_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_sea_food_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style45'
            ]
        );
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_sea_food_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_sea_food_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style45' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_sea_food_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style45' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_sea_food_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style45',
            ]
        );
		$this->add_control(
            'lcp_sea_food_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style45' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
        
        
        // NewsLetter Heading Style
        $this->add_control(
			'lcp_sea_food_banner_style_news_heading',
			[
				'label' => esc_html__( 'News Letter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_sea_food_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-newsltr-parent-style45 h4'
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-newsltr-parent-style45 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        // NewsLetter Sub  Heading Style
        $this->add_control(
			'lcp_sea_food_banner_style_subnews_heading',
			[
				'label' => esc_html__( 'News Letter Sub Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_sea_food_banner_style_newssub_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-newsltr-parent-style45 p'
            ]
        );
        $this->add_control(
            'lcp_sea_food_banner_style_newssub_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-newsltr-parent-style45 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<!-- banner section start -->
	<div class="lc-banner-wrapper-style45">
		<div class="container-fluid">
			<div class="row">
				<div class="col-xl-5 offset-xl-7 col-lg-6 offset-lg-6 col-md-12 offset-md-12">
					<div class="lc-banner-right-style45">
						<div class="lc-banner-heading-style45">';
						if(!empty($settings['lcp_sea_food_banner_subtitle'])):
						    echo '<p>'.esc_html($settings['lcp_sea_food_banner_subtitle']).'</p>';
						endif;
						if(!empty($settings['lcp_sea_food_banner_title'])):
						    echo '<h1>'.esc_html($settings['lcp_sea_food_banner_title']).'</h1>';
						endif;
						if(!empty($settings['lcp_sea_food_banner_btn_text'])):
						    echo '<a href="'.esc_html($settings['lcp_sea_food_banner_btn_url']).'" class="lc-btn-style45">'.esc_html($settings['lcp_sea_food_banner_btn_text']).'</a>';
						endif;
						echo '</div>
						    <div class="lc-banner-newsltr-parent-style45">';
						    if(!empty($settings['lcp_sea_food_banner_newsletter_head'])):
							    echo '<h4>'.esc_html($settings['lcp_sea_food_banner_newsletter_head']).'</h4>';
							endif;
							if(!empty($settings['lcp_sea_food_newsletter_desrcription'])):
							    echo '<p>'.esc_html($settings['lcp_sea_food_newsletter_desrcription']).'</p>';
							endif;
							if(!empty($settings['lcp_sea_food_newsletter_form'])):
							    echo do_shortcode($settings['lcp_sea_food_newsletter_form']);
							endif;
						echo '</div>
					</div>
				</div>
			</div>
		</div>
	</div>
	<!-- banner section end -->	';
	}
	}
}