<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();
 
/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Sea_Food_Products extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_sea_food_product';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __('Leadcapture Sea Food Products', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array('leadcapture-widget');
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'leadcapture_general',
            [
            'label' => esc_html__('Product Settings', 'leadcapture' ),
            ] 
        );
	    $repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_product_title',
            [
            'label' => esc_html__( 'Product Title', 'leadcapture' ),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_real_price',
            [
            'label'  => esc_html__('Price', 'leadcapture' ),
            'type'   => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_rating',
            [
            'label' => esc_html__('Rating', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
		$repeater->add_control(
            'leadcapture_product_image',
            [
			'label' => esc_html__( 'Product Image', 'leadcapture' ),
            'type'  => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
        $repeater->add_control(
            'leadcapture_delivery',
            [
            'label' => esc_html__('Delivery Time', 'leadcapture' ),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( '', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'leadcapture_product_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                    'leadcapture_product_title'  => esc_html__('', 'leadcapture'),
					'leadcapture_real_price'  => esc_html__('', 'leadcapture'),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_product_title}}',
            ]
        );
		$this->end_controls_section();
       	/**
       	 * Product Setting
       	 */ 
       	$this->start_controls_section(
            'lps_heading_style_tab',
            [
            'label' => esc_html__('Product Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Product Heading Typography', 'leadcapture'),
            'name'     => 'lps_heading_typography',
            'selector' => '{{WRAPPER}} .lc-product-details-style45 h4',
            ]
        );
        $this->add_control(
        	'lps_pro_heading_text_color',
        	[
        	'label' => esc_html__('Product Heading Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-product-details-style45 h4' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Product Price Typography', 'leadcapture'),
            'name'     => 'lps_product_price_typography',
            'selector' => '{{WRAPPER}} .lc-product-details-style45 h6',
            ]
        );
        $this->add_control(
        	'lps_real_price_color',
        	[
        	'label' => esc_html__('Price Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-product-details-style45 h6' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_control(
        	'lps_rating_color',
        	[
        	'label' => esc_html__('Rating Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-rating-style45' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Rating Typography', 'leadcapture'),
            'name'     => 'lps_product_rating_typography',
            'selector' => '{{WRAPPER}} .lc-rating-style45',
            ]
        );
        $this->add_control(
        	'lps_carticon_bg_colors',
        	[
        	'label' => esc_html__('Rating Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        		'{{WRAPPER}} .lc-product-details-style45 span.lc-rating-style45' => 'background-color: {{VALUE}}',
        	  ],
        	]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Delivery Typography', 'leadcapture'),
            'name'     => 'lps_product_delivery_typography',
            'selector' => '{{WRAPPER}} .lc-product-details-style45 p',
            ]
        );
        $this->add_control(
        	'lps_delivery_color',
        	[
        	'label' => esc_html__('Delivery Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-product-details-style45 p' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<!-- product section start -->
		<div class="lc-product-wrapper-style45">
			<div class="container">
				<div class="row gy-4">';
                    if(!empty($settings['leadcapture_product_list'])):
                        foreach($settings['leadcapture_product_list'] as $product_de):
                        echo '<div class="col-lg-3 col-md-6">
						<div class="lc-product-main-style45">';
							if(!empty($product_de['leadcapture_product_image']['url'])):
                                echo '<div class="lc-product-img">
                                    <img src="'.esc_url($product_de['leadcapture_product_image']['url']).'" alt="'.esc_attr__('product','leadcapture').'">
                                    </div>';
                            endif;
							echo '<div class="lc-product-details-style45">';
							    if(!empty($product_de['leadcapture_product_title'])):
							        echo '<h4>'.esc_html($product_de['leadcapture_product_title']).'</h4>';
							    endif;
							    if(!empty($product_de['leadcapture_real_price'])):
							        echo '<h6>'.esc_html($product_de['leadcapture_real_price']).'</h6>';
							    endif;   
								if(!empty($product_de['leadcapture_rating'])):
							        echo '<span class="lc-rating-style45"><i class="fa fa-star"></i>'.esc_html($product_de['leadcapture_rating']).'</span>';
							    endif;   						
								if(!empty($product_de['leadcapture_delivery'])):
								    echo '<p><span><svg width="12" height="12" viewBox="0 0 12 12">  
									<path id="Icon" d="M701,2166a6,6,0,1,0,6,6,6.005,6.005,0,0,0-6-6h0Zm0,10.72a4.72,4.72,0,1,1,4.724-4.72,4.722,4.722,0,0,1-4.724,4.72h0Zm0,0,3.127-4.9h-2.7v-3.25a0.494,0.494,0,0,0-.988,0v3.74a0.492,0.492,0,0,0,.494.49h3.19a0.49,0.49,0,1,0,0-.98h0Zm0,0" transform="translate(-695 -2166)"/>
								  </svg></span>'.esc_html($product_de['leadcapture_delivery']).'</p>';	
								endif; 												
							 echo '</div>
						</div>
					</div>';
                    endforeach;                                 
                endif;
                echo '</div>
			</div>
		</div>
		<!-- product section end -->'; 
	}
}