<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Security_Abouts extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_security_abouts';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Security Abouts', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $this->start_controls_section(
            'lcp_security_abouts_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
		$this->add_control(
            'lcp_security_abouts_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_security_abouts_textarea',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::WYSIWYG,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_security_abouts_phone_title',
            [
                'label'       => esc_html__( 'Phone Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_security_abouts_phone_number',
            [
                'label'       => esc_html__( 'Phone Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_security_abouts_phone_icon',
            [
				'label'       => esc_html__( 'Phone Icon', 'invory' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_security_abouts_image_one',
            [
				'label'       => esc_html__( 'Image One', 'invory' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_security_abouts_image_two',
            [
				'label'       => esc_html__( 'Image Two', 'invory' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_security_abouts_counter_list_title',
            [
                'label'       => esc_html__( 'Title', 'invory' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_security_abouts_counter_list_number',
            [
                'label'       => esc_html__( 'Number', 'invory' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_security_abouts_counter_list_suffix',
            [
                'label'       => esc_html__( 'Suffix', 'invory' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_security_abouts_counter_list_icon',
            [
				'label'       => esc_html__( 'Image One', 'invory' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_security_abouts_counter_list',
            [
                'label'       => esc_html__( 'Add Item', 'invory' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_security_abouts_counter_list_title}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_security_abouts_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_security_abouts_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_abouts_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-abouttext-style29 > h2'
            ]
        );
        $this->add_control(
            'lcp_security_abouts_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-abouttext-style29 > h2' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_security_abouts_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_abouts_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-abouttext-style29 > p'
            ]
        );
        $this->add_control(
            'lcp_security_abouts_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-abouttext-style29 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_security_abouts_ptitle',
			[
				'label' => esc_html__( 'Phone Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_abouts_ptitle_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-enquiry-box-text-style29 > span'
            ]
        );
        $this->add_control(
            'lcp_security_abouts_ptitle_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-enquiry-box-text-style29 > span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_security_abouts_ptitle_bgcolor',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-enquiry-style29' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_security_abouts_phone',
			[
				'label' => esc_html__( 'Phone', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_abouts_phone_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-enquiry-box-style29 > p'
            ]
        );
        $this->add_control(
            'lcp_security_abouts_phone_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-enquiry-box-style29 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_security_abouts_counter_style', 
            [
                'label' => esc_html__( 'Counter Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Description Style
        $this->add_control(
			'lcp_security_abouts_counter_style_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_abouts_counter_style_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-box-style29 > p'
            ]
        );
        $this->add_control(
            'lcp_security_abouts_counter_style_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-style29 > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Description Style
        $this->add_control(
			'lcp_security_abouts_counter_style_number',
			[
				'label' => esc_html__( 'Number', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_abouts_counter_style_number_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-box-style29 > h4'
            ]
        );
        $this->add_control(
            'lcp_security_abouts_counter_style_number_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-style29 > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Style
        $this->add_control(
			'lcp_security_abouts_counter_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_security_abouts_counter_style_extra_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-box-img-style29' => 'border: 2px solid {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-about-section-wrapper lc-about-section-style29">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-7">
                            <div class="lc-about-text-wrapper lc-abouttext-wrapper-style29">
                                <div class="row">
                                    <div class="col-lg-7 col-md-7">
                                        <div class="lc-about-text lc-abouttext-style29 fadeInTopLeft wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: fadeInTopLeft;">';
                                            if(!empty($settings['lcp_security_abouts_title'])){
                                                echo '<h2>'.esc_html($settings['lcp_security_abouts_title']).'</h2>';
                                            }
                                            if(!empty($settings['lcp_security_abouts_textarea'])){
                                                printf($settings['lcp_security_abouts_textarea']);
                                            }
                                        echo '</div>
                                        <div class="lc-enquiry-style29 fadeInLeft wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: fadeInLeft;">
                                            <div class="lc-enquiry-box-style29">
                                                <div class="lc-enquiry-box-text-style29">';
                                                    if(!empty($settings['lcp_security_abouts_phone_icon']['url'])){
                                                        echo '<img src="'.esc_url($settings['lcp_security_abouts_phone_icon']['url']).'">';
                                                    }
                                                    if(!empty($settings['lcp_security_abouts_phone_title'])){
                                                        echo '<span>'.esc_html($settings['lcp_security_abouts_phone_title']).'</span>';
                                                    }
                                                echo '</div>';
                                                if(!empty($settings['lcp_security_abouts_phone_number'])){
                                                    echo '<p>'.esc_html($settings['lcp_security_abouts_phone_number']).'</p>';
                                                }
                                            echo '</div>
                                        </div>
                                    </div>
                                    <div class="col-lg-5 col-md-5">
                                        <div class="lc-aboutleft-img lc-aboutleft-img-style29 slideInRight wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: slideInRight;">';
                                            if(!empty($settings['lcp_security_abouts_image_one']['url'])){
                                                echo '<img src="'.esc_url($settings['lcp_security_abouts_image_one']['url']).'" alt="'.esc_attr('security-girl', 'leadcapture').'">';
                                            }
                                        echo '</div>
                                    </div>
                                    <div class="col-lg-12">
                                        <div class="row">';
                                            if(!empty($settings['lcp_security_abouts_counter_list'])){
                                                foreach($settings['lcp_security_abouts_counter_list'] as $list){
                                                    echo '<div class="col-lg-3 col-md-3 col-sm-3 col-6">
                                                        <div class="lc-service-box lc-service-box-style29 flipInY wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: flipInY;">
                                                            <div class="lc-service-box-img lc-service-box-img-style29">';
                                                                if(!empty($list['lcp_security_abouts_counter_list_icon']['url'])){
                                                                    echo '<img src="'.esc_url($list['lcp_security_abouts_counter_list_icon']['url']).'" alt="'.esc_attr('icons', 'leadcapture').'">';
                                                                }
                                                            echo '</div>';
                                                            if(!empty($list['lcp_security_abouts_counter_list_title'])){
                                                                echo '<h4>
                                                                    <span class="lc-counter" data-count="'.esc_attr($list['lcp_security_abouts_counter_list_number']).'">'.esc_html($list['lcp_security_abouts_counter_list_number']).'</span>';
                                                                    if(!empty($list['lcp_security_abouts_counter_list_suffix'])){
                                                                        echo esc_html($list['lcp_security_abouts_counter_list_suffix']);
                                                                    }
                                                                echo '</h4>';
                                                            }
                                                            if(!empty($list['lcp_security_abouts_counter_list_title'])){
                                                                echo '<p>'.esc_html($list['lcp_security_abouts_counter_list_title']).'</p>';
                                                            }
                                                        echo '</div>
                                                    </div>';
                                                }
                                            }
                                        echo '</div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-5">
                            <div class="lc-aboutright-img lc-aboutright-img-style29 zoomIn wow" data-wow-delay="300ms" data-wow-duration="1500ms" style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: zoomIn;">';
                                if(!empty($settings['lcp_security_abouts_image_two']['url'])){
                                    echo '<img src="'.esc_url($settings['lcp_security_abouts_image_two']['url']).'" alt="'.esc_attr('security-boy', 'leadcapture').'">';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>';
		}
	}
}