<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Security_Video extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_security_video';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Security Video', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0 
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_security_video_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_security_video_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_security_video_url',
            [
                'label'       => esc_html__( 'Url', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_security_video_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_security_video_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_security_video_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_security_video_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-video-text > h5'
            ]
        );
        $this->add_control(
            'lcp_security_video_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-video-text > h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_security_video_style_icon',
			[
				'label' => esc_html__( 'Icon', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_security_video_style_icon_color',
            [
                'label'     => esc_html__( 'Icon Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-video-img.lc-video-img-style29' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_security_video_style_icon_effect',
            [
                'label'     => esc_html__( 'Effect Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-video-img > .lc-ripple' => 'box-shadow: 0 0 0 0 {{VALUE}};',
                ],
            ]
        );
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-video-section-wrapper lc-video-setion-wrapper-style29">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="lc-video-box lc-videobox-style29">';
                                if(!empty($settings['lcp_security_video_url'])){
                                    echo ' <a href="'.esc_url($settings['lcp_security_video_url']).'" class="lc-video-img lc-video-img-style29" target="_blank">';
                                        if(!empty($settings['lcp_security_video_image']['url'])){
                                            echo '<img src="'.esc_url($settings['lcp_security_video_image']['url']).'">';
                                        }
                                        echo '<span class="lc-ripple"></span>
                                    </a>';
                                }
                                if(!empty($settings['lcp_security_video_title'])){
                                    echo '<div class="lc-video-text">
                                        <h5>';
                                            printf($settings['lcp_security_video_title']);
                                        echo '</h5>
                                    </div>';
                                }
                            echo '</div>
                        </div>
                    </div>
                </div>
            </div>';
	}
}