<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Single_Property_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_single_property_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Single Property', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_single_property_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_single_property_logo',
            [
				'label'       => esc_html__( 'Section Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_single_property_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_single_property_email',
            [
				'label'       => esc_html__( 'Email Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_single_property_newsletter',
            [
                'label'       => esc_html__( 'NewsLetter Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
         $this->add_control(
            'lcp_single_property_arrow_image',
            [
				'label'       => esc_html__( 'Section Arrow Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_single_property_newsletter_form',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_single_property_image_one',
            [
				'label'       => esc_html__( 'Right Image 1', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_single_property_image_two',
            [
				'label'       => esc_html__( 'Right Image 2', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_single_property_number_head',
            [
                'label'       => esc_html__( 'Right Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_single_property_call_image',
            [
				'label'       => esc_html__( 'Select Phone Number', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_single_property_phone_number',
            [
                'label'       => esc_html__( 'Phone Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
		$this->end_controls_section();
		$this->start_controls_section(
            'lcp_property_banner_statics',
            [
                'label' => esc_html__( 'property Statistics', 'leadcapture' ),
            ] 
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_property_statics_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_property_conter_number',
            [ 
                'label'       => esc_html__( 'Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_property_counter_list_symbol',
            [
                'label'       => esc_html__( 'Symbol', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_property_banner_statics_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_property_statics_list_title}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_property_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_property_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style33 h1'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style33 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_property_banner_style_news_heading',
			[
				'label' => esc_html__( 'NewsLetter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-newltr-styl33 h6'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-newltr-styl33 h6' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_property_banner_style_list', 
            [
                'label' => esc_html__( 'List Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_property_banner_style_list_heading',
			[
				'label' => esc_html__( 'Number Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_list_number_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .count-no'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_list_number_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .count-no' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style 
        $this->add_control(
			'lcp_property_banner_style_list_title',
			[
				'label' => esc_html__( 'Title Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_list_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-info-inner-style33 p'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_list_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-info-inner-style33 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<!-- banner section start -->
		<div class="lc-banner-wrapper-style33">
			<div class="container-fluid">
				<div class="row">
					<div class="col-lg-5">
						<div class="lc-banner-left-style33">';
						if(!empty($settings['lcp_single_property_logo']['url'])):
							echo '<div class="lc-logo-style33">
								<a href="javascript:;">
									<img src="'.esc_url($settings['lcp_single_property_logo']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
								</a>
							</div>';
						endif;
						if(!empty($settings['lcp_single_property_banner_title'])):
							echo '<div class="lc-banner-heading-style33">
							<h1>'.esc_html($settings['lcp_single_property_banner_title']).'</h1>
							</div>';   
						endif;    
						echo '<div class="lc-banner-newltr-styl33">';
						if(!empty($settings['lcp_single_property_email']['url'])):	
							echo '<img src="'.esc_url($settings['lcp_single_property_email']['url']).'" alt="'.esc_attr__('email-image', 'leadcapture').'">';
						endif;
						if(!empty($settings['lcp_single_property_newsletter'])):
							echo '<h6>'.esc_html($settings['lcp_single_property_newsletter']).'</h6>';
						endif;
						if(!empty($settings['lcp_single_property_arrow_image']['url'])):	
							echo '<img src="'.esc_url($settings['lcp_single_property_arrow_image']['url']).'" alt="'.esc_attr__('email-image', 'leadcapture').'" class="ls-banner-arrowimg-33">';
						endif;
						echo '</div>';
						if(!empty($settings['lcp_single_property_newsletter_form'])):	
						    echo do_shortcode($settings['lcp_single_property_newsletter_form']);
						endif;
						if(!empty($settings['lcp_property_banner_statics_list'])):
						    echo '<div class="lc-banner-info-style33">';
    						foreach($settings['lcp_property_banner_statics_list'] as $list):
    							echo '<div class="lc-banner-info-inner-style33">';
    							if(!empty($list['lcp_property_conter_number']) || !empty($list['lcp_property_counter_list_symbol'])):
								 echo '<h4>
                                <span class="count-no" data-count="'.esc_attr($list['lcp_property_conter_number']).'">'.esc_html__('0','astrologer').'</span>
                                <span>'.esc_html($list['lcp_property_counter_list_symbol']).'</span>
								</h4>';
    							endif;
								if(!empty($list['lcp_property_statics_list_title'])):
								    echo '<p>'.esc_html($list['lcp_property_statics_list_title']).'</p>';
								endif;   
    							echo '</div>';
    						endforeach;	
						    echo '</div>';
						endif;
					echo '</div>
				</div>
				<div class="col-lg-7">
					<div class="lc-banner-right-style33">
						<div class="lc-banner-img-style33">';
						if(!empty($settings['lcp_single_property_image_one']['url'])):	
							echo '<img src="'.esc_url($settings['lcp_single_property_image_one']['url']).'" alt="'.esc_attr__('Right-image1', 'leadcapture').'">';
						endif;
						if(!empty($settings['lcp_single_property_image_two']['url'])):	
							echo '<img src="'.esc_url($settings['lcp_single_property_image_two']['url']).'" alt="'.esc_attr__('Right-image2', 'leadcapture').'">';
						endif;
							echo '</div>
						<div class="lc-banner-contact-style33">';
						if(!empty($settings['lcp_single_property_call_image']['url'])):
						    echo '<img src="'.esc_url($settings['lcp_single_property_call_image']['url']).'" alt="'.esc_attr__('call-image', 'leadcapture').'">';
						endif;
							echo '<div class="lc-banner-cnt-detail-style33">';
						if(!empty(['lcp_single_property_number_head'])):
							    echo '<p>'.esc_html($settings['lcp_single_property_number_head']).'</p>';
						endif;
						if(!empty(['lcp_single_property_phone_number'])):
							    echo '<h4>'.esc_html($settings['lcp_single_property_phone_number']).'</h4>';
						endif;	
						echo '</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
	<!-- banner section end -->';
	}
	}
}