<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Single_Property_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_single_property_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Single Property Services', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_single_property_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_single_property_image',
            [
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_single_property_heading',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_single_property_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Praesent tincidunt lorem vel augue mollis, sed ultrices dui pretium.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_single_property_button',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_single_property_btn_url',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        $this->add_control(
            'lcp_single_property_services_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'label'       => esc_html__( 'Add Services', 'leadcapture' ),
                        'lcp_single_property_heading'  => esc_html__( 'Services', 'leadcapture' ),
						'lcp_single_property_description'  => esc_html__( 'Praesent tincidunt lorem vel augue mollis, sed ultrices dui pretium.', 'leadcapture' ),
						'lcp_single_property_button'  => esc_html__( 'Read More', 'leadcapture' ),
                        
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_single_property_heading}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
		$this->start_controls_section(
            'leadcapture_ab_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'leadcapture_ab_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_heading_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-inner-style33 h4'
            ]
        );
        $this->add_control(
            'leadcapture_ab_heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-service-inner-style33 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
         $this->add_control(
            'leadcapture_ab_heading_hover_color',
            [
                'label'     => esc_html__( 'Hover Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-service-inner-style33:hover h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'heading_control',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-service-inner-style33 p',
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-service-inner-style33 p' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        
        // Button Style
        $this->add_control(
			'lcp_interiordesign_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style33'
            ]
        );
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_interiordesign_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_interiordesign_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style33' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_interiordesign_style_btn_hover_color',
            [
                'label'     => esc_html__( 'Title Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style33:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style33' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_interiordesign_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style33',
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style33' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
        
		$this->end_controls_section();
        // Services Link style
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
		if(!empty($settings)):
		 echo '<!-- service section start -->
		<div class="lc-service-wrapper-style33">
			<div class="container">
				<div class="row gy-4">';
				foreach($settings['lcp_single_property_services_list'] as $serv):
					echo '<div class="lc-service-box-style33">
							<div class="lc-service-inner-style33">';
                                if(!empty($serv['lcp_single_property_image']['url'])):
                                    echo '<img src="'.esc_html($serv['lcp_single_property_image']['url']).'" alt="'.esc_attr__('service', 'leadcapture').'">';
                                endif;
                                if(!empty($serv['lcp_single_property_heading'])):
                                    echo '<h4>'.esc_html($serv['lcp_single_property_heading']).'</h4>';
                                endif; 
                                if(!empty($serv['lcp_single_property_description'])):
                                    echo '<p>'.esc_html($serv['lcp_single_property_description']).'</p>';
                                endif;
                                if(!empty($serv['lcp_single_property_button'])):
								 echo '<a href="'.esc_url($serv['lcp_single_property_btn_url']).'" class="lc-btn-style33">'.esc_html($serv['lcp_single_property_button']).'</a>';
								endif;
							echo '</div>
						</div>';
				endforeach;	
				echo'</div>
			</div>
		</div>
		<!-- service section end -->';
		endif;
    }
}