<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Single_Property_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_single_property_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Single Property Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_desc',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Typography', 'leadcapture'),
            'name'     => 'lps_meetup_testi_typography',
            'selector' => '{{WRAPPER}} .lps-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_descs_typography',
            'selector' => '{{WRAPPER}} .lps-desc-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_designation_typography',
            'selector' => '{{WRAPPER}} .lps-designation-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
		$this->add_control(
        	'lps_cons_testi_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-description-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
		$this->add_control(
        	'lps_cons_testi_designation_text_color',
        	[
        	'label' => esc_html__('Testimonial Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-designation-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
          
        $this->add_control(
        	'lps_cons_testi_pagination_color',
        	[
        	'label' => esc_html__('Testimonial Pagination Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testimonial-slider-style11 .swiper-pagination  .swiper-pagination-bullet-active' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<!-- testimonial section start -->
		<div class="lc-testimonial-wrapper-style33">
			<div class="container">
				<div class="swiper lc-testmnl-slider-parent-style33">
					<div class="swiper-wrapper">';
					if(!empty($settings['leadcapture_testimonial_list'])):
                        foreach($settings['leadcapture_testimonial_list'] as $testi):
						echo '<div class="swiper-slide">
							<div class="lc-testmnl-slider-box-style33">
								<div class="lc-tesml-client-info-style33">';
    								if(!empty($testi['leadcapture_testimonial_image']['url'])):  
    									echo '<img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr('testimonial','leadcapture').'">';
    								endif;
									echo '<div class="lc-testmnl-client-name-style33">';
									if($testi['leadcapture_testimonial_author']):
									    echo '<h4 class="lps-typography add-author-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h4>';
									endif;
									if($testi['leadcapture_testimonial_dest']):
										echo '<p class="lps-designation-typography add-designation-colors">'.esc_html($testi['leadcapture_testimonial_dest']).'</p>';
									endif;
									echo '</div>
								</div>
								<div class="lc-testmnl-detail-style33">';
    								if($testi['leadcapture_testimonial_desc']):
    								    echo '<p class="lps-desc-typography add-description-colors">'.esc_html($testi['leadcapture_testimonial_desc']).'</p>';
    								endif;
									echo '<svg version="1.2" viewBox="0 0 35 25" width="35" height="25">									
									<g id="Group">
									<path id="Vector" d="m12.2 20.3c0.5 0.7 1 1.3 1.5 1.9 0.4 0.6 0.5 1.3 0.2 1.9-0.3 0.6-1 1-1.7 0.9-0.3-0.1-0.5-0.2-0.8-0.3-5-1.7-8.5-5-10-10.2-0.7-2.2-1-4.5-0.6-6.8 0.7-4.2 4.6-7.5 9.3-6.5 3.4 0.6 5.8 3.2 6.3 6.8 0.5 3.1-1.2 6.4-4.1 7.9-0.6 0.3-1.4 0.6-2.1 0.9q0.8 1.8 2 3.5z"/>
									<path id="Vector" d="m29.8 19.6c0.6 0.9 1.3 1.8 2 2.6 0.5 0.7 0.5 1.4 0.1 2-0.4 0.6-1.1 0.9-1.8 0.7-3.1-0.9-5.8-2.5-7.9-5-1.8-2.2-2.8-4.8-3.2-7.6-0.3-1.6-0.4-3.2-0.1-4.8 0.8-4 4.6-7.3 9.3-6.3 3.2 0.6 5.7 3.1 6.3 6.5 0.5 3.2-1 6.5-3.9 8.1-0.7 0.4-1.5 0.6-2.4 1 0.5 0.9 1 1.9 1.6 2.8z"/>
									</g>
									</svg>
								</div>
							</div>
						</div>';
					    endforeach;
					endif; 
					echo '</div>
				</div>
			</div>
		</div>
		<!-- testimonial section end -->';
  }
}