<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Solar_Progress_Bar extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_solar-progress-bar';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Solar Progress Bar', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_progress_bar',
            [
            'label' => esc_html__('Progress Bar Settings', 'leadcapture'),
            ] 
        );
		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_progress_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_percentage',
            [
            'label' => esc_html__('Percentage', 'leadcapture'), 
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		
	
		$this->add_control(
            'leadcapture_progress_bar_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_progress_title'  => esc_html__('Solar Energy #', 'leadcapture'),
					'leadcapture_percentage'  => esc_html__('50 #', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_progress_title}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_progress_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Progress Typography', 'leadcapture'),
            'name'     => 'lps_meetup_testi_typography',
            'selector' => '{{WRAPPER}} .it-prog-box h2',
            ]
        );
        
		$this->add_control(
        	'lps_progress_text_color',
        	[
        	'label' => esc_html__('Progress Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .it-prog-box h2' => 'color: {{VALUE}}',
        	 ],
           ]
        );
		$this->add_control(
        	'lps_progress_bg_color',
        	[
        	'label' => esc_html__('Progress Background Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-description-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<div class="it-progresbar-wrapper progress-holder">
	<div class="container-fluid">
		<div class="row">
			<div class="col-lg-12 col-md-12 pr-0">
				<div class="progress-rightbox">
					<div class="row">
						<div class="col-xl-12 col-lg-12">
                        <div class="it-prog-box">';
                       	if(!empty($settings['leadcapture_progress_bar_list'])):
                           foreach($settings['leadcapture_progress_bar_list'] as $bar):
                                
                                if(!empty($bar['leadcapture_progress_title'])): 
                                    echo '<h2>'.esc_html($bar['leadcapture_progress_title']).'</h2>';
                                endif;
                                if(!empty($bar['leadcapture_percentage'])):
                                echo '<div class="progress-bar">
                                    <div class="label" data-count="'.esc_attr($bar['leadcapture_percentage']).'">'.esc_html('0%','inland').'</div>
                                    <div class="line"><span></span></div>
                                </div>'; 
                                endif;
                            endforeach;
                        endif;
						echo '</div>
					</div>
				</div>
			</div>
	 	 </div>
 	  </div>
   </div>
</div>';
  }
}