<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Solar_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_solar_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Solar Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_desc',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Typography', 'leadcapture'),
            'name'     => 'lps_meetup_testi_typography',
            'selector' => '{{WRAPPER}} .lps-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_descs_typography',
            'selector' => '{{WRAPPER}} .lps-desc-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_designation_typography',
            'selector' => '{{WRAPPER}} .lps-designation-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
		$this->add_control(
        	'lps_cons_testi_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-description-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
		$this->add_control(
        	'lps_cons_testi_designation_text_color',
        	[
        	'label' => esc_html__('Testimonial Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-designation-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
          
        $this->add_control(
        	'lps_cons_testi_pagination_color',
        	[
        	'label' => esc_html__('Testimonial Pagination Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testimonial-slider-style11 .swiper-pagination  .swiper-pagination-bullet-active' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<div class="lc-testmonial-section-style37">
		<div class="container">
			<div class="container">
				<div class="lc-testimonialslider-wrapper-style37">
					<div class="row">
						<div class="col-lg-12">
							<div class="swiper lc-testimonialslider-style37">
								<div class="swiper-wrapper">';
                					if(!empty($settings['leadcapture_testimonial_list'])):
                                        foreach($settings['leadcapture_testimonial_list'] as $testi):
                                            echo '<div class="swiper-slide">
                                                <div class="lc-testimonial-slidebox-style37">
                                                    <div class="lc-testslide-namewrapper-style37">
                                                        <div class="lc-testslide-imgname-style37">
                                                        	<div class="lc-testslide-img-style37">';
                                								if(!empty($testi['leadcapture_testimonial_image']['url'])):  
                                									echo '<img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">';
                                								endif;
                        									echo '</div>
                                                        	<div class="lc-testslide-name-style37">';
                                                        	if($testi['leadcapture_testimonial_author']):
                        									    echo '<h3 class="lps-typography add-author-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h3>';
                        									endif;
                                                        	if($testi['leadcapture_testimonial_dest']):
                        										echo '<p class="lps-designation-typography add-designation-colors">'.esc_html($testi['leadcapture_testimonial_dest']).'</p>';
                        									endif;
                                                        	echo '</div>
                                                        </div>
                                                        <div class="lc-testslide-svg-style37">
                                                        	<svg xmlns="http://www.w3.org/2000/svg" width="47" height="41" viewBox="0 0 47 41">
                                                        		<path class="cls-1" d="M11.083,40.124A10.886,10.886,0,0,1,.321,29.141V29.086c0-.036,0-0.09-0.009-0.162C0.091,24.935.73,14.167,11.407,0.368A0.649,0.649,0,0,1,12.33.258,0.679,0.679,0,0,1,12.544,1c-0.03.091-3.948,11.011-1.954,19.172,5.937,0.284,11.524,3.426,11.246,9.485A10.861,10.861,0,0,1,11.08,40.125h0ZM1.635,29.179a9.544,9.544,0,0,0,9.484,9.6A9.548,9.548,0,0,0,20.53,29.1c-0.02-5.31-5.244-7.6-10.447-7.6a0.66,0.66,0,0,1-.634-0.493C7.937,15.393,9.679,7.5,10.43,3.93c-8.469,12.106-9,21.347-8.8,24.919A2.9,2.9,0,0,1,1.635,29.179ZM35.525,40.124A10.886,10.886,0,0,1,24.763,29.141V29.086c0-.036,0-0.09-0.009-0.162-0.221-3.989.418-14.757,11.095-28.556A0.648,0.648,0,0,1,36.772.258,0.679,0.679,0,0,1,36.987,1c-0.03.091-3.948,11.011-1.954,19.172,5.937,0.284,11.524,3.426,11.246,9.485A10.861,10.861,0,0,1,35.522,40.125h0ZM26.077,29.179A9.449,9.449,0,1,0,44.972,29.1c-0.02-5.31-5.244-7.6-10.447-7.6a0.66,0.66,0,0,1-.634-0.493c-1.512-5.615.23-13.5,0.981-17.078-8.469,12.106-9,21.347-8.8,24.919A2.9,2.9,0,0,1,26.077,29.179Z"/>
                                                        	</svg>
                                                        </div>
                                                    </div> ';
                    								if($testi['leadcapture_testimonial_desc']):
                    								    echo '<p class="lps-desc-typography add-description-colors">'.esc_html($testi['leadcapture_testimonial_desc']).'</p>';
                    								endif;          
                                                echo '</div>
                                            </div>';
                					    endforeach;
                					endif; 
                					echo '</div>
								<div class="swiper-pagination"></div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>';
  }
}