<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Spa_Center_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_spa_center_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Spa Center', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_spa_center_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_logo_image',
            [
				'label'       => esc_html__( 'Section Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_banner_title1',
            [
                'label'       => esc_html__( 'Heading 1', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_title2',
            [
                'label'       => esc_html__( 'Heading 2', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_sub_heading',
            [
                'label'       => esc_html__( 'Sub Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_btn',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_btn_url',
            [
                'label'       => esc_html__( 'Button URL', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_email_image',
[
				'label'       => esc_html__( 'Email Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_newsletter_heading',
            [
                'label'       => esc_html__( 'News Letter Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
         $this->add_control(
            'lcp_newsletter_sub_heading',
            [
                'label'       => esc_html__( 'News Letter Sub Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_newsletter_form',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_offer_up_to',
            [
                'label'       => esc_html__( 'Up to', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_discount_offer',
            [
                'label'       => esc_html__( 'Discount', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_booking',
            [
                'label'       => esc_html__( 'booking Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_booking_website_text',
            [
                'label'       => esc_html__( 'Website Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_booking_weburl',
            [
                'label'       => esc_html__( 'Website Url', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_bgshape_image',
            [
				'label'       => esc_html__( 'Select Background Shape', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_style_heading_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style32 h1'
            ]
        );
        $this->add_control(
            'lcp_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style32 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_sub_heading_typography',
                'label'       => esc_html__( 'Sub Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-text-style32 span'
            ]
        );
        $this->add_control(
            'lcp_banner_style_sub_heading_color',
            [
                'label'     => esc_html__( 'Sub Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style32 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_banner_style_sub_heading_bgcolor',
            [
                'label'     => esc_html__( 'Sub Heading backgrond Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-text-style32 span' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_btn_typography',
                'label'       => esc_html__( 'Button Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style32 a'
            ]
        );
        $this->add_control(
            'lcp_btn_color',
            [
                'label'     => esc_html__( 'Button Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style32 a' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_btn_hover_color',
            [
                'label'     => esc_html__( 'Button Hover Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style32 a::after' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_banner_style_news_heading',
			[
				'label' => esc_html__( 'NewsLetter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_newsletter_typography',
                'label'       => esc_html__( 'News Letter Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subupdate-texthead-style32 h3'
            ]
        );
        $this->add_control(
            'lcp_newsletter_color',
            [
                'label'     => esc_html__( 'News Letter Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subupdate-texthead-style32 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_newsletter_subheading_typography',
                'label'       => esc_html__( 'News Sub Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-subupdate-texthead-style32 p'
            ]
        );
        $this->add_control(
            'lcp_newsletter_subheading_color',
            [
                'label'     => esc_html__( 'News Sub Heading color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-subupdate-texthead-style32 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_spa_banner_style_list', 
            [
                'label' => esc_html__( 'Discound Box Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_spa_banner_style_list_heading',
			[
				'label' => esc_html__( 'Discound Box Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_discound_upto_typography',
                'label'       => esc_html__( 'Up to Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc_banner-booking-text-style32 span'
            ]
        );
        $this->add_control(
            'lcp_discound_typography_upto__color',
            [
                'label'     => esc_html__( 'Up to color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc_banner-booking-text-style32 span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_discound_typography',
                'label'       => esc_html__( 'Discound Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc_banner-booking-text-style32 h4'
            ]
        );
        $this->add_control(
            'lcp_discound_color',
            [
                'label'     => esc_html__( 'Discound color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc_banner-booking-text-style32 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_discound_booking_text_typography',
                'label'       => esc_html__( 'Booking Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc_banner-booking-text-style32 p'
            ]
        );
        $this->add_control(
            'lcp_discound_booking_text_color',
            [
                'label'     => esc_html__( 'Booking color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc_banner-booking-text-style32 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '<!-- Add HTML Here  -->
		<div class="lc-banner-section-style32">
			<div class="container-fluid">
				<div class="row">
					<div class="col-lg-12 col-md-12 col-sm-12">';
					    if(!empty($settings['lcp_logo_image']['url'])):
							echo '<div class="lc-logo-style32">
							<img src="'.esc_url($settings['lcp_logo_image']['url']).'" alt="'.esc_attr__('logo-image', 'leadcapture').'">
						</div>';
						endif;
					echo '</div>
					<div class="col-lg-6 col-md-12 col-sm-12">
						<div class="lc-banner-text-style32">';
						if(!empty($settings['lcp_banner_sub_heading'])):
						   	echo '<span>'.esc_html($settings['lcp_banner_sub_heading']).'</span>';
						endif;
						if(!empty($settings['lcp_banner_title1'])):
						    echo '<h1>'.esc_html($settings['lcp_banner_title1']).'<br>'.esc_html($settings['lcp_banner_title2']).'</h1>';
						endif;
						if(!empty($settings['lcp_banner_btn'])):	
							echo '<div class="lc-btn-style32">
								<a href="'.esc_url($settings['lcp_banner_btn_url']).'">'.esc_html($settings['lcp_banner_btn']).'</a>
							</div>';
						endif;
						echo '</div>
						<div class="lc-subscribe-wrapper-style32">
							<div class="lc-subupdate-text-style32">';
                                if(!empty($settings['lcp_email_image']['url'])):
                                    echo '<img src="'.esc_url($settings['lcp_email_image']['url']).'" alt="'.esc_attr__('email-image', 'leadcapture').'">';
                                endif;
								echo '<div class="lc-subupdate-texthead-style32">';
								if(!empty($settings['lcp_newsletter_heading'])):
								    echo '<h3>'.esc_html($settings['lcp_newsletter_heading']).'</h3>';   
							    endif;
								if(!empty($settings['lcp_newsletter_sub_heading'])):
								    echo '<p>'.esc_html($settings['lcp_newsletter_sub_heading']).'</p>';
								endif;
								echo '</div>
							</div>';
							if(!empty($settings['lcp_newsletter_form'])):	
						        echo do_shortcode($settings['lcp_newsletter_form']);
						    endif;	
							echo '</div>
					</div>
				</div>
			</div>
			<div class="lc-banner-icon-style32">';
				 if(!empty($settings['lcp_bgshape_image']['url'])):
                    echo '<img src="'.esc_url($settings['lcp_bgshape_image']['url']).'" alt="'.esc_attr__('bgshape-image', 'leadcapture').'">';
                endif;
			echo '</div>
			<div class="lc-banner-booking-style32">
				<div class="lc-banner-booking-bg-style32">
					<div class="lc_banner-booking-text-style32">';
						if(!empty($settings['lcp_offer_up_to'])):	
						  echo '<span>'.esc_html($settings['lcp_offer_up_to']).'</span>'; 
						endif;
						if(!empty($settings['lcp_discount_offer'])):	
						  echo '<h4>'.esc_html($settings['lcp_discount_offer']).'</h4>'; 
						endif;
						if(!empty($settings['lcp_booking'])):	
						  echo '<p>'.esc_html($settings['lcp_booking']).'</p>'; 
						endif;
						if(!empty($settings['lcp_booking_website_text'])):	
						  echo '<a href="'.esc_url($settings['lcp_booking_weburl']).'">'.esc_html($settings['lcp_booking_website_text']).'</a>'; 
						endif;
					echo '</div>
				</div>
			</div>
		</div>';
	}
	}
}