<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Spa_Center_Pricing_plan extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_spa_center_pricingplan';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Spa Center Pricing Plan', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $this->start_controls_section(
            'lcp_spa_center_pricing_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_pricing_tab_one',
            [
                'label'       => esc_html__( 'Tab One', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
       
        $this->add_control(
            'lcp_pricing_tab_two',
            [
                'label'       => esc_html__( 'Tab Two', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_pricing_tab_three',
            [
                'label'       => esc_html__( 'Tab Three', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'pricing_tab_style',
            [
                'label'   => __( 'Table Tab', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'tab-1',
                'options' => [
                    'tab-1'   => __( 'Pricing One', 'leadcapture' ),
                    'tab-2'   => __( 'Pricing Two', 'leadcapture' ),
					'tab-3'   => __( 'Pricing Three', 'leadcapture' ),
					
                ],
            ]
        );
        $repeater->add_control(
            'lcp_table_active',
            [
                'label'     => esc_html__( 'Table Active', 'leadcapture' ),
                'type'      => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'leadcapture' ),
				'label_off' => esc_html__( 'Hide', 'leadcapture' ),
				'return_value' => 'yes',
				'default' => 'yes',
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_left_image',
           [
               'label'       => esc_html__( 'Left Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_left_discount',
            [
                'label'       => esc_html__( 'Left Discount', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_spa_plan2_setting',
            [
                'label' => esc_html__( 'Plan Two Setting', 'leadcapture' ),
                'type'        => Controls_Manager::HEADING,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_currency',
            [
                'label'       => esc_html__( 'Currency', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
       $repeater->add_control(
            'lcp_spa_center_pricing_period',
            [
                'label'       => esc_html__( 'Time Period', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_one',
            [
                'label'       => esc_html__( 'List 1', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_one_image',
           [
               'label'       => esc_html__( 'List 1', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_two',
            [
                'label'       => esc_html__( 'List 2', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_two_image',
           [
               'label'       => esc_html__( 'List 2', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_three',
            [
                'label'       => esc_html__( 'List 3', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_three_image',
           [
               'label'       => esc_html__( 'List 3', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_four',
            [
                'label'       => esc_html__( 'List 4', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_four_image',
           [
               'label'       => esc_html__( 'List 4', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_five',
            [
                'label'       => esc_html__( 'List 5', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_five_image',
           [
               'label'       => esc_html__( 'List 5', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_six',
            [
                'label'       => esc_html__( 'List 6', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Web & Mobile-Optimized', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_list_six_image',
           [
               'label'       => esc_html__( 'List 6', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_btn_title',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_btn_link',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_spa_plan3_setting',
            [
                'label' => esc_html__( 'Plan 3 Setting', 'leadcapture' ),
                'type'        => Controls_Manager::HEADING,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_plan3_heading',
            [
                'label'       => esc_html__( 'Plan 3 Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_plan3_image',
            [
                'label'       => esc_html__( 'List 3', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_plan3_upto',
            [
                'label'       => esc_html__( 'Up to', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_plan3_discount',
            [
                'label'       => esc_html__( 'Plan 3 Discount', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'lcp_spa_center_pricing_plan3_onoff',
            [
                'label'       => esc_html__( 'Plan 3 ON/OFF', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
            ]
        );
        $this->add_control(
            'lcp_spa_center_pricing_list',
            [
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [ 
                        'lcp_spa_center_pricing_title'  => esc_html__( 'Plan name', 'leadcapture' ),
                        'lcp_spa_center_pricing_left_discount'  => esc_html__( '25% discount', 'leadcapture' ),
                        'lcp_spa_center_pricing_currency'  => esc_html__( '$', 'leadcapture' ),
                        'lcp_spa_center_pricing_price'  => esc_html__( '90', 'leadcapture' ),
                        'lcp_spa_center_pricing_period'  => esc_html__( 'Monthly', 'leadcapture' ),
                        'lcp_spa_center_pricing_btn_title'  => esc_html__( 'Buy Now ', 'leadcapture' ),
                        'lcp_spa_center_pricing_list_one'  => esc_html__( 'Service One', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_spa_center_pricing_title}}',
            ]
        );
		$this->end_controls_section();
		
	    
	    //Widget Style Tab
	    $this->start_controls_section(
            'lcp_spa_center_pricing_style_tab',
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        //Heading Style 
        $this->add_control(
			'lcp_spa_center_pricing_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_spa_center_pricing_style_heading_typography',
                'label'       => esc_html__( 'Image Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing-tabbox-style32 h3'
            ]
        );
        $this->add_control(
            'lcp_spa_center_pricing_style_heading_color',
            [
                'label'     => esc_html__( 'Image Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-tabbox-style32 h3' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Symbol & Price Style 
        $this->add_control(
			'lcp_spa_center_pricing_style_symbol',
			[
				'label' => esc_html__( 'Symbol & Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_spa_center_pricing_style_symbol_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing-tabbox2-style32 h4'
            ]
        );
        $this->add_control(
            'lcp_spa_center_pricing_style_symbol_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-tabbox2-style32 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        //Time Period
        $this->add_control(
			'lcp_spa_center_pricing_style_time',
			[
				'label' => esc_html__( 'Time Period', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_spa_center_pricing_style_symbol_time',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing-tabbox2-style32 h4 span'
            ]
        );
        $this->add_control(
            'lcp_spa_center_symbol_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-tabbox2-style32 h4 span' => 'color: {{VALUE}};',
                ],
            ]
        );
         $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_spa_center_symbol_typography',
                'label'       => esc_html__( 'Description Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing-tabbox-style32 p'
            ]
        );
        $this->add_control(
            'lcp_spa_center_symbol_description',
            [
                'label'     => esc_html__( 'Description', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-tabbox-style32 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        
        //List
        $this->add_control(
			'lcp_spa_center_pricing_style_list',
			[
				'label' => esc_html__( 'List', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_spa_center_list_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricing-tabbox2-style32 ul li'
            ]
        );
        $this->add_control(
            'lcp_spa_center_list_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-pricing-tabbox2-style32 ul li' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        
        // Button Settings Tab
        $this->add_control(
			'lcp_spa_center_pricing_style_button',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_spa_center_pricing_style_button_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricebtn-style32 a',
            ]
        );
        $this->add_control(
            'lcp_spa_center_pricing_style_button_padding',
            [
                'label'      => __( 'Padding', 'leadcapture' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors'  => [
                    '{{WRAPPER}} .lc-pricebtn-style32' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        // Hover or Normal Tab
        $this->start_controls_tabs( 'button_colors' );
        $this->start_controls_tab(
			'lcp_spa_center_pricing_style_button_normal',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_spa_center_pricing_style_button_tcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricebtn-style32 a' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_spa_center_pricing_style_button_border',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricebtn-style32 a',
            ]
        );
		$this->add_control(
            'lcp_spa_center_pricing_style_button_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-pricebtn-style32 a' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lcp_spa_center_pricing_style_button_bt_bg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricebtn-style32 a' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->start_controls_tab(
			'lcp_spa_center_pricing_style_button_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_spa_center_pricing_style_button_htcolor',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-pricebtn-style32 a:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_spa_center_pricing_style_button_hborder',
                'label'    => esc_html__( 'Price Table Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-pricebtn-style32 a:hover',
            ]
        );
		$this->add_control(
            'lcp_spa_center_pricing_style_button_hradius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => 0,
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-pricebtn-style32 a:hover' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->add_control(
            'lcp_spa_center_pricing_style_button_bt_hbg',
            [
                'label'     => esc_html__( 'Button Background', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-plan-btn:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
		
		
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$id = uniqid();
	$settings = $this->get_settings_for_display();
	
	if(!empty($settings)){
	    echo '<div class="lc-pricing-section-style32">
            <div class="container">
                <div class="lc-pricing-tab-style32">
                    <div class="lc-pricing-header-style32">
                        <ul class="nav nav-tabs">';
                        if(!empty($settings['lcp_pricing_tab_one'])):
                            echo '<li class="nav-item wesonalbtn"><a class="active nav-link" data-bs-toggle="tab" href="#tab-1" role="tab">'.esc_html($settings['lcp_pricing_tab_one']).'</a></li>';
                        endif;
                        if(!empty($settings['lcp_pricing_tab_two'])):
                            echo '<li class="nav-item probtn"><a data-bs-toggle="tab" class="nav-link" href="#tab-2" role="tab">'.esc_html($settings['lcp_pricing_tab_two']).'</a></li>';
                        endif;
        				if(!empty($settings['lcp_pricing_tab_three'])):
        				     echo '<li class="nav-item businessbtn"><a data-bs-toggle="tab" class="nav-link" href="#tab-3" role="tab">'.esc_html($settings['lcp_pricing_tab_three']).'</a></li>';
        				endif;
                        echo '</ul>
                    </div>
                    <div class="tab-content">';
        			if(!empty($settings['lcp_spa_center_pricing_list'])):
					    foreach($settings['lcp_spa_center_pricing_list'] as $list):
					         if($list['lcp_table_active'] == 'yes'){
					             $active = 'active';
					         }else{
					            $active = ''; 
					         }
                            if($list['pricing_tab_style'] == 'tab-1'){
                                $tab = 'tab-1';
                            } else if($list['pricing_tab_style'] == 'tab-2'){
                                $tab = 'tab-2';
                            } else {
                                $tab = 'tab-3';
                            }   
                        echo '<div class="tab-pane '.esc_attr($active).'" id="'.esc_attr($tab).'" role="tabpanel">
                            <div class="lc-tab-wrapper-style32">
                                <div class="row justify-content-center">
                                    <div class="col-lg-4 col-md-6">
                                        <div class="lc-pricing-tabbox-style32">';
                                        	if(!empty($list['lcp_spa_center_pricing_title'])):
                                        	    echo '<h3>'.esc_html($list['lcp_spa_center_pricing_title']).'</h3>';
                                        	endif;
                                        	if(!empty($list['lcp_spa_center_pricing_left_image']['url'])):
                                        	    echo '<div class="lc-pricing-tabbox-img-style32">
                                               <img src="'.esc_html($list['lcp_spa_center_pricing_left_image']['url']).'" alt="'.esc_attr__('left-image', 'leadcapture').'">
                                               </div>';
                                            endif;
                                            if(!empty($list['lcp_spa_center_pricing_left_discount'])):
                                                echo '<span>'.esc_html($list['lcp_spa_center_pricing_left_discount']).'</span> ';
                                            endif;                          
                                        echo '</div>
                                    </div>
                                    <div class="col-lg-4 col-md-6">
                                        <div class="lc-pricing-tabbox-style32 lc-pricing-tabbox2-style32">';
                                        if(!empty($list['lcp_spa_center_pricing_currency']) || !empty($list['lcp_spa_center_pricing_price']) || !empty($list['lcp_spa_center_pricing_period'])):
                                           echo '<h4>'.esc_html($list['lcp_spa_center_pricing_currency'].$list['lcp_spa_center_pricing_price']).'<span>/'.esc_html($list['lcp_spa_center_pricing_period']).'</span></h4>';
                                        endif;
                                        if(!empty($list['lcp_spa_center_pricing_description'])):
                                           echo '<p>'.esc_html($list['lcp_spa_center_pricing_description']).'</p>';
                                        endif;
                                        echo '<ul>';
                                            if(!empty($list['lcp_spa_center_pricing_list_one'])):
                                                 echo '<li>';
                                                    if(!empty($list['lcp_spa_center_pricing_list_one_image']['url'])):
                                                        echo '<img src="'.esc_html($list['lcp_spa_center_pricing_list_one_image']['url']).'" alt="'.esc_attr__('list1-image', 'leadcapture').'">';
                                                    endif;
                                                    echo '<p>'.esc_html($list['lcp_spa_center_pricing_list_one']).'</p>
                                                </li>';
                                            endif;
                                            if(!empty($list['lcp_spa_center_pricing_list_two'])):
                                                 echo '<li>';
                                                    if(!empty($list['lcp_spa_center_pricing_list_two_image']['url'])):
                                                        echo '<img src="'.esc_html($list['lcp_spa_center_pricing_list_two_image']['url']).'" alt="'.esc_attr__('list2-image', 'leadcapture').'">';
                                                    endif;
                                                    echo '<p>'.esc_html($list['lcp_spa_center_pricing_list_two']).'</p>
                                                </li>';
                                            endif;
                                            if(!empty($list['lcp_spa_center_pricing_list_three'])):
                                                 echo '<li>';
                                                    if(!empty($list['lcp_spa_center_pricing_list_three_image']['url'])):
                                                        echo '<img src="'.esc_html($list['lcp_spa_center_pricing_list_three_image']['url']).'" alt="'.esc_attr__('list3-image', 'leadcapture').'">';
                                                    endif;
                                                    echo '<p>'.esc_html($list['lcp_spa_center_pricing_list_three']).'</p>
                                                </li>';
                                            endif;
                                            if(!empty($list['lcp_spa_center_pricing_list_four'])):
                                                 echo '<li>';
                                                    if(!empty($list['lcp_spa_center_pricing_list_four_image']['url'])):
                                                        echo '<img src="'.esc_html($list['lcp_spa_center_pricing_list_four_image']['url']).'" alt="'.esc_attr__('list4-image', 'leadcapture').'">';
                                                    endif;
                                                    echo '<p>'.esc_html($list['lcp_spa_center_pricing_list_four']).'</p>
                                                </li>';
                                            endif;
                                            if(!empty($list['lcp_spa_center_pricing_list_five'])):
                                                 echo '<li>';
                                                    if(!empty($list['lcp_spa_center_pricing_list_five_image']['url'])):
                                                        echo '<img src="'.esc_html($list['lcp_spa_center_pricing_list_five_image']['url']).'" alt="'.esc_attr__('list5-image', 'leadcapture').'">';
                                                    endif;
                                                    echo '<p>'.esc_html($list['lcp_spa_center_pricing_list_five']).'</p>
                                                </li>';
                                            endif;
                                            if(!empty($list['lcp_spa_center_pricing_list_six'])):
                                                 echo '<li>';
                                                    if(!empty($list['lcp_spa_center_pricing_list_six_image']['url'])):
                                                        echo '<img src="'.esc_html($list['lcp_spa_center_pricing_list_six_image']['url']).'" alt="'.esc_attr__('list6-image', 'leadcapture').'">';
                                                    endif;
                                                    echo '<p>'.esc_html($list['lcp_spa_center_pricing_list_six']).'</p>
                                                </li>';
                                            endif;  
                                        echo '</ul>';
                                        if(!empty($list['lcp_spa_center_pricing_btn_title'])):
                                            echo '<div class="lc-btn-style32 lc-pricebtn-style32">
                                                <a href="'.esc_url($list['lcp_spa_center_pricing_btn_link']).'">'.esc_html($list['lcp_spa_center_pricing_btn_title']).'</a>
                                            </div>'; 
                                        endif;                             
                                        echo '</div>
                                    </div>
                                    <div class="col-lg-4 col-md-6">
                                        <div class="lc-pricing-tabbox-style32 lc-pricing-tabbox3-style32">';
                                        if(!empty($list['lcp_spa_center_pricing_plan3_heading'])):
                                            echo '<h3>'.esc_html($list['lcp_spa_center_pricing_plan3_heading']).'</h3>';   
                                        endif;
                                        if(!empty($list['lcp_spa_center_pricing_plan3_image']['url'])):
                                            echo '<div class="lc-pricing-tabbox-img-style32">
                                                <img src="'.esc_html($list['lcp_spa_center_pricing_plan3_image']['url']).'" alt="'.esc_attr__('right-image', 'leadcapture').'">
                                            </div>';
                                        endif;    
                                        echo '<div class="lc-off-style32">';
                                            if(!empty($list['lcp_spa_center_pricing_plan3_upto'])):
                                                echo '<span>'.esc_html($list['lcp_spa_center_pricing_plan3_upto']).'</span>';
                                            endif;     
                                            if(!empty($list['lcp_spa_center_pricing_plan3_discount'])):
                                                echo '<h4>'.esc_html($list['lcp_spa_center_pricing_plan3_discount']).'</h4>';
                                            endif;
                                            if(!empty($list['lcp_spa_center_pricing_plan3_onoff'])):
                                                echo '<p>'.esc_html($list['lcp_spa_center_pricing_plan3_onoff']).'</p>';
                                            endif;   
                                        echo '</div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>';
					endforeach;
				endif;
				echo '</div>
                </div>
            </div>
        </div>';
        } 
	}
}