<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Spa_Center_Services extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_spa_center_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Spa Center Services', 'leadcapture');
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_spa_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
         $this->add_control(
            'lcp_srvice_image',
            [
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_service_box_number',
            [
                'label'       => esc_html__( 'Box Number', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '01', 'leadcapture' ),
            ]
        );
         $this->add_control(
            'lcp_service_heading',
            [
                'label'       => esc_html__( 'Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_service_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Praesent tincidunt lorem vel augue mollis, sed ultrices dui pretium.', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_service_button',
            [
                'label'       => esc_html__( 'Button Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Services', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_service_button_url',
            [
                'label'       => esc_html__( 'Button Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
		$this->start_controls_section(
            'leadcapture_ab_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
			'leadcapture_ab_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_heading_typography',
                'label'       => esc_html__( 'Heading Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-ser-boxtext-style32 h4'
            ]
        );
        $this->add_control(
            'leadcapture_ab_heading_color',
            [
                'label'     => esc_html__( 'Heading Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-ser-boxtext-style32 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'heading_control',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_sheading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-ser-boxtext-style32 p',
            ]
        );
        
        $this->add_control(
            'leadcapture_ab_sheading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-ser-boxtext-style32 p' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
        $this->add_control(
			'heading_servies_link_control',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'leadcapture_ab_servies_link_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-ser-boxbtn-style32 a',
            ]
        );
        $this->add_control(
            'leadcapture_ab_servies_link_color',
            [
                'label'     => esc_html__( 'Text Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-ser-boxbtn-style32 a' => 'color: {{VALUE}};',
                ],
                'separator' => 'after',
            ]
        );
		$this->end_controls_section();
        // Services Link style
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)):
		echo '<div class="lc-ser-box-wrapper-style32">';
		if(!empty($settings['lcp_srvice_image']['url'])):
			echo '<div class="lc-ser-boximg-style32">
				<img src="'.esc_url($settings['lcp_srvice_image']['url']).'" alt="'.esc_attr__('service', 'leadcapture').'">
			</div>';
		endif;
		if(!empty($settings['lcp_service_box_number'])):
            echo '<div class="lc-ser-boxnum-style32">
            <p>'.esc_html($settings['lcp_service_box_number']).'</p>
            </div>';
		endif;
		    echo '<div class="lc-ser-boxtext-style32">';
			if(!empty($settings['lcp_service_heading'])):
			    echo '<h4>'.esc_html($settings['lcp_service_heading']).'</h4>';
			endif;
			if(!empty($settings['lcp_service_description'])):
			    echo '<p>'.esc_html($settings['lcp_service_description']).'</p>';
			endif;
			if(!empty($settings['lcp_service_button'])):
			    echo '<div class="lc-ser-boxbtn-style32">
					<a href="'.esc_url($settings['lcp_service_button_url']).'">'.esc_html($settings['lcp_service_button']).' 
					<svg xmlns="http://www.w3.org/2000/svg" width="13" height="10" viewBox="0 0 13 10">
					<path class="cls-1" d="M0.584,4.181A0.611,0.611,0,0,1,.708,4.17H10.776l-0.154-.084a1.459,1.459,0,0,1-.4-0.334L8.235,1.446a0.97,0.97,0,0,1-.1-1.106,0.654,0.654,0,0,1,1-.18,0.786,0.786,0,0,1,.073.072L12.79,4.4a0.934,0.934,0,0,1,0,1.18h0L9.206,9.756a0.648,0.648,0,0,1-1.014,0,0.8,0.8,0,0,1-.061-0.082,0.97,0.97,0,0,1,.1-1.106l1.978-2.311a1.469,1.469,0,0,1,.358-0.3l0.215-.113H0.748a0.776,0.776,0,0,1-.756-0.7A0.828,0.828,0,0,1,.584,4.181Z"/>
					</svg>  
					</a>
				</div>';
			endif;
			echo '</div>
		</div>';
		endif;
    }
}