<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Startup_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_startup_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Startup Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_startup_testimonials_general', 
            [
               'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        ); 
       
        $repeater = new Repeater();
		$repeater->add_control(
            'lcp_startup_testimonials_list_author',
            [
                'label'       => esc_html__( 'Author', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_startup_testimonials_list_postion',
            [
                'label'       => esc_html__( 'Designation', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_startup_testimonials_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_startup_test_image',
            [
				'label'       => esc_html__( 'Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
		$this->add_control(
            'lcp_startup_testimonials_list',
            [
                'label'       => esc_html__( 'Add Testimonial', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_startup_testimonials_list_author}}',
            ]
        );
		$this->end_controls_section();
		
		// Widget Style
        $this->start_controls_section(
            'lcp_startup_testimonials_testi_style_tab', 
            [
                'label' => esc_html__( 'Testimonial Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Heading Style
        $this->add_control(
			'lcp_startup_testimonials_style_author',
			[
				'label' => esc_html__( 'Author', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_startup_testimonials_style_author_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .author-typography > h4'
            ]
        );
        $this->add_control(
            'lcp_startup_startup_style_author_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .author-color > h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Postion Style
        $this->add_control(
			'lcp_startup_startup_designation',
			[
				'label' => esc_html__( 'Designation', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_startup_testimonials_style_postion_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .startup-designation > p'
            ]
        );
        $this->add_control(
            'lcp_startup_testimonials_style_postion_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .startup-designation-color > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Postion Style
        $this->add_control(
			'lcp_startup_testimonials_style_testi',
			[
				'label' => esc_html__( 'Testimonial', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_startup_testimonials_style_testi_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-testimonial-box-startup > p'
            ]
        );
        $this->add_control(
            'lcp_startup_testimonials_style_testi_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-box-startup > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_startup_testimonials_nav_style_tab', 
            [
                'label' => esc_html__( 'Bullet Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'lcp_startup_testimonials_style_nav_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-slider-wrapper .swiper-pagination-bullet' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_startup_testimonials_style_nav_acolor',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-testimonial-slider-style24 .swiper-pagination .swiper-pagination-bullet.swiper-pagination-bullet-active' => 'background: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
	    echo '<!------- Testimonial-Section-Start ------>
        <div class="lc-testimonial-startup">
            <div class="container">                
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="lc-testimonial-slider-wrapper headShake wow" data-wow-delay="300ms"
                            data-wow-duration="1500ms"
                            style="visibility: visible; animation-duration: 1500ms; animation-delay: 300ms; animation-name: headShake;">
                            <div class="swiper lc-testimonial-slider-startup">
                                <div class="swiper-wrapper">';
                                if(!empty($settings['lcp_startup_testimonials_list'])):
                                    foreach($settings['lcp_startup_testimonials_list'] as $list):
                                     echo '<div class="swiper-slide">
                                        <div class="lc-testimonial-slider-inner-startup">';
                                        	if(!empty($list['lcp_startup_testimonials_desc'])){
											echo '<div class="lc-testimonial-box-startup">
												<p>'.esc_html($list['lcp_startup_testimonials_desc']).'</p>                                            
											</div>';
                                        	}
											echo '<div class="lc-testimonial-box-img-wrapper lc-testimonial-box-img-wrapper-startup">
												<div class="lc-testimonial-box-img lc-testimonial-box-img-startup">';
												if(!empty($list['lcp_startup_test_image']['url'])):
												echo '<img src="'.esc_url($list['lcp_startup_test_image']['url']).'" alt="'.esc_attr__('testimonial','leadcapture').'">';
												endif;
													echo '<div class="btest-box-text btest-box-text-startup author-typography author-color startup-designation startup-designation-color">';
													if(!empty($list['lcp_startup_testimonials_list_author'])){
													    echo '<h4>'.esc_html($list['lcp_startup_testimonials_list_author']).'</h4>';
													}
													if(!empty($list['lcp_startup_testimonials_list_postion'])){
													    echo '<p>'.esc_html($list['lcp_startup_testimonials_list_postion']).'</p>';
													}
													echo '</div>
												</div>
											</div>
										</div>
                                    </div>';
                                    endforeach;
                                endif;
                                echo '</div>
                                <div class="swiper-pagination"></div>								
                            </div>
                        </div>
                    </div>
                </div>
            </div>
			<div class="lc-testimonial-navigation-startup">
				<div class="swiper-button-next"></div>
				<div class="swiper-button-prev"></div>
			</div>
        </div>';
		}
	}
}