<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Tatto_Blog extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_tatto_blog';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Tatto Blog', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    $categories = get_categories();
		$cats = array();
		foreach( $categories as $terms ){
			$cats[$terms->term_id] = $terms->name;
		}
		$this->start_controls_section(
            'lcp_tatto_blog_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_tatto_blog_post_show',
            [
                'label'       => esc_html__( 'Number of Post', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '3', 'leadcapture' ),
            ]
        );
        $this->add_control(
            'lcp_tatto_blog_category',
            [
                'label'   => __( 'Select Categories', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT2,
				'multiple' => true,
                'options' => $cats
            ]
        );
        $this->add_control(
            'lcp_tatto_blog_order_by',
            [
                'label'   => __( 'Order By', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'   => __( 'None', 'leadcapture' ),
                    'id'   => __( 'Id', 'leadcapture' ),					
					'title'   => __( 'Title', 'leadcapture' ),
					'date'   => __( 'Date', 'leadcapture' ),
                ],
            ]
        );
		$this->add_control(
            'lcp_tatto_blog_sort',
            [
                'label'   => __( 'Sort Order', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC'   => __( 'Ascending', 'leadcapture' ),
                    'DESC'   => __( 'Descending', 'leadcapture' ),
                ],
            ]
        );
		$this->end_controls_section();
		
		//Widget Style
		$this->start_controls_section(
            'lcp_tatto_blog_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        //Title Style
        $this->add_control(
			'lcp_tatto_blog_style_title',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_tatto_blog_style_title_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text >h4'
            ]
        );
        $this->add_control(
            'lcp_tatto_blog_style_title_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text >h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Description Style
        $this->add_control(
			'lcp_tatto_blog_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_tatto_blog_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-text > p'
            ]
        );
        $this->add_control(
            'lcp_tatto_blog_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-text > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Meta Deta Style
        $this->add_control(
			'lcp_tatto_blog_style_meta',
			[
				'label' => esc_html__( 'Metadata', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_tatto_blog_style_meta_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-date > p, .lc-blog-comment > p'
            ]
        );
        $this->add_control(
            'lcp_tatto_blog_style_meta_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-date > p' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-blog-comment > p' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-blog-text-date > div span svg path' => 'fill: {{VALUE}};',
                ],
            ]
        );
        
        //Link Style
        $this->add_control(
			'lcp_tatto_blog_style_link',
			[
				'label' => esc_html__( 'Link', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_tatto_blog_style_link_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-blog-btn a'
            ]
        );
        $this->add_control(
            'lcp_tatto_blog_style_link_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-btn a' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .lc-blog-btn a svg path' => 'fill: {{VALUE}};',
                    '{{WRAPPER}} .lc-blog-text > .lc-blog-btn > a:after' => 'background: {{VALUE}};'
                ],
            ]
        );
        
        //Hover Style
        $this->add_control(
			'lcp_tatto_blog_style_hover',
			[
				'label' => esc_html__( 'Hover', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
            'lcp_tatto_blog_style_title_hcolor',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-box-wrapper:hover .lc-blog-text >h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'lcp_tatto_blog_style_link_hcolor',
            [
                'label'     => esc_html__( 'Link Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-blog-btn:hover > a' => 'color: {{VALUE}};',
                ],
            ]
        );
        
		$this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    if(!empty($settings['lcp_tatto_blog_category'])){
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_tatto_blog_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_tatto_blog_sort'],
    				'orderby'         => $settings['lcp_tatto_blog_order_by'],
    				'tax_query' => array(
    				array(
    					'taxonomy'  => 'category',
    					'field'     => 'ID',
    					'terms'     => $settings['lcp_tatto_blog_category'],
    					),
    				),	
    			));
    		} else {
    			$query = new \WP_Query( array(
    				'post_type' => 'post', 
    				'posts_per_page' => $settings['lcp_tatto_blog_post_show'],
    				'post_status'     => 'publish',
    				'order'           => $settings['lcp_tatto_blog_sort'],
    				'orderby'         => $settings['lcp_tatto_blog_order_by'],
    			));
    		}
		    
		    echo '<div class="row">';
		        if($query->have_posts() ) {
		            while($query->have_posts()): $query->the_post();
		                echo '<div class="col-lg-4 col-md-6 col-sm-12">
                            <div class="lc-blog-box-wrapper">
                                <div class="lc-blog-img">';
                                    $attach_id = get_post_thumbnail_id(get_the_ID());
                    				$thumbnail_url = wp_get_attachment_url($attach_id, 'full');
                                    if(!empty($thumbnail_url)){
                                        echo '<img src="'.esc_html($thumbnail_url).'" alt="blog-img">';
                                    }
                                echo '</div>
                                <div class="lc-blog-text">
                                    <div class="lc-blog-text-date">
                                        <div class="lc-blog-date">
                                            <span>
                                                <svg style="width: 15px;margin-top: -7px;" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" version="1.1" x="0" y="0" viewBox="0 0 512.228 512.228" style="enable-background:new 0 0 512 512" xml:space="preserve"><g><g><path d="m413.333 39.447h-19.106v-19.333c0-11.046-8.954-20-20-20s-20 8.954-20 20v19.333h-196.227v-19.333c0-11.046-8.954-20-20-20s-20 8.954-20 20v19.333h-19.105c-54.531 0-98.895 44.364-98.895 98.894v274.878c0 54.531 44.364 98.895 98.895 98.895h314.439c54.53 0 98.894-44.364 98.894-98.895v-274.878c0-54.53-44.364-98.894-98.895-98.894zm-314.438 40h19.105v39c0 11.046 8.954 20 20 20s20-8.954 20-20v-39h196.228v39c0 11.046 8.954 20 20 20s20-8.954 20-20v-39h19.106c32.474 0 58.894 26.42 58.894 58.894v19.106h-432.228v-19.106c0-32.474 26.42-58.894 58.895-58.894zm314.438 392.667h-314.438c-32.475 0-58.895-26.42-58.895-58.895v-215.772h432.228v215.772c0 32.475-26.42 58.895-58.895 58.895zm-235.666-196c0 11.046-8.954 20-20 20h-39.333c-11.046 0-20-8.954-20-20s8.954-20 20-20h39.333c11.045 0 20 8.954 20 20zm236.228 0c0 11.046-8.954 20-20 20h-39.333c-11.046 0-20-8.954-20-20s8.954-20 20-20h39.333c11.045 0 20 8.954 20 20zm-118.228 0c0 11.046-8.954 20-20 20h-39.333c-11.046 0-20-8.954-20-20s8.954-20 20-20h39.333c11.045 0 20 8.954 20 20zm-118 118c0 11.046-8.954 20-20 20h-39.333c-11.046 0-20-8.954-20-20s8.954-20 20-20h39.333c11.045 0 20 8.954 20 20zm236.228 0c0 11.046-8.954 20-20 20h-39.333c-11.046 0-20-8.954-20-20s8.954-20 20-20h39.333c11.045 0 20 8.954 20 20zm-118.228 0c0 11.046-8.954 20-20 20h-39.333c-11.046 0-20-8.954-20-20s8.954-20 20-20h39.333c11.045 0 20 8.954 20 20z" fill="currentColor" data-original="#000000"/></g></g></svg>
                                            </span>
                                            <p>'.esc_html(get_the_date('M d, Y')).'</p>
                                        </div>
                                        <div class="lc-blog-comment">
                                            <span>
                                                <svg style="width: 15px;margin-top: -7px;" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:svgjs="http://svgjs.com/svgjs" version="1.1" x="0" y="0" viewBox="0 0 512 512" style="enable-background:new 0 0 512 512" xml:space="preserve"><g><path d="m480.052 369.741c49.476-69.417 41.913-164.522-25.665-226.473-30.877-28.305-70.24-45.926-112.761-50.847-.265-.326-.536-.649-.833-.958-36.991-38.425-90.135-60.463-145.805-60.463-105.939 0-194.988 78.933-194.988 180 0 35.435 11.007 69.404 31.916 98.741l-29.209 91.706c-1.836 5.764-.03 12.065 4.579 15.982 4.617 3.924 11.13 4.678 16.511 1.941l88.827-45.167c18.242 7.855 37.586 13.009 57.618 15.354 38.642 40.636 92.073 61.443 146.738 61.443 28.416 0 56.729-5.791 82.36-16.798l88.831 45.169c2.151 1.094 4.48 1.629 6.795 1.629 10.123 0 17.38-9.865 14.295-19.553zm-361.374-25.72c-4.201-1.995-9.088-1.929-13.233.179l-63.267 32.17 20.66-64.866c1.504-4.723.579-9.883-2.473-13.788-19.866-25.43-30.367-55.415-30.367-86.716 0-82.71 74.014-150 164.99-150 36.636 0 71.905 11.099 100.514 31.086-96.348 9.688-173.51 84.942-173.51 178.914 0 29.228 7.492 57.366 21.617 82.576-8.552-2.547-16.881-5.732-24.931-9.555zm287.845 60.178c-4.085-2.077-8.976-2.202-13.233-.178-23.385 11.108-49.772 16.979-76.31 16.979-90.976 0-164.99-67.29-164.99-150s74.014-150 164.99-150 164.99 67.29 164.99 150c0 31.301-10.501 61.286-30.368 86.715-3.051 3.905-3.976 9.065-2.473 13.788l20.66 64.866z" fill="currentColor" data-original="#000000"/></g></svg>
                                            </span>
                                            <p>';
                                            if(get_comments_number(get_the_ID()) == "1"){
    											echo get_comments_number(get_the_ID()); 
    										} else{
    											echo get_comments_number(get_the_ID());    
    										}
    										echo esc_html(' Comments', 'leadcapture').'</p>
                                        </div>
                                    </div>
                                    <h4>'. substr(get_the_title(),0,100).'</h4>
                                    <p>'. substr(get_the_excerpt(),0,300).'</p>
                                    <div class="lc-blog-btn">
                                        <a href="'. esc_url(get_permalink()).'">'.esc_html('Read More', 'leadcapture').'
                                            <svg version="1.2" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 17 16"
                                                width="17" height="16">
                                                <title>Shape 6</title>
                                                <path id="Shape 6" class="s0"
                                                    d="m2.8 7q0.1 0 0.1 0h9.2l-0.2-0.1q-0.3-0.1-0.5-0.4l-2.6-2.8c-0.3-0.3-0.4-0.9-0.1-1.3 0.3-0.4 0.9-0.5 1.3-0.2q0 0 0.1 0.1l4.6 5c0.4 0.4 0.4 1 0 1.4q0 0 0 0l-4.6 5c-0.4 0.4-1 0.4-1.3 0q-0.1 0-0.1-0.1c-0.3-0.4-0.2-1 0.1-1.3l2.6-2.8q0.2-0.2 0.4-0.4l0.3-0.1h-9.1c-0.5 0-0.9-0.3-1-0.8-0.1-0.6 0.3-1.1 0.8-1.2z" />
                                            </svg>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </div>';
		            endwhile;
					wp_reset_query();
		        }
		    echo '</div>';
		}
	}
}