<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Tatto_Pricelist extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_tatto_pricelist';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Tatto Price List', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_tatto_price_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_tatto_price_list_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( 'Classic Tattoo', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_tatto_price_list_desc',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default'     => esc_html__( 'Consectetur adipiscingdo eiusmod tempor incididunt ut labore et dolore magna.', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_tatto_price_list_price',
            [
                'label'       => esc_html__( 'Price', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__( '$30', 'leadcapture' ),
            ]
        );
        $repeater->add_control(
            'lcp_tatto_price_list_link',
            [
                'label'       => esc_html__( 'Link', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_tatto_price_list',
            [
                'label'       => esc_html__( 'Price List', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'default'     => [
                    [
                        'lcp_tatto_price_list_title'  => esc_html__( 'Classic Tattoo', 'leadcapture' ),
						'lcp_tatto_price_list_desc'  => esc_html__( 'Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture' ),
						'lcp_tatto_price_list_price'  => esc_html__( '$30', 'leadcapture' ),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_tatto_price_list_title}}',
            ]
        );
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_tatto_price_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        // Title Tab
        $this->add_control(
			'lcp_tatto_price_style_heading',
			[
				'label' => esc_html__( 'Title', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_tatto_price_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-price-content > a'
            ]
        );
        $this->add_control(
            'lcp_tatto_price_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-price-content > a' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Description Tab
        $this->add_control(
			'lcp_tatto_price_style_desc',
			[
				'label' => esc_html__( 'Description', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_tatto_price_style_desc_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-price-content > p'
            ]
        );
        $this->add_control(
            'lcp_tatto_price_style_desc_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-price-content > p' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Price Tab
        $this->add_control(
			'lcp_tatto_price_style_price',
			[
				'label' => esc_html__( 'Price', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_tatto_price_style_price_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-price-value > h6'
            ]
        );
        $this->add_control(
            'lcp_tatto_price_style_price_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-price-value > h6' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Price Tab
        $this->add_control(
			'lcp_tatto_price_style_extra',
			[
				'label' => esc_html__( 'Extra', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
            'lcp_tatto_price_style_extra_bcolor',
            [
                'label'     => esc_html__( 'Border Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '', 
                'selectors' => [
                    '{{WRAPPER}} .lc-price-box:after' => 'border-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$id = uniqid();	
		$settings = $this->get_settings_for_display();
		if(!empty($settings)){
		    echo '<div class="lc-pricelist-div">';
		        if(!empty($settings['lcp_tatto_price_list'])){
		            foreach($settings['lcp_tatto_price_list'] as $list){
		                echo '<div class="lc-price-box">
		                    <div class="lc-price-content">';
    		                    $link = !empty($list['lcp_tatto_price_list']) ? $list['lcp_tatto_price_list'] : '#';
    		                    echo '<a href="'.esc_url($link).'">';
    		                        if(!empty($list['lcp_tatto_price_list_title'])){
    		                            echo esc_html($list['lcp_tatto_price_list_title']);
    		                        }
    		                    echo '</a>';
    		                    if($list['lcp_tatto_price_list_desc']){
    		                        echo '<p>'.esc_html($list['lcp_tatto_price_list_desc']).'</p>';
    		                    }
                            echo '</div>
                            <div class="lc-price-value">';
                                if($list['lcp_tatto_price_list_price']){
                                    echo '<h6>'.esc_html($list['lcp_tatto_price_list_price']).'</h6>';
                                }
                            echo '</div>
		                </div>';
		            }
		        }
		    echo '</div>';
		}
	}
}