<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Yoga_Classes_Banner extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_yoga_classes_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Yoga Classes', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_yoga_classes_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_yoga_classes_logo',
            [
				'label'       => esc_html__( 'Section Logo Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
			]
        );
        $this->add_control(
            'lcp_yoga_classes_banner_title',
            [
                'label'       => esc_html__( 'Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_banner_description',
            [
                'label'       => esc_html__( 'Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_banner_button',
            [
                'label'       => esc_html__( 'Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_banner_button_url',
            [
                'label'       => esc_html__( 'Button URL', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_video_text',
            [
                'label'       => esc_html__( 'Video Text', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_video_url',
            [
                'label'       => esc_html__( 'Video Url', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_newsletter',
            [
                'label'       => esc_html__( 'NewsLetter Title', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_newsletter_desc',
            [
                'label'       => esc_html__( 'NewsLetter Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_newsletter_form',
            [
                'label'       => esc_html__( 'News Letter Form Shortcode', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        $this->end_controls_section();
    	$this->start_controls_section(
            'lcp_yoga_classes_banner_right',
            [
                'label' => esc_html__( 'General Right Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_yoga_classes_right_image',
            [
                'label'       => esc_html__( 'Right Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box1_image',
            [
                'label'       => esc_html__( 'Box 1 Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box1_heading',
            [
                'label'       => esc_html__( 'Box 1 Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box1_description',
            [
                'label'       => esc_html__( 'Box 2 Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box2_image',
            [
                'label'       => esc_html__( 'Box 2 Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box2_heading',
            [
                'label'       => esc_html__( 'Box 2 Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box2_description',
            [
                'label'       => esc_html__( 'Box 2 Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box3_image',
            [
                'label'       => esc_html__( 'Box 3 Image', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box3_heading',
            [
                'label'       => esc_html__( 'Box 3 Heading', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_box3_description',
            [
                'label'       => esc_html__( 'Box 3 Description', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_animation_shape1',
            [
                'label'       => esc_html__( 'Animation Shape 1', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_animation_shape2',
            [
                'label'       => esc_html__( 'Animation Shape 2', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_animation_shape3',
            [
                'label'       => esc_html__( 'Animation Shape 3', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_animation_shape4',
            [
                'label'       => esc_html__( 'Animation Shape 4', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_banner_animation_shape5',
            [
                'label'       => esc_html__( 'Animation Shape 5', 'leadcapture' ),
                'type'        => Controls_Manager::MEDIA,
                'label_block' => true,
            ]
        );
		$this->end_controls_section();
        
        // Widget Left Heading Style
        $this->start_controls_section(
            'lcp_property_banner_style_tab', 
            [
                'label' => esc_html__( 'Left Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_property_banner_style_heading',
			[
				'label' => esc_html__( 'Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style38 h1'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style38 h1' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Description Style
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_banner_style_description_typography',
                'label'       => esc_html__( 'Description Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-heading-style38 p'
            ]
        );
        $this->add_control(
            'lcp_banner_style_description_color',
            [
                'label'     => esc_html__( 'Description Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-heading-style38 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Button Style
        $this->add_control(
			'lcp_interiordesign_style_btn',
			[
				'label' => esc_html__( 'Button', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_interiordesign_btn_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style38'
            ]
        );
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_interiordesign_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_interiordesign_style_btn_color',
            [
                'label'     => esc_html__( 'Title Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style38' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style38' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_interiordesign_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-btn-style38',
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .lc-btn-style38' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
		
		// Video Heading Style
        $this->add_control(
			'lcp_property_banner_style_video_heading',
			[
				'label' => esc_html__( 'Video Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_video_typography',
                'label'       => esc_html__( 'Video Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-video-left'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_video_color',
            [
                'label'     => esc_html__( 'Video Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-video-left' => 'color: {{VALUE}};',
                ],
            ]
        );
        // NewsLetter Heading Style
        $this->add_control(
			'lcp_property_banner_style_news_heading',
			[
				'label' => esc_html__( 'News Letter Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-newltr-box-style38 h4'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-newltr-box-style38 h4' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_news_des_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-newltr-left p'
            ]
        );
        $this->add_control(
            'lcp_property_news_des_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-newltr-left p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
        
        // Right Style
        $this->start_controls_section(
            'lcp_property_banner_style_list', 
            [
                'label' => esc_html__( 'Right Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
       
		// Right Box 1 setting
        $this->add_control(
			'lcp_property_banner_style_list_right_box1',
			[
				'label' => esc_html__( 'Right Box 1', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_right_box1_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-right-calories-style38 p'
            ]
        );
        $this->add_control(
            'lcp_property_banner_right_box1_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-right-calories-style38 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_right_box1_des_typography',
                'label'       => esc_html__( 'Description Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-right-calories-style38 h5'
            ]
        );
        $this->add_control(
            'lcp_property_banner_right_box1_des_color',
            [
                'label'     => esc_html__( 'Description Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-right-calories-style38 h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Right Box 2 setting
        $this->add_control(
			'lcp_property_banner_style_list_right_box2',
			[
				'label' => esc_html__( 'Right Box 2', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_right_box2_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heatbeat-style38 p'
            ]
        );
        $this->add_control(
            'lcp_property_banner_right_box2_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heatbeat-style38 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_right_box2_des_typography',
                'label'       => esc_html__( 'Description Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-heatbeat-style38 h5'
            ]
        );
        $this->add_control(
            'lcp_property_banner_right_box2_des_color',
            [
                'label'     => esc_html__( 'Description Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-heatbeat-style38 h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        // Right Box 3 setting
        $this->add_control(
			'lcp_property_banner_style_list_right_box3',
			[
				'label' => esc_html__( 'Right Box 3', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_right_box3_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-right-bp-style38 h5'
            ]
        );
        $this->add_control(
            'lcp_property_banner_right_box3_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-right-bp-style38 h5' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_right_box3_des_typography',
                'label'       => esc_html__( 'Description Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-right-bp-style38 p'
            ]
        );
        $this->add_control(
            'lcp_property_banner_right_box3_des_color',
            [
                'label'     => esc_html__( 'Description Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-right-bp-style38 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        // Heading Style 
        $this->add_control(
			'lcp_property_banner_style_list_title',
			[
				'label' => esc_html__( 'Title Style', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_property_banner_style_list_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-banner-info-inner-style33 p'
            ]
        );
        $this->add_control(
            'lcp_property_banner_style_list_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-banner-info-inner-style33 p' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
	echo '<!-- banner section end -->
	<div class="lc-banner-wraper-style38">
		<div class="container-fluid">
			<div class="row">
				<div class="col-lg-6">
					<div class="lc-banner-left-style38">';
					    if(!empty($settings['lcp_yoga_classes_logo']['url'])):
    						echo '<div class="lc-logo-style38">
    							<a href="javascript:;">
    						        <img src="'.esc_url($settings['lcp_yoga_classes_logo']['url']).'" alt="'.esc_attr__('logo', 'leadcapture').'">
    							</a>
    						</div>';
						endif;
						echo '<div class="lc-banner-heading-style38">';
						if(!empty($settings['lcp_yoga_classes_banner_title'])):
							echo '<h1>'.esc_html($settings['lcp_yoga_classes_banner_title']).'</h1>';
						endif;
						if(!empty($settings['lcp_yoga_classes_banner_description'])):
							echo '<p>'.esc_html($settings['lcp_yoga_classes_banner_description']).'</p>';
						endif;
						echo '</div>
						<div class="lc-banner-left-content">';
						if(!empty($settings['lcp_yoga_classes_banner_button'])):
							echo '<a href="'.esc_url($settings['lcp_yoga_classes_banner_button_url']).'" class="lc-btn-style38">'.esc_html($settings['lcp_yoga_classes_banner_button']).'</a>';
						endif;
						if(!empty($settings['lcp_yoga_classes_video_text'])):
							echo '<a href="'.esc_url($settings['lcp_yoga_classes_video_url']).'" class="lc-banner-video-left">
								<span>
									<svg width="16" height="20" viewBox="0 0 16 20">  
										<path id="Polygon_1" data-name="Polygon 1" d="M406.038,575.522l-16,10v-20Z" transform="translate(-390.031 -565.531)"/>
									  </svg>
								</span>
								'.esc_html($settings['lcp_yoga_classes_video_text']).'
							</a>';
						endif;
						echo '</div>';
						if(!empty($settings['lcp_yoga_classes_newsletter_form'])):	
						   echo '<div class="lc-banner-newltr-box-style38">
							<div class="lc-banner-newltr-left">';
							if(!empty($settings['lcp_yoga_classes_newsletter'])):
								echo '<h4>'.esc_html($settings['lcp_yoga_classes_newsletter']).'</h4>';
							endif;
							if(!empty($settings['lcp_yoga_classes_newsletter_desc'])):
							   echo '<p>'.esc_html($settings['lcp_yoga_classes_newsletter_desc']).'</p>';
							endif;
    						echo do_shortcode($settings['lcp_yoga_classes_newsletter_form']);
							echo '</div>
							<div class="lc-banner-newltr-right"></div>
						</div>';
						endif;
					    echo '</div>
				</div>
				<div class="col-lg-6">
					<div class="lc-banner-right-parent-style38">';
					if(!empty($settings['lcp_yoga_classes_right_image']['url'])):
						echo '<div class="lc-banner-right-img-style38">
							<img src="'.esc_url($settings['lcp_yoga_classes_right_image']['url']).'" alt="'.esc_attr__('right-image', 'leadcapture').'">
						</div>';
					endif;
					if(!empty($settings['lcp_yoga_classes_box1_heading'])):
						echo '<div class="lc-banner-right-calories-style38">';
						    if(!empty($settings['lcp_yoga_classes_box1_heading'])):
							    echo '<p>'.esc_html($settings['lcp_yoga_classes_box1_heading']).'</p>';
							endif;
							if(!empty($settings['lcp_yoga_classes_box1_description'])):
							    echo '<h5>'.esc_html($settings['lcp_yoga_classes_box1_description']).'</h5>';
							endif;
							if(!empty($settings['lcp_yoga_classes_box1_image']['url'])):
							    echo '<img src="'.esc_url($settings['lcp_yoga_classes_box1_image']['url']).'" alt="'.esc_attr__('box1-image', 'leadcapture').'">';
                            endif;
						echo '</div>';
					endif;
					if(!empty($settings['lcp_yoga_classes_box2_heading'])):
					    echo '<div class="lc-banner-right-heartbeat-style38">';
    					    if(!empty($settings['lcp_yoga_classes_box2_image']['url'])):
    							echo '<img src="'.esc_url($settings['lcp_yoga_classes_box2_image']['url']).'" alt="'.esc_attr__('box2-image', 'leadcapture').'">';
    						endif;	
							echo '<div class="lc-heatbeat-style38">';
							if(!empty($settings['lcp_yoga_classes_box2_heading'])):
							    echo '<p>'.esc_html($settings['lcp_yoga_classes_box2_heading']).'</p>';
							endif;
							if(!empty($settings['lcp_yoga_classes_box2_description'])):	
								echo '<h5>'.esc_html($settings['lcp_yoga_classes_box2_description']).'</h5>';
							endif;
							echo '</div>
						</div>';
					endif;
					if(!empty($settings['lcp_yoga_classes_box2_heading'])):
						echo '<div class="lc-banner-right-bp-style38">';
						    if(!empty($settings['lcp_yoga_classes_box3_heading'])):
						        echo '<h5>96 <span>'.esc_html($settings['lcp_yoga_classes_box3_heading']).'</span></h5>';
						    endif;
							if(!empty($settings['lcp_yoga_classes_box3_image']['url'])):
    							echo '<img src="'.esc_url($settings['lcp_yoga_classes_box3_image']['url']).'" alt="'.esc_attr__('box3-image', 'leadcapture').'">';
    						endif;	
    						if(!empty($settings['lcp_yoga_classes_box3_description'])):	
							    echo '<p>'.esc_html($settings['lcp_yoga_classes_box3_description']).'</p>';
							endif;	
						echo '</div>';
					endif;	
					if(!empty($settings['lcp_banner_animation_shape1']['url'])):
				    	echo '<img src="'.esc_url($settings['lcp_banner_animation_shape1']['url']).'" alt="'.esc_attr__('shope1', 'leadcapture').'" class="lc-banner-shp1-style38">';
					endif;	
					if(!empty($settings['lcp_banner_animation_shape2']['url'])):
					    echo '<img src="'.esc_url($settings['lcp_banner_animation_shape2']['url']).'" alt="'.esc_attr__('shope2', 'leadcapture').'" class="lc-banner-shp2-style38">';
					endif;
					if(!empty($settings['lcp_banner_animation_shape3']['url'])):
					    echo '<img src="'.esc_url($settings['lcp_banner_animation_shape3']['url']).'" alt="'.esc_attr__('shope3', 'leadcapture').'" class="lc-banner-shp3-style38">';
					endif;
					if(!empty($settings['lcp_banner_animation_shape4']['url'])):
					    echo '<img src="'.esc_url($settings['lcp_banner_animation_shape4']['url']).'" alt="'.esc_attr__('shope4', 'leadcapture').'" class="lc-banner-shp4-style38">';
					endif;
					if(!empty($settings['lcp_banner_animation_shape5']['url'])):
					    echo '<img src="'.esc_url($settings['lcp_banner_animation_shape5']['url']).'" alt="'.esc_attr__('shope5', 'leadcapture').'" class="lc-banner-shp5-style38">';
					endif;
					echo '</div>
				</div>
			</div>
		</div>
	</div>';
	}
	}
}