<?php
namespace ElementorLeadcapture;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 

class Leadcapture_Yoga_Classes_Testimonials extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_yoga_classes_testimonials';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Yoga Classes Testimonials', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
	    
        $this->start_controls_section(
            'leadcapture_testimonials',
            [
            'label' => esc_html__('Testimonials Settings', 'leadcapture'),
            ] 
        );

		$repeater = new Repeater();
		$repeater->add_control(
            'leadcapture_testimonial_author',
            [
                'label'       => esc_html__( 'Author Name', 'leadcapture'),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_dest',
            [
            'label' => esc_html__('Designation', 'leadcapture'),
            'type'  => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__('', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_desc',
            [
            'label'       => esc_html__( 'Testimonial', 'leadcapture'),
            'type'        => Controls_Manager::TEXTAREA,
            'label_block' => true,
            'default'     => esc_html__( '', 'leadcapture'),
            ]
        );
		$repeater->add_control(
            'leadcapture_testimonial_image',
            [
			'label'       => esc_html__( 'Author Image', 'leadcapture'),
            'type'        => Controls_Manager::MEDIA,
            'label_block' => true,				
			]
        );
		$this->add_control(
            'leadcapture_testimonial_list',
            [
            'type' => Controls_Manager::REPEATER,
            'seperator' => 'before',
            'default' => [
                    [
                    'leadcapture_testimonial_author'  => esc_html__('Author Name #', 'leadcapture'),
					'leadcapture_testimonial_dest'  => esc_html__('Designation #', 'leadcapture'),
					'leadcapture_testimonial_testi'  => esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry.', 'leadcapture'),
                    ]
                ],
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{leadcapture_testimonial_author}}',
            ]
        );
        $this->end_controls_section();
       	
       	/** 
         * Testimonial Captur Style Tab
         */
        $this->start_controls_section(
            'lps_cons_testi_style_tab',
            [
            'label' => esc_html__('Testimonial Style', 'leadcapture'),
            'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
	    $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Testimonial Typography', 'leadcapture'),
            'name'     => 'lps_meetup_testi_typography',
            'selector' => '{{WRAPPER}} .lps-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Description Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_descs_typography',
            'selector' => '{{WRAPPER}} .lps-desc-typography',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [   
            'label' => esc_html__('Designation Typography', 'leadcapture'),
            'name'     => 'lps_cons_testi_designation_typography',
            'selector' => '{{WRAPPER}} .lps-designation-typography',
            ]
        );
		$this->add_control(
        	'lps_cons_testi_one_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Name Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-author-text-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
		$this->add_control(
        	'lps_cons_testi_heading_text_color',
        	[
        	'label' => esc_html__('Testimonial Description Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-description-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
        
		$this->add_control(
        	'lps_cons_testi_designation_text_color',
        	[
        	'label' => esc_html__('Testimonial Designation Text Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .add-designation-colors' => 'color: {{VALUE}}',
        	 ],
           ]
        );
          
        $this->add_control(
        	'lps_cons_testi_pagination_color',
        	[
        	'label' => esc_html__('Testimonial Pagination Color', 'leadcapture'),
        	'type' => \Elementor\Controls_Manager::COLOR,
        	'selectors' => [
        	   '{{WRAPPER}} .lc-testimonial-slider-style11 .swiper-pagination  .swiper-pagination-bullet-active' => 'background-color: {{VALUE}}',
        	 ],
           ]
        );
        
        // Testimonial Pagination Style
        $this->add_control(
			'lcp_interiordesign_style_btn',
			[
				'label' => esc_html__( 'Testimonial Pagination', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->start_controls_tabs( 'button_color' );
		$this->start_controls_tab(
			'lcp_interiordesign_style_btn_noraml',
			[
				'label' => esc_html__( 'Normal', 'leadcapture' ),
			]
		);
		$this->add_control(
            'lcp_interiordesign_style_btn_color',
            [
                'label'     => esc_html__( 'Arrow Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .pagination-color' => 'color: {{VALUE}};',
                ],
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_bg',
            [
                'label'     => esc_html__( 'Background Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .pagination-color' => 'background: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'     => 'lcp_interiordesign_style_btn_border',
                'label'    => esc_html__( 'Border', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .pagination-color',
            ]
        );
		$this->add_control(
            'lcp_interiordesign_style_btn_radius',
            [
                'label'     => esc_html__( 'Border Radius', 'leadcapture' ),
                'type'      => Controls_Manager::SLIDER,
                'default'   => [
                    'size' => '',
                ],
                'range'     => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .pagination-color' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );
		$this->end_controls_tab();
        
       	$this->end_controls_section();
	}
   
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		echo '<!-- testimonial section start -->
		<div class="lc-tesml-wrapper-style38">
			<div class="container">
				<div class="swiper lc-temnl-main-parent-style38">
					<div class="swiper-wrapper">';
					if(!empty($settings['leadcapture_testimonial_list'])):
                        foreach($settings['leadcapture_testimonial_list'] as $testi):
						echo '<div class="swiper-slide">
							<div class="lc-tesmnl-parent-style38">
								<div class="lc-temnl-box-style38">';
    								if($testi['leadcapture_testimonial_desc']):
    								    echo '<p class="lps-desc-typography add-description-colors">'.esc_html($testi['leadcapture_testimonial_desc']).'</p>';
    								endif;
								echo '</div>
								<div class="lc-temnl-info-style38">';
    								if(!empty($testi['leadcapture_testimonial_image']['url'])):  
    									echo '<img src="'.esc_url($testi['leadcapture_testimonial_image']['url']).'" alt="'.esc_attr('testimonial','leadcapture').'">';
    								endif;
									echo '<div class="lc-temnl-name-style38">';
									if($testi['leadcapture_testimonial_author']):
									    echo '<h4 class="lps-typography add-author-text-colors">'.esc_html($testi['leadcapture_testimonial_author']).'</h4>';
									endif;
									if($testi['leadcapture_testimonial_dest']):
										echo '<p class="lps-designation-typography add-designation-colors">'.esc_html($testi['leadcapture_testimonial_dest']).'</p>';
									endif;
									echo '
									</div>
								</div>
							</div>
						</div>';
					    endforeach;
					endif; 
					echo '</div>				
				</div>			
			</div>
			<div class="swiper-button-next pagination-color">
				<span>
					<svg width="16.03" height="14.03" viewBox="0 0 16.03 14.03">  
						<path d="M1437.96,1895.85a1.34,1.34,0,0,1,.2-0.01h11.29l-0.25-.12a2.117,2.117,0,0,1-.65-0.47l-3.16-3.22a1.228,1.228,0,0,1-.17-1.55,1.123,1.123,0,0,1,1.6-.25,1.059,1.059,0,0,1,.12.1l5.72,5.84a1.177,1.177,0,0,1,0,1.65h0l-5.72,5.84a1.141,1.141,0,0,1-1.62,0c-0.03-.04-0.07-0.08-0.1-0.12a1.228,1.228,0,0,1,.17-1.55l3.16-3.23a2.374,2.374,0,0,1,.57-0.43l0.34-.16h-11.24A1.17,1.17,0,0,1,1437.96,1895.85Z" transform="translate(-1437 -1890)"/>
					</svg>
				</span>
			</div>
			<div class="swiper-button-prev pagination-color">
				<span>
					<svg width="15.969" height="14" viewBox="0 0 15.969 14">  
						<path d="M487.04,1895.84a0.651,0.651,0,0,0-.2-0.01H475.577l0.246-.12a2.233,2.233,0,0,0,.645-0.47l3.159-3.22a1.219,1.219,0,0,0,.166-1.54,1.129,1.129,0,0,0-1.6-.26c-0.041.04-.08,0.07-0.117,0.11l-5.713,5.82a1.185,1.185,0,0,0,0,1.65h0l5.713,5.83a1.136,1.136,0,0,0,1.616,0c0.035-.04.068-0.08,0.1-0.12a1.218,1.218,0,0,0-.166-1.54l-3.153-3.23a2.341,2.341,0,0,0-.571-0.43l-0.343-.15h11.22a1.2,1.2,0,0,0,1.205-.98A1.162,1.162,0,0,0,487.04,1895.84Z" transform="translate(-472.031 -1890)"/>
					</svg>
				</span>
			</div>
		</div>
		<!-- testimonial section end -->';
  }
}