<?php
namespace ElementorLeadcapture;

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography;
use \Elementor\Widget_Base;
use \Elementor\Repeater;
use Elementor\Icons_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined( 'ABSPATH' ) || die();

/**
 * Awesomesauce widget class.
 *
 * @since 1.0.0
 */ 
class Leadcapture_Yoga_Classes_Time_Table extends Widget_Base {
	
	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'leadcapture_yoga_classes_time_table';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Leadcapture Time Table', 'leadcapture');
		
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-lightbox-expand';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'leadcapture-widget' );
	}
	
	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
            'lcp_yoga_classes_banner_general',
            [
                'label' => esc_html__( 'General Settings', 'leadcapture' ),
            ] 
        );
        $this->add_control(
            'lcp_yoga_classes_tab1',
            [
                'label'       => esc_html__( 'Tab 1', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_tab2',
            [
                'label'       => esc_html__( 'Tab 2', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_tab3',
            [
                'label'       => esc_html__( 'Tab 3', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_tab4',
            [
                'label'       => esc_html__( 'Tab 4', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_tab5',
            [
                'label'       => esc_html__( 'Tab 5', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_tab6',
            [
                'label'       => esc_html__( 'Tab 6', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_tab7',
            [
                'label'       => esc_html__( 'Tab 7', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
		
        $repeater = new Repeater();
        $repeater->add_control(
            'lcp_table_active',
            [
                'label'     => esc_html__( 'Table Active', 'leadcapture' ),
                'type'      => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'leadcapture' ),
				'label_off' => esc_html__( 'Hide', 'leadcapture' ),
				'return_value' => 'yes',
				'default' => 'yes',
            ]
        );
        $repeater->add_control(
            'lcp_yoga_tab_style',
            [
                'label'   => __( 'Select Tab', 'leadcapture' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'tab-1',
                'options' => [
                    'tab-1'   => __( 'Tab 1', 'leadcapture' ),
                    'tab-2'   => __( 'Tab 2', 'leadcapture' ),
					'tab-3'   => __( 'Tab 3', 'leadcapture' ),
					'tab-4'   => __( 'Tab 4', 'leadcapture' ),
					'tab-5'   => __( 'Tab 5', 'leadcapture' ),
					'tab-6'   => __( 'Tab 6', 'leadcapture' ),
					'tab-7'   => __( 'Tab 7', 'leadcapture' ),
                ],
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_time',
            [
                'label'       => esc_html__( 'Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_classes',
            [
                'label'       => esc_html__( 'Classes', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_trainer',
            [
                'label'       => esc_html__( 'Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_action',
            [
                'label'       => esc_html__( 'Action', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        // Slot 1 Setting
        $repeater->add_control(
			'lcp_yoga_classes_banner_style_heading',
			[
				'label' => esc_html__( 'Slot 1 Setting', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $repeater->add_control(
            'lcp_yoga_classes_slot1_time',
            [
                'label'       => esc_html__( 'Slot 1 Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot1_hours',
            [
                'label'       => esc_html__( 'Slot 1 Hours', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot1_class_name',
            [
                'label'       => esc_html__( 'Slot 1 Class Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot1_trainer',
            [
                'label'       => esc_html__( 'Slot 1 Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot1_btn',
            [
                'label'       => esc_html__( 'Slot 1 Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot1_btnurl',
            [
                'label'       => esc_html__( 'Slot 1 Button URl', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        
        // Slot 2 Setting
        $repeater->add_control(
			'lcp_yoga_classes_banner_heading_slot2',
			[
				'label' => esc_html__( 'Slot 2 Setting', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $repeater->add_control(
            'lcp_yoga_classes_slot2_time',
            [
                'label'       => esc_html__( 'Slot 2 Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot2_hours',
            [
                'label'       => esc_html__( 'Slot 2 Hours', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot2_class_name',
            [
                'label'       => esc_html__( 'Slot 2 Class Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot2_trainer',
            [
                'label'       => esc_html__( 'Slot 2 Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot2_btn',
            [
                'label'       => esc_html__( 'Slot 2 Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot2_btnurl',
            [
                'label'       => esc_html__( 'Slot 2 Button URl', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 
        // Slot 3 Setting
        $repeater->add_control(
			'lcp_yoga_classes_banner_heading_slot3',
			[
				'label' => esc_html__( 'Slot 3 Setting', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $repeater->add_control(
            'lcp_yoga_classes_slot3_time',
            [
                'label'       => esc_html__( 'Slot 3 Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot3_hours',
            [
                'label'       => esc_html__( 'Slot 3 Hours', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot3_class_name',
            [
                'label'       => esc_html__( 'Slot 3 Class Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot3_trainer',
            [
                'label'       => esc_html__( 'Slot 3 Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot3_btn',
            [
                'label'       => esc_html__( 'Slot 3 Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot3_btnurl',
            [
                'label'       => esc_html__( 'Slot 3 Button URl', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 
        
        // Slot 4 Setting
        $repeater->add_control(
			'lcp_yoga_classes_banner_heading_slot4',
			[
				'label' => esc_html__( 'Slot 4 Setting', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $repeater->add_control(
            'lcp_yoga_classes_slot4_time',
            [
                'label'       => esc_html__( 'Slot 4 Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot4_hours',
            [
                'label'       => esc_html__( 'Slot 4 Hours', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot4_class_name',
            [
                'label'       => esc_html__( 'Slot 4 Class Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot4_trainer',
            [
                'label'       => esc_html__( 'Slot 4 Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot4_btn',
            [
                'label'       => esc_html__( 'Slot 4 Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot4_btnurl',
            [
                'label'       => esc_html__( 'Slot 4 Button URl', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 
        // Slot 5 Setting
        $repeater->add_control(
			'lcp_yoga_classes_banner_heading_slot5',
			[
				'label' => esc_html__( 'Slot 5 Setting', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $repeater->add_control(
            'lcp_yoga_classes_slot5_time',
            [
                'label'       => esc_html__( 'Slot 5 Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot5_hours',
            [
                'label'       => esc_html__( 'Slot 5 Hours', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot5_class_name',
            [
                'label'       => esc_html__( 'Slot 5 Class Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot5_trainer',
            [
                'label'       => esc_html__( 'Slot 5 Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot5_btn',
            [
                'label'       => esc_html__( 'Slot 5 Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot5_btnurl',
            [
                'label'       => esc_html__( 'Slot 5 Button URl', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 
        // Slot 6 Setting
        $repeater->add_control(
			'lcp_yoga_classes_banner_heading_slot6',
			[
				'label' => esc_html__( 'Slot 6 Setting', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $repeater->add_control(
            'lcp_yoga_classes_slot6_time',
            [
                'label'       => esc_html__( 'Slot 6 Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot6_hours',
            [
                'label'       => esc_html__( 'Slot 6 Hours', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot6_class_name',
            [
                'label'       => esc_html__( 'Slot 6 Class Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot6_trainer',
            [
                'label'       => esc_html__( 'Slot 6 Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot6_btn',
            [
                'label'       => esc_html__( 'Slot 6 Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot6_btnurl',
            [
                'label'       => esc_html__( 'Slot 6 Button URl', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 
        // Slot 7 Setting
        $repeater->add_control(
			'lcp_yoga_classes_banner_heading_slot7',
			[
				'label' => esc_html__( 'Slot 7 Setting', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
        $repeater->add_control(
            'lcp_yoga_classes_slot7_time',
            [
                'label'       => esc_html__( 'Slot 7 Time', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot7_hours',
            [
                'label'       => esc_html__( 'Slot 7 Hours', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot7_class_name',
            [
                'label'       => esc_html__( 'Slot 7 Class Name', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot7_trainer',
            [
                'label'       => esc_html__( 'Slot 7 Trainer', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot7_btn',
            [
                'label'       => esc_html__( 'Slot 7 Button', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'lcp_yoga_classes_slot7_btnurl',
            [
                'label'       => esc_html__( 'Slot 7 Button URl', 'leadcapture' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        ); 
        $this->add_control(
            'lcp_yoga_classes_banner_statics_list',
            [
                'label'       => esc_html__( 'Add Item', 'leadcapture' ),
                'type'        => Controls_Manager::REPEATER,
                'seperator'   => 'before',
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{lcp_yoga_classes_time}}',
            ]
        );
       
        $this->end_controls_section();
        
        // Widget Style
        $this->start_controls_section(
            'lcp_yoga_classes_banner_style_tab', 
            [
                'label' => esc_html__( 'Style', 'leadcapture' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        // Heading Style
        $this->add_control(
			'lcp_yoga_classes_banner_style_heading',
			[
				'label' => esc_html__( 'Navigation Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING,
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_yoga_classes_banner_style_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .nav-tabs li a'
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_banner_style_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .nav-tabs li a' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        //Table Heading Style
        $this->add_control(
			'lcp_yoga_classes_banner_style_news_heading',
			[
				'label' => esc_html__( 'Table Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_yoga_classes_banner_style_news_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-timetable-inner-table-style38 table tr th'
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_banner_style_news_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-timetable-inner-table-style38 table tr th' => 'color: {{VALUE}};',
                ],
            ]
        );
        //Table Heading Style
        $this->add_control(
			'lcp_yoga_classes_table_data_heading',
			[
				'label' => esc_html__( 'Table Heading', 'leadcapture' ),
				'type' => Controls_Manager::HEADING, 
				'separator' => 'before',
			]
		);
		$this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'lcp_yoga_classes_table_data_heading_typography',
                'label'       => esc_html__( 'Typography', 'leadcapture' ),
                'selector' => '{{WRAPPER}} .lc-timetable-inner-table-style38 table tr:nth-child(even)'
            ]
        );
        $this->add_control(
            'lcp_yoga_classes_table_data_heading_color',
            [
                'label'     => esc_html__( 'Color', 'leadcapture' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .lc-timetable-inner-table-style38 table tr:nth-child(even)' => 'color: {{VALUE}};',
                ],
            ]
        );
        
        $this->end_controls_section();
	}
 
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	 
	protected function render() {
	$settings = $this->get_settings_for_display();
	if(!empty($settings)){
		echo '	<!-- time table section start -->	
	<div class="lc-timetable-wrapper-style38">
		<div class="container">
			<div class="row">
				<div class="col-lg-12">
					<div class="lc-tab-header-style38">
						<ul class="nav nav-tabs">';
						    if(!empty($settings['lcp_yoga_classes_tab1'])):
						        echo '<li ><a data-bs-toggle="tab" href="#tab-1" role="tab" class="active">'.esc_html($settings['lcp_yoga_classes_tab1']).'</a></li>';
						    endif;
							if(!empty($settings['lcp_yoga_classes_tab2'])):
						        echo '<li><a data-bs-toggle="tab" href="#tab-2" role="tab">'.esc_html($settings['lcp_yoga_classes_tab2']).'</a></li>';
						    endif;
						    if(!empty($settings['lcp_yoga_classes_tab3'])):
						        echo '<li><a data-bs-toggle="tab" href="#tab-3" role="tab">'.esc_html($settings['lcp_yoga_classes_tab3']).'</a></li>';
						    endif;
						    if(!empty($settings['lcp_yoga_classes_tab4'])):
						        echo '<li><a data-bs-toggle="tab" href="#tab-4" role="tab">'.esc_html($settings['lcp_yoga_classes_tab4']).'</a></li>';
						    endif; 
						    if(!empty($settings['lcp_yoga_classes_tab5'])):
						        echo '<li><a data-bs-toggle="tab" href="#tab-5" role="tab">'.esc_html($settings['lcp_yoga_classes_tab5']).'</a></li>';
						    endif; 
						    if(!empty($settings['lcp_yoga_classes_tab6'])):
						        echo '<li><a data-bs-toggle="tab" href="#tab-6" role="tab">'.esc_html($settings['lcp_yoga_classes_tab6']).'</a></li>';
						    endif; 
						    if(!empty($settings['lcp_yoga_classes_tab7'])):
						        echo '<li><a data-bs-toggle="tab" href="#tab-7" role="tab">'.esc_html($settings['lcp_yoga_classes_tab7']).'</a></li>';
						    endif; 
						echo '</ul>
					</div>
					<div class="tab-content lc-tabeldata-style38">';
					if(!empty($settings['lcp_yoga_classes_banner_statics_list'])):
					    foreach($settings['lcp_yoga_classes_banner_statics_list'] as $list):
                        if($list['lcp_table_active'] == 'yes'){
                            $active = 'active';
                        }else{
                            $active = ''; 
                        }
				        if($list['lcp_yoga_tab_style'] == 'tab-1'){
                            $tab = 'tab-1';
                        } else if($list['lcp_yoga_tab_style'] == 'tab-2'){
                            $tab = 'tab-2';
                        } else if($list['lcp_yoga_tab_style'] == 'tab-3'){
                            $tab = 'tab-3';
                        } else if($list['lcp_yoga_tab_style'] == 'tab-4'){
                         $tab = 'tab-4';
                        } else if($list['lcp_yoga_tab_style'] == 'tab-5'){
                            $tab = 'tab-5';
                        } else if($list['lcp_yoga_tab_style'] == 'tab-6'){
                            $tab = 'tab-6';
                        } else {
                            $tab = 'tab-7';
                        }  
						echo '<div class="tab-pane '.esc_attr($active).'" id="'.esc_attr($tab).'" role="tabpanel">
							<div class="lc-timetable-inner-table-style38">
								<div class="table-responsive">
									<table class="table">
										<tr>';
										if(!empty($list['lcp_yoga_classes_time'])):
											echo '<th>'.esc_html($list['lcp_yoga_classes_time']).'</th>';
										endif;
										if(!empty($list['lcp_yoga_classes_classes'])):
											echo '<th>'.esc_html($list['lcp_yoga_classes_classes']).'</th>';
										endif;
										if(!empty($list['lcp_yoga_classes_trainer'])):
											echo '<th>'.esc_html($list['lcp_yoga_classes_trainer']).'</th>';
										endif;
										if(!empty($list['lcp_yoga_classes_action'])):
											echo '<th>'.esc_html($list['lcp_yoga_classes_action']).'</th>';
										endif;
										echo '</tr>
										<tr>
											<td>
												<div class="lc-tt-data-style38">
													<svg width="16" height="16" viewBox="0 0 16 16">
														<path d="M533,1359a8,8,0,1,0,8,8A8,8,0,0,0,533,1359Zm2.7,10.7a0.734,0.734,0,0,1-1.028,0l-2.182-2.19a0.709,0.709,0,0,1-.213-0.51v-4.36a0.727,0.727,0,1,1,1.454,0v4.06l1.969,1.97A0.729,0.729,0,0,1,535.7,1369.7Z" transform="translate(-525 -1359)"/>
													</svg>';
													if(!empty($list['lcp_yoga_classes_slot1_time'])):
													    echo '<span>'.esc_html($list['lcp_yoga_classes_slot1_time']).'</span>';
													endif;
													if(!empty($list['lcp_yoga_classes_slot1_time'])):
												    	echo '<p>'.esc_html($list['lcp_yoga_classes_slot1_hours']).'</p>';
													endif;
												echo '</div>
											</td>';
                                            if(!empty($list['lcp_yoga_classes_slot1_class_name'])):
                                                echo '<td>'.esc_html($list['lcp_yoga_classes_slot1_class_name']).'</td>';
                                            endif;
                                            if(!empty($list['lcp_yoga_classes_slot1_trainer'])):
											    echo '<td>'.esc_html($list['lcp_yoga_classes_slot1_trainer']).'</td>';
											endif;
											if(!empty($list['lcp_yoga_classes_slot1_btn'])):
											    echo '<td><a href="'.esc_url($list['lcp_yoga_classes_slot1_btnurl']).'" class="lc-btn-style38">'.esc_html($list['lcp_yoga_classes_slot1_btn']).'</a></td>';
											endif;
										echo '</tr>
										<tr>
											<td>
												<div class="lc-tt-data-style38">
													<svg width="16" height="16" viewBox="0 0 16 16">
														<path d="M533,1359a8,8,0,1,0,8,8A8,8,0,0,0,533,1359Zm2.7,10.7a0.734,0.734,0,0,1-1.028,0l-2.182-2.19a0.709,0.709,0,0,1-.213-0.51v-4.36a0.727,0.727,0,1,1,1.454,0v4.06l1.969,1.97A0.729,0.729,0,0,1,535.7,1369.7Z" transform="translate(-525 -1359)"/>
													</svg>';
													if(!empty($list['lcp_yoga_classes_slot2_time'])):
													    echo '<span>'.esc_html($list['lcp_yoga_classes_slot2_time']).'</span>';
													endif;
													if(!empty($list['lcp_yoga_classes_slot2_hours'])):
												    	echo '<p>'.esc_html($list['lcp_yoga_classes_slot2_hours']).'</p>';
													endif;
												echo '</div>
											</td>';
                                            if(!empty($list['lcp_yoga_classes_slot2_class_name'])):
                                                echo '<td>'.esc_html($list['lcp_yoga_classes_slot2_class_name']).'</td>';
                                            endif;
                                            if(!empty($list['lcp_yoga_classes_slot2_trainer'])):
											    echo '<td>'.esc_html($list['lcp_yoga_classes_slot2_trainer']).'</td>';
											endif;
											if(!empty($list['lcp_yoga_classes_slot2_btn'])):
											    echo '<td><a href="'.esc_url($list['lcp_yoga_classes_slot2_btnurl']).'" class="lc-btn-style38">'.esc_html($list['lcp_yoga_classes_slot2_btn']).'</a></td>';
											endif;
										echo '</tr>
										<tr>
											<td>
												<div class="lc-tt-data-style38">
													<svg width="16" height="16" viewBox="0 0 16 16">
														<path d="M533,1359a8,8,0,1,0,8,8A8,8,0,0,0,533,1359Zm2.7,10.7a0.734,0.734,0,0,1-1.028,0l-2.182-2.19a0.709,0.709,0,0,1-.213-0.51v-4.36a0.727,0.727,0,1,1,1.454,0v4.06l1.969,1.97A0.729,0.729,0,0,1,535.7,1369.7Z" transform="translate(-525 -1359)"/>
													</svg>';
													if(!empty($list['lcp_yoga_classes_slot3_time'])):
													    echo '<span>'.esc_html($list['lcp_yoga_classes_slot3_time']).'</span>';
													endif;
													if(!empty($list['lcp_yoga_classes_slot3_hours'])):
												    	echo '<p>'.esc_html($list['lcp_yoga_classes_slot3_hours']).'</p>';
													endif;
												echo '</div>
											</td>';
                                            if(!empty($list['lcp_yoga_classes_slot3_class_name'])):
                                                echo '<td>'.esc_html($list['lcp_yoga_classes_slot3_class_name']).'</td>';
                                            endif;
                                            if(!empty($list['lcp_yoga_classes_slot3_trainer'])):
											    echo '<td>'.esc_html($list['lcp_yoga_classes_slot3_trainer']).'</td>';
											endif;
											if(!empty($list['lcp_yoga_classes_slot3_btn'])):
											    echo '<td><a href="'.esc_url($list['lcp_yoga_classes_slot3_btnurl']).'" class="lc-btn-style38">'.esc_html($list['lcp_yoga_classes_slot1_btn']).'</a></td>';
											endif;
										echo '</tr>
										<tr>
											<td>
												<div class="lc-tt-data-style38">
													<svg width="16" height="16" viewBox="0 0 16 16">
														<path d="M533,1359a8,8,0,1,0,8,8A8,8,0,0,0,533,1359Zm2.7,10.7a0.734,0.734,0,0,1-1.028,0l-2.182-2.19a0.709,0.709,0,0,1-.213-0.51v-4.36a0.727,0.727,0,1,1,1.454,0v4.06l1.969,1.97A0.729,0.729,0,0,1,535.7,1369.7Z" transform="translate(-525 -1359)"/>
													</svg>';
													if(!empty($list['lcp_yoga_classes_slot4_time'])):
													    echo '<span>'.esc_html($list['lcp_yoga_classes_slot4_time']).'</span>';
													endif;
													if(!empty($list['lcp_yoga_classes_slot4_hours'])):
												    	echo '<p>'.esc_html($list['lcp_yoga_classes_slot4_hours']).'</p>';
													endif;
												echo '</div>
											</td>';
                                            if(!empty($list['lcp_yoga_classes_slot4_class_name'])):
                                                echo '<td>'.esc_html($list['lcp_yoga_classes_slot4_class_name']).'</td>';
                                            endif;
                                            if(!empty($list['lcp_yoga_classes_slot4_trainer'])):
											    echo '<td>'.esc_html($list['lcp_yoga_classes_slot4_trainer']).'</td>';
											endif;
											if(!empty($list['lcp_yoga_classes_slot4_btn'])):
											    echo '<td><a href="'.esc_url($list['lcp_yoga_classes_slot4_btnurl']).'" class="lc-btn-style38">'.esc_html($list['lcp_yoga_classes_slot4_btn']).'</a></td>';
											endif;
										echo '</tr>
										<tr>
											<td>
												<div class="lc-tt-data-style38">
													<svg width="16" height="16" viewBox="0 0 16 16">
														<path d="M533,1359a8,8,0,1,0,8,8A8,8,0,0,0,533,1359Zm2.7,10.7a0.734,0.734,0,0,1-1.028,0l-2.182-2.19a0.709,0.709,0,0,1-.213-0.51v-4.36a0.727,0.727,0,1,1,1.454,0v4.06l1.969,1.97A0.729,0.729,0,0,1,535.7,1369.7Z" transform="translate(-525 -1359)"/>
													</svg>';
													if(!empty($list['lcp_yoga_classes_slot5_time'])):
													    echo '<span>'.esc_html($list['lcp_yoga_classes_slot5_time']).'</span>';
													endif;
													if(!empty($list['lcp_yoga_classes_slot5_hours'])):
												    	echo '<p>'.esc_html($list['lcp_yoga_classes_slot5_hours']).'</p>';
													endif;
												echo '</div>
											</td>';
                                            if(!empty($list['lcp_yoga_classes_slot5_class_name'])):
                                                echo '<td>'.esc_html($list['lcp_yoga_classes_slot5_class_name']).'</td>';
                                            endif;
                                            if(!empty($list['lcp_yoga_classes_slot5_trainer'])):
											    echo '<td>'.esc_html($list['lcp_yoga_classes_slot5_trainer']).'</td>';
											endif;
											if(!empty($list['lcp_yoga_classes_slot5_btn'])):
											    echo '<td><a href="'.esc_url($list['lcp_yoga_classes_slot5_btnurl']).'" class="lc-btn-style38">'.esc_html($list['lcp_yoga_classes_slot5_btn']).'</a></td>';
											endif;
										echo '</tr>								
									</table>
								</div>
							</div>
						</div>';
						endforeach;	
						endif;    
					echo '</div>
				</div>
			</div>
		</div>
	</div>
	<!-- time table section start -->';
	}
	}
}