<?php
/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    pixelform
 * @subpackage pixelform/public
 * @author     Kamleshyadav <#>
 */
class pixelform_public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		add_action( 'wp_ajax_pixelform_form_submit', array($this,'pixelform_form_submit') );
		add_action( 'wp_ajax_nopriv_pixelform_form_submit', array($this,'pixelform_form_submit') );
		
		add_action( 'wp_ajax_pixelform_form_newsletter_submit', array($this,'pixelform_form_newsletter_submit') );
		add_action( 'wp_ajax_nopriv_pixelform_form_newsletter_submit', array($this,'pixelform_form_newsletter_submit') );
		
		add_action( 'wp_ajax_post_like_func', array($this,'post_like_func') );
		add_action( 'wp_ajax_nopriv_post_like_func', array($this,'post_like_func') );
		
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

	/**
	 * This function is provided for demonstration purposes only.
	 *
	 * An instance of this class should be passed to the run() function
	 * defined in pixelform_Loader as all of the hooks are defined
	 * in that particular class.
	 *
	 * The pixelform_Loader will then create the relationship
	 * between the defined hooks and the functions defined in this
	 * class.
	 */
	wp_enqueue_style( 'bootstrap', plugins_url() . '/pixel-formbuilder/assets/css/bootstrap.min.css', array(), $this->version, 'all' );
	wp_enqueue_style( 'bootstrap-datepicker', plugins_url() . '/pixel-formbuilder/assets/css/bootstrap-datepicker.min.css', array(), $this->version, 'all' );
	wp_enqueue_style( 'font-awesome', plugins_url() . '/pixel-formbuilder/assets/css/font-awesome.min.css', array(), $this->version, 'all' );
	wp_enqueue_style( 'animate', plugins_url() . '/pixel-formbuilder/assets/css/animate.css', array(), $this->version, 'all' );
	wp_enqueue_style( 'swiper-bundle', plugins_url() . '/pixel-formbuilder/assets/css/swiper-bundle.min.css', array(), $this->version, 'all' );
	wp_enqueue_style( 'magnific-popup', plugins_url() . '/pixel-formbuilder/assets/css/magnific-popup.css', array(), $this->version, 'all' );
	wp_enqueue_style( 'owl-carousel', plugins_url() . '/pixel-formbuilder/assets/css/owl.carousel.min.css', array(), $this->version, 'all' );
    wp_enqueue_style( $this->plugin_name, PIXELFORM_URL . 'public/css/pixelform-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in pixelform_formbuilder_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The pixelform_formbuilder_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script('bootstrap', plugins_url() . '/pixel-formbuilder/assets/js/bootstrap.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script('bootstrap-datepicker', plugins_url() . '/pixel-formbuilder/assets/js/bootstrap-datepicker.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script('aos', plugins_url() . '/pixel-formbuilder/assets/js/aos.js', array('jquery'), $this->version, true );
		wp_enqueue_script('owl-carousel', plugins_url() . '/pixel-formbuilder/assets/js/owl.carousel.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script('circle-progress', plugins_url() . '/pixel-formbuilder/assets/js/jquery-circle-progress.js', array('jquery'), $this->version, true );
		wp_enqueue_script('swiper-bundle', plugins_url() . '/pixel-formbuilder/assets/js/swiper-bundle.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script('swiper-bundle', plugins_url() . '/pixel-formbuilder/assets/js/swiper-bundle.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script('smooth-scroll', plugins_url() . '/pixel-formbuilder/assets/js/smooth-scroll.min.js', array('jquery'), $this->version, true );
		wp_enqueue_script('Pixelform-custom', plugins_url() . '/pixel-formbuilder/assets/js/pixelform-custom.js', array('jquery'), $this->version, true );

		wp_enqueue_script('pixelform-public', PIXELFORM_URL . 'public/js/pixelform-public.js', array('jquery'), $this->version, true );
		wp_localize_script('pixelform-public', 'ajax_obj',
				array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );	 

	}
	
	public function pixelform_form_submit() {
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_submit'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
			$id = esc_html($_POST['form_id']);
			$row = $wpdb->get_results ( "SELECT * FROM $table_name WHERE ID = $id" );
			$mail_settings = json_decode($row[0]->Mail);
			
			$messages = json_decode($row[0]->Messages);
			$success = !empty($messages[0]) ? $messages[0] : esc_html__('Thank you for your message. It has been sent.','Pixelform');
			$error = !empty($messages[1]) ? $messages[1] : esc_html__('There was an error trying to send your message. Please try again later.','Pixelform');
			if( empty($mail_settings[0]) ){
				echo json_encode(array('error' => esc_html__('Reciver email is not set, please contact to administrator.','Pixelform')));
				wp_die();
				return;
			} 
			 
			$subject = !empty($mail_settings[2]) ? $mail_settings[2] : get_option('blogname').esc_html__('Informations','Pixelform'); 
		
			$data = '<html>
					<head><title>'.esc_html($subject).'</title></head>
					<body>
					<table>';
			//Ignore first key element from the array.		
			foreach( array_slice($_POST,2) as $key => $val ){
				if( $key != 'user_email' ){
					$form_data[$key] = $val;
					$data .= '<tr>
								<th>'.esc_attr(str_replace('_',' ',$key)).'</th>
								<td>'.esc_attr($val).'</td>
							 </tr>';
				}		 
			}
		$data .= '</table></body></html>';
		
			$to = $mail_settings[0]; //Multiple Receiver Allowed By Entering Comma Seperated Emails.			
			$headers[] = 'MIME-Version: 1.0';
			$headers[] = 'Content-type:text/html;charset=UTF-8';
			
			// More headers
			$from = !empty($mail_settings[1]) ? $mail_settings[1] : get_option('blogname').'<WordPress@'.$_SERVER['HTTP_HOST'].'>';
			$headers[] = 'From: '.$mail_settings[1].'';
			if(!empty($mail_settings[3])){
				$headers[]   = 'Reply-To: '.$mail_settings[3].'';
			}
			
			 $email = esc_html($_POST['user_email']);
			 $formName = esc_html($row[0]->Name);
			 $form_data = json_encode($form_data);
			 
			// Need to require these files
			if ( !function_exists('media_handle_upload') ) {
				require_once(ABSPATH . "wp-admin" . '/includes/image.php');
				require_once(ABSPATH . "wp-admin" . '/includes/file.php');
				require_once(ABSPATH . "wp-admin" . '/includes/media.php');
			}
			
			if( !empty($_FILES) ){
				for( $i=0; $i<count($_FILES); $i++ ){	  
					$attachment_ids[] = media_handle_sideload( $_FILES['file-'.$i], 0 );
					$attachment_url[] = get_attached_file( $attachment_ids[$i] );
				}
			}
			
			$email = esc_html($_POST['user_email']);
			$formName = $row[0]->Name;
			
			if( wp_mail($to, $subject, $data, $headers, $attachment_url ) ){
				if( !empty($attachment_ids) ){
					foreach($attachment_ids as $ids){
						wp_delete_attachment( $ids, true );
					}
				}
				echo json_encode(array('success'=>$success));
				$this->pixelform_form_database_create( $formName,$email,$form_data );
		    }else{
				echo json_encode(array('error'=>$error));
		    }
			
			
		}
		wp_die();
	}
	
	public function pixelform_form_newsletter_submit() {
   
		if(isset($_POST['action']) && $_POST['action'] == 'pixelform_form_newsletter_submit'){
			global $wpdb;
			$table_name = $wpdb->prefix . 'pixelform_form_forms';
		
			$formid = isset($_POST['formid']) ? esc_html($_POST['formid']) : '';
			$row = $wpdb->get_results ( "SELECT * FROM  $table_name WHERE ID = $formid" );
			$responderData = json_decode($row[0]->Responder);
			
			$data = get_option('pixelform_form_autoresponder_settings');
			
			 require_once WP_PLUGIN_DIR . '/pixel-formbuilder/admin/autoresponder/subscriber.php';
			
			$api = $data[ $responderData->responder ];
			
			if($responderData->responder == 'Sendiio'){
				$api['listType'] = $responderData->listType;
			}
			
			$_POST['email'] = isset($_POST['fields']['email']) ? esc_html($_POST['fields']['email']) : '';
			$_POST['name'] = isset($_POST['fields']['name']) ? esc_html($_POST['fields']['name']) : '';
			$subscriber = new pixelform_form_subscriber();
			$response = $subscriber->pixelform_form_switch_responder($api, 'subsCribe', $responderData->responder, $responderData->list_id);
		
			if( isset($response['success']) ){
				echo json_encode(array('msg' => 'success' ));
			}else{
				echo json_encode(array('msg' => 'error' ));
			}
		}
		wp_die();
		
	}
	
	public function pixelform_form_database_create( $formName,$email,$form_data ){
		global $wpdb;
		$table_name = $wpdb->prefix . 'pixelform_form_database';
	    $date = date("Y-m-d");
		$row = $wpdb->get_results ( "SELECT * FROM $table_name WHERE User_Email = '$email'" );
		if( count($row) == 0 ){
			$email = !empty($email) ? $email : '-------';
			$form_data = !empty($form_data) ? $form_data : 'No Email';
			$wpdb->insert( $table_name, array( 'Form_Name' => $formName, 'User_Email' => $email, 'Form_Data' => $form_data, 'Date_Created' => $date ) );
		}
	}
	
	public function post_like_func(){
	    $id = $_POST['id'];
	    $likes = 1;
	    if(!empty($id)){
	        $like = get_post_meta( $id, 'Pixelform_post_likes',false);
	        if(!empty($like[0])){
	            $likes =  $like[0] +=1;
	            update_post_meta( $id, 'Pixelform_post_likes', $likes );
	        } else {
	            update_post_meta( $id, 'Pixelform_post_likes', 1 );
	        }
	        $data = array('status' => 'true', 'likes' => $likes);
	        echo json_encode($data);
	    }
	    die();
	} 
	
	

}
